# -*- coding: utf-8 -*-
"""`PKD2007 Standard <https://stat.gov.pl/en/metainformation/classifications/#Polish%20Classification%20of%20Activities%20(PKD)>`_.
"""
from ...types import Category, Classification, Standard, Standards

PKD2007 = Standard(
    standard=Standards.PKD2007,
    classes=[
        Classification("A", "AGRICULTURE, FORESTRY, HUNTING AND FISHING", Category.SECTION),
        Classification("01", "CROP AND ANIMAL PRODUCTION, HUNTING, INCLUDING SERVICE ACTIVITIES", Category.DIVISION),
        Classification("01.1", "Growing of non-perennial crops", Category.GROUP),
        Classification(
            "01.11", "Growing of cereals, leguminous crops and oil plants, for seeds, except rice", Category.CLASS
        ),
        Classification(
            "01.11.Z", "Growing of cereals, leguminous crops and oil plants, for seeds, except rice", Category.SUBCLASS
        ),
        Classification("01.12", "Growing of rice", Category.CLASS),
        Classification("01.12.Z", "Growing of rice", Category.SUBCLASS),
        Classification(
            "01.13", "Growing of vegetables, including melons, and growing of roots and tubers", Category.CLASS
        ),
        Classification(
            "01.13.Z", "Growing of vegetables, including melons, and of roots and tubers", Category.SUBCLASS
        ),
        Classification("01.14", "Growing of sugar cane", Category.CLASS),
        Classification("01.14.Z", "Growing of sugar cane", Category.SUBCLASS),
        Classification("01.15", "Growing of tobacco", Category.CLASS),
        Classification("01.15.Z", "Growing of tobacco", Category.SUBCLASS),
        Classification("01.16", "Growing of fibre crops", Category.CLASS),
        Classification("01.16.Z", "Growing of fibre crops", Category.SUBCLASS),
        Classification("01.19", "Growing of other non-perennial crops", Category.CLASS),
        Classification("01.19.Z", "Growing of other non-perennial crops", Category.SUBCLASS),
        Classification("01.2", "Growing of perennial crops", Category.GROUP),
        Classification("01.21", "Growing of grapes", Category.CLASS),
        Classification("01.21.Z", "Growing of grapes", Category.SUBCLASS),
        Classification("01.22", "Growing of tree and bush tropical and subtropical fruits", Category.CLASS),
        Classification("01.22.Z", "Growing of tree and bush tropical and subtropical fruits", Category.SUBCLASS),
        Classification("01.23", "Growing of  tree and bush citrus fruits", Category.CLASS),
        Classification("01.23.Z", "Growing of  tree and bush citrus fruits", Category.SUBCLASS),
        Classification("01.24", "Growing of  tree and bush pome fruits and stone fruits", Category.CLASS),
        Classification("01.24.Z", "Growing of  tree and bush pome fruits and stone fruits", Category.SUBCLASS),
        Classification("01.25", "Growing of other tree and bush fruits and nuts", Category.CLASS),
        Classification("01.25.Z", "Growing of other tree and bush fruits and nuts", Category.SUBCLASS),
        Classification("01.26", "Growing of tree oleaginous fruits", Category.CLASS),
        Classification("01.26.Z", "Growing of  tree oleaginous fruits", Category.SUBCLASS),
        Classification("01.27", "Growing of beverage crops", Category.CLASS),
        Classification("01.27.Z", "Growing of beverage crops", Category.SUBCLASS),
        Classification("01.28", "Growing of spices, aromatic, drug and pharmaceutical crops", Category.CLASS),
        Classification("01.28.Z", "Growing of spices, aromatic, drug and pharmaceutical crops", Category.SUBCLASS),
        Classification("01.29", "Growing of other perennial crops", Category.CLASS),
        Classification("01.29.Z", "Growing of other perennial crops", Category.SUBCLASS),
        Classification("01.3", "Plant propagation", Category.GROUP),
        Classification("01.30", "Plant propagation", Category.CLASS),
        Classification("01.30.Z", "Plant propagation", Category.SUBCLASS),
        Classification("01.4", "Animal production", Category.GROUP),
        Classification("01.41", "Raising of dairy cattle", Category.CLASS),
        Classification("01.41.Z", "Raising of dairy cattle", Category.SUBCLASS),
        Classification("01.42", "Raising of other cattle and buffaloes", Category.CLASS),
        Classification("01.42.Z", "Raising of other cattle and buffaloes", Category.SUBCLASS),
        Classification("01.43", "Raising of horses and other equines", Category.CLASS),
        Classification("01.43.Z", "Raising of horses and other equines", Category.SUBCLASS),
        Classification("01.44", "Raising of camels and camelids", Category.CLASS),
        Classification("01.44.Z", "Raising of camels and camelids", Category.SUBCLASS),
        Classification("01.45", "Raising of sheep and goats", Category.CLASS),
        Classification("01.45.Z", "Raising of sheep and goats", Category.SUBCLASS),
        Classification("01.46", "Raising of swine/pigs", Category.CLASS),
        Classification("01.46.Z", "Raising of swine/pigs", Category.SUBCLASS),
        Classification("01.47", "Raising of poultry", Category.CLASS),
        Classification("01.47.Z", "Raising of poultry", Category.SUBCLASS),
        Classification("01.49", "Raising of other animals", Category.CLASS),
        Classification("01.49.Z", "Raising of other animals", Category.SUBCLASS),
        Classification(
            "01.5", "Agricultural cultivation together with raising of animals (mixed activity)", Category.GROUP
        ),
        Classification(
            "01.50", "Agricultural cultivation together with raising of animals (mixed activity)", Category.CLASS
        ),
        Classification(
            "01.50.Z", "Agricultural cultivation together with raising of animals (mixed activity)", Category.SUBCLASS
        ),
        Classification("01.6", "Support activities to agriculture and post-harvest crop activities", Category.GROUP),
        Classification("01.61", "Support activities for crop production", Category.CLASS),
        Classification("01.61.Z", "Support activities for crop production", Category.SUBCLASS),
        Classification("01.62", "Support activities for farm animal production", Category.CLASS),
        Classification("01.62.Z", "Support activities for farm animal production", Category.SUBCLASS),
        Classification("01.63", "Post-harvest crop activities", Category.CLASS),
        Classification("01.63.Z", "Post-harvest crop activities", Category.SUBCLASS),
        Classification("01.64", "Seed processing for propagation", Category.CLASS),
        Classification("01.64.Z", "Seed processing for propagation", Category.SUBCLASS),
        Classification("01.7", "Hunting and acquiring of hunting animals, including service activity", Category.GROUP),
        Classification("01.70", "Hunting and acquiring of hunting animals, including service activity", Category.CLASS),
        Classification(
            "01.70.Z", "Hunting and acquiring of hunting animals, including service activity", Category.SUBCLASS
        ),
        Classification("02", "FORESTRY AND LOGGING", Category.DIVISION),
        Classification(
            "02.1",
            "Silviculture and other forestry activities, excluding gathering of forestry products",
            Category.GROUP,
        ),
        Classification(
            "02.10",
            "Silviculture and other forestry activities, excluding gathering of forestry products",
            Category.CLASS,
        ),
        Classification(
            "02.10.Z",
            "Silviculture and other forestry activities, excluding gathering of forestry products",
            Category.SUBCLASS,
        ),
        Classification("02.2", "Logging", Category.GROUP),
        Classification("02.20", "Logging", Category.CLASS),
        Classification("02.20.Z", "Logging", Category.SUBCLASS),
        Classification("02.3", "Gathering of wild growing forestry products, excluding wood ", Category.GROUP),
        Classification("02.30", "Gathering of wild growing forestry products, excluding wood ", Category.CLASS),
        Classification("02.30.Z", "Gathering of wild growing forestry products, excluding wood ", Category.SUBCLASS),
        Classification("02.4", "Service activity related to forestry", Category.GROUP),
        Classification("02.40", "Service activity related to forestry", Category.CLASS),
        Classification("02.40.Z", "Service activity related to forestry", Category.SUBCLASS),
        Classification("03", "FISHING AND AQUACULTURE", Category.DIVISION),
        Classification("03.1", "Fishing", Category.GROUP),
        Classification("03.11", "Marine fishing", Category.CLASS),
        Classification("03.11.Z", "Marine fishing", Category.SUBCLASS),
        Classification("03.12", "Freshwater fishing", Category.CLASS),
        Classification("03.12.Z", "Freshwater fishing", Category.SUBCLASS),
        Classification("03.2", "Aquaculture", Category.GROUP),
        Classification("03.21", "Marine aquaculture", Category.CLASS),
        Classification("03.21.Z", "Marine aquaculture", Category.SUBCLASS),
        Classification("03.22", "Freshwater aquaculture", Category.CLASS),
        Classification("03.22.Z", "Freshwater aquaculture", Category.SUBCLASS),
        Classification("B", "MINING AND QUARRYING", Category.SECTION),
        Classification("05", "MINING OF COAL AND LIGNITE", Category.DIVISION),
        Classification("05.1", "Mining of hard coal", Category.GROUP),
        Classification("05.10", "Mining of hard coal", Category.CLASS),
        Classification("05.10.Z", "Mining of hard coal", Category.SUBCLASS),
        Classification("05.2", "Mining of lignite", Category.GROUP),
        Classification("05.20", "Mining of lignite", Category.CLASS),
        Classification("05.20.Z", "Mining of lignite", Category.SUBCLASS),
        Classification("06", "EXTRACTION OF CRUDE PETROLEUM AND NATURAL GAS", Category.DIVISION),
        Classification("06.1", "Extraction of crude petroleum", Category.GROUP),
        Classification("06.10", "Extraction of crude petroleum", Category.CLASS),
        Classification("06.10.Z", "Extraction of crude petroleum", Category.SUBCLASS),
        Classification("06.2", "Extraction of natural gas", Category.GROUP),
        Classification("06.20", "Extraction of natural gas", Category.CLASS),
        Classification("06.20.Z", "Extraction of natural gas", Category.SUBCLASS),
        Classification("07", "MINING OF METAL ORES", Category.DIVISION),
        Classification("07.1", "Mining of iron ores", Category.GROUP),
        Classification("07.10", "Mining of iron ores", Category.CLASS),
        Classification("07.10.Z", "Mining of iron ores", Category.SUBCLASS),
        Classification("07.2", "Mining of non-ferrous metal ores", Category.GROUP),
        Classification("07.21", "Mining of uranium and thorium ores", Category.CLASS),
        Classification("07.21.Z", "Mining of uranium and thorium ores", Category.SUBCLASS),
        Classification("07.29", "Mining of other non-ferrous metal ores", Category.CLASS),
        Classification("07.29.Z", "Mining of other non-ferrous metal ores", Category.SUBCLASS),
        Classification("08", "OTHER MINING AND QUARRYING", Category.DIVISION),
        Classification("08.1", "Quarrying of stone, sand and clay", Category.GROUP),
        Classification(
            "08.11", "Quarrying of ornamental and building stone, limestone, gypsum, chalk and slate", Category.CLASS
        ),
        Classification(
            "08.11.Z",
            "Quarrying of ornamental and building stone, limestone, gypsum, chalk and slate",
            Category.SUBCLASS,
        ),
        Classification("08.12", "Operation of gravel and sand pits; mining of clays and kaolin", Category.CLASS),
        Classification("08.12.Z", "Operation of gravel and sand pits; mining of clays and kaolin", Category.SUBCLASS),
        Classification("08.9", "Mining and quarrying not elsewhere classified", Category.GROUP),
        Classification(
            "08.91", "Mining of minerals for chemical industry and for production of fertilizers", Category.CLASS
        ),
        Classification(
            "08.91.Z", "Mining of minerals for chemical industry and for production of fertilizers", Category.SUBCLASS
        ),
        Classification("08.92", "Extraction of peat", Category.CLASS),
        Classification("08.92.Z", "Extraction of peat", Category.SUBCLASS),
        Classification("08.93", "Extraction of salt", Category.CLASS),
        Classification("08.93.Z", "Extraction of salt", Category.SUBCLASS),
        Classification("08.99", "Other mining and quarrying not elsewhere classified", Category.CLASS),
        Classification("08.99.Z", "Other mining and quarrying not elsewhere classified", Category.SUBCLASS),
        Classification("09", "MINING AND QUARRYING SUPPORT SERVICE ACTIVITIES", Category.DIVISION),
        Classification("09.1", "Support activities for petroleum and natural gas extraction", Category.GROUP),
        Classification("09.10", "Support activities for petroleum and natural gas extraction", Category.CLASS),
        Classification("09.10.Z", "Support activities for petroleum and natural gas extraction", Category.SUBCLASS),
        Classification("09.9", "Support activities for other mining and quarrying", Category.GROUP),
        Classification("09.90", "Support activities for other mining and quarrying", Category.CLASS),
        Classification("09.90.Z", "Support activities for other mining and quarrying", Category.SUBCLASS),
        Classification("C", "MANUFACTURING", Category.SECTION),
        Classification("10", "MANUFACTURE OF FOOD PRODUCTS", Category.DIVISION),
        Classification("10.1", "Processing and preserving of meat and production of meat products", Category.GROUP),
        Classification("10.11", "Processing and preserving of meat, excluding poultry meat", Category.CLASS),
        Classification("10.11.Z", "Processing and preserving of meat, excluding poultry meat", Category.SUBCLASS),
        Classification("10.12", "Processing and preserving of poultry meat", Category.CLASS),
        Classification("10.12.Z", "Processing and preserving of poultry meat", Category.SUBCLASS),
        Classification("10.13", "Production of meat products, including poultry meat products", Category.CLASS),
        Classification("10.13.Z", "Production of meat products, including poultry meat products", Category.SUBCLASS),
        Classification("10.2", "Processing and preserving of fish, crustaceans and molluscs", Category.GROUP),
        Classification("10.20", "Processing and preserving of fish, crustaceans and molluscs", Category.CLASS),
        Classification("10.20.Z", "Processing and preserving of fish, crustaceans and molluscs", Category.SUBCLASS),
        Classification("10.3", "Processing and preserving of fruit and vegetables", Category.GROUP),
        Classification("10.31", "Processing and preserving of potatoes", Category.CLASS),
        Classification("10.31.Z", "Processing and preserving of potatoes", Category.SUBCLASS),
        Classification("10.32", "Manufacture of fruit and vegetable juice", Category.CLASS),
        Classification("10.32.Z", "Manufacture of fruit and vegetable juice", Category.SUBCLASS),
        Classification("10.39", "Other processing and preserving of fruit and vegetables", Category.CLASS),
        Classification("10.39.Z", "Other processing and preserving of fruit and vegetables", Category.SUBCLASS),
        Classification("10.4", "Manufacture of vegetable and animal oils and fats", Category.GROUP),
        Classification("10.41", "Manufacture of oils and other fluid fats", Category.CLASS),
        Classification("10.41.Z", "Manufacture of oils and other fluid fats", Category.SUBCLASS),
        Classification("10.42", "Manufacture of margarine and similar edible fats", Category.CLASS),
        Classification("10.42.Z", "Manufacture of margarine and similar edible fats", Category.SUBCLASS),
        Classification("10.5", "Manufacture of dairy products", Category.GROUP),
        Classification("10.51", "Operation of dairies and cheese making", Category.CLASS),
        Classification("10.51.Z", "Operation of dairies and cheese making", Category.SUBCLASS),
        Classification("10.52", "Manufacture of ice cream", Category.CLASS),
        Classification("10.52.Z", "Manufacture of ice cream", Category.SUBCLASS),
        Classification("10.6", "Manufacture of grain mill products, starches and starch products", Category.GROUP),
        Classification("10.61", "Manufacture of grain mill products", Category.CLASS),
        Classification("10.61.Z", "Manufacture of grain mill products", Category.SUBCLASS),
        Classification("10.62", "Manufacture of starches and starch products", Category.CLASS),
        Classification("10.62.Z", "Manufacture of starches and starch products", Category.SUBCLASS),
        Classification("10.7", "Manufacture of bakery and farinaceous products", Category.GROUP),
        Classification("10.71", "Manufacture of bread; manufacture of fresh pastry goods and cakes", Category.CLASS),
        Classification(
            "10.71.Z", "Manufacture of bread; manufacture of fresh pastry goods and cakes", Category.SUBCLASS
        ),
        Classification(
            "10.72",
            "Manufacture of rusks and biscuits; manufacture of preserved pastry goods and cakes",
            Category.CLASS,
        ),
        Classification(
            "10.72.Z",
            "Manufacture of rusks and biscuits; manufacture of preserved pastry goods and cakes",
            Category.SUBCLASS,
        ),
        Classification(
            "10.73", "Manufacture of macaroni, noodles, couscous and similar farinaceous products", Category.CLASS
        ),
        Classification(
            "10.73.Z", "Manufacture of macaroni, noodles, couscous and similar farinaceous products", Category.SUBCLASS
        ),
        Classification("10.8", "Manufacture of other food products", Category.GROUP),
        Classification("10.81", "Manufacture of sugar", Category.CLASS),
        Classification("10.81.Z", "Manufacture of sugar", Category.SUBCLASS),
        Classification("10.82", "Manufacture of cocoa, chocolate and sugar confectionery", Category.CLASS),
        Classification("10.82.Z", "Manufacture of cocoa, chocolate and sugar confectionery", Category.SUBCLASS),
        Classification("10.83", "Processing of tea and coffee", Category.CLASS),
        Classification("10.83.Z", "Processing of tea and coffee", Category.SUBCLASS),
        Classification("10.84", "Manufacture of condiments and seasonings", Category.CLASS),
        Classification("10.84.Z", "Manufacture of condiments and seasonings", Category.SUBCLASS),
        Classification("10.85", "Manufacture of prepared meals and dishes", Category.CLASS),
        Classification("10.85.Z", "Manufacture of prepared meals and dishes", Category.SUBCLASS),
        Classification("10.86", "Manufacture of homogenised food preparations and dietetic food", Category.CLASS),
        Classification("10.86.Z", "Manufacture of homogenised food preparations and dietetic food", Category.SUBCLASS),
        Classification("10.89", "Manufacture of other food products not elsewhere classified", Category.CLASS),
        Classification("10.89.Z", "Manufacture of other food products not elsewhere classified", Category.SUBCLASS),
        Classification("10.9", "Manufacture of prepared animal feeds", Category.GROUP),
        Classification("10.91", "Manufacture of prepared feeds for farm animals", Category.CLASS),
        Classification("10.91.Z", "Manufacture of prepared feeds for farm animals", Category.SUBCLASS),
        Classification("10.92", "Manufacture of prepared pet foods", Category.CLASS),
        Classification("10.92.Z", "Manufacture of prepared pet foods", Category.SUBCLASS),
        Classification("11", "MANUFACTURE OF BEVERAGES", Category.DIVISION),
        Classification("11.0", "Manufacture of beverages", Category.GROUP),
        Classification("11.01", "Distilling, rectifying and blending of spirits", Category.CLASS),
        Classification("11.01.Z", "Distilling, rectifying and blending of spirits", Category.SUBCLASS),
        Classification("11.02", "Manufacture of wine from grape", Category.CLASS),
        Classification("11.02.Z", "Manufacture of wine from grape", Category.SUBCLASS),
        Classification("11.03", "Manufacture of cider and other fruit wines", Category.CLASS),
        Classification("11.03.Z", "Manufacture of cider and other fruit wines", Category.SUBCLASS),
        Classification("11.04", "Manufacture of other non-distilled fermented beverages", Category.CLASS),
        Classification("11.04.Z", "Manufacture of other non-distilled fermented beverages", Category.SUBCLASS),
        Classification("11.05", "Manufacture of beer", Category.CLASS),
        Classification("11.05.Z", "Manufacture of beer", Category.SUBCLASS),
        Classification("11.06", "Manufacture of malt", Category.CLASS),
        Classification("11.06.Z", "Manufacture of malt", Category.SUBCLASS),
        Classification(
            "11.07", "Manufacture of soft drinks; production of mineral waters and other bottled waters", Category.CLASS
        ),
        Classification(
            "11.07.Z",
            "Manufacture of soft drinks; production of mineral waters and other bottled waters",
            Category.SUBCLASS,
        ),
        Classification("12", "MANUFACTURE OF TOBACCO PRODUCTS", Category.DIVISION),
        Classification("12.0", "Manufacture of tobacco products", Category.GROUP),
        Classification("12.00", "Manufacture of tobacco products", Category.CLASS),
        Classification("12.00.Z", "Manufacture of tobacco products", Category.SUBCLASS),
        Classification("13", "MANUFACTURE OF TEXTILES", Category.DIVISION),
        Classification("13.1", "Preparation and spinning of textile fibres", Category.GROUP),
        Classification("13.10", "Preparation and spinning of textile fibres", Category.CLASS),
        Classification("13.10.A", "Manufacture of cotton yarn", Category.SUBCLASS),
        Classification("13.10.B", "Manufacture of wool yarn", Category.SUBCLASS),
        Classification("13.10.C", "Manufacture of man-made fibres yarn", Category.SUBCLASS),
        Classification(
            "13.10.D",
            "Manufacture of yarn from other textile fibres, including manufacture of sewing thread",
            Category.SUBCLASS,
        ),
        Classification("13.2", "Manufacture of woven fabrics", Category.GROUP),
        Classification("13.20", "Manufacture of woven fabrics", Category.CLASS),
        Classification("13.20.A", "Manufacture of cotton woven fabrics", Category.SUBCLASS),
        Classification("13.20.B", "Manufacture of wool woven fabrics", Category.SUBCLASS),
        Classification("13.20.C", "Manufacture of man-made woven fabrics", Category.SUBCLASS),
        Classification("13.20.D", "Manufacture of other woven fabrics", Category.SUBCLASS),
        Classification("13.3", "Finishing of textiles", Category.GROUP),
        Classification("13.30", "Finishing of textiles", Category.CLASS),
        Classification("13.30.Z", "Finishing of textiles", Category.SUBCLASS),
        Classification("13.9", "Manufacture of other textiles", Category.GROUP),
        Classification("13.91", "Manufacture of knitted and crocheted fabrics", Category.CLASS),
        Classification("13.91.Z", "Manufacture of knitted and crocheted fabrics", Category.SUBCLASS),
        Classification("13.92", "Manufacture of made-up textile articles", Category.CLASS),
        Classification("13.92.Z", "Manufacture of made-up textile articles", Category.SUBCLASS),
        Classification("13.93", "Manufacture of carpets and rugs", Category.CLASS),
        Classification("13.93.Z", "Manufacture of carpets and rugs", Category.SUBCLASS),
        Classification("13.94", "Manufacture of cordage, rope, twine and netting", Category.CLASS),
        Classification("13.94.Z", "Manufacture of cordage, rope, twine and netting", Category.SUBCLASS),
        Classification(
            "13.95", "Manufacture of non-wovens and articles made from non-wovens, except apparel", Category.CLASS
        ),
        Classification(
            "13.95.Z", "Manufacture of non-wovens and articles made from non-wovens, except apparel", Category.SUBCLASS
        ),
        Classification("13.96", "Manufacture of other technical and industrial textiles", Category.CLASS),
        Classification("13.96.Z", "Manufacture of other technical and industrial textiles", Category.SUBCLASS),
        Classification("13.99", "Manufacture of other textiles not elsewhere classified", Category.CLASS),
        Classification("13.99.Z", "Manufacture of other textiles not elsewhere classified", Category.SUBCLASS),
        Classification("14", "MANUFACTURE OF WEARING APPAREL", Category.DIVISION),
        Classification("14.1", "Manufacture of wearing apparel, except fur apparel", Category.GROUP),
        Classification("14.11", "Manufacture of leather clothes", Category.CLASS),
        Classification("14.11.Z", "Manufacture of leather clothes", Category.SUBCLASS),
        Classification("14.12", "Manufacture of workwear", Category.CLASS),
        Classification("14.12.Z", "Manufacture of workwear", Category.SUBCLASS),
        Classification("14.13", "Manufacture of other outerwear", Category.CLASS),
        Classification("14.13.Z", "Manufacture of other outerwear", Category.SUBCLASS),
        Classification("14.14", "Manufacture of underwear", Category.CLASS),
        Classification("14.14.Z", "Manufacture of underwear", Category.SUBCLASS),
        Classification("14.19", "Manufacture of other wearing apparel and accessories", Category.CLASS),
        Classification("14.19.Z", "Manufacture of other wearing apparel and accessories", Category.SUBCLASS),
        Classification("14.2", "Manufacture of articles of fur", Category.GROUP),
        Classification("14.20", "Manufacture of articles of fur", Category.CLASS),
        Classification("14.20.Z", "Manufacture of articles of fur", Category.SUBCLASS),
        Classification("14.3", "Manufacture of knitted and crocheted apparel", Category.GROUP),
        Classification("14.31", "Manufacture of knitted and crocheted hosiery", Category.CLASS),
        Classification("14.31.Z", "Manufacture of knitted and crocheted hosiery", Category.SUBCLASS),
        Classification("14.39", "Manufacture of other knitted and crocheted apparel", Category.CLASS),
        Classification("14.39.Z", "Manufacture of other knitted and crocheted apparel", Category.SUBCLASS),
        Classification("15", "MANUFACTURE OF LEATHER AND RELATED PRODUCTS", Category.DIVISION),
        Classification(
            "15.1",
            "Tanning and dressing of leather; dressing and dyeing of fur; manufacture of luggage, handbags and similar leather goods; manufacture of saddlery",
            Category.GROUP,
        ),
        Classification("15.11", "Tanning and dressing of leather; dressing and dyeing of fur", Category.CLASS),
        Classification("15.11.Z", "Tanning and dressing of leather; dressing and dyeing of fur", Category.SUBCLASS),
        Classification(
            "15.12",
            "Manufacture of luggage, handbags and similar leather goods; manufacture of saddlery ",
            Category.CLASS,
        ),
        Classification(
            "15.12.Z",
            "Manufacture of luggage, handbags and similar leather goods; manufacture of saddlery",
            Category.SUBCLASS,
        ),
        Classification("15.2", "Manufacture of footwear", Category.GROUP),
        Classification("15.20", "Manufacture of footwear", Category.CLASS),
        Classification("15.20.Z", "Manufacture of footwear", Category.SUBCLASS),
        Classification(
            "16",
            "MANUFACTURE OF PRODUCTS OF WOOD AND CORK, EXCEPT FURNITURE; MANUFACTURE OF ARTICLES OF STRAW AND PLAITING MATERIALS",
            Category.DIVISION,
        ),
        Classification("16.1", "Sawmilling and planing of wood", Category.GROUP),
        Classification("16.10", "Sawmilling and planing of wood", Category.CLASS),
        Classification("16.10.Z", "Sawmilling and planing of wood", Category.SUBCLASS),
        Classification("16.2", "Manufacture of products of wood, cork, straw and plaiting materials", Category.GROUP),
        Classification("16.21", "Manufacture of veneer sheets and wood-based panels", Category.CLASS),
        Classification("16.21.Z", "Manufacture of veneer sheets and wood-based panels", Category.SUBCLASS),
        Classification("16.22", "Manufacture of assembled parquet floors", Category.CLASS),
        Classification("16.22.Z", "Manufacture of assembled parquet floors", Category.SUBCLASS),
        Classification("16.23", "Manufacture of other builders' carpentry and joinery", Category.CLASS),
        Classification("16.23.Z", "Manufacture of other builders' carpentry and joinery", Category.SUBCLASS),
        Classification("16.24", "Manufacture of wooden containers", Category.CLASS),
        Classification("16.24.Z", "Manufacture of wooden containers", Category.SUBCLASS),
        Classification(
            "16.29",
            "Manufacture of other products of wood; manufacture of articles of cork, straw and plaiting materials",
            Category.CLASS,
        ),
        Classification(
            "16.29.Z",
            "Manufacture of other products of wood; manufacture of articles of cork, straw and plaiting materials",
            Category.SUBCLASS,
        ),
        Classification("17", "MANUFACTURE OF PAPER AND PAPER PRODUCTS", Category.DIVISION),
        Classification("17.1", "Manufacture of pulp, paper and paperboard", Category.GROUP),
        Classification("17.11", "Manufacture of pulp", Category.CLASS),
        Classification("17.11.Z", "Manufacture of pulp", Category.SUBCLASS),
        Classification("17.12", "Manufacture of paper and paperboard", Category.CLASS),
        Classification("17.12.Z", "Manufacture of paper and paperboard", Category.SUBCLASS),
        Classification("17.2", "Manufacture of articles of paper and paperboard ", Category.GROUP),
        Classification(
            "17.21",
            "Manufacture of corrugated paper and paperboard and of containers of paper and paperboard",
            Category.CLASS,
        ),
        Classification(
            "17.21.Z",
            "Manufacture of corrugated paper and paperboard and of containers of paper and paperboard",
            Category.SUBCLASS,
        ),
        Classification("17.22", "Manufacture of household and sanitary goods and of toilet requisites", Category.CLASS),
        Classification(
            "17.22.Z", "Manufacture of household and sanitary goods and of toilet requisites", Category.SUBCLASS
        ),
        Classification("17.23", "Manufacture of paper stationery", Category.CLASS),
        Classification("17.23.Z", "Manufacture of paper stationery", Category.SUBCLASS),
        Classification("17.24", "Manufacture of wallpaper", Category.CLASS),
        Classification("17.24.Z", "Manufacture of wallpaper", Category.SUBCLASS),
        Classification("17.29", "Manufacture of other articles of paper and paperboard", Category.CLASS),
        Classification("17.29.Z", "Manufacture of other articles of paper and paperboard", Category.SUBCLASS),
        Classification("18", "PRINTING AND REPRODUCTION OF RECORDED MEDIA", Category.DIVISION),
        Classification("18.1", "Printing and service activities related to printing", Category.GROUP),
        Classification("18.11", "Printing of newspapers", Category.CLASS),
        Classification("18.11.Z", "Printing of newspapers", Category.SUBCLASS),
        Classification("18.12", "Other printing", Category.CLASS),
        Classification("18.12.Z", "Other printing", Category.SUBCLASS),
        Classification("18.13", "Pre-press and pre-media services", Category.CLASS),
        Classification("18.13.Z", "Pre-press and pre-media services", Category.SUBCLASS),
        Classification("18.14", "Binding and related services", Category.CLASS),
        Classification("18.14.Z", "Binding and related services", Category.SUBCLASS),
        Classification("18.2", "Reproduction of recorded media", Category.GROUP),
        Classification("18.20", "Reproduction of recorded media", Category.CLASS),
        Classification("18.20.Z", "Reproduction of recorded media", Category.SUBCLASS),
        Classification("19", "MANUFACTURE AND PROCESSING OF COKE AND REFINED  PETROLEUM PRODUCTS", Category.DIVISION),
        Classification("19.1", "Manufacture and processing of coke", Category.GROUP),
        Classification("19.10", "Manufacture and processing of coke", Category.CLASS),
        Classification("19.10.Z", "Manufacture and processing of coke", Category.SUBCLASS),
        Classification("19.2", "Manufacture and processing of refind petroleum products", Category.GROUP),
        Classification("19.20", "Manufacture and processing of refind petroleum products", Category.CLASS),
        Classification("19.20.Z", "Manufacture and processing of refind petroleum products", Category.SUBCLASS),
        Classification("20", "MANUFACTURE OF CHEMICALS AND CHEMICAL PRODUCTS", Category.DIVISION),
        Classification(
            "20.1",
            "Manufacture of basic chemicals, fertilisers and nitrogen compounds, plastics and synthetic rubber in primary forms",
            Category.GROUP,
        ),
        Classification("20.11", "Manufacture of industrial gases", Category.CLASS),
        Classification("20.11.Z", "Manufacture of industrial gases", Category.SUBCLASS),
        Classification("20.12", "Manufacture of dyes and pigments", Category.CLASS),
        Classification("20.12.Z", "Manufacture of dyes and pigments", Category.SUBCLASS),
        Classification("20.13", "Manufacture of other inorganic basic chemicals", Category.CLASS),
        Classification("20.13.Z", "Manufacture of other inorganic basic chemicals", Category.SUBCLASS),
        Classification("20.14", "Manufacture of other organic basic chemicals", Category.CLASS),
        Classification("20.14.Z", "Manufacture of other organic basic chemicals", Category.SUBCLASS),
        Classification("20.15", "Manufacture of fertilisers and nitrogen compounds", Category.CLASS),
        Classification("20.15.Z", "Manufacture of fertilisers and nitrogen compounds", Category.SUBCLASS),
        Classification("20.16", "Manufacture of plastics in primary forms", Category.CLASS),
        Classification("20.16.Z", "Manufacture of plastics in primary forms", Category.SUBCLASS),
        Classification("20.17", "Manufacture of synthetic rubber in primary forms", Category.CLASS),
        Classification("20.17.Z", "Manufacture of synthetic rubber in primary forms", Category.SUBCLASS),
        Classification("20.2", "Manufacture of pesticides and other agrochemical products", Category.GROUP),
        Classification("20.20", "Manufacture of pesticides and other agrochemical products", Category.CLASS),
        Classification("20.20.Z", "Manufacture of pesticides and other agrochemical products", Category.SUBCLASS),
        Classification(
            "20.3", "Manufacture of paints, varnishes and similar coatings, printing ink and mastics", Category.GROUP
        ),
        Classification(
            "20.30", "Manufacture of paints, varnishes and similar coatings, printing ink and mastics", Category.CLASS
        ),
        Classification(
            "20.30.Z",
            "Manufacture of paints, varnishes and similar coatings, printing ink and mastics",
            Category.SUBCLASS,
        ),
        Classification(
            "20.4",
            "Manufacture of soap and detergents, cleaning and polishing preparations, perfumes and toilet preparations",
            Category.GROUP,
        ),
        Classification(
            "20.41", "Manufacture of soap and detergents, cleaning and polishing preparations", Category.CLASS
        ),
        Classification(
            "20.41.Z", "Manufacture of soap and detergents, cleaning and polishing preparations", Category.SUBCLASS
        ),
        Classification("20.42", "Manufacture of perfumes and toilet preparations", Category.CLASS),
        Classification("20.42.Z", "Manufacture of perfumes and toilet preparations", Category.SUBCLASS),
        Classification("20.5", "Manufacture of other chemical products", Category.GROUP),
        Classification("20.51", "Manufacture of explosives", Category.CLASS),
        Classification("20.51.Z", "Manufacture of explosives", Category.SUBCLASS),
        Classification("20.52", "Manufacture of glues", Category.CLASS),
        Classification("20.52.Z", "Manufacture of glues", Category.SUBCLASS),
        Classification("20.53", "Manufacture of essential oils", Category.CLASS),
        Classification("20.53.Z", "Manufacture of essential oils", Category.SUBCLASS),
        Classification("20.59", "Manufacture of other chemical products not elsewhere classified ", Category.CLASS),
        Classification(
            "20.59.Z", "Manufacture of other chemical products not elsewhere classified ", Category.SUBCLASS
        ),
        Classification("20.6", "Manufacture of man-made fibres", Category.GROUP),
        Classification("20.60", "Manufacture of man-made fibres", Category.CLASS),
        Classification("20.60.Z", "Manufacture of man-made fibres", Category.SUBCLASS),
        Classification(
            "21",
            "MANUFACTURE OF BASIC PHARMACEUTICAL SUBSTANCES AND MEDICINES AND OTHER PHARMACEUTICAL PRODUCTS",
            Category.DIVISION,
        ),
        Classification("21.1", "Manufacture of basic pharmaceutical substances", Category.GROUP),
        Classification("21.10", "Manufacture of basic pharmaceutical substances", Category.CLASS),
        Classification("21.10.Z", "Manufacture of basic pharmaceutical substances", Category.SUBCLASS),
        Classification("21.2", "Manufacture of  medicines and other pharmaceutical products", Category.GROUP),
        Classification("21.20", "Manufacture of  medicines and other pharmaceutical products", Category.CLASS),
        Classification("21.20.Z", "Manufacture of  medicines and other pharmaceutical products", Category.SUBCLASS),
        Classification("22", "MANUFACTURE OF RUBBER AND PLASTIC PRODUCTS", Category.DIVISION),
        Classification("22.1", "Manufacture of rubber products", Category.GROUP),
        Classification(
            "22.11", "Manufacture of rubber tyres and tubes; retreading and rebuilding of rubber tyres", Category.CLASS
        ),
        Classification(
            "22.11.Z",
            "Manufacture of rubber tyres and tubes; retreading and rebuilding of rubber tyres",
            Category.SUBCLASS,
        ),
        Classification("22.19", "Manufacture of other rubber products", Category.CLASS),
        Classification("22.19.Z", "Manufacture of other rubber products", Category.SUBCLASS),
        Classification("22.2", "Manufacture of plastic products", Category.GROUP),
        Classification("22.21", "Manufacture of plastic plates, sheets, tubes and profiles", Category.CLASS),
        Classification("22.21.Z", "Manufacture of plastic plates, sheets, tubes and profiles", Category.SUBCLASS),
        Classification("22.22", "Manufacture of plastic packing goods", Category.CLASS),
        Classification("22.22.Z", "Manufacture of plastic packing goods", Category.SUBCLASS),
        Classification("22.23", "Manufacture of builders’ ware of plastic", Category.CLASS),
        Classification("22.23.Z", "Manufacture of builders’ ware of plastic", Category.SUBCLASS),
        Classification("22.29", "Manufacture of other plastic products", Category.CLASS),
        Classification("22.29.Z", "Manufacture of other plastic products", Category.SUBCLASS),
        Classification("23", "MANUFACTURE OF OTHER NON-METALLIC MINERAL PRODUCTS", Category.DIVISION),
        Classification("23.1", "Manufacture of glass and glass products", Category.GROUP),
        Classification("23.11", "Manufacture of flat glass", Category.CLASS),
        Classification("23.11.Z", "Manufacture of flat glass", Category.SUBCLASS),
        Classification("23.12", "Shaping and processing of flat glass", Category.CLASS),
        Classification("23.12.Z", "Shaping and processing of flat glass", Category.SUBCLASS),
        Classification("23.13", "Manufacture of hollow glass", Category.CLASS),
        Classification("23.13.Z", "Manufacture of hollow glass", Category.SUBCLASS),
        Classification("23.14", "Manufacture of glass fibres", Category.CLASS),
        Classification("23.14.Z", "Manufacture of glass fibres", Category.SUBCLASS),
        Classification(
            "23.19", "Manufacture and processing of other glass, including technical glassware", Category.CLASS
        ),
        Classification(
            "23.19.Z", "Manufacture and processing of other glass, including technical glassware", Category.SUBCLASS
        ),
        Classification("23.2", "Manufacture of refractory products", Category.GROUP),
        Classification("23.20", "Manufacture of refractory products", Category.CLASS),
        Classification("23.20.Z", "Manufacture of refractory products", Category.SUBCLASS),
        Classification("23.3", "Manufacture of ceramic building materials", Category.GROUP),
        Classification("23.31", "Manufacture of ceramic tiles and flags", Category.CLASS),
        Classification("23.31.Z", "Manufacture of ceramic tiles and flags", Category.SUBCLASS),
        Classification(
            "23.32", "Manufacture of bricks, tiles and construction products, in baked clay", Category.CLASS
        ),
        Classification(
            "23.32.Z", "Manufacture of bricks, tiles and construction products, in baked clay", Category.SUBCLASS
        ),
        Classification("23.4", "Manufacture of other porcelain and ceramic products", Category.GROUP),
        Classification("23.41", "Manufacture of ceramic tableware and ornamental articles", Category.CLASS),
        Classification("23.41.Z", "Manufacture of ceramic tableware and ornamental articles", Category.SUBCLASS),
        Classification("23.42", "Manufacture of ceramic sanitary fixtures", Category.CLASS),
        Classification("23.42.Z", "Manufacture of ceramic sanitary fixtures", Category.SUBCLASS),
        Classification("23.43", "Manufacture of ceramic insulators and hollow insulators ", Category.CLASS),
        Classification("23.43.Z", "Manufacture of ceramic insulators and hollow insulators ", Category.SUBCLASS),
        Classification("23.44", "Manufacture of other technical ceramic products", Category.CLASS),
        Classification("23.44.Z", "Manufacture of other technical ceramic products", Category.SUBCLASS),
        Classification("23.49", "Manufacture of other ceramic products", Category.CLASS),
        Classification("23.49.Z", "Manufacture of other ceramic products", Category.SUBCLASS),
        Classification("23.5", "Manufacture of cement, lime and plaster", Category.GROUP),
        Classification("23.51", "Manufacture of cement", Category.CLASS),
        Classification("23.51.Z", "Manufacture of cement", Category.SUBCLASS),
        Classification("23.52", "Manufacture of lime and plaster", Category.CLASS),
        Classification("23.52.Z", "Manufacture of lime and plaster", Category.SUBCLASS),
        Classification("23.6", "Manufacture of articles of concrete, cement and plaster", Category.GROUP),
        Classification("23.61", "Manufacture of concrete products for construction purposes", Category.CLASS),
        Classification("23.61.Z", "Manufacture of concrete products for construction purposes", Category.SUBCLASS),
        Classification("23.62", "Manufacture of plaster products for construction purposes", Category.CLASS),
        Classification("23.62.Z", "Manufacture of plaster products for construction purposes", Category.SUBCLASS),
        Classification("23.63", "Manufacture of ready-mixed concrete", Category.CLASS),
        Classification("23.63.Z", "Manufacture of ready-mixed concrete", Category.SUBCLASS),
        Classification("23.64", "Manufacture of mortars", Category.CLASS),
        Classification("23.64.Z", "Manufacture of mortars", Category.SUBCLASS),
        Classification("23.65", "Manufacture of fibre cement", Category.CLASS),
        Classification("23.65.Z", "Manufacture of fibre cement", Category.SUBCLASS),
        Classification("23.69", "Manufacture of other articles of concrete, plaster and cement", Category.CLASS),
        Classification("23.69.Z", "Manufacture of other articles of concrete, plaster and cement", Category.SUBCLASS),
        Classification("23.7", "Cutting, shaping and finishing of stone", Category.GROUP),
        Classification("23.70", "Cutting, shaping and finishing of stone", Category.CLASS),
        Classification("23.70.Z", "Cutting, shaping and finishing of stone", Category.SUBCLASS),
        Classification(
            "23.9",
            "Manufacture of abrasive products and others non-metallic mineral products not elsewhere classified ",
            Category.GROUP,
        ),
        Classification("23.91", "Production of abrasive products", Category.CLASS),
        Classification("23.91.Z", "Production of abrasive products", Category.SUBCLASS),
        Classification(
            "23.99",
            "Manufacture of abrasive products and others non-metallic mineral products not elsewhere classified ",
            Category.CLASS,
        ),
        Classification(
            "23.99.Z",
            "Manufacture of abrasive products and others non-metallic mineral products not elsewhere classified ",
            Category.SUBCLASS,
        ),
        Classification("24", "MANUFACTURE OF METALS", Category.DIVISION),
        Classification(
            "24.1",
            "Manufacture of pig iron, ferro-alloys, basic iron and steel and metallurgic articles",
            Category.GROUP,
        ),
        Classification(
            "24.10",
            "Manufacture of pig iron, ferro-alloys, basic iron and steel and metallurgic articles",
            Category.CLASS,
        ),
        Classification(
            "24.10.Z",
            "Manufacture of pig iron, ferro-alloys, basic iron and steel and metallurgic articles",
            Category.SUBCLASS,
        ),
        Classification(
            "24.2", "Manufacture of tubes and pipes, conduits, closed sections and connectors, of steel", Category.GROUP
        ),
        Classification(
            "24.20",
            "Manufacture of tubes and pipes, conduits, closed sections and connectors, of steel",
            Category.CLASS,
        ),
        Classification(
            "24.20.Z",
            "Manufacture of tubes and pipes, conduits, closed sections and connectors, of steel",
            Category.SUBCLASS,
        ),
        Classification("24.3", "Manufacture of other products of first processing of steel", Category.GROUP),
        Classification("24.31", "Cold drawing of bars", Category.CLASS),
        Classification("24.31.Z", "Cold drawing of bars", Category.SUBCLASS),
        Classification("24.32", "Cold rolling of narrow strip", Category.CLASS),
        Classification("24.32.Z", "Cold rolling of narrow strip", Category.SUBCLASS),
        Classification("24.33", "Manufacture of cold forming products", Category.CLASS),
        Classification("24.33.Z", "Manufacture of cold forming products", Category.SUBCLASS),
        Classification("24.34", "Manufacture of wire", Category.CLASS),
        Classification("24.34.Z", "Manufacture of wire", Category.SUBCLASS),
        Classification("24.4", "Manufacture of precious metals and other non-ferrous metals", Category.GROUP),
        Classification("24.41", "Precious metals production", Category.CLASS),
        Classification("24.41.Z", "Precious metals production", Category.SUBCLASS),
        Classification("24.42", "Aluminium production", Category.CLASS),
        Classification("24.42.A", "Primary aluminium production", Category.SUBCLASS),
        Classification("24.42.B", "Aluminium and aluminium alloy goods production", Category.SUBCLASS),
        Classification("24.43", "Lead, zinc and tin production", Category.CLASS),
        Classification("24.43.Z", "Lead, zinc and tin production", Category.SUBCLASS),
        Classification("24.44", "Copper production", Category.CLASS),
        Classification("24.44.Z", "Copper production", Category.SUBCLASS),
        Classification("24.45", "Other non-ferrous metal production", Category.CLASS),
        Classification("24.45.Z", "Other non-ferrous metal production", Category.SUBCLASS),
        Classification("24.46", "Nuclear fuel production", Category.CLASS),
        Classification("24.46.Z", "Nuclear fuel production", Category.SUBCLASS),
        Classification("24.5", "Casting of metals", Category.GROUP),
        Classification("24.51", "Casting of iron", Category.CLASS),
        Classification("24.51.Z", "Casting of iron", Category.SUBCLASS),
        Classification("24.52", "Casting of steel", Category.CLASS),
        Classification("24.52.Z", "Casting of steel", Category.SUBCLASS),
        Classification("24.53", "Casting of light metals", Category.CLASS),
        Classification("24.53.Z", "Casting of light metals", Category.SUBCLASS),
        Classification("24.54", "Casting of other non-ferrous metals", Category.CLASS),
        Classification("24.54.A", "Casting of copper and copper alloy", Category.SUBCLASS),
        Classification("24.54.B", "Casting of other non-ferrous metals not elsewhere classified ", Category.SUBCLASS),
        Classification(
            "25", "MANUFACTURE OF FABRICATED METAL PRODUCTS, EXCEPT MACHINERY AND EQUIPMENT", Category.DIVISION
        ),
        Classification("25.1", "Manufacture of structural metal products", Category.GROUP),
        Classification("25.11", "Manufacture of metal structures and parts of structures", Category.CLASS),
        Classification("25.11.Z", "Manufacture of metal structures and parts of structures", Category.SUBCLASS),
        Classification("25.12", "Manufacture of metal elements of building woodwork", Category.CLASS),
        Classification("25.12.Z", "Manufacture of metal elements of building woodwork", Category.SUBCLASS),
        Classification("25.2", "Manufacture of tanks, reservoirs and containers of metal", Category.GROUP),
        Classification("25.21", "Manufacture of central heating radiators and boilers", Category.CLASS),
        Classification("25.21.Z", "Manufacture of central heating radiators and boilers", Category.SUBCLASS),
        Classification("25.29", "Manufacture of other tanks, reservoirs and containers of metal", Category.CLASS),
        Classification("25.29.Z", "Manufacture of other tanks, reservoirs and containers of metal", Category.SUBCLASS),
        Classification(
            "25.3", "Manufacture of steam generators, except central heating hot water boilers", Category.GROUP
        ),
        Classification(
            "25.30", "Manufacture of steam generators, except central heating hot water boilers", Category.CLASS
        ),
        Classification(
            "25.30.Z", "Manufacture of steam generators, except central heating hot water boilers", Category.SUBCLASS
        ),
        Classification("25.4", "Manufacture of weapons and ammunition", Category.GROUP),
        Classification("25.40", "Manufacture of weapons and ammunition", Category.CLASS),
        Classification("25.40.Z", "Manufacture of weapons and ammunition", Category.SUBCLASS),
        Classification(
            "25.5", "Forging, pressing, stamping and roll-forming of metal; powder metallurgy", Category.GROUP
        ),
        Classification(
            "25.50", "Forging, pressing, stamping and roll-forming of metal; powder metallurgy", Category.CLASS
        ),
        Classification(
            "25.50.Z", "Forging, pressing, stamping and roll-forming of metal; powder metallurgy", Category.SUBCLASS
        ),
        Classification("25.6", "Treatment and coating of metals; mechanical working of metal elements", Category.GROUP),
        Classification("25.61", "Treatment and coating of metals", Category.CLASS),
        Classification("25.61.Z", "Treatment and coating of metals", Category.SUBCLASS),
        Classification("25.62", "Mechanical working of metal elements", Category.CLASS),
        Classification("25.62.Z", "Mechanical working of metal elements", Category.SUBCLASS),
        Classification("25.7", "Manufacture of cutlery, tools and general hardware", Category.GROUP),
        Classification("25.71", "Manufacture of cutlery", Category.CLASS),
        Classification("25.71.Z", "Manufacture of cutlery", Category.SUBCLASS),
        Classification("25.72", "Manufacture of locks and hinges", Category.CLASS),
        Classification("25.72.Z", "Manufacture of locks and hinges", Category.SUBCLASS),
        Classification("25.73", "Manufacture of tools", Category.CLASS),
        Classification("25.73.Z", "Manufacture of tools", Category.SUBCLASS),
        Classification("25.9", "Manufacture of other fabricated metal products", Category.GROUP),
        Classification("25.91", "Manufacture of metal containers", Category.CLASS),
        Classification("25.91.Z", "Manufacture of metal containers", Category.SUBCLASS),
        Classification("25.92", "Manufacture of metal packaging ", Category.CLASS),
        Classification("25.92.Z", "Manufacture of metal packaging", Category.SUBCLASS),
        Classification("25.93", "Manufacture of wire products, chains and springs", Category.CLASS),
        Classification("25.93.Z", "Manufacture of wire products, chains and springs", Category.SUBCLASS),
        Classification("25.94", "Manufacture of fasteners and screws", Category.CLASS),
        Classification("25.94.Z", "Manufacture of fasteners and screws", Category.SUBCLASS),
        Classification(
            "25.99", "Manufacture of other fabricated metal products not elsewhere classified", Category.CLASS
        ),
        Classification(
            "25.99.Z", "Manufacture of other fabricated metal products not elsewhere classified", Category.SUBCLASS
        ),
        Classification("26", "MANUFACTURE OF COMPUTER, ELECTRONIC AND OPTICAL PRODUCTS", Category.DIVISION),
        Classification("26.1", "Manufacture of electronic components and printed circuits", Category.GROUP),
        Classification("26.11", "Manufacture of electronic components", Category.CLASS),
        Classification("26.11.Z", "Manufacture of electronic components", Category.SUBCLASS),
        Classification("26.12", "Manufacture of electronic printed circuits", Category.CLASS),
        Classification("26.12.Z", "Manufacture of electronic printed circuits", Category.SUBCLASS),
        Classification("26.2", "Manufacture of computers and peripheral equipment", Category.GROUP),
        Classification("26.20", "Manufacture of computers and peripheral equipment", Category.CLASS),
        Classification("26.20.Z", "Manufacture of computers and peripheral equipment", Category.SUBCLASS),
        Classification("26.3", "Manufacture of (tele)communication equipment", Category.GROUP),
        Classification("26.30", "Manufacture of (tele)communication equipment", Category.CLASS),
        Classification("26.30.Z", "Manufacture of (tele)communication equipment", Category.SUBCLASS),
        Classification("26.4", "Manufacture of consumer electronics", Category.GROUP),
        Classification("26.40", "Manufacture of consumer electronics", Category.CLASS),
        Classification("26.40.Z", "Manufacture of consumer electronics", Category.SUBCLASS),
        Classification(
            "26.5",
            "Manufacture of instruments and appliances for measuring, testing and navigation; watches and clocks",
            Category.GROUP,
        ),
        Classification(
            "26.51", "Manufacture of instruments and appliances for measuring, testing and navigation", Category.CLASS
        ),
        Classification(
            "26.51.Z",
            "Manufacture of instruments and appliances for measuring, testing and navigation",
            Category.SUBCLASS,
        ),
        Classification("26.52", "Manufacture of watches and clocks", Category.CLASS),
        Classification("26.52.Z", "Manufacture of watches and clocks", Category.SUBCLASS),
        Classification(
            "26.6", "Manufacture of irradiation, electromedical and electrotherapeutic equipment", Category.GROUP
        ),
        Classification(
            "26.60", "Manufacture of irradiation, electromedical and electrotherapeutic equipment", Category.CLASS
        ),
        Classification(
            "26.60.Z", "Manufacture of irradiation, electromedical and electrotherapeutic equipment", Category.SUBCLASS
        ),
        Classification("26.7", "Manufacture of optical instruments and photographic equipment", Category.GROUP),
        Classification("26.70", "Manufacture of optical instruments and photographic equipment", Category.CLASS),
        Classification("26.70.Z", "Manufacture of optical instruments and photographic equipment", Category.SUBCLASS),
        Classification("26.8", "Manufacture of unrecorded magnetic and optical media", Category.GROUP),
        Classification("26.80", "Manufacture of unrecorded magnetic and optical media", Category.CLASS),
        Classification("26.80.Z", "Manufacture of unrecorded magnetic and optical media", Category.SUBCLASS),
        Classification("27", "MANUFACTURE OF ELECTRICAL EQUIPMENT", Category.DIVISION),
        Classification(
            "27.1",
            "Manufacture of electric motors, generators, transformers and electricity distribution and control apparatus",
            Category.GROUP,
        ),
        Classification("27.11", "Manufacture of electric motors, generators and transformers", Category.CLASS),
        Classification("27.11.Z", "Manufacture of electric motors, generators and transformers", Category.SUBCLASS),
        Classification("27.12", "Manufacture of electricity distribution and control apparatus", Category.CLASS),
        Classification("27.12.Z", "Manufacture of electricity distribution and control apparatus", Category.SUBCLASS),
        Classification("27.2", "Manufacture of batteries and accumulators", Category.GROUP),
        Classification("27.20", "Manufacture of batteries and accumulators", Category.CLASS),
        Classification("27.20.Z", "Manufacture of batteries and accumulators", Category.SUBCLASS),
        Classification("27.3", "Manufacture of insulated wiring and installing equipment", Category.GROUP),
        Classification("27.31", "Manufacture of fibre optic cables", Category.CLASS),
        Classification("27.31.Z", "Manufacture of fibre optic cables", Category.SUBCLASS),
        Classification("27.32", "Manufacture of other electronic and electric wires and cables", Category.CLASS),
        Classification("27.32.Z", "Manufacture of other electronic and electric wires and cables", Category.SUBCLASS),
        Classification("27.33", "Manufacture of installing equipment", Category.CLASS),
        Classification("27.33.Z", "Manufacture of installing equipment", Category.SUBCLASS),
        Classification("27.4", "Manufacture of electric lighting equipment", Category.GROUP),
        Classification("27.40", "Manufacture of electric lighting equipment", Category.CLASS),
        Classification("27.40.Z", "Manufacture of electric lighting equipment", Category.SUBCLASS),
        Classification("27.5", "Manufacture of domestic appliances", Category.GROUP),
        Classification("27.51", "Manufacture of electric domestic appliances", Category.CLASS),
        Classification("27.51.Z", "Manufacture of electric domestic appliances", Category.SUBCLASS),
        Classification("27.52", "Manufacture of non-electric domestic appliances", Category.CLASS),
        Classification("27.52.Z", "Manufacture of non-electric domestic appliances", Category.SUBCLASS),
        Classification("27.9", "Manufacture of other electrical equipment", Category.GROUP),
        Classification("27.90", "Manufacture of other electrical equipment", Category.CLASS),
        Classification("27.90.Z", "Manufacture of other electrical equipment", Category.SUBCLASS),
        Classification("28", "MANUFACTURE OF MACHINERY AND EQUIPMENT NOT ELSEWHERE CLASSIFIED", Category.DIVISION),
        Classification("28.1", "Manufacture of general-purpose machinery", Category.GROUP),
        Classification(
            "28.11", "Manufacture of engines and turbines, except aircraft, vehicle and cycle engines", Category.CLASS
        ),
        Classification(
            "28.11.Z",
            "Manufacture of engines and turbines, except aircraft, vehicle and cycle engines",
            Category.SUBCLASS,
        ),
        Classification("28.12", "Manufacture of fluid power equipment", Category.CLASS),
        Classification("28.12.Z", "Manufacture of fluid power equipment", Category.SUBCLASS),
        Classification("28.13", "Manufacture of other pumps and compressors", Category.CLASS),
        Classification("28.13.Z", "Manufacture of other pumps and compressors", Category.SUBCLASS),
        Classification("28.14", "Manufacture of other taps and valves", Category.CLASS),
        Classification("28.14.Z", "Manufacture of other taps and valves", Category.SUBCLASS),
        Classification("28.15", "Manufacture of bearings, gears, gearing and driving elements", Category.CLASS),
        Classification("28.15.Z", "Manufacture of bearings, gears, gearing and driving elements", Category.SUBCLASS),
        Classification("28.2", "Manufacture of other general-purpose machinery", Category.GROUP),
        Classification("28.21", "Manufacture of ovens, furnaces and furnace burners", Category.CLASS),
        Classification("28.21.Z", "Manufacture of ovens, furnaces and furnace burners", Category.SUBCLASS),
        Classification("28.22", "Manufacture of lifting equipment and gripping devices ", Category.CLASS),
        Classification("28.22.Z", "Manufacture of lifting equipment and gripping devices ", Category.SUBCLASS),
        Classification(
            "28.23",
            "Manufacture of office machinery and equipment, except computers and peripheral equipment",
            Category.CLASS,
        ),
        Classification(
            "28.23.Z",
            "Manufacture of office machinery and equipment, except computers and peripheral equipment",
            Category.SUBCLASS,
        ),
        Classification("28.24", "Manufacture of power-driven hand tools", Category.CLASS),
        Classification("28.24.Z", "Manufacture of power-driven hand tools", Category.SUBCLASS),
        Classification("28.25", "Manufacture of industrial cooling and ventilation equipment", Category.CLASS),
        Classification("28.25.Z", "Manufacture of industrial cooling and ventilation equipment", Category.SUBCLASS),
        Classification(
            "28.29", "Manufacture of other general-purpose machinery not elsewhere classified", Category.CLASS
        ),
        Classification(
            "28.29.Z", "Manufacture of other general-purpose machinery not elsewhere classified", Category.SUBCLASS
        ),
        Classification("28.3", "Manufacture of agricultural and forestry machinery", Category.GROUP),
        Classification("28.30", "Manufacture of agricultural and forestry machinery", Category.CLASS),
        Classification("28.30.Z", "Manufacture of agricultural and forestry machinery", Category.SUBCLASS),
        Classification("28.4", "Manufacture of machines and mechanical tools", Category.GROUP),
        Classification("28.41", "Manufacture of metal forming machinery", Category.CLASS),
        Classification("28.41.Z", "Manufacture of metal forming machinery", Category.SUBCLASS),
        Classification("28.49", "Manufacture of other mechanical tools", Category.CLASS),
        Classification("28.49.Z", "Manufacture of other mechanical tools", Category.SUBCLASS),
        Classification("28.9", "Manufacture of other special-purpose machinery", Category.GROUP),
        Classification("28.91", "Manufacture of machinery for metallurgy", Category.CLASS),
        Classification("28.91.Z", "Manufacture of machinery for metallurgy", Category.SUBCLASS),
        Classification("28.92", "Manufacture of machinery for mining, quarrying and construction", Category.CLASS),
        Classification("28.92.Z", "Manufacture of machinery for mining, quarrying and construction", Category.SUBCLASS),
        Classification("28.93", "Manufacture of machinery for food, beverage and tobacco processing", Category.CLASS),
        Classification(
            "28.93.Z", "Manufacture of machinery for food, beverage and tobacco processing", Category.SUBCLASS
        ),
        Classification("28.94", "Manufacture of machinery for textile, apparel and leather production", Category.CLASS),
        Classification(
            "28.94.Z", "Manufacture of machinery for textile, apparel and leather production", Category.SUBCLASS
        ),
        Classification("28.95", "Manufacture of machinery for paper and paperboard production", Category.CLASS),
        Classification("28.95.Z", "Manufacture of machinery for paper and paperboard production", Category.SUBCLASS),
        Classification(
            "28.96",
            "Manufacture of machinery for working rubber or plastics and for manufacture of the articles from these materials",
            Category.CLASS,
        ),
        Classification(
            "28.96.Z",
            "Manufacture of machinery for working rubber or plastics and for manufacture of the articles from these materials",
            Category.SUBCLASS,
        ),
        Classification(
            "28.99", "Manufacture of other special-purpose machinery not elsewhere classified ", Category.CLASS
        ),
        Classification(
            "28.99.Z", "Manufacture of other special-purpose machinery not elsewhere classified ", Category.SUBCLASS
        ),
        Classification(
            "29", "MANUFACTURE OF MOTOR VEHICLES, TRAILERS AND SEMI-TRAILERS EXCLUDING   MOTORCYCLES", Category.DIVISION
        ),
        Classification("29.1", "Manufacture of motor vehicles excluding motorcycles", Category.GROUP),
        Classification("29.10", "Manufacture of motor vehicles excluding motorcycles", Category.CLASS),
        Classification(
            "29.10.A",
            "Manufacture of engines for motor vehicles (excluding motorcycles) and for agricultural tractors",
            Category.SUBCLASS,
        ),
        Classification("29.10.B", "Manufacture of  cars", Category.SUBCLASS),
        Classification("29.10.C", "Manufacture of buses", Category.SUBCLASS),
        Classification("29.10.D", "Manufacture of motor vehicles for the transport of goods", Category.SUBCLASS),
        Classification("29.10.E", "Manufacture of other motor vehicles excluding motorcycles", Category.SUBCLASS),
        Classification(
            "29.2",
            "Manufacture of bodies (coachwork) for motor vehicles; manufacture of trailers and semi-trailers",
            Category.GROUP,
        ),
        Classification(
            "29.20",
            "Manufacture of bodies (coachwork) for motor vehicles; manufacture of trailers and semi-trailers",
            Category.CLASS,
        ),
        Classification(
            "29.20.Z",
            "Manufacture of bodies (coachwork) for motor vehicles; manufacture of trailers and semi-trailers",
            Category.SUBCLASS,
        ),
        Classification("29.3", "Manufacture of parts and accessories for motor vehicles", Category.GROUP),
        Classification(
            "29.31", "Manufacture of electrical and electronic equipment for motor vehicles", Category.CLASS
        ),
        Classification(
            "29.31.Z", "Manufacture of electrical and electronic equipment for motor vehicles", Category.SUBCLASS
        ),
        Classification(
            "29.32",
            "Manufacture of other parts and accessories for motor vehicles excluding motorcycles",
            Category.CLASS,
        ),
        Classification(
            "29.32.Z",
            "Manufacture of other parts and accessories for motor vehicles excluding motorcycles",
            Category.SUBCLASS,
        ),
        Classification("30", "MANUFACTURE OF OTHER TRANSPORT EQUIPMENT", Category.DIVISION),
        Classification("30.1", "Building of ships and boats", Category.GROUP),
        Classification("30.11", "Building of ships and floating structures", Category.CLASS),
        Classification("30.11.Z", "Building of ships and floating structures", Category.SUBCLASS),
        Classification("30.12", "Building of pleasure and sporting boats", Category.CLASS),
        Classification("30.12.Z", "Building of pleasure and sporting boats", Category.SUBCLASS),
        Classification("30.2", "Manufacture of railway locomotives and rolling stock", Category.GROUP),
        Classification("30.20", "Manufacture of railway locomotives and rolling stock", Category.CLASS),
        Classification("30.20.Z", "Manufacture of railway locomotives and rolling stock", Category.SUBCLASS),
        Classification("30.3", "Manufacture of air and spacecraft and related machinery", Category.GROUP),
        Classification("30.30", "Manufacture of air and spacecraft and related machinery", Category.CLASS),
        Classification("30.30.Z", "Manufacture of air and spacecraft and related machinery", Category.SUBCLASS),
        Classification("30.4", "Manufacture of military fighting vehicles", Category.GROUP),
        Classification("30.40", "Manufacture of military fighting vehicles", Category.CLASS),
        Classification("30.40.Z", "Manufacture of military fighting vehicles", Category.SUBCLASS),
        Classification("30.9", "Manufacture of transport equipment not elsewhere classified", Category.GROUP),
        Classification("30.91", "Manufacture of motorcycles", Category.CLASS),
        Classification("30.91.Z", "Manufacture of motorcycles", Category.SUBCLASS),
        Classification("30.92", "Manufacture of bicycles and invalid carriages", Category.CLASS),
        Classification("30.92.Z", "Manufacture of bicycles and invalid carriages", Category.SUBCLASS),
        Classification("30.99", "Manufacture of other transport equipment not elsewhere classified", Category.CLASS),
        Classification(
            "30.99.Z", "Manufacture of other transport equipment not elsewhere classified", Category.SUBCLASS
        ),
        Classification("31", "MANUFACTURE OF FURNITURE", Category.DIVISION),
        Classification("31.0", "MANUFACTURE OF FURNITURE", Category.GROUP),
        Classification("31.01", "Manufacture of office and shop furniture", Category.CLASS),
        Classification("31.01.Z", "Manufacture of office and shop furniture", Category.SUBCLASS),
        Classification("31.02", "Manufacture of kitchen furniture", Category.CLASS),
        Classification("31.02.Z", "Manufacture of kitchen furniture", Category.SUBCLASS),
        Classification("31.03", "Manufacture of mattresses", Category.CLASS),
        Classification("31.03.Z", "Manufacture of mattresses", Category.SUBCLASS),
        Classification("31.09", "Manufacture of other furniture", Category.CLASS),
        Classification("31.09.Z", "Manufacture of other furniture", Category.SUBCLASS),
        Classification("32", "OTHER MANUFACTURING", Category.DIVISION),
        Classification("32.1", "Manufacture of jewellery, bijouterie and related articles", Category.GROUP),
        Classification("32.11", "Striking of coins", Category.CLASS),
        Classification("32.11.Z", "Striking of coins", Category.SUBCLASS),
        Classification("32.12", "Manufacture of jewellery and related articles", Category.CLASS),
        Classification("32.12.Z", "Manufacture of jewellery and related articles", Category.SUBCLASS),
        Classification("32.13", "Manufacture of imitation jewellery and related articles", Category.CLASS),
        Classification("32.13.Z", "Manufacture of imitation jewellery and related articles", Category.SUBCLASS),
        Classification("32.2", "Manufacture of musical instruments", Category.GROUP),
        Classification("32.20", "Manufacture of musical instruments", Category.CLASS),
        Classification("32.20.Z", "Manufacture of musical instruments", Category.SUBCLASS),
        Classification("32.3", "Manufacture of sports goods", Category.GROUP),
        Classification("32.30", "Manufacture of sports goods", Category.CLASS),
        Classification("32.30.Z", "Manufacture of sports goods", Category.SUBCLASS),
        Classification("32.4", "Manufacture of games and toys", Category.GROUP),
        Classification("32.40", "Manufacture of games and toys", Category.CLASS),
        Classification("32.40.Z", "Manufacture of games and toys", Category.SUBCLASS),
        Classification("32.5", "Manufacture of medical and dental instruments and supplies", Category.GROUP),
        Classification("32.50", "Manufacture of medical and dental instruments and supplies", Category.CLASS),
        Classification("32.50.Z", "Manufacture of medical and dental instruments and supplies", Category.SUBCLASS),
        Classification("32.9", "Manufacturing not elsewhere classified ", Category.GROUP),
        Classification("32.91", "Manufacture of brooms and brushes", Category.CLASS),
        Classification("32.91.Z", "Manufacture of brooms and brushes", Category.SUBCLASS),
        Classification("32.99", "Other manufacturing not elsewhere classified", Category.CLASS),
        Classification("32.99.Z", "Other manufacturing not elsewhere classified", Category.SUBCLASS),
        Classification("33", "REPAIR, MAINTENANCE AND INSTALLATION OF MACHINERY AND EQUIPMENT", Category.DIVISION),
        Classification(
            "33.1", "Repair and maintenance of fabricated metal products, machinery and equipment", Category.GROUP
        ),
        Classification("33.11", "Repair and maintenance of fabricated metal products", Category.CLASS),
        Classification("33.11.Z", "Repair and maintenance of fabricated metal products", Category.SUBCLASS),
        Classification("33.12", "Repair and maintenance of machinery", Category.CLASS),
        Classification("33.12.Z", "Repair and maintenance of machinery", Category.SUBCLASS),
        Classification("33.13", "Repair and maintenance of electronic and optical equipment", Category.CLASS),
        Classification("33.13.Z", "Repair and maintenance of electronic and optical equipment", Category.SUBCLASS),
        Classification("33.14", "Repair and maintenance of electrical equipment", Category.CLASS),
        Classification("33.14.Z", "Repair and maintenance of electrical equipment", Category.SUBCLASS),
        Classification("33.15", "Repair and maintenance of ships and boats", Category.CLASS),
        Classification("33.15.Z", "Repair and maintenance of ships and boats", Category.SUBCLASS),
        Classification("33.16", "Repair and maintenance of aircraft and spacecraft", Category.CLASS),
        Classification("33.16.Z", "Repair and maintenance of aircraft and spacecraft", Category.SUBCLASS),
        Classification("33.17", "Repair and maintenance of other transport equipment", Category.CLASS),
        Classification("33.17.Z", "Repair and maintenance of other transport equipment", Category.SUBCLASS),
        Classification("33.19", "Repair and maintenance of other equipment ", Category.CLASS),
        Classification("33.19.Z", "Repair and maintenance of other equipment ", Category.SUBCLASS),
        Classification("33.2", "Installation of industrial machinery and equipment", Category.GROUP),
        Classification("33.20", "Installation of industrial machinery and equipment", Category.CLASS),
        Classification("33.20.Z", "Installation of industrial machinery and equipment and outfit", Category.SUBCLASS),
        Classification(
            "D", "ELECTRICITY, GAS, STEAM, HOT WATER AND AIR CONDITIONING MANUFACTURING AND   SUPPLY", Category.SECTION
        ),
        Classification(
            "35",
            "ELECTRICITY, GAS, STEAM, HOT WATER AND AIR CONDITIONING MANUFACTURING AND   SUPPLY",
            Category.DIVISION,
        ),
        Classification("35.1", "Electric power generation, transmission and distribution", Category.GROUP),
        Classification("35.11", "Production of electricity", Category.CLASS),
        Classification("35.11.Z", "Production of electricity", Category.SUBCLASS),
        Classification("35.12", "Transmission of electricity", Category.CLASS),
        Classification("35.12.Z", "Transmission of electricity", Category.SUBCLASS),
        Classification("35.13", "Distribution of electricity", Category.CLASS),
        Classification("35.13.Z", "Distribution of electricity", Category.SUBCLASS),
        Classification("35.14", "Trade of electricity", Category.CLASS),
        Classification("35.14.Z", "Trade of electricity", Category.SUBCLASS),
        Classification(
            "35.2",
            "Manufacture of gaseous fuels; distribution and trade of gaseous fuels through mains",
            Category.GROUP,
        ),
        Classification("35.21", "Manufacture of gaseous fuels", Category.CLASS),
        Classification("35.21.Z", "Manufacture of gaseous fuels", Category.SUBCLASS),
        Classification("35.22", "Distribution of gaseous fuels through mains", Category.CLASS),
        Classification("35.22.Z", "Distribution of gaseous fuels through mains", Category.SUBCLASS),
        Classification("35.23", "Trade of gaseous fuels through mains", Category.CLASS),
        Classification("35.23.Z", "Trade of gaseous fuels through mains", Category.SUBCLASS),
        Classification("35.3", "Steam, hot water and air conditioning manufacturing and supply", Category.GROUP),
        Classification("35.30", "Steam, hot water and air conditioning manufacturing and supply", Category.CLASS),
        Classification("35.30.Z", "Steam, hot water and air conditioning manufacturing and supply", Category.SUBCLASS),
        Classification("E", "WATER SUPPLY; SEWERAGE, WASTE MANAGEMENT AND REMEDIATION ACTIVITIES", Category.SECTION),
        Classification("36", "WATER COLLECTION, TREATMENT AND SUPPLY", Category.DIVISION),
        Classification("36.0", "Water collection, treatment and supply", Category.GROUP),
        Classification("36.00", "Water collection, treatment and supply", Category.CLASS),
        Classification("36.00.Z", "Water collection, treatment and supply", Category.SUBCLASS),
        Classification("37", "SEWAGE DISPOSAL AND TREATMENT", Category.DIVISION),
        Classification("37.0", "Sewage disposal and treatment", Category.GROUP),
        Classification("37.00", "Sewage disposal and treatment", Category.CLASS),
        Classification("37.00.Z", "Sewage disposal and treatment", Category.SUBCLASS),
        Classification(
            "38", "WASTE COLLECTION, PROCESSING AND NEUTRALIZING ACTIVITIES; MATERIALS RECOVERY", Category.DIVISION
        ),
        Classification("38.1", "Waste collection", Category.GROUP),
        Classification("38.11", "Collection of non-hazardous waste", Category.CLASS),
        Classification("38.11.Z", "Collection of non-hazardous waste", Category.SUBCLASS),
        Classification("38.12", "Collection of hazardous waste", Category.CLASS),
        Classification("38.12.Z", "Collection of hazardous waste", Category.SUBCLASS),
        Classification("38.2", "Waste processing and neutralizing ", Category.GROUP),
        Classification("38.21", "Treatment and disposal of non-hazardous waste", Category.CLASS),
        Classification("38.21.Z", "Treatment and disposal of non-hazardous waste", Category.SUBCLASS),
        Classification("38.22", "Hazardous waste processing and neutralizing", Category.CLASS),
        Classification("38.22.Z", "Hazardous waste processing and neutralizing", Category.SUBCLASS),
        Classification("38.3", "Materials recovery", Category.GROUP),
        Classification("38.31", "Dismantling of wrecks", Category.CLASS),
        Classification("38.31.Z", "Dismantling of wrecks", Category.SUBCLASS),
        Classification("38.32", "Recovery of sorted materials", Category.CLASS),
        Classification("38.32.Z", "Recovery of sorted materials", Category.SUBCLASS),
        Classification("39", "REMEDIATION ACTIVITIES AND OTHER WASTE MANAGEMENT SERVICES", Category.DIVISION),
        Classification("39.0", "Remediation activities and other waste management services", Category.GROUP),
        Classification("39.00", "Remediation activities and other waste management services", Category.CLASS),
        Classification("39.00.Z", "Remediation activities and other waste management services", Category.SUBCLASS),
        Classification("F", "CONSTRUCTION", Category.SECTION),
        Classification("41", "Construction of buildings", Category.DIVISION),
        Classification("41.1", "Realization of building projects related to erection of buildings", Category.GROUP),
        Classification("41.10", "Realization of building projects related to erection of buildings", Category.CLASS),
        Classification(
            "41.10.Z", "Realization of building projects related to erection of buildings", Category.SUBCLASS
        ),
        Classification(
            "41.2", "Building works related to erection of residential and non-residential buildings", Category.GROUP
        ),
        Classification(
            "41.20", "Building works related to erection of residential and non-residential buildings", Category.CLASS
        ),
        Classification(
            "41.20.Z",
            "Building works related to erection of residential and non-residential buildings",
            Category.SUBCLASS,
        ),
        Classification("42", "WORKS RELATED TO CONSTRUCTION OF CIVIL ENGINEERING", Category.DIVISION),
        Classification("42.1", "Works related to construction of roads and railways", Category.GROUP),
        Classification("42.11", "Works related to construction of roads and motorways", Category.CLASS),
        Classification("42.11.Z", "Works related to construction of roads and motorways", Category.SUBCLASS),
        Classification("42.12", "Works related to construction of railways and underground railways", Category.CLASS),
        Classification(
            "42.12.Z", "Works related to construction of railways and underground railways", Category.SUBCLASS
        ),
        Classification("42.13", "Works related to construction of bridges and tunnels", Category.CLASS),
        Classification("42.13.Z", "Works related to construction of bridges and tunnels", Category.SUBCLASS),
        Classification(
            "42.2",
            "Works related to construction of pipelines, telecommunications and electricity lines",
            Category.GROUP,
        ),
        Classification(
            "42.21", "Works related to construction of transmit pipelines and distribution networs", Category.CLASS
        ),
        Classification(
            "42.21.Z",
            "Works related to construction of transmission pipelines and distribution networks",
            Category.SUBCLASS,
        ),
        Classification(
            "42.22", "Works related to construction of telecommunications and electricity lines", Category.CLASS
        ),
        Classification(
            "42.22.Z", "Works related to construction of telecommunications and electricity lines", Category.SUBCLASS
        ),
        Classification("42.9", "Works related to construction of other civil engineering projects", Category.GROUP),
        Classification("42.91", "Works related to construction of water projects", Category.CLASS),
        Classification("42.91.Z", "Works related to construction of water projects", Category.SUBCLASS),
        Classification(
            "42.99",
            "Works related to construction of other civil engineering projects not elsewhere classified",
            Category.CLASS,
        ),
        Classification(
            "42.99.Z",
            "Works related to construction of other civil engineering projects not elsewhere classified",
            Category.SUBCLASS,
        ),
        Classification("43", "SPECIALISED CONSTRUCTION ACTIVITIES", Category.DIVISION),
        Classification("43.1", "Demolition and site preparation", Category.GROUP),
        Classification("43.11", "Demolition", Category.CLASS),
        Classification("43.11.Z", "Demolition", Category.SUBCLASS),
        Classification("43.12", "Site preparation", Category.CLASS),
        Classification("43.12.Z", "Site preparation", Category.SUBCLASS),
        Classification("43.13", "Test drilling and boring", Category.CLASS),
        Classification("43.13.Z", "Test drilling and boring", Category.SUBCLASS),
        Classification("43.2", "Electrical, plumbing and other construction installation activities", Category.GROUP),
        Classification("43.21", "Electrical installation", Category.CLASS),
        Classification("43.21.Z", "Electrical installation", Category.SUBCLASS),
        Classification("43.22", "Plumbing, heat and air-conditioning installation", Category.CLASS),
        Classification("43.22.Z", "Plumbing, heat and air-conditioning installation", Category.SUBCLASS),
        Classification("43.29", "Other construction installation", Category.CLASS),
        Classification("43.29.Z", "Other construction installation", Category.SUBCLASS),
        Classification("43.3", "Building completion and finishing", Category.GROUP),
        Classification("43.31", "Plastering", Category.CLASS),
        Classification("43.31.Z", "Plastering", Category.SUBCLASS),
        Classification("43.32", "Joinery installation", Category.CLASS),
        Classification("43.32.Z", "Joinery installation", Category.SUBCLASS),
        Classification("43.33", "Floor and wall covering", Category.CLASS),
        Classification("43.33.Z", "Floor and wall covering", Category.SUBCLASS),
        Classification("43.34", "Painting and glazing", Category.CLASS),
        Classification("43.34.Z", "Painting and glazing", Category.SUBCLASS),
        Classification("43.39", "Other building completion and finishing", Category.CLASS),
        Classification("43.39.Z", "Other building completion and finishing", Category.SUBCLASS),
        Classification("43.9", "Other specialised construction activities", Category.GROUP),
        Classification("43.91", "Roofing activities", Category.CLASS),
        Classification("43.91.Z", "Roofing activities", Category.SUBCLASS),
        Classification("43.99", "Other specialised construction activities not elsewhere classified", Category.CLASS),
        Classification(
            "43.99.Z", "Other specialised construction activities not elsewhere classified", Category.SUBCLASS
        ),
        Classification(
            "G", "WHOLESALE AND RETAIL TRADE; REPAIR OF MOTOR VEHICLES INCLUDING MOTORCYCLES", Category.SECTION
        ),
        Classification(
            "45", "WHOLESALE AND RETAIL TRADE OF MOTOR VEHICLES; REPAIR OF MOTOR VEHICLES ", Category.DIVISION
        ),
        Classification("45.1", "Sale of motor vehicles, excluding motorcycles", Category.GROUP),
        Classification("45.11", "Sale of cars and light motor vehicles", Category.CLASS),
        Classification("45.11.Z", "Sale of cars and light motor vehicles", Category.SUBCLASS),
        Classification("45.19", "Sale of other motor vehicles, excluding motorcycles", Category.CLASS),
        Classification("45.19.Z", "Sale of other motor vehicles, excluding motorcycles", Category.SUBCLASS),
        Classification("45.2", "Maintenance and repair of motor vehicles, excluding motorcycles", Category.GROUP),
        Classification("45.20", "Maintenance and repair of motor vehicles, excluding motorcycles", Category.CLASS),
        Classification("45.20.Z", "Maintenance and repair of motor vehicles, excluding motorcycles", Category.SUBCLASS),
        Classification("45.3", "Sale of motor vehicle parts and accessories, excluding motorcycles", Category.GROUP),
        Classification(
            "45.31", "Wholesale trade of motor vehicle parts and accessories, excluding motorcycles", Category.CLASS
        ),
        Classification(
            "45.31.Z",
            "Wholesale trade of motor vehicle parts and accessories, excluding motorcycles",
            Category.SUBCLASS,
        ),
        Classification(
            "45.32", "Retail trade of motor vehicle parts and accessories, excluding motorcycles", Category.CLASS
        ),
        Classification(
            "45.32.Z", "Retail trade of motor vehicle parts and accessories, excluding motorcycles", Category.SUBCLASS
        ),
        Classification(
            "45.4", "Sale, maintenance and repair of motorcycles and related parts and accessories", Category.GROUP
        ),
        Classification(
            "45.40", "Sale, maintenance and repair of motorcycles and related parts and accessories", Category.CLASS
        ),
        Classification(
            "45.40.Z",
            "Sale, maintenance and repair of motorcycles and related parts and accessories",
            Category.SUBCLASS,
        ),
        Classification("46", "WHOLESALE TRADE, EXCLUDING MOTOR VEHICLES ", Category.DIVISION),
        Classification("46.1", "Wholesale on a fee or contract basis", Category.GROUP),
        Classification(
            "46.11",
            "Agents involved in the sale of agricultural raw materials, live animals, textile raw materials and semi-finished goods",
            Category.CLASS,
        ),
        Classification(
            "46.11.Z",
            "Agents involved in the sale of agricultural raw materials, live animals, textile raw materials and semi-finished goods",
            Category.SUBCLASS,
        ),
        Classification(
            "46.12", "Agents involved in the sale of fuels, ores, metals and industrial chemicals", Category.CLASS
        ),
        Classification(
            "46.12.Z", "Agents involved in the sale of fuels, ores, metals and industrial chemicals", Category.SUBCLASS
        ),
        Classification("46.13", "Agents involved in the sale of timber and building materials", Category.CLASS),
        Classification("46.13.Z", "Agents involved in the sale of timber and building materials", Category.SUBCLASS),
        Classification(
            "46.14",
            "Agents involved in the sale of machinery, industrial equipment, ships and aircraft",
            Category.CLASS,
        ),
        Classification(
            "46.14.Z",
            "Agents involved in the sale of machinery, industrial equipment, ships and aircraft",
            Category.SUBCLASS,
        ),
        Classification(
            "46.15",
            "Agents involved in the sale of furniture, household goods, hardware and ironmongery",
            Category.CLASS,
        ),
        Classification(
            "46.15.Z",
            "Agents involved in the sale of furniture, household goods, hardware and ironmongery",
            Category.SUBCLASS,
        ),
        Classification(
            "46.16",
            "Agents involved in the sale of textiles, clothing, fur, footwear and leather goods",
            Category.CLASS,
        ),
        Classification(
            "46.16.Z",
            "Agents involved in the sale of textiles, clothing, fur, footwear and leather goods",
            Category.SUBCLASS,
        ),
        Classification("46.17", "Agents involved in the sale of food, beverages and tobacco", Category.CLASS),
        Classification("46.17.Z", "Agents involved in the sale of food, beverages and tobacco", Category.SUBCLASS),
        Classification("46.18", "Agents specialised in the sale of other particular products", Category.CLASS),
        Classification("46.18.Z", "Agents specialised in the sale of other particular products", Category.SUBCLASS),
        Classification("46.19", "Agents involved in the sale of a variety of goods", Category.CLASS),
        Classification("46.19.Z", "Agents involved in the sale of a variety of goods", Category.SUBCLASS),
        Classification("46.2", "Wholesale of agricultural raw materials and live animals", Category.GROUP),
        Classification("46.21", "Wholesale of grain, unmanufactured tobacco, seeds and animal feeds", Category.CLASS),
        Classification(
            "46.21.Z", "Wholesale of grain, unmanufactured tobacco, seeds and animal feeds", Category.SUBCLASS
        ),
        Classification("46.22", "Wholesale of flowers and plants", Category.CLASS),
        Classification("46.22.Z", "Wholesale of flowers and plants", Category.SUBCLASS),
        Classification("46.23", "Wholesale of live animals", Category.CLASS),
        Classification("46.23.Z", "Wholesale of live animals", Category.SUBCLASS),
        Classification("46.24", "Wholesale of hides, skins and leather", Category.CLASS),
        Classification("46.24.Z", "Wholesale of hides, skins and leather", Category.SUBCLASS),
        Classification("46.3", "Wholesale of food, beverages and tobacco", Category.GROUP),
        Classification("46.31", "Wholesale of fruit and vegetables", Category.CLASS),
        Classification("46.31.Z", "Wholesale of fruit and vegetables", Category.SUBCLASS),
        Classification("46.32", "Wholesale of meat and meat products", Category.CLASS),
        Classification("46.32.Z", "Wholesale of meat and meat products", Category.SUBCLASS),
        Classification("46.33", "Wholesale of dairy products, eggs and edible oils and fats", Category.CLASS),
        Classification("46.33.Z", "Wholesale of dairy products, eggs and edible oils and fats", Category.SUBCLASS),
        Classification("46.34", "Wholesale of beverages", Category.CLASS),
        Classification("46.34.A", "Wholesale of alcoholic beverages", Category.SUBCLASS),
        Classification("46.34.B", "Wholesale of non-alcoholic beverages", Category.SUBCLASS),
        Classification("46.35", "Wholesale of tobacco products", Category.CLASS),
        Classification("46.35.Z", "Wholesale of tobacco products", Category.SUBCLASS),
        Classification("46.36", "Wholesale of sugar and chocolate and sugar confectionery", Category.CLASS),
        Classification("46.36.Z", "Wholesale of sugar and chocolate and sugar confectionery", Category.SUBCLASS),
        Classification("46.37", "Wholesale of coffee, tea, cocoa and spices", Category.CLASS),
        Classification("46.37.Z", "Wholesale of coffee, tea, cocoa and spices", Category.SUBCLASS),
        Classification("46.38", "Wholesale of other food, including fish, crustaceans and molluscs", Category.CLASS),
        Classification(
            "46.38.Z", "Wholesale of other food, including fish, crustaceans and molluscs", Category.SUBCLASS
        ),
        Classification("46.39", "Non-specialised wholesale of food, beverages and tobacco", Category.CLASS),
        Classification("46.39.Z", "Non-specialised wholesale of food, beverages and tobacco", Category.SUBCLASS),
        Classification("46.4", "Wholesale of household goods", Category.GROUP),
        Classification("46.41", "Wholesale of textiles", Category.CLASS),
        Classification("46.41.Z", "Wholesale of textiles", Category.SUBCLASS),
        Classification("46.42", "Wholesale of clothing and footwear", Category.CLASS),
        Classification("46.42.Z", "Wholesale of clothing and footwear", Category.SUBCLASS),
        Classification("46.43", "Wholesale of electrical household appliances", Category.CLASS),
        Classification("46.43.Z", "Wholesale of electrical household appliances", Category.SUBCLASS),
        Classification("46.44", "Wholesale of china, ceramics and glassware and cleaning materials", Category.CLASS),
        Classification(
            "46.44.Z", "Wholesale of china, ceramics and glassware and cleaning materials", Category.SUBCLASS
        ),
        Classification("46.45", "Wholesale of perfume and cosmetics", Category.CLASS),
        Classification("46.45.Z", "Wholesale of perfume and cosmetics", Category.SUBCLASS),
        Classification("46.46", "Wholesale of pharmaceutical goods", Category.CLASS),
        Classification("46.46.Z", "Wholesale of pharmaceutical goods", Category.SUBCLASS),
        Classification("46.47", "Wholesale of furniture, carpets and lighting equipment", Category.CLASS),
        Classification("46.47.Z", "Wholesale of furniture, carpets and lighting equipment", Category.SUBCLASS),
        Classification("46.48", "Wholesale of watches, clocks and jewellery", Category.CLASS),
        Classification("46.48.Z", "Wholesale of watches, clocks and jewellery", Category.SUBCLASS),
        Classification("46.49", "Wholesale of other household goods", Category.CLASS),
        Classification("46.49.Z", "Wholesale of other household goods", Category.SUBCLASS),
        Classification("46.5", "Wholesale of information and communication equipment", Category.GROUP),
        Classification("46.51", "Wholesale of computers, peripheral equipment and software", Category.CLASS),
        Classification("46.51.Z", "Wholesale of computers, peripheral equipment and software", Category.SUBCLASS),
        Classification(
            "46.52", "Wholesale of electronic and telecommunications equipment and parts thereof", Category.CLASS
        ),
        Classification(
            "46.52.Z", "Wholesale of electronic and telecommunications equipment and parts thereof", Category.SUBCLASS
        ),
        Classification("46.6", "Wholesale of machinery, equipment and supplies", Category.GROUP),
        Classification("46.61", "Wholesale of agricultural machinery, equipment and supplies", Category.CLASS),
        Classification("46.61.Z", "Wholesale of agricultural machinery, equipment and supplies", Category.SUBCLASS),
        Classification("46.62", "Wholesale of machine tools", Category.CLASS),
        Classification("46.62.Z", "Wholesale of machine tools", Category.SUBCLASS),
        Classification("46.63", "Wholesale of mining, construction and civil engineering machinery", Category.CLASS),
        Classification(
            "46.63.Z", "Wholesale of mining, construction and civil engineering machinery", Category.SUBCLASS
        ),
        Classification(
            "46.64",
            "Wholesale of machinery for the textile industry and of sewing and knitting machines",
            Category.CLASS,
        ),
        Classification(
            "46.64.Z",
            "Wholesale of machinery for the textile industry and of sewing and knitting machines",
            Category.SUBCLASS,
        ),
        Classification("46.65", "Wholesale of office furniture", Category.CLASS),
        Classification("46.65.Z", "Wholesale of office furniture", Category.SUBCLASS),
        Classification("46.66", "Wholesale of other office machinery and equipment", Category.CLASS),
        Classification("46.66.Z", "Wholesale of other office machinery and equipment", Category.SUBCLASS),
        Classification("46.69", "Wholesale of other machinery and equipment", Category.CLASS),
        Classification("46.69.Z", "Wholesale of other machinery and equipment", Category.SUBCLASS),
        Classification("46.7", "Other specialised wholesale", Category.GROUP),
        Classification("46.71", "Wholesale of fuels and related products", Category.CLASS),
        Classification("46.71.Z", "Wholesale of fuels and related products", Category.SUBCLASS),
        Classification("46.72", "Wholesale of metals and metal ores", Category.CLASS),
        Classification("46.72.Z", "Wholesale of metals and metal ores", Category.SUBCLASS),
        Classification("46.73", "Wholesale of wood, construction materials and sanitary equipment", Category.CLASS),
        Classification(
            "46.73.Z", "Wholesale of wood, construction materials and sanitary equipment", Category.SUBCLASS
        ),
        Classification(
            "46.74", "Wholesale of hardware and plumbing and heating equipment and supplies", Category.CLASS
        ),
        Classification(
            "46.74.Z", "Wholesale of hardware and plumbing and heating equipment and supplies", Category.SUBCLASS
        ),
        Classification("46.75", "Wholesale of chemical products", Category.CLASS),
        Classification("46.75.Z", "Wholesale of chemical products", Category.SUBCLASS),
        Classification("46.76", "Wholesale of other intermediate products", Category.CLASS),
        Classification("46.76.Z", "Wholesale of other intermediate products", Category.SUBCLASS),
        Classification("46.77", "Wholesale of waste and scrap", Category.CLASS),
        Classification("46.77.Z", "Wholesale of waste and scrap", Category.SUBCLASS),
        Classification("46.9", "Non-specialised wholesale trade", Category.GROUP),
        Classification("46.90", "Non-specialised wholesale trade", Category.CLASS),
        Classification("46.90.Z", "Non-specialised wholesale trade", Category.SUBCLASS),
        Classification("47", "RETAIL TRADE, EXCEPT RETAIL TRADE OF MOTOR VEHICLES ", Category.DIVISION),
        Classification("47.1", "Retail sale in non-specialised stores", Category.GROUP),
        Classification(
            "47.11",
            "Retail sale in non-specialised stores with food, beverages or tobacco predominating",
            Category.CLASS,
        ),
        Classification(
            "47.11.Z",
            "Retail sale in non-specialised stores with food, beverages or tobacco predominating",
            Category.SUBCLASS,
        ),
        Classification("47.19", "Other retail sale in non-specialised stores", Category.CLASS),
        Classification("47.19.Z", "Other retail sale in non-specialised stores", Category.SUBCLASS),
        Classification("47.2", "Retail sale of food, beverages and tobacco in specialised stores", Category.GROUP),
        Classification("47.21", "Retail sale of fruit and vegetables in specialised stores", Category.CLASS),
        Classification("47.21.Z", "Retail sale of fruit and vegetables in specialised stores", Category.SUBCLASS),
        Classification("47.22", "Retail sale of meat and meat products in specialised stores", Category.CLASS),
        Classification("47.22.Z", "Retail sale of meat and meat products in specialised stores", Category.SUBCLASS),
        Classification("47.23", "Retail sale of fish, crustaceans and molluscs in specialised stores", Category.CLASS),
        Classification(
            "47.23.Z", "Retail sale of fish, crustaceans and molluscs in specialised stores", Category.SUBCLASS
        ),
        Classification(
            "47.24",
            "Retail sale of bread, cakes, flour confectionery and sugar confectionery in specialised     stores",
            Category.CLASS,
        ),
        Classification(
            "47.24.Z",
            "Retail sale of bread, cakes, flour confectionery and sugar confectionery in specialised    stores",
            Category.SUBCLASS,
        ),
        Classification(
            "47.25", "Retail sale of alcoholic and non-alcoholic beverages in specialised stores", Category.CLASS
        ),
        Classification(
            "47.25.Z", "Retail sale of alcoholic and non-alcoholic beverages in specialised stores", Category.SUBCLASS
        ),
        Classification("47.26", "Retail sale of tobacco products in specialised stores", Category.CLASS),
        Classification("47.26.Z", "Retail sale of tobacco products in specialised stores", Category.SUBCLASS),
        Classification("47.29", "Other retail sale of food in specialised stores", Category.CLASS),
        Classification("47.29.Z", "Other retail sale of food in specialised stores", Category.SUBCLASS),
        Classification("47.3", "Retail sale of fuel for motor vehicles in fuel stations", Category.GROUP),
        Classification("47.30", "Retail sale of fuel for motor vehicles in fuel stations", Category.CLASS),
        Classification("47.30.Z", "Retail sale of fuel for motor vehicles in fuel stations", Category.SUBCLASS),
        Classification(
            "47.4", "Retail sale of information and communication equipment in specialised stores", Category.GROUP
        ),
        Classification(
            "47.41", "Retail sale of computers, peripheral units and software in specialised stores", Category.CLASS
        ),
        Classification(
            "47.41.Z",
            "Retail sale of computers, peripheral units and software in specialised stores",
            Category.SUBCLASS,
        ),
        Classification("47.42", "Retail sale of telecommunications equipment in specialised stores", Category.CLASS),
        Classification(
            "47.42.Z", "Retail sale of telecommunications equipment in specialised stores", Category.SUBCLASS
        ),
        Classification("47.43", "Retail sale of audio and video equipment in specialised stores", Category.CLASS),
        Classification("47.43.Z", "Retail sale of audio and video equipment in specialised stores", Category.SUBCLASS),
        Classification("47.5", "Retail sale of household equipment in specialised stores", Category.GROUP),
        Classification("47.51", "Retail sale of textiles in specialised stores", Category.CLASS),
        Classification("47.51.Z", "Retail sale of textiles in specialised stores", Category.SUBCLASS),
        Classification("47.52", "Retail sale of hardware, paints and glass in specialised stores", Category.CLASS),
        Classification("47.52.Z", "Retail sale of hardware, paints and glass in specialised stores", Category.SUBCLASS),
        Classification(
            "47.53", "Retail sale of carpets, rugs, wall and floor coverings in specialised stores", Category.CLASS
        ),
        Classification(
            "47.53.Z", "Retail sale of carpets, rugs, wall and floor coverings in specialised stores", Category.SUBCLASS
        ),
        Classification("47.54", "Retail sale of electrical household appliances in specialised stores", Category.CLASS),
        Classification(
            "47.54.Z", "Retail sale of electrical household appliances in specialised stores", Category.SUBCLASS
        ),
        Classification(
            "47.59",
            "Retail sale of furniture, lighting equipment and other household articles in specialised    stores",
            Category.CLASS,
        ),
        Classification(
            "47.59.Z",
            "Retail sale of furniture, lighting equipment and other household articles in specialised    stores",
            Category.SUBCLASS,
        ),
        Classification("47.6", "Retail sale of cultural and recreation goods in specialised stores", Category.GROUP),
        Classification("47.61", "Retail sale of books in specialised stores", Category.CLASS),
        Classification("47.61.Z", "Retail sale of books in specialised stores", Category.SUBCLASS),
        Classification("47.62", "Retail sale of newspapers and stationery in specialised stores", Category.CLASS),
        Classification("47.62.Z", "Retail sale of newspapers and stationery in specialised stores", Category.SUBCLASS),
        Classification("47.63", "Retail sale of music and video recordings in specialised stores", Category.CLASS),
        Classification("47.63.Z", "Retail sale of music and video recordings in specialised stores", Category.SUBCLASS),
        Classification("47.64", "Retail sale of sporting equipment in specialised stores", Category.CLASS),
        Classification("47.64.Z", "Retail sale of sporting equipment in specialised stores", Category.SUBCLASS),
        Classification("47.65", "Retail sale of games and toys in specialised stores", Category.CLASS),
        Classification("47.65.Z", "Retail sale of games and toys in specialised stores", Category.SUBCLASS),
        Classification("47.7", "Retail sale of other goods in specialised stores", Category.GROUP),
        Classification("47.71", "Retail sale of clothing in specialised stores", Category.CLASS),
        Classification("47.71.Z", "Retail sale of clothing in specialised stores", Category.SUBCLASS),
        Classification("47.72", "Retail sale of footwear and leather goods in specialised stores", Category.CLASS),
        Classification("47.72.Z", "Retail sale of footwear and leather goods in specialised stores", Category.SUBCLASS),
        Classification("47.73", "Dispensing chemist in specialised stores", Category.CLASS),
        Classification("47.73.Z", "Dispensing chemist in specialised stores", Category.SUBCLASS),
        Classification("47.74", "Retail sale of medical and orthopaedic goods in specialised stores", Category.CLASS),
        Classification(
            "47.74.Z", "Retail sale of medical and orthopaedic goods in specialised stores", Category.SUBCLASS
        ),
        Classification("47.75", "Retail sale of cosmetic and toilet articles in specialised stores", Category.CLASS),
        Classification(
            "47.75.Z", "Retail sale of cosmetic and toilet articles in specialised stores", Category.SUBCLASS
        ),
        Classification(
            "47.76",
            "Retail sale of flowers, plants, seeds, fertilisers, pet animals and pet food in specialised    stores",
            Category.CLASS,
        ),
        Classification(
            "47.76.Z",
            "Retail sale of flowers, plants, seeds, fertilisers, pet animals and pet food in specialised    stores",
            Category.SUBCLASS,
        ),
        Classification("47.77", "Retail sale of watches, clocks and jewellery in specialised stores", Category.CLASS),
        Classification(
            "47.77.Z", "Retail sale of watches, clocks and jewellery in specialised stores", Category.SUBCLASS
        ),
        Classification("47.78", "Other retail sale of new goods in specialised stores", Category.CLASS),
        Classification("47.78.Z", "Other retail sale of new goods in specialised stores", Category.SUBCLASS),
        Classification("47.79", "Retail sale of second-hand goods in specialised stores", Category.CLASS),
        Classification("47.79.Z", "Retail sale of second-hand goods in specialised stores", Category.SUBCLASS),
        Classification("47.8", "Retail sale via stalls and markets", Category.GROUP),
        Classification(
            "47.81", "Retail sale via stalls and markets of food, beverages and tobacco products", Category.CLASS
        ),
        Classification(
            "47.81.Z", "Retail sale via stalls and markets of food, beverages and tobacco products", Category.SUBCLASS
        ),
        Classification(
            "47.82", "Retail sale via stalls and markets of textiles, clothing and footwear", Category.CLASS
        ),
        Classification(
            "47.82.Z", "Retail sale via stalls and markets of textiles, clothing and footwear", Category.SUBCLASS
        ),
        Classification("47.89", "Retail sale via stalls and markets of other goods", Category.CLASS),
        Classification("47.89.Z", "Retail sale via stalls and markets of other goods", Category.SUBCLASS),
        Classification("47.9", "Retail sale not in stores, stalls or markets", Category.GROUP),
        Classification("47.91", "Retail sale via mail order houses or via Internet", Category.CLASS),
        Classification("47.91.Z", "Retail sale via mail order houses or via Internet", Category.SUBCLASS),
        Classification("47.99", "Other retail sale not in stores, stalls or markets", Category.CLASS),
        Classification("47.99.Z", "Other retail sale not in stores, stalls or markets", Category.SUBCLASS),
        Classification("H", "TRANSPORTATION AND STORAGE", Category.SECTION),
        Classification("49", "LAND TRANSPORT AND TRANSPORT VIA PIPELINES", Category.DIVISION),
        Classification("49.1", "Passenger rail transport, interurban", Category.GROUP),
        Classification("49.10", "Passenger rail transport, interurban", Category.CLASS),
        Classification("49.10.Z", "Passenger rail transport, interurban", Category.SUBCLASS),
        Classification("49.2", "Freight rail transport", Category.GROUP),
        Classification("49.20", "Freight rail transport", Category.CLASS),
        Classification("49.20.Z", "Freight rail transport", Category.SUBCLASS),
        Classification("49.3", "Other passenger land transport ", Category.GROUP),
        Classification("49.31", "Urban and suburban passenger land transport", Category.CLASS),
        Classification("49.31.Z", "Urban and suburban passenger land transport", Category.SUBCLASS),
        Classification("49.32", "Taxi operation", Category.CLASS),
        Classification("49.32.Z", "Taxi operation", Category.SUBCLASS),
        Classification("49.39", "Other passenger land transport not elsewhere classified", Category.CLASS),
        Classification("49.39.Z", "Other passenger land transport not elsewhere classified", Category.SUBCLASS),
        Classification("49.4", "Freight transport by road and removal services", Category.GROUP),
        Classification("49.41", "Freight transport by road", Category.CLASS),
        Classification("49.41.Z", "Freight transport by road", Category.SUBCLASS),
        Classification("49.42", "Removal services", Category.CLASS),
        Classification("49.42.Z", "Removal services", Category.SUBCLASS),
        Classification("49.5", "Transport via pipeline", Category.GROUP),
        Classification("49.50", "Transport via pipeline", Category.CLASS),
        Classification("49.50.A", "Transport via pipeline of fuel gases ", Category.SUBCLASS),
        Classification("49.50.B", "Transport via pipeline of other commodities", Category.SUBCLASS),
        Classification("50", "WATER TRANSPORT", Category.DIVISION),
        Classification("50.1", "Sea and coastal passenger water transport", Category.GROUP),
        Classification("50.10", "Sea and coastal passenger water transport", Category.CLASS),
        Classification("50.10.Z", "Sea and coastal passenger water transport", Category.SUBCLASS),
        Classification("50.2", "Sea and coastal freight water transport", Category.GROUP),
        Classification("50.20", "Sea and coastal freight water transport", Category.CLASS),
        Classification("50.20.Z", "Sea and coastal freight water transport", Category.SUBCLASS),
        Classification("50.3", "Inland passenger water transport", Category.GROUP),
        Classification("50.30", "Inland passenger water transport", Category.CLASS),
        Classification("50.30.Z", "Inland passenger water transport", Category.SUBCLASS),
        Classification("50.4", "Inland freight water transport", Category.GROUP),
        Classification("50.40", "Inland freight water transport", Category.CLASS),
        Classification("50.40.Z", "Inland freight water transport", Category.SUBCLASS),
        Classification("51", "AIR TRANSPORT", Category.DIVISION),
        Classification("51.1", "Passenger air transport", Category.GROUP),
        Classification("51.10", "Passenger air transport", Category.CLASS),
        Classification("51.10.Z", "Passenger air transport", Category.SUBCLASS),
        Classification("51.2", "Freight air transport and space transport", Category.GROUP),
        Classification("51.21", "Freight air transport", Category.CLASS),
        Classification("51.21.Z", "Freight air transport", Category.SUBCLASS),
        Classification("51.22", "Space transport", Category.CLASS),
        Classification("51.22.Z", "Space transport", Category.SUBCLASS),
        Classification("52", "WAREHOUSING AND SUPPORT ACTIVITIES FOR TRANSPORTATION", Category.DIVISION),
        Classification("52.1", "Warehousing and storage", Category.GROUP),
        Classification("52.10", "Warehousing and storage", Category.CLASS),
        Classification("52.10.A", "Warehousing and storage of fuel gases ", Category.SUBCLASS),
        Classification("52.10.B", "Warehousing and storage of other goods", Category.SUBCLASS),
        Classification("52.2", "Support activities for transportation", Category.GROUP),
        Classification("52.21", "Service activities incidental to land transportation", Category.CLASS),
        Classification("52.21.Z", "Service activities incidental to land transportation", Category.SUBCLASS),
        Classification("52.22", "Service activities incidental to water transportation", Category.CLASS),
        Classification("52.22.A", "Service activities incidental to sea transportation", Category.SUBCLASS),
        Classification("52.22.B", "Service activities incidental to inland transportation", Category.SUBCLASS),
        Classification("52.23", "Service activities incidental to air transportation", Category.CLASS),
        Classification("52.23.Z", "Service activities incidental to air transportation", Category.SUBCLASS),
        Classification("52.24", "Cargo handling", Category.CLASS),
        Classification("52.24.A", "Cargo handling in sea ports", Category.SUBCLASS),
        Classification("52.24.B", "Cargo handling in inland ports", Category.SUBCLASS),
        Classification("52.24.C", "Cargo handling in other reloading points", Category.SUBCLASS),
        Classification("52.29", "Other transportation support activities ", Category.CLASS),
        Classification("52.29.A", "Sea  transportation agencies activities", Category.SUBCLASS),
        Classification("52.29.B", "Inland transportation agencies activities", Category.SUBCLASS),
        Classification("52.29.C", "Other transportation agencies activities", Category.SUBCLASS),
        Classification("53", "POSTAL AND COURIER ACTIVITIES", Category.DIVISION),
        Classification(
            "53.1", "Postal activities under universal service obligation (public operator)", Category.GROUP
        ),
        Classification(
            "53.10", "Postal activities under universal service obligation (public operator)", Category.CLASS
        ),
        Classification(
            "53.10.Z", "Postal activities under universal service obligation (public operator)", Category.SUBCLASS
        ),
        Classification("53.2", "Other postal and courier activities", Category.GROUP),
        Classification("53.20", "Other postal and courier activities", Category.CLASS),
        Classification("53.20.Z", "Other postal and courier activities", Category.SUBCLASS),
        Classification("I", "ACCOMMODATION AND FOOD SERVICE ACTIVITIES", Category.SECTION),
        Classification("55", "ACCOMMODATION ", Category.DIVISION),
        Classification("55.1", "Hotels and similar accommodation", Category.GROUP),
        Classification("55.10", "Hotels and similar accommodation", Category.CLASS),
        Classification("55.10.Z", "Hotels and similar accommodation", Category.SUBCLASS),
        Classification("55.2", "Holiday and other short-stay accommodation", Category.GROUP),
        Classification("55.20", "Holiday and other short-stay accommodation", Category.CLASS),
        Classification("55.20.Z", "Holiday and other short-stay accommodation", Category.SUBCLASS),
        Classification(
            "55.3", "Camping grounds (including grounds for camping vehicles), and campsites ", Category.GROUP
        ),
        Classification(
            "55.30", "Camping grounds (including grounds for camping vehicles), and campsites ", Category.CLASS
        ),
        Classification(
            "55.30.Z", "Camping grounds (including grounds for camping vehicles), and campsites ", Category.SUBCLASS
        ),
        Classification("55.9", "Other accommodation", Category.GROUP),
        Classification("55.90", "Other accommodation", Category.CLASS),
        Classification("55.90.Z", "Other accommodation", Category.SUBCLASS),
        Classification("56", "FOOD AND BEVERAGE SERVICE ACTIVITIES", Category.DIVISION),
        Classification("56.1", "Restaurants and other eating places", Category.GROUP),
        Classification("56.10", "Restaurants and other eating places", Category.CLASS),
        Classification("56.10.A", "Restaurants and other eating places", Category.SUBCLASS),
        Classification("56.10.B", "Mobile eating places", Category.SUBCLASS),
        Classification("56.2", "Event catering and other food service activities", Category.GROUP),
        Classification("56.21", "Event catering activities", Category.CLASS),
        Classification("56.21.Z", "Event catering activities", Category.SUBCLASS),
        Classification("56.29", "Other food service activities", Category.CLASS),
        Classification("56.29.Z", "Other food service activities", Category.SUBCLASS),
        Classification("56.3", "Beverage serving activities", Category.GROUP),
        Classification("56.30", "Beverage serving activities", Category.CLASS),
        Classification("56.30.Z", "Beverage serving activities", Category.SUBCLASS),
        Classification("J", "INFORMATION AND COMMUNICATION", Category.SECTION),
        Classification("58", "PUBLISHING ACTIVITIES", Category.DIVISION),
        Classification(
            "58.1",
            "Publishing of books, periodicals and other publishing activities, excluding software      publishing",
            Category.GROUP,
        ),
        Classification("58.11", "Book publishing", Category.CLASS),
        Classification("58.11.Z", "Book publishing", Category.SUBCLASS),
        Classification(
            "58.12", "Publishing of directories and registers (e.g. street, phone directory)", Category.CLASS
        ),
        Classification(
            "58.12.Z", "Publishing of directories and registers (e.g. street, phone directory)", Category.SUBCLASS
        ),
        Classification("58.13", "Publishing of newspapers", Category.CLASS),
        Classification("58.13.Z", "Publishing of newspapers", Category.SUBCLASS),
        Classification("58.14", "Publishing of journals and periodicals", Category.CLASS),
        Classification("58.14.Z", "Publishing of journals and periodicals", Category.SUBCLASS),
        Classification("58.19", "Other publishing activities", Category.CLASS),
        Classification("58.19.Z", "Other publishing activities", Category.SUBCLASS),
        Classification("58.2", "Software publishing", Category.GROUP),
        Classification("58.21", "Publishing of computer games", Category.CLASS),
        Classification("58.21.Z", "Publishing of computer games", Category.SUBCLASS),
        Classification("58.29", "Other software publishing", Category.CLASS),
        Classification("58.29.Z", "Other software publishing", Category.SUBCLASS),
        Classification(
            "59",
            "MOTION PICTURE, VIDEO AND TELEVISION PROGRAMME PRODUCTION, SOUND RECORDING AND MUSIC PUBLISHING ACTIVITIES",
            Category.DIVISION,
        ),
        Classification("59.1", "Motion picture, video and television programme activities", Category.GROUP),
        Classification("59.11", "Motion picture, video and television programme production activities", Category.CLASS),
        Classification(
            "59.11.Z", "Motion picture, video and television programme production activities", Category.SUBCLASS
        ),
        Classification(
            "59.12", "Motion picture, video and television programme post-production activities", Category.CLASS
        ),
        Classification(
            "59.12.Z", "Motion picture, video and television programme post-production activities", Category.SUBCLASS
        ),
        Classification(
            "59.13", "Motion picture, video and television programme distribution activities", Category.CLASS
        ),
        Classification(
            "59.13.Z", "Motion picture, video and television programme distribution activities", Category.SUBCLASS
        ),
        Classification("59.14", "Motion picture projection activities", Category.CLASS),
        Classification("59.14.Z", "Motion picture projection activities", Category.SUBCLASS),
        Classification("59.2", "Sound recording and music publishing activities", Category.GROUP),
        Classification("59.20", "Sound recording and music publishing activities", Category.CLASS),
        Classification("59.20.Z", "Sound recording and music publishing activities", Category.SUBCLASS),
        Classification("60", "PUBLIC AND LICENCE PROGRAMMES BROADCASTING", Category.DIVISION),
        Classification("60.1", "Radio broadcasting", Category.GROUP),
        Classification("60.10", "Radio broadcasting", Category.CLASS),
        Classification("60.10.Z", "Radio broadcasting", Category.SUBCLASS),
        Classification("60.2", "Public and licence television programmes broadcasting", Category.GROUP),
        Classification("60.20", "Public and licence television programmes broadcasting", Category.CLASS),
        Classification("60.20.Z", "Public and licence television programmes broadcasting", Category.SUBCLASS),
        Classification("61", "TELECOMMUNICATIONS", Category.DIVISION),
        Classification("61.1", "Wired telecommunications activities", Category.GROUP),
        Classification("61.10", "Wired telecommunications activities", Category.CLASS),
        Classification("61.10.Z", "Wired telecommunications activities", Category.SUBCLASS),
        Classification(
            "61.2",
            "Wireless telecommunications activities, excluding satellite telecommunications activities",
            Category.GROUP,
        ),
        Classification(
            "61.20",
            "Wireless telecommunications activities, excluding satellite telecommunications activities",
            Category.CLASS,
        ),
        Classification(
            "61.20.Z",
            "Wireless telecommunications activities, excluding satellite telecommunications activities",
            Category.SUBCLASS,
        ),
        Classification("61.3", "Satellite telecommunications activities", Category.GROUP),
        Classification("61.30", "Satellite telecommunications activities", Category.CLASS),
        Classification("61.30.Z", "Satellite telecommunications activities", Category.SUBCLASS),
        Classification("61.9", "Other telecommunications activities", Category.GROUP),
        Classification("61.90", "Other telecommunications activities", Category.CLASS),
        Classification("61.90.Z", "Other telecommunications activities", Category.SUBCLASS),
        Classification("62", "COMPUTER PROGRAMMING, CONSULTANCY AND RELATED ACTIVITIES", Category.DIVISION),
        Classification("62.0", "Computer programming, consultancy and related activities", Category.GROUP),
        Classification("62.01", "Computer programming activities", Category.CLASS),
        Classification("62.01.Z", "Computer programming activities", Category.SUBCLASS),
        Classification("62.02", "Computer consultancy activities", Category.CLASS),
        Classification("62.02.Z", "Computer consultancy activities", Category.SUBCLASS),
        Classification("62.03", "Computer facilities management activities", Category.CLASS),
        Classification("62.03.Z", "Computer facilities management activities", Category.SUBCLASS),
        Classification("62.09", "Other information technology and computer service activities", Category.CLASS),
        Classification("62.09.Z", "Other information technology and computer service activities", Category.SUBCLASS),
        Classification("63", "INFORMATION SERVICE ACTIVITIES", Category.DIVISION),
        Classification("63.1", "Data processing, hosting and related activities; web portals", Category.GROUP),
        Classification("63.11", "Data processing, hosting and related activities", Category.CLASS),
        Classification("63.11.Z", "Data processing, hosting and related activities", Category.SUBCLASS),
        Classification("63.12", "Web portals", Category.CLASS),
        Classification("63.12.Z", "Web portals", Category.SUBCLASS),
        Classification("63.9", "Other information service activities", Category.GROUP),
        Classification("63.91", "News agency activities", Category.CLASS),
        Classification("63.91.Z", "News agency activities", Category.SUBCLASS),
        Classification("63.99", "Other information service activities not elsewhere classified", Category.CLASS),
        Classification("63.99.Z", "Other information service activities not elsewhere classified", Category.SUBCLASS),
        Classification("K", "FINANCIAL AND INSURANCE ACTIVITIES", Category.SECTION),
        Classification("64", "FINANCIAL SERVICE ACTIVITIES, EXCEPT INSURANCE AND PENSION FUNDING", Category.DIVISION),
        Classification("64.1", "Monetary intermediation", Category.GROUP),
        Classification("64.11", "Central banking", Category.CLASS),
        Classification("64.11.Z", "Central banking", Category.SUBCLASS),
        Classification("64.19", "Other monetary intermediation", Category.CLASS),
        Classification("64.19.Z", "Other monetary intermediation", Category.SUBCLASS),
        Classification("64.2", "Activities of holding companies", Category.GROUP),
        Classification("64.20", "Activities of holding companies", Category.CLASS),
        Classification("64.20.Z", "Activities of holding companies", Category.SUBCLASS),
        Classification("64.3", "Trusts, funds and similar financial entities", Category.GROUP),
        Classification("64.30", "Trusts, funds and similar financial entities", Category.CLASS),
        Classification("64.30.Z", "Trusts, funds and similar financial entities", Category.SUBCLASS),
        Classification(
            "64.9", "Other financial service activities, except insurance and pension funding", Category.GROUP
        ),
        Classification("64.91", "Financial leasing", Category.CLASS),
        Classification("64.91.Z", "Financial leasing", Category.SUBCLASS),
        Classification("64.92", "Other credit granting", Category.CLASS),
        Classification("64.92.Z", "Other credit granting", Category.SUBCLASS),
        Classification(
            "64.99",
            "Other financial service activities, except insurance and pension funding not elsewhere classified",
            Category.CLASS,
        ),
        Classification(
            "64.99.Z",
            "Other financial service activities, except insurance and pension funding not elsewhere classified",
            Category.SUBCLASS,
        ),
        Classification(
            "65",
            "INSURANCE, REINSURANCE AND PENSION FUNDING, EXCEPT COMPULSORY SOCIAL        SECURITY",
            Category.DIVISION,
        ),
        Classification("65.1", "Insurance", Category.GROUP),
        Classification("65.11", "Life insurance", Category.CLASS),
        Classification("65.11.Z", "Life insurance", Category.SUBCLASS),
        Classification("65.12", "Other personal and property insurance", Category.CLASS),
        Classification("65.12.Z", "Other personal and property insurance", Category.SUBCLASS),
        Classification("65.2", "Reinsurance", Category.GROUP),
        Classification("65.20", "Reinsurance", Category.CLASS),
        Classification("65.20.Z", "Reinsurance", Category.SUBCLASS),
        Classification("65.3", "Pension funding", Category.GROUP),
        Classification("65.30", "Pension funding", Category.CLASS),
        Classification("65.30.Z", "Pension funding", Category.SUBCLASS),
        Classification("66", "ACTIVITIES AUXILIARY TO FINANCIAL SERVICES AND INSURANCE ACTIVITIES", Category.DIVISION),
        Classification(
            "66.1", "Activities auxiliary to financial services, except insurance and pension funding", Category.GROUP
        ),
        Classification("66.11", "Administration of financial markets", Category.CLASS),
        Classification("66.11.Z", "Administration of financial markets", Category.SUBCLASS),
        Classification("66.12", "Security and commodity contracts brokerage", Category.CLASS),
        Classification("66.12.Z", "Security and commodity contracts brokerage", Category.SUBCLASS),
        Classification(
            "66.19",
            "Other activities auxiliary to financial services, except insurance and pension funding",
            Category.CLASS,
        ),
        Classification(
            "66.19.Z",
            "Other activities auxiliary to financial services, except insurance and pension funding",
            Category.SUBCLASS,
        ),
        Classification("66.2", "Activities auxiliary to insurance and pension funding", Category.GROUP),
        Classification("66.21", "Risk and damage evaluation", Category.CLASS),
        Classification("66.21.Z", "Risk and damage evaluation", Category.SUBCLASS),
        Classification("66.22", "Activities of insurance agents and brokers", Category.CLASS),
        Classification("66.22.Z", "Activities of insurance agents and brokers", Category.SUBCLASS),
        Classification("66.29", "Other activities auxiliary to insurance and pension funding", Category.CLASS),
        Classification("66.29.Z", "Other activities auxiliary to insurance and pension funding", Category.SUBCLASS),
        Classification("66.3", "Fund management activities", Category.GROUP),
        Classification("66.30", "Fund management activities", Category.CLASS),
        Classification("66.30.Z", "Fund management activities", Category.SUBCLASS),
        Classification("L", "REAL ESTATE ACTIVITIES", Category.SECTION),
        Classification("68", "Real estate activities", Category.DIVISION),
        Classification("68.1", "Buying and selling of own real estate", Category.GROUP),
        Classification("68.10", "Buying and selling of own real estate", Category.CLASS),
        Classification("68.10.Z", "Buying and selling of own real estate", Category.SUBCLASS),
        Classification("68.2", "Rental and operating of own or leased real estate", Category.GROUP),
        Classification("68.20", "Rental and operating of own or leased real estate", Category.CLASS),
        Classification("68.20.Z", "Rental and operating of own or leased real estate", Category.SUBCLASS),
        Classification("68.3", "Real estate activities on a fee or contract basis", Category.GROUP),
        Classification("68.31", "Real estate agencies", Category.CLASS),
        Classification("68.31.Z", "Real estate agencies", Category.SUBCLASS),
        Classification("68.32", "Management of real estate on a fee or contract basis", Category.CLASS),
        Classification("68.32.Z", "Management of real estate on a fee or contract basis", Category.SUBCLASS),
        Classification("M", "PROFESSIONAL, SCIENTIFIC AND TECHNICAL ACTIVITIES", Category.SECTION),
        Classification(
            "69", "LEGAL, ACCOUNTING, BOOKKEEPING AND AUDITING ACTIVITIES; TAX CONSULTANCY", Category.DIVISION
        ),
        Classification("69.1", "Legal activities", Category.GROUP),
        Classification("69.10", "Legal activities", Category.CLASS),
        Classification("69.10.Z", "Legal activities", Category.SUBCLASS),
        Classification("69.2", "Accounting, bookkeeping and auditing activities; tax consultancy", Category.GROUP),
        Classification("69.20", "Accounting, bookkeeping and auditing activities; tax consultancy", Category.CLASS),
        Classification(
            "69.20.Z", "Accounting, bookkeeping and auditing activities; tax consultancy", Category.SUBCLASS
        ),
        Classification("70", "ACTIVITIES OF HEAD OFFICES; MANAGEMENT CONSULTANCY ACTIVITIES", Category.DIVISION),
        Classification(
            "70.1",
            "Activities of head office and holding companies, excluding financial holding companies ",
            Category.GROUP,
        ),
        Classification(
            "70.10",
            "Activities of head office and holding companies, excluding financial holding companies ",
            Category.CLASS,
        ),
        Classification(
            "70.10.Z",
            "Activities of head office and holding companies, excluding financial holding companies ",
            Category.SUBCLASS,
        ),
        Classification("70.2", "Management consultancy activities", Category.GROUP),
        Classification("70.21", "Public relations and communication activities", Category.CLASS),
        Classification("70.21.Z", "Public relations and communication activities", Category.SUBCLASS),
        Classification("70.22", "Business and other management consultancy activities", Category.CLASS),
        Classification("70.22.Z", "Business and other management consultancy activities", Category.SUBCLASS),
        Classification(
            "71", "ARCHITECTURAL AND ENGINEERING ACTIVITIES; TECHNICAL TESTING AND ANALYSIS", Category.DIVISION
        ),
        Classification(
            "71.1", "Architectural and engineering activities and related technical consultancy", Category.GROUP
        ),
        Classification("71.11", "Architectural activities ", Category.CLASS),
        Classification("71.11.Z", "Architectural activities ", Category.SUBCLASS),
        Classification("71.12", "Engineering activities and related technical consultancy", Category.CLASS),
        Classification("71.12.Z", "Engineering activities and related technical consultancy", Category.SUBCLASS),
        Classification("71.2", "Technical testing and analysis", Category.GROUP),
        Classification("71.20", "Technical testing and analysis", Category.CLASS),
        Classification("71.20.A", "Food quality testing and analysis", Category.SUBCLASS),
        Classification("71.20.B", "Other technical testing and analysis", Category.SUBCLASS),
        Classification("72", "SCIENTIFIC RESEARCH AND DEVELOPMENT ", Category.DIVISION),
        Classification(
            "72.1", "Research and experimental development on natural sciences and engineering", Category.GROUP
        ),
        Classification("72.11", "Research and experimental development on biotechnology", Category.CLASS),
        Classification("72.11.Z", "Research and experimental development on biotechnology", Category.SUBCLASS),
        Classification(
            "72.19", "Other research and experimental development on natural sciences and engineering", Category.CLASS
        ),
        Classification(
            "72.19.Z",
            "Other research and experimental development on natural sciences and engineering",
            Category.SUBCLASS,
        ),
        Classification(
            "72.2", "Research and experimental development on social sciences and humanities", Category.GROUP
        ),
        Classification(
            "72.20", "Research and experimental development on social sciences and humanities", Category.CLASS
        ),
        Classification(
            "72.20.Z", "Research and experimental development on social sciences and humanities", Category.SUBCLASS
        ),
        Classification("73", "ADVERTISING AND MARKET RESEARCH", Category.DIVISION),
        Classification("73.1", "Advertising", Category.GROUP),
        Classification("73.11", "Advertising agencies activities", Category.CLASS),
        Classification("73.11.Z", "Advertising agencies activities", Category.SUBCLASS),
        Classification("73.12", "Media representation activities", Category.CLASS),
        Classification(
            "73.12.A",
            "Intermediation in the sale of time and place on advertising aims in the radio  and       television",
            Category.SUBCLASS,
        ),
        Classification(
            "73.12.B", "Intermediation in the sale of the place on advertising aims in printed media", Category.SUBCLASS
        ),
        Classification(
            "73.12.C",
            "Intermediation in the sale of the place on advertising aims in electronic media (Internet)",
            Category.SUBCLASS,
        ),
        Classification(
            "73.12.D", "Intermediation in the sale of the place on advertising aims in other media", Category.SUBCLASS
        ),
        Classification("73.2", "Market research and public opinion polling", Category.GROUP),
        Classification("73.20", "Market research and public opinion polling", Category.CLASS),
        Classification("73.20.Z", "Market research and public opinion polling", Category.SUBCLASS),
        Classification("74", "OTHER PROFESSIONAL, SCIENTIFIC AND TECHNICAL ACTIVITIES", Category.DIVISION),
        Classification("74.1", "Specialised design activities", Category.GROUP),
        Classification("74.10", "Specialised design activities", Category.CLASS),
        Classification("74.10.Z", "Specialised design activities", Category.SUBCLASS),
        Classification("74.2", "Photographic activities", Category.GROUP),
        Classification("74.20", "Photographic activities", Category.CLASS),
        Classification("74.20.Z", "Photographic activities", Category.SUBCLASS),
        Classification("74.3", "Translation and interpretation activities", Category.GROUP),
        Classification("74.30", "Translation and interpretation activities", Category.CLASS),
        Classification("74.30.Z", "Translation and interpretation activities", Category.SUBCLASS),
        Classification(
            "74.9", "Other professional, scientific and technical activities not elsewhere classified", Category.GROUP
        ),
        Classification(
            "74.90", "Other professional, scientific and technical activities not elsewhere classified", Category.CLASS
        ),
        Classification(
            "74.90.Z",
            "Other professional, scientific and technical activities not elsewhere classified",
            Category.SUBCLASS,
        ),
        Classification("75", "VETERINARY ACTIVITIES", Category.DIVISION),
        Classification("75.0", "Veterinary activities", Category.GROUP),
        Classification("75.00", "Veterinary activities", Category.CLASS),
        Classification("75.00.Z", "Veterinary activities", Category.SUBCLASS),
        Classification("N", "ADMINISTRATIVE AND SUPPORT SERVICE ACTIVITIES", Category.SECTION),
        Classification("77", "RENTAL AND LEASING ACTIVITIES", Category.DIVISION),
        Classification("77.1", "Rental and leasing of motor vehicles excluding motorcycles", Category.GROUP),
        Classification("77.11", "Rental and leasing of cars and light motor vehicles", Category.CLASS),
        Classification("77.11.Z", "Rental and leasing of cars and light motor vehicles", Category.SUBCLASS),
        Classification("77.12", "Rental and leasing of other motor vehicle, excluding motorcycles", Category.CLASS),
        Classification(
            "77.12.Z", "Rental and leasing of other motor vehicle, excluding motorcycles", Category.SUBCLASS
        ),
        Classification("77.2", "Rental and leasing of personal and household goods", Category.GROUP),
        Classification("77.21", "Rental and leasing of recreational and sports goods", Category.CLASS),
        Classification("77.21.Z", "Rental and leasing of recreational and sports goods", Category.SUBCLASS),
        Classification("77.22", "Rental of video tapes and  CDs, DVDs etc.", Category.CLASS),
        Classification("77.22.Z", "Rental of video tapes and  CDs, DVDs etc.", Category.SUBCLASS),
        Classification("77.29", "Rental and leasing of other personal and household goods", Category.CLASS),
        Classification("77.29.Z", "Rental and leasing of other personal and household goods", Category.SUBCLASS),
        Classification("77.3", "Rental and leasing of other machinery, equipment and tangible goods", Category.GROUP),
        Classification("77.31", "Rental and leasing of agricultural machinery and equipment", Category.CLASS),
        Classification("77.31.Z", "Rental and leasing of agricultural machinery and equipment", Category.SUBCLASS),
        Classification("77.32", "Rental and leasing of construction machinery and equipment", Category.CLASS),
        Classification("77.32.Z", "Rental and leasing of construction machinery and equipment", Category.SUBCLASS),
        Classification(
            "77.33", "Rental and leasing of office machinery and equipment, including computers", Category.CLASS
        ),
        Classification(
            "77.33.Z", "Rental and leasing of office machinery and equipment, including computers", Category.SUBCLASS
        ),
        Classification("77.34", "Rental and leasing of water transport equipment", Category.CLASS),
        Classification("77.34.Z", "Rental and leasing of water transport equipment", Category.SUBCLASS),
        Classification("77.35", "Rental and leasing of air transport equipment", Category.CLASS),
        Classification("77.35.Z", "Rental and leasing of air transport equipment", Category.SUBCLASS),
        Classification(
            "77.39",
            "Rental and leasing of other machinery, equipment and tangible goods not elsewhere classified",
            Category.CLASS,
        ),
        Classification(
            "77.39.Z",
            "Rental and leasing of other machinery, equipment and tangible goods not elsewhere classified",
            Category.SUBCLASS,
        ),
        Classification(
            "77.4", "Leasing of intellectual property and similar products, except copyrighted works", Category.GROUP
        ),
        Classification(
            "77.40", "Leasing of intellectual property and similar products, except copyrighted works", Category.CLASS
        ),
        Classification(
            "77.40.Z",
            "Leasing of intellectual property and similar products, except copyrighted works",
            Category.SUBCLASS,
        ),
        Classification("78", "EMPLOYMENT ACTIVITIES", Category.DIVISION),
        Classification("78.1", "Activities of employment placement agencies", Category.GROUP),
        Classification("78.10", "Activities of employment placement agencies", Category.CLASS),
        Classification("78.10.Z", "Activities of employment placement agencies", Category.SUBCLASS),
        Classification("78.2", "Temporary employment agency activities", Category.GROUP),
        Classification("78.20", "Temporary employment agency activities", Category.CLASS),
        Classification("78.20.Z", "Temporary employment agency activities", Category.SUBCLASS),
        Classification("78.3", "Other human resources provision", Category.GROUP),
        Classification("78.30", "Other human resources provision", Category.CLASS),
        Classification("78.30.Z", "Other human resources provision", Category.SUBCLASS),
        Classification(
            "79",
            "TOUR OPERATOR, MIDDLEMEN, AGENTS AND OTHER RESERVATION SERVICE AND RELATED ACTIVITIES",
            Category.DIVISION,
        ),
        Classification("79.1", "Tour agents, middlemen and tour operators activities", Category.GROUP),
        Classification("79.11", "Tour agents and middlemen activities", Category.CLASS),
        Classification("79.11.A", "Tour agents activities", Category.SUBCLASS),
        Classification("79.11.B", "Tour middlemen activities", Category.SUBCLASS),
        Classification("79.12", "Tour operator activities", Category.CLASS),
        Classification("79.12.Z", "Tour operator activities", Category.SUBCLASS),
        Classification("79.9", "Other reservation service and related activities", Category.GROUP),
        Classification("79.90", "Other reservation service and related activities", Category.CLASS),
        Classification("79.90.A", "Couriers on package tours and tour guides activities", Category.SUBCLASS),
        Classification("79.90.B", "Tourist information activities", Category.SUBCLASS),
        Classification("79.90.C", "Other reservation service activities not elsewhere classified", Category.SUBCLASS),
        Classification("80", "SECURITY AND INVESTIGATION ACTIVITIES", Category.DIVISION),
        Classification(
            "80.1", "Private security activities, excluding security systems service activities", Category.GROUP
        ),
        Classification(
            "80.10", "Private security activities, excluding security systems service activities", Category.CLASS
        ),
        Classification(
            "80.10.Z", "Private security activities, excluding security systems service activities", Category.SUBCLASS
        ),
        Classification("80.2", "Security systems service activities", Category.GROUP),
        Classification("80.20", "Security systems service activities", Category.CLASS),
        Classification("80.20.Z", "Security systems service activities", Category.SUBCLASS),
        Classification("80.3", "Investigation activities", Category.GROUP),
        Classification("80.30", "Investigation activities", Category.CLASS),
        Classification("80.30.Z", "Investigation activities", Category.SUBCLASS),
        Classification("81", "SERVICES TO BUILDINGS AND LANDSCAPE ACTIVITIES", Category.DIVISION),
        Classification("81.1", "Buildings service support activities", Category.GROUP),
        Classification("81.10", "Buildings service support activities", Category.CLASS),
        Classification("81.10.Z", "Buildings service support activities", Category.SUBCLASS),
        Classification("81.2", "Objects cleaning activities", Category.GROUP),
        Classification("81.21", "General cleaning of buildings", Category.CLASS),
        Classification("81.21.Z", "General cleaning of buildings", Category.SUBCLASS),
        Classification("81.22", "Specialised building and industrial cleaning activities", Category.CLASS),
        Classification("81.22.Z", "Specialised building and industrial cleaning activities", Category.SUBCLASS),
        Classification("81.29", "Other cleaning activities", Category.CLASS),
        Classification("81.29.Z", "Other cleaning activities", Category.SUBCLASS),
        Classification("81.3", "Landscape service activities", Category.GROUP),
        Classification("81.30", "Landscape service activities", Category.CLASS),
        Classification("81.30.Z", "Landscape service activities", Category.SUBCLASS),
        Classification(
            "82", "OFFICE ADMINISTRATIVE SERVICE ACTIVITIES AND OTHER BUSINESS SUPPORT ACTIVITIES", Category.DIVISION
        ),
        Classification(
            "82.1", "Office administrative services activities, including support activities", Category.GROUP
        ),
        Classification("82.11", "Office administrative service activities", Category.CLASS),
        Classification("82.11.Z", "Office administrative service activities", Category.SUBCLASS),
        Classification(
            "82.19",
            "Photocopying, document preparation and other specialised office support activities",
            Category.CLASS,
        ),
        Classification(
            "82.19.Z",
            "Photocopying, document preparation and other specialised office support activities",
            Category.SUBCLASS,
        ),
        Classification("82.2", "Activities of call centres", Category.GROUP),
        Classification("82.20", "Activities of call centres", Category.CLASS),
        Classification("82.20.Z", "Activities of call centres", Category.SUBCLASS),
        Classification("82.3", "Organisation of conventions and trade shows", Category.GROUP),
        Classification("82.30", "Organisation of conventions and trade shows", Category.CLASS),
        Classification("82.30.Z", "Organisation of conventions and trade shows", Category.SUBCLASS),
        Classification("82.9", "Commercial activities not elsewhere classified", Category.GROUP),
        Classification("82.91", "Activities of collection agencies and credit bureaus", Category.CLASS),
        Classification("82.91.Z", "Activities of collection agencies and credit bureaus", Category.SUBCLASS),
        Classification("82.92", "Packaging activities", Category.CLASS),
        Classification("82.92.Z", "Packaging activities", Category.SUBCLASS),
        Classification("82.99", "Other business support service activities not elsewhere classified", Category.CLASS),
        Classification(
            "82.99.Z", "Other business support service activities not elsewhere classified", Category.SUBCLASS
        ),
        Classification("O", "PUBLIC ADMINISTRATION AND DEFENCE; COMPULSORY SOCIAL SECURITY", Category.SECTION),
        Classification("84", "Public administration and defence; compulsory social security", Category.DIVISION),
        Classification(
            "84.1", "Public administration and the economic and social policy of the community", Category.GROUP
        ),
        Classification("84.11", "General public administration activities", Category.CLASS),
        Classification("84.11.Z", "General public administration activities", Category.SUBCLASS),
        Classification(
            "84.12",
            "Regulation of the activities of providing health care, education, cultural services and other social services, excluding social security",
            Category.CLASS,
        ),
        Classification(
            "84.12.Z",
            "Regulation of the activities of providing health care, education, cultural services and other social services, excluding social security",
            Category.SUBCLASS,
        ),
        Classification(
            "84.13", "Regulation of and contribution to more efficient operation of businesses", Category.CLASS
        ),
        Classification(
            "84.13.Z", "Regulation of and contribution to more efficient operation of businesses", Category.SUBCLASS
        ),
        Classification("84.2", "Provision of services to the community as a whole", Category.GROUP),
        Classification("84.21", "Foreign affairs", Category.CLASS),
        Classification("84.21.Z", "Foreign affairs", Category.SUBCLASS),
        Classification("84.22", "Defence activities", Category.CLASS),
        Classification("84.22.Z", "Defence activities", Category.SUBCLASS),
        Classification("84.23", "Justice and judicial activities", Category.CLASS),
        Classification("84.23.Z", "Justice and judicial activities", Category.SUBCLASS),
        Classification("84.24", "Public order and safety activities", Category.CLASS),
        Classification("84.24.Z", "Public order and safety activities", Category.SUBCLASS),
        Classification("84.25", "Fire service activities", Category.CLASS),
        Classification("84.25.Z", "Fire service activities", Category.SUBCLASS),
        Classification("84.3", "Compulsory social security activities", Category.GROUP),
        Classification("84.30", "Compulsory social security activities", Category.CLASS),
        Classification("84.30.Z", "Compulsory social security activities", Category.SUBCLASS),
        Classification("P", "EDUCATION", Category.SECTION),
        Classification("85", "Education", Category.DIVISION),
        Classification("85.1", "Pre-primary education", Category.GROUP),
        Classification("85.10", "Pre-primary education ", Category.CLASS),
        Classification("85.10.Z", "Pre-primary education ", Category.SUBCLASS),
        Classification("85.2", "Primary education", Category.GROUP),
        Classification("85.20", "Primary education ", Category.CLASS),
        Classification("85.20.Z", "Primary education ", Category.SUBCLASS),
        Classification(
            "85.3", "Lower secondary and post lower secondary schools, excluding post-secondary schools", Category.GROUP
        ),
        Classification(
            "85.31", "Lower secondary schools, general upper and specialised upper secondary schools", Category.CLASS
        ),
        Classification("85.31.A", "Lower secondary schools", Category.SUBCLASS),
        Classification("85.31.B", "General upper secondary schools", Category.SUBCLASS),
        Classification("85.31.C", "Specialised upper secondary schools", Category.SUBCLASS),
        Classification(
            "85.32",
            "Vocational upper secondary schools (technical secondary schools and basic vocational schools), excluding post-secondary schools",
            Category.CLASS,
        ),
        Classification("85.32.A", "Technical secondary schools", Category.SUBCLASS),
        Classification("85.32.B", "Basic vocational schools", Category.SUBCLASS),
        Classification("85.32.C", "Special job-training schools", Category.SUBCLASS),
        Classification("85.4", "Post - secondary schools and higher education institutions", Category.GROUP),
        Classification("85.41", "Post - secondary schools", Category.CLASS),
        Classification("85.41.Z", "Post - secondary schools", Category.SUBCLASS),
        Classification(
            "85.42",
            "Initial teacher training institutions, colleges of social work and other higher education institutions",
            Category.CLASS,
        ),
        Classification(
            "85.42.A", "Initial teacher training institutions and colleges of social work ", Category.SUBCLASS
        ),
        Classification("85.42.B", "Higher education institutions", Category.SUBCLASS),
        Classification("85.5", "Out-of- school forms of education", Category.GROUP),
        Classification("85.51", "Out-of- school forms of sports and leisure education", Category.CLASS),
        Classification("85.51.Z", "Out-of-school forms of sports and leisure education", Category.SUBCLASS),
        Classification("85.52", "Out-of- school forms of cultural education", Category.CLASS),
        Classification("85.52.Z", "Out-of-school forms of cultural education", Category.SUBCLASS),
        Classification("85.53", "Out-of- school forms of driving  education", Category.CLASS),
        Classification("85.53.Z", "Out-of- school forms of driving  education", Category.SUBCLASS),
        Classification("85.59", "Out-of-school forms of education, not elsewhere classified ", Category.CLASS),
        Classification("85.59.A", "Learning of foreign languages", Category.SUBCLASS),
        Classification(
            "85.59.B", "Other out-of-school forms of education, not elsewhere classified ", Category.SUBCLASS
        ),
        Classification("85.6", "Educational support activities", Category.GROUP),
        Classification("85.60", "Educational support activities", Category.CLASS),
        Classification("85.60.Z", "Educational support activities", Category.SUBCLASS),
        Classification("Q", "HUMAN HEALTH AND SOCIAL WORK ACTIVITIES", Category.SECTION),
        Classification("86", "HUMAN HEALTH ACTIVITIES", Category.DIVISION),
        Classification("86.1", "Hospital activities", Category.GROUP),
        Classification("86.10", "Hospital activities", Category.CLASS),
        Classification("86.10.Z", "Hospital activities", Category.SUBCLASS),
        Classification("86.2", "Medical and dental practice activities", Category.GROUP),
        Classification("86.21", "General medical practice activities", Category.CLASS),
        Classification("86.21.Z", "General medical practice activities", Category.SUBCLASS),
        Classification("86.22", "Specialist medical practice activities", Category.CLASS),
        Classification("86.22.Z", "Specialist medical practice activities", Category.SUBCLASS),
        Classification("86.23", "Dental practice activities", Category.CLASS),
        Classification("86.23.Z", "Dental practice activities", Category.SUBCLASS),
        Classification("86.9", "Other human health activities", Category.GROUP),
        Classification("86.90", "Other human health activities", Category.CLASS),
        Classification("86.90.A", "Physiotherapeutical activities", Category.SUBCLASS),
        Classification("86.90.B", "Emergency ambulance activities", Category.SUBCLASS),
        Classification("86.90.C", "Nurses and midwives activities", Category.SUBCLASS),
        Classification("86.90.D", "Paramedical activities", Category.SUBCLASS),
        Classification("86.90.E", "Other human health activities not elsewhere classified", Category.SUBCLASS),
        Classification("87", "RESIDENTIAL CARE ACTIVITIES", Category.DIVISION),
        Classification("87.1", "Residential nursing care activities", Category.GROUP),
        Classification("87.10", "Residential nursing care activities", Category.CLASS),
        Classification("87.10.Z", "Residential nursing care activities", Category.SUBCLASS),
        Classification(
            "87.2",
            "Residential care activities for mental retardation, mental health and substance abuse",
            Category.GROUP,
        ),
        Classification(
            "87.20",
            "Residential care activities for mental retardation, mental health and substance abuse",
            Category.CLASS,
        ),
        Classification(
            "87.20.Z",
            "Residential care activities for mental retardation, mental health and substance abuse",
            Category.SUBCLASS,
        ),
        Classification("87.3", "Residential care activities for the elderly and disabled", Category.GROUP),
        Classification("87.30", "Residential care activities for the elderly and disabled", Category.CLASS),
        Classification("87.30.Z", "Residential care activities for the elderly and disabled", Category.SUBCLASS),
        Classification("87.9", "Other residential care activities", Category.GROUP),
        Classification("87.90", "Other residential care activities", Category.CLASS),
        Classification("87.90.Z", "Other residential care activities", Category.SUBCLASS),
        Classification("88", "SOCIAL WORK ACTIVITIES WITHOUT ACCOMMODATION", Category.DIVISION),
        Classification(
            "88.1", "Social work activities without accommodation for the elderly and disabled", Category.GROUP
        ),
        Classification(
            "88.10", "Social work activities without accommodation for the elderly and disabled", Category.CLASS
        ),
        Classification(
            "88.10.Z", "Social work activities without accommodation for the elderly and disabled", Category.SUBCLASS
        ),
        Classification("88.9", "Other social work activities without accommodation", Category.GROUP),
        Classification("88.91", "Child day-care activities", Category.CLASS),
        Classification("88.91.Z", "Child day-care activities", Category.SUBCLASS),
        Classification(
            "88.99", "Other social work activities without accommodation not elsewhere classified", Category.CLASS
        ),
        Classification(
            "88.99.Z", "Other social work activities without accommodation not elsewhere classified", Category.SUBCLASS
        ),
        Classification("R", "ARTS, ENTERTAINMENT AND RECREATION ACTIVITIES", Category.SECTION),
        Classification("90", "CREATIVE, ARTS AND ENTERTAINMENT ACTIVITIES", Category.DIVISION),
        Classification("90.0", "Creative, arts and entertainment activities", Category.GROUP),
        Classification("90.01", "Performing arts activities", Category.CLASS),
        Classification("90.01.Z", "Performing arts activities", Category.SUBCLASS),
        Classification("90.02", "Support activities to performing arts", Category.CLASS),
        Classification("90.02.Z", "Support activities to performing arts", Category.SUBCLASS),
        Classification("90.03", "Artistic creation activities", Category.CLASS),
        Classification("90.03.Z", "Artistic creation activities", Category.SUBCLASS),
        Classification("90.04", "Operation of arts facilities", Category.CLASS),
        Classification("90.04.Z", "Operation of arts facilities", Category.SUBCLASS),
        Classification("91", "LIBRARIES, ARCHIVES, MUSEUMS AND OTHER CULTURAL ACTIVITIES", Category.DIVISION),
        Classification("91.0", "LIBRARIES, ARCHIVES, MUSEUMS AND OTHER CULTURAL ACTIVITIES", Category.GROUP),
        Classification("91.01", "Library and archives activities", Category.CLASS),
        Classification("91.01.A", "Library activities", Category.SUBCLASS),
        Classification("91.01.B", "Archives activities", Category.SUBCLASS),
        Classification("91.02", "Museums activities", Category.CLASS),
        Classification("91.02.Z", "Museums activities", Category.SUBCLASS),
        Classification(
            "91.03", "Operation of historical sites and buildings and similar visitor attractions", Category.CLASS
        ),
        Classification(
            "91.03.Z", "Operation of historical sites and buildings and similar visitor attractions", Category.SUBCLASS
        ),
        Classification("91.04", "Botanical and zoological gardens and nature reserves activities", Category.CLASS),
        Classification("91.04.Z", "Botanical and zoological gardens and nature reserves activities", Category.SUBCLASS),
        Classification("92", "GAMBLING AND BETTING ACTIVITIES", Category.DIVISION),
        Classification("92.0", "Gambling and betting activities", Category.GROUP),
        Classification("92.00", "Gambling and betting activities", Category.CLASS),
        Classification("92.00.Z", "Gambling and betting activities", Category.SUBCLASS),
        Classification("93", "SPORTS ACTIVITIES AND AMUSEMENT AND RECREATION ACTIVITIES", Category.DIVISION),
        Classification("93.1", "Sports activities", Category.GROUP),
        Classification("93.11", "Operation of sports facilities", Category.CLASS),
        Classification("93.11.Z", "Operation of sports facilities", Category.SUBCLASS),
        Classification("93.12", "Activities of sports clubs", Category.CLASS),
        Classification("93.12.Z", "Activities of sports clubs", Category.SUBCLASS),
        Classification("93.13", "Operation of fitness facilities", Category.CLASS),
        Classification("93.13.Z", "Operation of fitness facilities", Category.SUBCLASS),
        Classification("93.19", "Other sports activities", Category.CLASS),
        Classification("93.19.Z", "Other sports activities", Category.SUBCLASS),
        Classification("93.2", "Amusement and recreation activities", Category.GROUP),
        Classification("93.21", "Activities of amusement parks and theme parks", Category.CLASS),
        Classification("93.21.Z", "Activities of amusement parks and theme parks", Category.SUBCLASS),
        Classification("93.29", "Other amusement and recreation activities", Category.CLASS),
        Classification("93.29.Z", "Other amusement and recreation activities", Category.SUBCLASS),
        Classification("S", "OTHER SERVICE ACTIVITIES", Category.SECTION),
        Classification("94", "ACTIVITIES OF MEMBERSHIP ORGANISATIONS", Category.DIVISION),
        Classification("94.1", "Activities of commercial, employers and professional organisations", Category.GROUP),
        Classification("94.11", "Activities of commercial and employers organisations", Category.CLASS),
        Classification("94.11.Z", "Activities of commercial and employers organisations", Category.SUBCLASS),
        Classification("94.12", "Activities of professional organisations", Category.CLASS),
        Classification("94.12.Z", "Activities of professional organisations", Category.SUBCLASS),
        Classification("94.2", "Activities of trade unions", Category.GROUP),
        Classification("94.20", "Activities of trade unions", Category.CLASS),
        Classification("94.20.Z", "Activities of trade unions", Category.SUBCLASS),
        Classification("94.9", "Activities of other membership organisations", Category.GROUP),
        Classification("94.91", "Activities of religious organisations", Category.CLASS),
        Classification("94.91.Z", "Activities of religious organisations", Category.SUBCLASS),
        Classification("94.92", "Activities of political organisations", Category.CLASS),
        Classification("94.92.Z", "Activities of political organisations", Category.SUBCLASS),
        Classification(
            "94.99", "Activities of other membership organisations not elsewhere classified", Category.CLASS
        ),
        Classification(
            "94.99.Z", "Activities of other membership organisations not elsewhere classified", Category.SUBCLASS
        ),
        Classification("95", "REPAIR AND MAINTENANCE OF COMPUTERS AND PERSONAL AND HOUSEHOLD GOODS", Category.DIVISION),
        Classification("95.1", "Repair and maintenance of computers and communication equipment", Category.GROUP),
        Classification("95.11", "Repair and maintenance of computers and peripheral equipment", Category.CLASS),
        Classification("95.11.Z", "Repair and maintenance of computers and peripheral equipment", Category.SUBCLASS),
        Classification("95.12", "Repair and maintenance of (tele)communication equipment", Category.CLASS),
        Classification("95.12.Z", "Repair and maintenance of (tele)communication equipment", Category.SUBCLASS),
        Classification("95.2", "Repair and maintenance of personal and household goods", Category.GROUP),
        Classification("95.21", "Repair and maintenance of consumer electronics", Category.CLASS),
        Classification("95.21.Z", "Repair and maintenance of consumer electronics", Category.SUBCLASS),
        Classification(
            "95.22", "Repair and maintenance of household appliances and home and garden equipment", Category.CLASS
        ),
        Classification(
            "95.22.Z", "Repair and maintenance of household appliances and home and garden equipment", Category.SUBCLASS
        ),
        Classification("95.23", "Repair of footwear and leather goods", Category.CLASS),
        Classification("95.23.Z", "Repair of footwear and leather goods", Category.SUBCLASS),
        Classification("95.24", "Repair and maintenance of furniture and home furnishings", Category.CLASS),
        Classification("95.24.Z", "Repair and maintenance of furniture and home furnishings", Category.SUBCLASS),
        Classification("95.25", "Repair of watches, clocks and jewellery", Category.CLASS),
        Classification("95.25.Z", "Repair of watches, clocks and jewellery", Category.SUBCLASS),
        Classification("95.29", "Repair of other personal and household goods", Category.CLASS),
        Classification("95.29.Z", "Repair of other personal and household goods", Category.SUBCLASS),
        Classification("96", "OTHER PERSONAL SERVICE ACTIVITIES", Category.DIVISION),
        Classification("96.0", "Other personal service activities", Category.GROUP),
        Classification("96.01", "Washing and (dry-)cleaning of textile and fur products", Category.CLASS),
        Classification("96.01.Z", "Washing and (dry-)cleaning of textile and fur products", Category.SUBCLASS),
        Classification("96.02", "Hairdressing and other beauty treatment", Category.CLASS),
        Classification("96.02.Z", "Hairdressing and other beauty treatment", Category.SUBCLASS),
        Classification("96.03", "Funeral and related activities", Category.CLASS),
        Classification("96.03.Z", "Funeral and related activities", Category.SUBCLASS),
        Classification("96.04", "Physical well-being activities", Category.CLASS),
        Classification("96.04.Z", "Physical well-being activities", Category.SUBCLASS),
        Classification("96.09", "Other personal service activities not elsewhere classified", Category.CLASS),
        Classification("96.09.Z", "Other personal service activities not elsewhere classified", Category.SUBCLASS),
        Classification(
            "T",
            "HOUSEHOLDS AS EMPLOYERS;  GOODS- AND SERVICES-PRODUCING ACTIVITIES OF HOUSEHOLDS FOR OWN USE",
            Category.SECTION,
        ),
        Classification("97", "HOUSEHOLDS AS EMPLOYERS OF DOMESTIC PERSONNEL", Category.DIVISION),
        Classification("97.0", "Households as employers of domestic personnel", Category.GROUP),
        Classification("97.00", "Households as employers of domestic personnel", Category.CLASS),
        Classification("97.00.Z", "Households as employers of domestic personnel", Category.SUBCLASS),
        Classification("98", "GOODS- AND SERVICES-PRODUCING ACTIVITIES OF HOUSEHOLDS FOR OWN USE", Category.DIVISION),
        Classification("98.1", "Goods-producing activities of private households for own use", Category.GROUP),
        Classification("98.10", "Goods-producing activities of private households for own use", Category.CLASS),
        Classification("98.10.Z", "Goods-producing activities of private households for own use", Category.SUBCLASS),
        Classification("98.2", "Service-producing activities of private households for own use", Category.GROUP),
        Classification("98.20", "Service-producing activities of private households for own use", Category.CLASS),
        Classification("98.20.Z", "Service-producing activities of private households for own use", Category.SUBCLASS),
        Classification("U", "EXTRATERRITORIAL ORGANISATIONS AND BODIES", Category.SECTION),
        Classification("99", "EXTRATERRITORIAL ORGANISATIONS AND BODIES", Category.DIVISION),
        Classification("99.0", "Extraterritorial organisations and bodies", Category.GROUP),
        Classification("99.00", "Extraterritorial organisations and bodies", Category.CLASS),
        Classification("99.00.Z", "Extraterritorial organisations and bodies", Category.SUBCLASS),
    ],
)
