# -*- coding: utf-8 -*-
"""`Concordance between PKD2007 and NACE2 standards, "PKD-2007 is fully methodologically, conceptually, in the scope and coding system (up to fourth digit) coherent and comparable with the classification NACE Revision 2." <https://stat.gov.pl/en/metainformation/classifications/#Polish%20Classification%20of%20Activities%20(PKD)>`_.
"""
from ...types import Concordance, Standards
from ..nace2 import NACE2
from . import PKD2007

PKD2007_to_NACE2 = Concordance(
    src=PKD2007,
    dst=NACE2,
    concordances=[
        ((Standards.PKD2007, "A"), (Standards.NACE2, "A")),
        ((Standards.PKD2007, "01"), (Standards.NACE2, "01")),
        ((Standards.PKD2007, "01.1"), (Standards.NACE2, "01.1")),
        ((Standards.PKD2007, "01.11"), (Standards.NACE2, "01.11")),
        ((Standards.PKD2007, "01.11.Z"), (Standards.NACE2, "01.11")),
        ((Standards.PKD2007, "01.12"), (Standards.NACE2, "01.12")),
        ((Standards.PKD2007, "01.12.Z"), (Standards.NACE2, "01.12")),
        ((Standards.PKD2007, "01.13"), (Standards.NACE2, "01.13")),
        ((Standards.PKD2007, "01.13.Z"), (Standards.NACE2, "01.13")),
        ((Standards.PKD2007, "01.14"), (Standards.NACE2, "01.14")),
        ((Standards.PKD2007, "01.14.Z"), (Standards.NACE2, "01.14")),
        ((Standards.PKD2007, "01.15"), (Standards.NACE2, "01.15")),
        ((Standards.PKD2007, "01.15.Z"), (Standards.NACE2, "01.15")),
        ((Standards.PKD2007, "01.16"), (Standards.NACE2, "01.16")),
        ((Standards.PKD2007, "01.16.Z"), (Standards.NACE2, "01.16")),
        ((Standards.PKD2007, "01.19"), (Standards.NACE2, "01.19")),
        ((Standards.PKD2007, "01.19.Z"), (Standards.NACE2, "01.19")),
        ((Standards.PKD2007, "01.2"), (Standards.NACE2, "01.2")),
        ((Standards.PKD2007, "01.21"), (Standards.NACE2, "01.21")),
        ((Standards.PKD2007, "01.21.Z"), (Standards.NACE2, "01.21")),
        ((Standards.PKD2007, "01.22"), (Standards.NACE2, "01.22")),
        ((Standards.PKD2007, "01.22.Z"), (Standards.NACE2, "01.22")),
        ((Standards.PKD2007, "01.23"), (Standards.NACE2, "01.23")),
        ((Standards.PKD2007, "01.23.Z"), (Standards.NACE2, "01.23")),
        ((Standards.PKD2007, "01.24"), (Standards.NACE2, "01.24")),
        ((Standards.PKD2007, "01.24.Z"), (Standards.NACE2, "01.24")),
        ((Standards.PKD2007, "01.25"), (Standards.NACE2, "01.25")),
        ((Standards.PKD2007, "01.25.Z"), (Standards.NACE2, "01.25")),
        ((Standards.PKD2007, "01.26"), (Standards.NACE2, "01.26")),
        ((Standards.PKD2007, "01.26.Z"), (Standards.NACE2, "01.26")),
        ((Standards.PKD2007, "01.27"), (Standards.NACE2, "01.27")),
        ((Standards.PKD2007, "01.27.Z"), (Standards.NACE2, "01.27")),
        ((Standards.PKD2007, "01.28"), (Standards.NACE2, "01.28")),
        ((Standards.PKD2007, "01.28.Z"), (Standards.NACE2, "01.28")),
        ((Standards.PKD2007, "01.29"), (Standards.NACE2, "01.29")),
        ((Standards.PKD2007, "01.29.Z"), (Standards.NACE2, "01.29")),
        ((Standards.PKD2007, "01.3"), (Standards.NACE2, "01.3")),
        ((Standards.PKD2007, "01.30"), (Standards.NACE2, "01.30")),
        ((Standards.PKD2007, "01.30.Z"), (Standards.NACE2, "01.30")),
        ((Standards.PKD2007, "01.4"), (Standards.NACE2, "01.4")),
        ((Standards.PKD2007, "01.41"), (Standards.NACE2, "01.41")),
        ((Standards.PKD2007, "01.41.Z"), (Standards.NACE2, "01.41")),
        ((Standards.PKD2007, "01.42"), (Standards.NACE2, "01.42")),
        ((Standards.PKD2007, "01.42.Z"), (Standards.NACE2, "01.42")),
        ((Standards.PKD2007, "01.43"), (Standards.NACE2, "01.43")),
        ((Standards.PKD2007, "01.43.Z"), (Standards.NACE2, "01.43")),
        ((Standards.PKD2007, "01.44"), (Standards.NACE2, "01.44")),
        ((Standards.PKD2007, "01.44.Z"), (Standards.NACE2, "01.44")),
        ((Standards.PKD2007, "01.45"), (Standards.NACE2, "01.45")),
        ((Standards.PKD2007, "01.45.Z"), (Standards.NACE2, "01.45")),
        ((Standards.PKD2007, "01.46"), (Standards.NACE2, "01.46")),
        ((Standards.PKD2007, "01.46.Z"), (Standards.NACE2, "01.46")),
        ((Standards.PKD2007, "01.47"), (Standards.NACE2, "01.47")),
        ((Standards.PKD2007, "01.47.Z"), (Standards.NACE2, "01.47")),
        ((Standards.PKD2007, "01.49"), (Standards.NACE2, "01.49")),
        ((Standards.PKD2007, "01.49.Z"), (Standards.NACE2, "01.49")),
        ((Standards.PKD2007, "01.5"), (Standards.NACE2, "01.5")),
        ((Standards.PKD2007, "01.50"), (Standards.NACE2, "01.50")),
        ((Standards.PKD2007, "01.50.Z"), (Standards.NACE2, "01.50")),
        ((Standards.PKD2007, "01.6"), (Standards.NACE2, "01.6")),
        ((Standards.PKD2007, "01.61"), (Standards.NACE2, "01.61")),
        ((Standards.PKD2007, "01.61.Z"), (Standards.NACE2, "01.61")),
        ((Standards.PKD2007, "01.62"), (Standards.NACE2, "01.62")),
        ((Standards.PKD2007, "01.62.Z"), (Standards.NACE2, "01.62")),
        ((Standards.PKD2007, "01.63"), (Standards.NACE2, "01.63")),
        ((Standards.PKD2007, "01.63.Z"), (Standards.NACE2, "01.63")),
        ((Standards.PKD2007, "01.64"), (Standards.NACE2, "01.64")),
        ((Standards.PKD2007, "01.64.Z"), (Standards.NACE2, "01.64")),
        ((Standards.PKD2007, "01.7"), (Standards.NACE2, "01.7")),
        ((Standards.PKD2007, "01.70"), (Standards.NACE2, "01.70")),
        ((Standards.PKD2007, "01.70.Z"), (Standards.NACE2, "01.70")),
        ((Standards.PKD2007, "02"), (Standards.NACE2, "02")),
        ((Standards.PKD2007, "02.1"), (Standards.NACE2, "02.1")),
        ((Standards.PKD2007, "02.10"), (Standards.NACE2, "02.10")),
        ((Standards.PKD2007, "02.10.Z"), (Standards.NACE2, "02.10")),
        ((Standards.PKD2007, "02.2"), (Standards.NACE2, "02.2")),
        ((Standards.PKD2007, "02.20"), (Standards.NACE2, "02.20")),
        ((Standards.PKD2007, "02.20.Z"), (Standards.NACE2, "02.20")),
        ((Standards.PKD2007, "02.3"), (Standards.NACE2, "02.3")),
        ((Standards.PKD2007, "02.30"), (Standards.NACE2, "02.30")),
        ((Standards.PKD2007, "02.30.Z"), (Standards.NACE2, "02.30")),
        ((Standards.PKD2007, "02.4"), (Standards.NACE2, "02.4")),
        ((Standards.PKD2007, "02.40"), (Standards.NACE2, "02.40")),
        ((Standards.PKD2007, "02.40.Z"), (Standards.NACE2, "02.40")),
        ((Standards.PKD2007, "03"), (Standards.NACE2, "03")),
        ((Standards.PKD2007, "03.1"), (Standards.NACE2, "03.1")),
        ((Standards.PKD2007, "03.11"), (Standards.NACE2, "03.11")),
        ((Standards.PKD2007, "03.11.Z"), (Standards.NACE2, "03.11")),
        ((Standards.PKD2007, "03.12"), (Standards.NACE2, "03.12")),
        ((Standards.PKD2007, "03.12.Z"), (Standards.NACE2, "03.12")),
        ((Standards.PKD2007, "03.2"), (Standards.NACE2, "03.2")),
        ((Standards.PKD2007, "03.21"), (Standards.NACE2, "03.21")),
        ((Standards.PKD2007, "03.21.Z"), (Standards.NACE2, "03.21")),
        ((Standards.PKD2007, "03.22"), (Standards.NACE2, "03.22")),
        ((Standards.PKD2007, "03.22.Z"), (Standards.NACE2, "03.22")),
        ((Standards.PKD2007, "B"), (Standards.NACE2, "B")),
        ((Standards.PKD2007, "05"), (Standards.NACE2, "05")),
        ((Standards.PKD2007, "05.1"), (Standards.NACE2, "05.1")),
        ((Standards.PKD2007, "05.10"), (Standards.NACE2, "05.10")),
        ((Standards.PKD2007, "05.10.Z"), (Standards.NACE2, "05.10")),
        ((Standards.PKD2007, "05.2"), (Standards.NACE2, "05.2")),
        ((Standards.PKD2007, "05.20"), (Standards.NACE2, "05.20")),
        ((Standards.PKD2007, "05.20.Z"), (Standards.NACE2, "05.20")),
        ((Standards.PKD2007, "06"), (Standards.NACE2, "06")),
        ((Standards.PKD2007, "06.1"), (Standards.NACE2, "06.1")),
        ((Standards.PKD2007, "06.10"), (Standards.NACE2, "06.10")),
        ((Standards.PKD2007, "06.10.Z"), (Standards.NACE2, "06.10")),
        ((Standards.PKD2007, "06.2"), (Standards.NACE2, "06.2")),
        ((Standards.PKD2007, "06.20"), (Standards.NACE2, "06.20")),
        ((Standards.PKD2007, "06.20.Z"), (Standards.NACE2, "06.20")),
        ((Standards.PKD2007, "07"), (Standards.NACE2, "07")),
        ((Standards.PKD2007, "07.1"), (Standards.NACE2, "07.1")),
        ((Standards.PKD2007, "07.10"), (Standards.NACE2, "07.10")),
        ((Standards.PKD2007, "07.10.Z"), (Standards.NACE2, "07.10")),
        ((Standards.PKD2007, "07.2"), (Standards.NACE2, "07.2")),
        ((Standards.PKD2007, "07.21"), (Standards.NACE2, "07.21")),
        ((Standards.PKD2007, "07.21.Z"), (Standards.NACE2, "07.21")),
        ((Standards.PKD2007, "07.29"), (Standards.NACE2, "07.29")),
        ((Standards.PKD2007, "07.29.Z"), (Standards.NACE2, "07.29")),
        ((Standards.PKD2007, "08"), (Standards.NACE2, "08")),
        ((Standards.PKD2007, "08.1"), (Standards.NACE2, "08.1")),
        ((Standards.PKD2007, "08.11"), (Standards.NACE2, "08.11")),
        ((Standards.PKD2007, "08.11.Z"), (Standards.NACE2, "08.11")),
        ((Standards.PKD2007, "08.12"), (Standards.NACE2, "08.12")),
        ((Standards.PKD2007, "08.12.Z"), (Standards.NACE2, "08.12")),
        ((Standards.PKD2007, "08.9"), (Standards.NACE2, "08.9")),
        ((Standards.PKD2007, "08.91"), (Standards.NACE2, "08.91")),
        ((Standards.PKD2007, "08.91.Z"), (Standards.NACE2, "08.91")),
        ((Standards.PKD2007, "08.92"), (Standards.NACE2, "08.92")),
        ((Standards.PKD2007, "08.92.Z"), (Standards.NACE2, "08.92")),
        ((Standards.PKD2007, "08.93"), (Standards.NACE2, "08.93")),
        ((Standards.PKD2007, "08.93.Z"), (Standards.NACE2, "08.93")),
        ((Standards.PKD2007, "08.99"), (Standards.NACE2, "08.99")),
        ((Standards.PKD2007, "08.99.Z"), (Standards.NACE2, "08.99")),
        ((Standards.PKD2007, "09"), (Standards.NACE2, "09")),
        ((Standards.PKD2007, "09.1"), (Standards.NACE2, "09.1")),
        ((Standards.PKD2007, "09.10"), (Standards.NACE2, "09.10")),
        ((Standards.PKD2007, "09.10.Z"), (Standards.NACE2, "09.10")),
        ((Standards.PKD2007, "09.9"), (Standards.NACE2, "09.9")),
        ((Standards.PKD2007, "09.90"), (Standards.NACE2, "09.90")),
        ((Standards.PKD2007, "09.90.Z"), (Standards.NACE2, "09.90")),
        ((Standards.PKD2007, "C"), (Standards.NACE2, "C")),
        ((Standards.PKD2007, "10"), (Standards.NACE2, "10")),
        ((Standards.PKD2007, "10.1"), (Standards.NACE2, "10.1")),
        ((Standards.PKD2007, "10.11"), (Standards.NACE2, "10.11")),
        ((Standards.PKD2007, "10.11.Z"), (Standards.NACE2, "10.11")),
        ((Standards.PKD2007, "10.12"), (Standards.NACE2, "10.12")),
        ((Standards.PKD2007, "10.12.Z"), (Standards.NACE2, "10.12")),
        ((Standards.PKD2007, "10.13"), (Standards.NACE2, "10.13")),
        ((Standards.PKD2007, "10.13.Z"), (Standards.NACE2, "10.13")),
        ((Standards.PKD2007, "10.2"), (Standards.NACE2, "10.2")),
        ((Standards.PKD2007, "10.20"), (Standards.NACE2, "10.20")),
        ((Standards.PKD2007, "10.20.Z"), (Standards.NACE2, "10.20")),
        ((Standards.PKD2007, "10.3"), (Standards.NACE2, "10.3")),
        ((Standards.PKD2007, "10.31"), (Standards.NACE2, "10.31")),
        ((Standards.PKD2007, "10.31.Z"), (Standards.NACE2, "10.31")),
        ((Standards.PKD2007, "10.32"), (Standards.NACE2, "10.32")),
        ((Standards.PKD2007, "10.32.Z"), (Standards.NACE2, "10.32")),
        ((Standards.PKD2007, "10.39"), (Standards.NACE2, "10.39")),
        ((Standards.PKD2007, "10.39.Z"), (Standards.NACE2, "10.39")),
        ((Standards.PKD2007, "10.4"), (Standards.NACE2, "10.4")),
        ((Standards.PKD2007, "10.41"), (Standards.NACE2, "10.41")),
        ((Standards.PKD2007, "10.41.Z"), (Standards.NACE2, "10.41")),
        ((Standards.PKD2007, "10.42"), (Standards.NACE2, "10.42")),
        ((Standards.PKD2007, "10.42.Z"), (Standards.NACE2, "10.42")),
        ((Standards.PKD2007, "10.5"), (Standards.NACE2, "10.5")),
        ((Standards.PKD2007, "10.51"), (Standards.NACE2, "10.51")),
        ((Standards.PKD2007, "10.51.Z"), (Standards.NACE2, "10.51")),
        ((Standards.PKD2007, "10.52"), (Standards.NACE2, "10.52")),
        ((Standards.PKD2007, "10.52.Z"), (Standards.NACE2, "10.52")),
        ((Standards.PKD2007, "10.6"), (Standards.NACE2, "10.6")),
        ((Standards.PKD2007, "10.61"), (Standards.NACE2, "10.61")),
        ((Standards.PKD2007, "10.61.Z"), (Standards.NACE2, "10.61")),
        ((Standards.PKD2007, "10.62"), (Standards.NACE2, "10.62")),
        ((Standards.PKD2007, "10.62.Z"), (Standards.NACE2, "10.62")),
        ((Standards.PKD2007, "10.7"), (Standards.NACE2, "10.7")),
        ((Standards.PKD2007, "10.71"), (Standards.NACE2, "10.71")),
        ((Standards.PKD2007, "10.71.Z"), (Standards.NACE2, "10.71")),
        ((Standards.PKD2007, "10.72"), (Standards.NACE2, "10.72")),
        ((Standards.PKD2007, "10.72.Z"), (Standards.NACE2, "10.72")),
        ((Standards.PKD2007, "10.73"), (Standards.NACE2, "10.73")),
        ((Standards.PKD2007, "10.73.Z"), (Standards.NACE2, "10.73")),
        ((Standards.PKD2007, "10.8"), (Standards.NACE2, "10.8")),
        ((Standards.PKD2007, "10.81"), (Standards.NACE2, "10.81")),
        ((Standards.PKD2007, "10.81.Z"), (Standards.NACE2, "10.81")),
        ((Standards.PKD2007, "10.82"), (Standards.NACE2, "10.82")),
        ((Standards.PKD2007, "10.82.Z"), (Standards.NACE2, "10.82")),
        ((Standards.PKD2007, "10.83"), (Standards.NACE2, "10.83")),
        ((Standards.PKD2007, "10.83.Z"), (Standards.NACE2, "10.83")),
        ((Standards.PKD2007, "10.84"), (Standards.NACE2, "10.84")),
        ((Standards.PKD2007, "10.84.Z"), (Standards.NACE2, "10.84")),
        ((Standards.PKD2007, "10.85"), (Standards.NACE2, "10.85")),
        ((Standards.PKD2007, "10.85.Z"), (Standards.NACE2, "10.85")),
        ((Standards.PKD2007, "10.86"), (Standards.NACE2, "10.86")),
        ((Standards.PKD2007, "10.86.Z"), (Standards.NACE2, "10.86")),
        ((Standards.PKD2007, "10.89"), (Standards.NACE2, "10.89")),
        ((Standards.PKD2007, "10.89.Z"), (Standards.NACE2, "10.89")),
        ((Standards.PKD2007, "10.9"), (Standards.NACE2, "10.9")),
        ((Standards.PKD2007, "10.91"), (Standards.NACE2, "10.91")),
        ((Standards.PKD2007, "10.91.Z"), (Standards.NACE2, "10.91")),
        ((Standards.PKD2007, "10.92"), (Standards.NACE2, "10.92")),
        ((Standards.PKD2007, "10.92.Z"), (Standards.NACE2, "10.92")),
        ((Standards.PKD2007, "11"), (Standards.NACE2, "11")),
        ((Standards.PKD2007, "11.0"), (Standards.NACE2, "11.0")),
        ((Standards.PKD2007, "11.01"), (Standards.NACE2, "11.01")),
        ((Standards.PKD2007, "11.01.Z"), (Standards.NACE2, "11.01")),
        ((Standards.PKD2007, "11.02"), (Standards.NACE2, "11.02")),
        ((Standards.PKD2007, "11.02.Z"), (Standards.NACE2, "11.02")),
        ((Standards.PKD2007, "11.03"), (Standards.NACE2, "11.03")),
        ((Standards.PKD2007, "11.03.Z"), (Standards.NACE2, "11.03")),
        ((Standards.PKD2007, "11.04"), (Standards.NACE2, "11.04")),
        ((Standards.PKD2007, "11.04.Z"), (Standards.NACE2, "11.04")),
        ((Standards.PKD2007, "11.05"), (Standards.NACE2, "11.05")),
        ((Standards.PKD2007, "11.05.Z"), (Standards.NACE2, "11.05")),
        ((Standards.PKD2007, "11.06"), (Standards.NACE2, "11.06")),
        ((Standards.PKD2007, "11.06.Z"), (Standards.NACE2, "11.06")),
        ((Standards.PKD2007, "11.07"), (Standards.NACE2, "11.07")),
        ((Standards.PKD2007, "11.07.Z"), (Standards.NACE2, "11.07")),
        ((Standards.PKD2007, "12"), (Standards.NACE2, "12")),
        ((Standards.PKD2007, "12.0"), (Standards.NACE2, "12.0")),
        ((Standards.PKD2007, "12.00"), (Standards.NACE2, "12.00")),
        ((Standards.PKD2007, "12.00.Z"), (Standards.NACE2, "12.00")),
        ((Standards.PKD2007, "13"), (Standards.NACE2, "13")),
        ((Standards.PKD2007, "13.1"), (Standards.NACE2, "13.1")),
        ((Standards.PKD2007, "13.10"), (Standards.NACE2, "13.10")),
        ((Standards.PKD2007, "13.10.A"), (Standards.NACE2, "13.10")),
        ((Standards.PKD2007, "13.10.B"), (Standards.NACE2, "13.10")),
        ((Standards.PKD2007, "13.10.C"), (Standards.NACE2, "13.10")),
        ((Standards.PKD2007, "13.10.D"), (Standards.NACE2, "13.10")),
        ((Standards.PKD2007, "13.2"), (Standards.NACE2, "13.2")),
        ((Standards.PKD2007, "13.20"), (Standards.NACE2, "13.20")),
        ((Standards.PKD2007, "13.20.A"), (Standards.NACE2, "13.20")),
        ((Standards.PKD2007, "13.20.B"), (Standards.NACE2, "13.20")),
        ((Standards.PKD2007, "13.20.C"), (Standards.NACE2, "13.20")),
        ((Standards.PKD2007, "13.20.D"), (Standards.NACE2, "13.20")),
        ((Standards.PKD2007, "13.3"), (Standards.NACE2, "13.3")),
        ((Standards.PKD2007, "13.30"), (Standards.NACE2, "13.30")),
        ((Standards.PKD2007, "13.30.Z"), (Standards.NACE2, "13.30")),
        ((Standards.PKD2007, "13.9"), (Standards.NACE2, "13.9")),
        ((Standards.PKD2007, "13.91"), (Standards.NACE2, "13.91")),
        ((Standards.PKD2007, "13.91.Z"), (Standards.NACE2, "13.91")),
        ((Standards.PKD2007, "13.92"), (Standards.NACE2, "13.92")),
        ((Standards.PKD2007, "13.92.Z"), (Standards.NACE2, "13.92")),
        ((Standards.PKD2007, "13.93"), (Standards.NACE2, "13.93")),
        ((Standards.PKD2007, "13.93.Z"), (Standards.NACE2, "13.93")),
        ((Standards.PKD2007, "13.94"), (Standards.NACE2, "13.94")),
        ((Standards.PKD2007, "13.94.Z"), (Standards.NACE2, "13.94")),
        ((Standards.PKD2007, "13.95"), (Standards.NACE2, "13.95")),
        ((Standards.PKD2007, "13.95.Z"), (Standards.NACE2, "13.95")),
        ((Standards.PKD2007, "13.96"), (Standards.NACE2, "13.96")),
        ((Standards.PKD2007, "13.96.Z"), (Standards.NACE2, "13.96")),
        ((Standards.PKD2007, "13.99"), (Standards.NACE2, "13.99")),
        ((Standards.PKD2007, "13.99.Z"), (Standards.NACE2, "13.99")),
        ((Standards.PKD2007, "14"), (Standards.NACE2, "14")),
        ((Standards.PKD2007, "14.1"), (Standards.NACE2, "14.1")),
        ((Standards.PKD2007, "14.11"), (Standards.NACE2, "14.11")),
        ((Standards.PKD2007, "14.11.Z"), (Standards.NACE2, "14.11")),
        ((Standards.PKD2007, "14.12"), (Standards.NACE2, "14.12")),
        ((Standards.PKD2007, "14.12.Z"), (Standards.NACE2, "14.12")),
        ((Standards.PKD2007, "14.13"), (Standards.NACE2, "14.13")),
        ((Standards.PKD2007, "14.13.Z"), (Standards.NACE2, "14.13")),
        ((Standards.PKD2007, "14.14"), (Standards.NACE2, "14.14")),
        ((Standards.PKD2007, "14.14.Z"), (Standards.NACE2, "14.14")),
        ((Standards.PKD2007, "14.19"), (Standards.NACE2, "14.19")),
        ((Standards.PKD2007, "14.19.Z"), (Standards.NACE2, "14.19")),
        ((Standards.PKD2007, "14.2"), (Standards.NACE2, "14.2")),
        ((Standards.PKD2007, "14.20"), (Standards.NACE2, "14.20")),
        ((Standards.PKD2007, "14.20.Z"), (Standards.NACE2, "14.20")),
        ((Standards.PKD2007, "14.3"), (Standards.NACE2, "14.3")),
        ((Standards.PKD2007, "14.31"), (Standards.NACE2, "14.31")),
        ((Standards.PKD2007, "14.31.Z"), (Standards.NACE2, "14.31")),
        ((Standards.PKD2007, "14.39"), (Standards.NACE2, "14.39")),
        ((Standards.PKD2007, "14.39.Z"), (Standards.NACE2, "14.39")),
        ((Standards.PKD2007, "15"), (Standards.NACE2, "15")),
        ((Standards.PKD2007, "15.1"), (Standards.NACE2, "15.1")),
        ((Standards.PKD2007, "15.11"), (Standards.NACE2, "15.11")),
        ((Standards.PKD2007, "15.11.Z"), (Standards.NACE2, "15.11")),
        ((Standards.PKD2007, "15.12"), (Standards.NACE2, "15.12")),
        ((Standards.PKD2007, "15.12.Z"), (Standards.NACE2, "15.12")),
        ((Standards.PKD2007, "15.2"), (Standards.NACE2, "15.2")),
        ((Standards.PKD2007, "15.20"), (Standards.NACE2, "15.20")),
        ((Standards.PKD2007, "15.20.Z"), (Standards.NACE2, "15.20")),
        ((Standards.PKD2007, "16"), (Standards.NACE2, "16")),
        ((Standards.PKD2007, "16.1"), (Standards.NACE2, "16.1")),
        ((Standards.PKD2007, "16.10"), (Standards.NACE2, "16.10")),
        ((Standards.PKD2007, "16.10.Z"), (Standards.NACE2, "16.10")),
        ((Standards.PKD2007, "16.2"), (Standards.NACE2, "16.2")),
        ((Standards.PKD2007, "16.21"), (Standards.NACE2, "16.21")),
        ((Standards.PKD2007, "16.21.Z"), (Standards.NACE2, "16.21")),
        ((Standards.PKD2007, "16.22"), (Standards.NACE2, "16.22")),
        ((Standards.PKD2007, "16.22.Z"), (Standards.NACE2, "16.22")),
        ((Standards.PKD2007, "16.23"), (Standards.NACE2, "16.23")),
        ((Standards.PKD2007, "16.23.Z"), (Standards.NACE2, "16.23")),
        ((Standards.PKD2007, "16.24"), (Standards.NACE2, "16.24")),
        ((Standards.PKD2007, "16.24.Z"), (Standards.NACE2, "16.24")),
        ((Standards.PKD2007, "16.29"), (Standards.NACE2, "16.29")),
        ((Standards.PKD2007, "16.29.Z"), (Standards.NACE2, "16.29")),
        ((Standards.PKD2007, "17"), (Standards.NACE2, "17")),
        ((Standards.PKD2007, "17.1"), (Standards.NACE2, "17.1")),
        ((Standards.PKD2007, "17.11"), (Standards.NACE2, "17.11")),
        ((Standards.PKD2007, "17.11.Z"), (Standards.NACE2, "17.11")),
        ((Standards.PKD2007, "17.12"), (Standards.NACE2, "17.12")),
        ((Standards.PKD2007, "17.12.Z"), (Standards.NACE2, "17.12")),
        ((Standards.PKD2007, "17.2"), (Standards.NACE2, "17.2")),
        ((Standards.PKD2007, "17.21"), (Standards.NACE2, "17.21")),
        ((Standards.PKD2007, "17.21.Z"), (Standards.NACE2, "17.21")),
        ((Standards.PKD2007, "17.22"), (Standards.NACE2, "17.22")),
        ((Standards.PKD2007, "17.22.Z"), (Standards.NACE2, "17.22")),
        ((Standards.PKD2007, "17.23"), (Standards.NACE2, "17.23")),
        ((Standards.PKD2007, "17.23.Z"), (Standards.NACE2, "17.23")),
        ((Standards.PKD2007, "17.24"), (Standards.NACE2, "17.24")),
        ((Standards.PKD2007, "17.24.Z"), (Standards.NACE2, "17.24")),
        ((Standards.PKD2007, "17.29"), (Standards.NACE2, "17.29")),
        ((Standards.PKD2007, "17.29.Z"), (Standards.NACE2, "17.29")),
        ((Standards.PKD2007, "18"), (Standards.NACE2, "18")),
        ((Standards.PKD2007, "18.1"), (Standards.NACE2, "18.1")),
        ((Standards.PKD2007, "18.11"), (Standards.NACE2, "18.11")),
        ((Standards.PKD2007, "18.11.Z"), (Standards.NACE2, "18.11")),
        ((Standards.PKD2007, "18.12"), (Standards.NACE2, "18.12")),
        ((Standards.PKD2007, "18.12.Z"), (Standards.NACE2, "18.12")),
        ((Standards.PKD2007, "18.13"), (Standards.NACE2, "18.13")),
        ((Standards.PKD2007, "18.13.Z"), (Standards.NACE2, "18.13")),
        ((Standards.PKD2007, "18.14"), (Standards.NACE2, "18.14")),
        ((Standards.PKD2007, "18.14.Z"), (Standards.NACE2, "18.14")),
        ((Standards.PKD2007, "18.2"), (Standards.NACE2, "18.2")),
        ((Standards.PKD2007, "18.20"), (Standards.NACE2, "18.20")),
        ((Standards.PKD2007, "18.20.Z"), (Standards.NACE2, "18.20")),
        ((Standards.PKD2007, "19"), (Standards.NACE2, "19")),
        ((Standards.PKD2007, "19.1"), (Standards.NACE2, "19.1")),
        ((Standards.PKD2007, "19.10"), (Standards.NACE2, "19.10")),
        ((Standards.PKD2007, "19.10.Z"), (Standards.NACE2, "19.10")),
        ((Standards.PKD2007, "19.2"), (Standards.NACE2, "19.2")),
        ((Standards.PKD2007, "19.20"), (Standards.NACE2, "19.20")),
        ((Standards.PKD2007, "19.20.Z"), (Standards.NACE2, "19.20")),
        ((Standards.PKD2007, "20"), (Standards.NACE2, "20")),
        ((Standards.PKD2007, "20.1"), (Standards.NACE2, "20.1")),
        ((Standards.PKD2007, "20.11"), (Standards.NACE2, "20.11")),
        ((Standards.PKD2007, "20.11.Z"), (Standards.NACE2, "20.11")),
        ((Standards.PKD2007, "20.12"), (Standards.NACE2, "20.12")),
        ((Standards.PKD2007, "20.12.Z"), (Standards.NACE2, "20.12")),
        ((Standards.PKD2007, "20.13"), (Standards.NACE2, "20.13")),
        ((Standards.PKD2007, "20.13.Z"), (Standards.NACE2, "20.13")),
        ((Standards.PKD2007, "20.14"), (Standards.NACE2, "20.14")),
        ((Standards.PKD2007, "20.14.Z"), (Standards.NACE2, "20.14")),
        ((Standards.PKD2007, "20.15"), (Standards.NACE2, "20.15")),
        ((Standards.PKD2007, "20.15.Z"), (Standards.NACE2, "20.15")),
        ((Standards.PKD2007, "20.16"), (Standards.NACE2, "20.16")),
        ((Standards.PKD2007, "20.16.Z"), (Standards.NACE2, "20.16")),
        ((Standards.PKD2007, "20.17"), (Standards.NACE2, "20.17")),
        ((Standards.PKD2007, "20.17.Z"), (Standards.NACE2, "20.17")),
        ((Standards.PKD2007, "20.2"), (Standards.NACE2, "20.2")),
        ((Standards.PKD2007, "20.20"), (Standards.NACE2, "20.20")),
        ((Standards.PKD2007, "20.20.Z"), (Standards.NACE2, "20.20")),
        ((Standards.PKD2007, "20.3"), (Standards.NACE2, "20.3")),
        ((Standards.PKD2007, "20.30"), (Standards.NACE2, "20.30")),
        ((Standards.PKD2007, "20.30.Z"), (Standards.NACE2, "20.30")),
        ((Standards.PKD2007, "20.4"), (Standards.NACE2, "20.4")),
        ((Standards.PKD2007, "20.41"), (Standards.NACE2, "20.41")),
        ((Standards.PKD2007, "20.41.Z"), (Standards.NACE2, "20.41")),
        ((Standards.PKD2007, "20.42"), (Standards.NACE2, "20.42")),
        ((Standards.PKD2007, "20.42.Z"), (Standards.NACE2, "20.42")),
        ((Standards.PKD2007, "20.5"), (Standards.NACE2, "20.5")),
        ((Standards.PKD2007, "20.51"), (Standards.NACE2, "20.51")),
        ((Standards.PKD2007, "20.51.Z"), (Standards.NACE2, "20.51")),
        ((Standards.PKD2007, "20.52"), (Standards.NACE2, "20.52")),
        ((Standards.PKD2007, "20.52.Z"), (Standards.NACE2, "20.52")),
        ((Standards.PKD2007, "20.53"), (Standards.NACE2, "20.53")),
        ((Standards.PKD2007, "20.53.Z"), (Standards.NACE2, "20.53")),
        ((Standards.PKD2007, "20.59"), (Standards.NACE2, "20.59")),
        ((Standards.PKD2007, "20.59.Z"), (Standards.NACE2, "20.59")),
        ((Standards.PKD2007, "20.6"), (Standards.NACE2, "20.6")),
        ((Standards.PKD2007, "20.60"), (Standards.NACE2, "20.60")),
        ((Standards.PKD2007, "20.60.Z"), (Standards.NACE2, "20.60")),
        ((Standards.PKD2007, "21"), (Standards.NACE2, "21")),
        ((Standards.PKD2007, "21.1"), (Standards.NACE2, "21.1")),
        ((Standards.PKD2007, "21.10"), (Standards.NACE2, "21.10")),
        ((Standards.PKD2007, "21.10.Z"), (Standards.NACE2, "21.10")),
        ((Standards.PKD2007, "21.2"), (Standards.NACE2, "21.2")),
        ((Standards.PKD2007, "21.20"), (Standards.NACE2, "21.20")),
        ((Standards.PKD2007, "21.20.Z"), (Standards.NACE2, "21.20")),
        ((Standards.PKD2007, "22"), (Standards.NACE2, "22")),
        ((Standards.PKD2007, "22.1"), (Standards.NACE2, "22.1")),
        ((Standards.PKD2007, "22.11"), (Standards.NACE2, "22.11")),
        ((Standards.PKD2007, "22.11.Z"), (Standards.NACE2, "22.11")),
        ((Standards.PKD2007, "22.19"), (Standards.NACE2, "22.19")),
        ((Standards.PKD2007, "22.19.Z"), (Standards.NACE2, "22.19")),
        ((Standards.PKD2007, "22.2"), (Standards.NACE2, "22.2")),
        ((Standards.PKD2007, "22.21"), (Standards.NACE2, "22.21")),
        ((Standards.PKD2007, "22.21.Z"), (Standards.NACE2, "22.21")),
        ((Standards.PKD2007, "22.22"), (Standards.NACE2, "22.22")),
        ((Standards.PKD2007, "22.22.Z"), (Standards.NACE2, "22.22")),
        ((Standards.PKD2007, "22.23"), (Standards.NACE2, "22.23")),
        ((Standards.PKD2007, "22.23.Z"), (Standards.NACE2, "22.23")),
        ((Standards.PKD2007, "22.29"), (Standards.NACE2, "22.29")),
        ((Standards.PKD2007, "22.29.Z"), (Standards.NACE2, "22.29")),
        ((Standards.PKD2007, "23"), (Standards.NACE2, "23")),
        ((Standards.PKD2007, "23.1"), (Standards.NACE2, "23.1")),
        ((Standards.PKD2007, "23.11"), (Standards.NACE2, "23.11")),
        ((Standards.PKD2007, "23.11.Z"), (Standards.NACE2, "23.11")),
        ((Standards.PKD2007, "23.12"), (Standards.NACE2, "23.12")),
        ((Standards.PKD2007, "23.12.Z"), (Standards.NACE2, "23.12")),
        ((Standards.PKD2007, "23.13"), (Standards.NACE2, "23.13")),
        ((Standards.PKD2007, "23.13.Z"), (Standards.NACE2, "23.13")),
        ((Standards.PKD2007, "23.14"), (Standards.NACE2, "23.14")),
        ((Standards.PKD2007, "23.14.Z"), (Standards.NACE2, "23.14")),
        ((Standards.PKD2007, "23.19"), (Standards.NACE2, "23.19")),
        ((Standards.PKD2007, "23.19.Z"), (Standards.NACE2, "23.19")),
        ((Standards.PKD2007, "23.2"), (Standards.NACE2, "23.2")),
        ((Standards.PKD2007, "23.20"), (Standards.NACE2, "23.20")),
        ((Standards.PKD2007, "23.20.Z"), (Standards.NACE2, "23.20")),
        ((Standards.PKD2007, "23.3"), (Standards.NACE2, "23.3")),
        ((Standards.PKD2007, "23.31"), (Standards.NACE2, "23.31")),
        ((Standards.PKD2007, "23.31.Z"), (Standards.NACE2, "23.31")),
        ((Standards.PKD2007, "23.32"), (Standards.NACE2, "23.32")),
        ((Standards.PKD2007, "23.32.Z"), (Standards.NACE2, "23.32")),
        ((Standards.PKD2007, "23.4"), (Standards.NACE2, "23.4")),
        ((Standards.PKD2007, "23.41"), (Standards.NACE2, "23.41")),
        ((Standards.PKD2007, "23.41.Z"), (Standards.NACE2, "23.41")),
        ((Standards.PKD2007, "23.42"), (Standards.NACE2, "23.42")),
        ((Standards.PKD2007, "23.42.Z"), (Standards.NACE2, "23.42")),
        ((Standards.PKD2007, "23.43"), (Standards.NACE2, "23.43")),
        ((Standards.PKD2007, "23.43.Z"), (Standards.NACE2, "23.43")),
        ((Standards.PKD2007, "23.44"), (Standards.NACE2, "23.44")),
        ((Standards.PKD2007, "23.44.Z"), (Standards.NACE2, "23.44")),
        ((Standards.PKD2007, "23.49"), (Standards.NACE2, "23.49")),
        ((Standards.PKD2007, "23.49.Z"), (Standards.NACE2, "23.49")),
        ((Standards.PKD2007, "23.5"), (Standards.NACE2, "23.5")),
        ((Standards.PKD2007, "23.51"), (Standards.NACE2, "23.51")),
        ((Standards.PKD2007, "23.51.Z"), (Standards.NACE2, "23.51")),
        ((Standards.PKD2007, "23.52"), (Standards.NACE2, "23.52")),
        ((Standards.PKD2007, "23.52.Z"), (Standards.NACE2, "23.52")),
        ((Standards.PKD2007, "23.6"), (Standards.NACE2, "23.6")),
        ((Standards.PKD2007, "23.61"), (Standards.NACE2, "23.61")),
        ((Standards.PKD2007, "23.61.Z"), (Standards.NACE2, "23.61")),
        ((Standards.PKD2007, "23.62"), (Standards.NACE2, "23.62")),
        ((Standards.PKD2007, "23.62.Z"), (Standards.NACE2, "23.62")),
        ((Standards.PKD2007, "23.63"), (Standards.NACE2, "23.63")),
        ((Standards.PKD2007, "23.63.Z"), (Standards.NACE2, "23.63")),
        ((Standards.PKD2007, "23.64"), (Standards.NACE2, "23.64")),
        ((Standards.PKD2007, "23.64.Z"), (Standards.NACE2, "23.64")),
        ((Standards.PKD2007, "23.65"), (Standards.NACE2, "23.65")),
        ((Standards.PKD2007, "23.65.Z"), (Standards.NACE2, "23.65")),
        ((Standards.PKD2007, "23.69"), (Standards.NACE2, "23.69")),
        ((Standards.PKD2007, "23.69.Z"), (Standards.NACE2, "23.69")),
        ((Standards.PKD2007, "23.7"), (Standards.NACE2, "23.7")),
        ((Standards.PKD2007, "23.70"), (Standards.NACE2, "23.70")),
        ((Standards.PKD2007, "23.70.Z"), (Standards.NACE2, "23.70")),
        ((Standards.PKD2007, "23.9"), (Standards.NACE2, "23.9")),
        ((Standards.PKD2007, "23.91"), (Standards.NACE2, "23.91")),
        ((Standards.PKD2007, "23.91.Z"), (Standards.NACE2, "23.91")),
        ((Standards.PKD2007, "23.99"), (Standards.NACE2, "23.99")),
        ((Standards.PKD2007, "23.99.Z"), (Standards.NACE2, "23.99")),
        ((Standards.PKD2007, "24"), (Standards.NACE2, "24")),
        ((Standards.PKD2007, "24.1"), (Standards.NACE2, "24.1")),
        ((Standards.PKD2007, "24.10"), (Standards.NACE2, "24.10")),
        ((Standards.PKD2007, "24.10.Z"), (Standards.NACE2, "24.10")),
        ((Standards.PKD2007, "24.2"), (Standards.NACE2, "24.2")),
        ((Standards.PKD2007, "24.20"), (Standards.NACE2, "24.20")),
        ((Standards.PKD2007, "24.20.Z"), (Standards.NACE2, "24.20")),
        ((Standards.PKD2007, "24.3"), (Standards.NACE2, "24.3")),
        ((Standards.PKD2007, "24.31"), (Standards.NACE2, "24.31")),
        ((Standards.PKD2007, "24.31.Z"), (Standards.NACE2, "24.31")),
        ((Standards.PKD2007, "24.32"), (Standards.NACE2, "24.32")),
        ((Standards.PKD2007, "24.32.Z"), (Standards.NACE2, "24.32")),
        ((Standards.PKD2007, "24.33"), (Standards.NACE2, "24.33")),
        ((Standards.PKD2007, "24.33.Z"), (Standards.NACE2, "24.33")),
        ((Standards.PKD2007, "24.34"), (Standards.NACE2, "24.34")),
        ((Standards.PKD2007, "24.34.Z"), (Standards.NACE2, "24.34")),
        ((Standards.PKD2007, "24.4"), (Standards.NACE2, "24.4")),
        ((Standards.PKD2007, "24.41"), (Standards.NACE2, "24.41")),
        ((Standards.PKD2007, "24.41.Z"), (Standards.NACE2, "24.41")),
        ((Standards.PKD2007, "24.42"), (Standards.NACE2, "24.42")),
        ((Standards.PKD2007, "24.42.A"), (Standards.NACE2, "24.42")),
        ((Standards.PKD2007, "24.42.B"), (Standards.NACE2, "24.42")),
        ((Standards.PKD2007, "24.43"), (Standards.NACE2, "24.43")),
        ((Standards.PKD2007, "24.43.Z"), (Standards.NACE2, "24.43")),
        ((Standards.PKD2007, "24.44"), (Standards.NACE2, "24.44")),
        ((Standards.PKD2007, "24.44.Z"), (Standards.NACE2, "24.44")),
        ((Standards.PKD2007, "24.45"), (Standards.NACE2, "24.45")),
        ((Standards.PKD2007, "24.45.Z"), (Standards.NACE2, "24.45")),
        ((Standards.PKD2007, "24.46"), (Standards.NACE2, "24.46")),
        ((Standards.PKD2007, "24.46.Z"), (Standards.NACE2, "24.46")),
        ((Standards.PKD2007, "24.5"), (Standards.NACE2, "24.5")),
        ((Standards.PKD2007, "24.51"), (Standards.NACE2, "24.51")),
        ((Standards.PKD2007, "24.51.Z"), (Standards.NACE2, "24.51")),
        ((Standards.PKD2007, "24.52"), (Standards.NACE2, "24.52")),
        ((Standards.PKD2007, "24.52.Z"), (Standards.NACE2, "24.52")),
        ((Standards.PKD2007, "24.53"), (Standards.NACE2, "24.53")),
        ((Standards.PKD2007, "24.53.Z"), (Standards.NACE2, "24.53")),
        ((Standards.PKD2007, "24.54"), (Standards.NACE2, "24.54")),
        ((Standards.PKD2007, "24.54.A"), (Standards.NACE2, "24.54")),
        ((Standards.PKD2007, "24.54.B"), (Standards.NACE2, "24.54")),
        ((Standards.PKD2007, "25"), (Standards.NACE2, "25")),
        ((Standards.PKD2007, "25.1"), (Standards.NACE2, "25.1")),
        ((Standards.PKD2007, "25.11"), (Standards.NACE2, "25.11")),
        ((Standards.PKD2007, "25.11.Z"), (Standards.NACE2, "25.11")),
        ((Standards.PKD2007, "25.12"), (Standards.NACE2, "25.12")),
        ((Standards.PKD2007, "25.12.Z"), (Standards.NACE2, "25.12")),
        ((Standards.PKD2007, "25.2"), (Standards.NACE2, "25.2")),
        ((Standards.PKD2007, "25.21"), (Standards.NACE2, "25.21")),
        ((Standards.PKD2007, "25.21.Z"), (Standards.NACE2, "25.21")),
        ((Standards.PKD2007, "25.29"), (Standards.NACE2, "25.29")),
        ((Standards.PKD2007, "25.29.Z"), (Standards.NACE2, "25.29")),
        ((Standards.PKD2007, "25.3"), (Standards.NACE2, "25.3")),
        ((Standards.PKD2007, "25.30"), (Standards.NACE2, "25.30")),
        ((Standards.PKD2007, "25.30.Z"), (Standards.NACE2, "25.30")),
        ((Standards.PKD2007, "25.4"), (Standards.NACE2, "25.4")),
        ((Standards.PKD2007, "25.40"), (Standards.NACE2, "25.40")),
        ((Standards.PKD2007, "25.40.Z"), (Standards.NACE2, "25.40")),
        ((Standards.PKD2007, "25.5"), (Standards.NACE2, "25.5")),
        ((Standards.PKD2007, "25.50"), (Standards.NACE2, "25.50")),
        ((Standards.PKD2007, "25.50.Z"), (Standards.NACE2, "25.50")),
        ((Standards.PKD2007, "25.6"), (Standards.NACE2, "25.6")),
        ((Standards.PKD2007, "25.61"), (Standards.NACE2, "25.61")),
        ((Standards.PKD2007, "25.61.Z"), (Standards.NACE2, "25.61")),
        ((Standards.PKD2007, "25.62"), (Standards.NACE2, "25.62")),
        ((Standards.PKD2007, "25.62.Z"), (Standards.NACE2, "25.62")),
        ((Standards.PKD2007, "25.7"), (Standards.NACE2, "25.7")),
        ((Standards.PKD2007, "25.71"), (Standards.NACE2, "25.71")),
        ((Standards.PKD2007, "25.71.Z"), (Standards.NACE2, "25.71")),
        ((Standards.PKD2007, "25.72"), (Standards.NACE2, "25.72")),
        ((Standards.PKD2007, "25.72.Z"), (Standards.NACE2, "25.72")),
        ((Standards.PKD2007, "25.73"), (Standards.NACE2, "25.73")),
        ((Standards.PKD2007, "25.73.Z"), (Standards.NACE2, "25.73")),
        ((Standards.PKD2007, "25.9"), (Standards.NACE2, "25.9")),
        ((Standards.PKD2007, "25.91"), (Standards.NACE2, "25.91")),
        ((Standards.PKD2007, "25.91.Z"), (Standards.NACE2, "25.91")),
        ((Standards.PKD2007, "25.92"), (Standards.NACE2, "25.92")),
        ((Standards.PKD2007, "25.92.Z"), (Standards.NACE2, "25.92")),
        ((Standards.PKD2007, "25.93"), (Standards.NACE2, "25.93")),
        ((Standards.PKD2007, "25.93.Z"), (Standards.NACE2, "25.93")),
        ((Standards.PKD2007, "25.94"), (Standards.NACE2, "25.94")),
        ((Standards.PKD2007, "25.94.Z"), (Standards.NACE2, "25.94")),
        ((Standards.PKD2007, "25.99"), (Standards.NACE2, "25.99")),
        ((Standards.PKD2007, "25.99.Z"), (Standards.NACE2, "25.99")),
        ((Standards.PKD2007, "26"), (Standards.NACE2, "26")),
        ((Standards.PKD2007, "26.1"), (Standards.NACE2, "26.1")),
        ((Standards.PKD2007, "26.11"), (Standards.NACE2, "26.11")),
        ((Standards.PKD2007, "26.11.Z"), (Standards.NACE2, "26.11")),
        ((Standards.PKD2007, "26.12"), (Standards.NACE2, "26.12")),
        ((Standards.PKD2007, "26.12.Z"), (Standards.NACE2, "26.12")),
        ((Standards.PKD2007, "26.2"), (Standards.NACE2, "26.2")),
        ((Standards.PKD2007, "26.20"), (Standards.NACE2, "26.20")),
        ((Standards.PKD2007, "26.20.Z"), (Standards.NACE2, "26.20")),
        ((Standards.PKD2007, "26.3"), (Standards.NACE2, "26.3")),
        ((Standards.PKD2007, "26.30"), (Standards.NACE2, "26.30")),
        ((Standards.PKD2007, "26.30.Z"), (Standards.NACE2, "26.30")),
        ((Standards.PKD2007, "26.4"), (Standards.NACE2, "26.4")),
        ((Standards.PKD2007, "26.40"), (Standards.NACE2, "26.40")),
        ((Standards.PKD2007, "26.40.Z"), (Standards.NACE2, "26.40")),
        ((Standards.PKD2007, "26.5"), (Standards.NACE2, "26.5")),
        ((Standards.PKD2007, "26.51"), (Standards.NACE2, "26.51")),
        ((Standards.PKD2007, "26.51.Z"), (Standards.NACE2, "26.51")),
        ((Standards.PKD2007, "26.52"), (Standards.NACE2, "26.52")),
        ((Standards.PKD2007, "26.52.Z"), (Standards.NACE2, "26.52")),
        ((Standards.PKD2007, "26.6"), (Standards.NACE2, "26.6")),
        ((Standards.PKD2007, "26.60"), (Standards.NACE2, "26.60")),
        ((Standards.PKD2007, "26.60.Z"), (Standards.NACE2, "26.60")),
        ((Standards.PKD2007, "26.7"), (Standards.NACE2, "26.7")),
        ((Standards.PKD2007, "26.70"), (Standards.NACE2, "26.70")),
        ((Standards.PKD2007, "26.70.Z"), (Standards.NACE2, "26.70")),
        ((Standards.PKD2007, "26.8"), (Standards.NACE2, "26.8")),
        ((Standards.PKD2007, "26.80"), (Standards.NACE2, "26.80")),
        ((Standards.PKD2007, "26.80.Z"), (Standards.NACE2, "26.80")),
        ((Standards.PKD2007, "27"), (Standards.NACE2, "27")),
        ((Standards.PKD2007, "27.1"), (Standards.NACE2, "27.1")),
        ((Standards.PKD2007, "27.11"), (Standards.NACE2, "27.11")),
        ((Standards.PKD2007, "27.11.Z"), (Standards.NACE2, "27.11")),
        ((Standards.PKD2007, "27.12"), (Standards.NACE2, "27.12")),
        ((Standards.PKD2007, "27.12.Z"), (Standards.NACE2, "27.12")),
        ((Standards.PKD2007, "27.2"), (Standards.NACE2, "27.2")),
        ((Standards.PKD2007, "27.20"), (Standards.NACE2, "27.20")),
        ((Standards.PKD2007, "27.20.Z"), (Standards.NACE2, "27.20")),
        ((Standards.PKD2007, "27.3"), (Standards.NACE2, "27.3")),
        ((Standards.PKD2007, "27.31"), (Standards.NACE2, "27.31")),
        ((Standards.PKD2007, "27.31.Z"), (Standards.NACE2, "27.31")),
        ((Standards.PKD2007, "27.32"), (Standards.NACE2, "27.32")),
        ((Standards.PKD2007, "27.32.Z"), (Standards.NACE2, "27.32")),
        ((Standards.PKD2007, "27.33"), (Standards.NACE2, "27.33")),
        ((Standards.PKD2007, "27.33.Z"), (Standards.NACE2, "27.33")),
        ((Standards.PKD2007, "27.4"), (Standards.NACE2, "27.4")),
        ((Standards.PKD2007, "27.40"), (Standards.NACE2, "27.40")),
        ((Standards.PKD2007, "27.40.Z"), (Standards.NACE2, "27.40")),
        ((Standards.PKD2007, "27.5"), (Standards.NACE2, "27.5")),
        ((Standards.PKD2007, "27.51"), (Standards.NACE2, "27.51")),
        ((Standards.PKD2007, "27.51.Z"), (Standards.NACE2, "27.51")),
        ((Standards.PKD2007, "27.52"), (Standards.NACE2, "27.52")),
        ((Standards.PKD2007, "27.52.Z"), (Standards.NACE2, "27.52")),
        ((Standards.PKD2007, "27.9"), (Standards.NACE2, "27.9")),
        ((Standards.PKD2007, "27.90"), (Standards.NACE2, "27.90")),
        ((Standards.PKD2007, "27.90.Z"), (Standards.NACE2, "27.90")),
        ((Standards.PKD2007, "28"), (Standards.NACE2, "28")),
        ((Standards.PKD2007, "28.1"), (Standards.NACE2, "28.1")),
        ((Standards.PKD2007, "28.11"), (Standards.NACE2, "28.11")),
        ((Standards.PKD2007, "28.11.Z"), (Standards.NACE2, "28.11")),
        ((Standards.PKD2007, "28.12"), (Standards.NACE2, "28.12")),
        ((Standards.PKD2007, "28.12.Z"), (Standards.NACE2, "28.12")),
        ((Standards.PKD2007, "28.13"), (Standards.NACE2, "28.13")),
        ((Standards.PKD2007, "28.13.Z"), (Standards.NACE2, "28.13")),
        ((Standards.PKD2007, "28.14"), (Standards.NACE2, "28.14")),
        ((Standards.PKD2007, "28.14.Z"), (Standards.NACE2, "28.14")),
        ((Standards.PKD2007, "28.15"), (Standards.NACE2, "28.15")),
        ((Standards.PKD2007, "28.15.Z"), (Standards.NACE2, "28.15")),
        ((Standards.PKD2007, "28.2"), (Standards.NACE2, "28.2")),
        ((Standards.PKD2007, "28.21"), (Standards.NACE2, "28.21")),
        ((Standards.PKD2007, "28.21.Z"), (Standards.NACE2, "28.21")),
        ((Standards.PKD2007, "28.22"), (Standards.NACE2, "28.22")),
        ((Standards.PKD2007, "28.22.Z"), (Standards.NACE2, "28.22")),
        ((Standards.PKD2007, "28.23"), (Standards.NACE2, "28.23")),
        ((Standards.PKD2007, "28.23.Z"), (Standards.NACE2, "28.23")),
        ((Standards.PKD2007, "28.24"), (Standards.NACE2, "28.24")),
        ((Standards.PKD2007, "28.24.Z"), (Standards.NACE2, "28.24")),
        ((Standards.PKD2007, "28.25"), (Standards.NACE2, "28.25")),
        ((Standards.PKD2007, "28.25.Z"), (Standards.NACE2, "28.25")),
        ((Standards.PKD2007, "28.29"), (Standards.NACE2, "28.29")),
        ((Standards.PKD2007, "28.29.Z"), (Standards.NACE2, "28.29")),
        ((Standards.PKD2007, "28.3"), (Standards.NACE2, "28.3")),
        ((Standards.PKD2007, "28.30"), (Standards.NACE2, "28.30")),
        ((Standards.PKD2007, "28.30.Z"), (Standards.NACE2, "28.30")),
        ((Standards.PKD2007, "28.4"), (Standards.NACE2, "28.4")),
        ((Standards.PKD2007, "28.41"), (Standards.NACE2, "28.41")),
        ((Standards.PKD2007, "28.41.Z"), (Standards.NACE2, "28.41")),
        ((Standards.PKD2007, "28.49"), (Standards.NACE2, "28.49")),
        ((Standards.PKD2007, "28.49.Z"), (Standards.NACE2, "28.49")),
        ((Standards.PKD2007, "28.9"), (Standards.NACE2, "28.9")),
        ((Standards.PKD2007, "28.91"), (Standards.NACE2, "28.91")),
        ((Standards.PKD2007, "28.91.Z"), (Standards.NACE2, "28.91")),
        ((Standards.PKD2007, "28.92"), (Standards.NACE2, "28.92")),
        ((Standards.PKD2007, "28.92.Z"), (Standards.NACE2, "28.92")),
        ((Standards.PKD2007, "28.93"), (Standards.NACE2, "28.93")),
        ((Standards.PKD2007, "28.93.Z"), (Standards.NACE2, "28.93")),
        ((Standards.PKD2007, "28.94"), (Standards.NACE2, "28.94")),
        ((Standards.PKD2007, "28.94.Z"), (Standards.NACE2, "28.94")),
        ((Standards.PKD2007, "28.95"), (Standards.NACE2, "28.95")),
        ((Standards.PKD2007, "28.95.Z"), (Standards.NACE2, "28.95")),
        ((Standards.PKD2007, "28.96"), (Standards.NACE2, "28.96")),
        ((Standards.PKD2007, "28.96.Z"), (Standards.NACE2, "28.96")),
        ((Standards.PKD2007, "28.99"), (Standards.NACE2, "28.99")),
        ((Standards.PKD2007, "28.99.Z"), (Standards.NACE2, "28.99")),
        ((Standards.PKD2007, "29"), (Standards.NACE2, "29")),
        ((Standards.PKD2007, "29.1"), (Standards.NACE2, "29.1")),
        ((Standards.PKD2007, "29.10"), (Standards.NACE2, "29.10")),
        ((Standards.PKD2007, "29.10.A"), (Standards.NACE2, "29.10")),
        ((Standards.PKD2007, "29.10.B"), (Standards.NACE2, "29.10")),
        ((Standards.PKD2007, "29.10.C"), (Standards.NACE2, "29.10")),
        ((Standards.PKD2007, "29.10.D"), (Standards.NACE2, "29.10")),
        ((Standards.PKD2007, "29.10.E"), (Standards.NACE2, "29.10")),
        ((Standards.PKD2007, "29.2"), (Standards.NACE2, "29.2")),
        ((Standards.PKD2007, "29.20"), (Standards.NACE2, "29.20")),
        ((Standards.PKD2007, "29.20.Z"), (Standards.NACE2, "29.20")),
        ((Standards.PKD2007, "29.3"), (Standards.NACE2, "29.3")),
        ((Standards.PKD2007, "29.31"), (Standards.NACE2, "29.31")),
        ((Standards.PKD2007, "29.31.Z"), (Standards.NACE2, "29.31")),
        ((Standards.PKD2007, "29.32"), (Standards.NACE2, "29.32")),
        ((Standards.PKD2007, "29.32.Z"), (Standards.NACE2, "29.32")),
        ((Standards.PKD2007, "30"), (Standards.NACE2, "30")),
        ((Standards.PKD2007, "30.1"), (Standards.NACE2, "30.1")),
        ((Standards.PKD2007, "30.11"), (Standards.NACE2, "30.11")),
        ((Standards.PKD2007, "30.11.Z"), (Standards.NACE2, "30.11")),
        ((Standards.PKD2007, "30.12"), (Standards.NACE2, "30.12")),
        ((Standards.PKD2007, "30.12.Z"), (Standards.NACE2, "30.12")),
        ((Standards.PKD2007, "30.2"), (Standards.NACE2, "30.2")),
        ((Standards.PKD2007, "30.20"), (Standards.NACE2, "30.20")),
        ((Standards.PKD2007, "30.20.Z"), (Standards.NACE2, "30.20")),
        ((Standards.PKD2007, "30.3"), (Standards.NACE2, "30.3")),
        ((Standards.PKD2007, "30.30"), (Standards.NACE2, "30.30")),
        ((Standards.PKD2007, "30.30.Z"), (Standards.NACE2, "30.30")),
        ((Standards.PKD2007, "30.4"), (Standards.NACE2, "30.4")),
        ((Standards.PKD2007, "30.40"), (Standards.NACE2, "30.40")),
        ((Standards.PKD2007, "30.40.Z"), (Standards.NACE2, "30.40")),
        ((Standards.PKD2007, "30.9"), (Standards.NACE2, "30.9")),
        ((Standards.PKD2007, "30.91"), (Standards.NACE2, "30.91")),
        ((Standards.PKD2007, "30.91.Z"), (Standards.NACE2, "30.91")),
        ((Standards.PKD2007, "30.92"), (Standards.NACE2, "30.92")),
        ((Standards.PKD2007, "30.92.Z"), (Standards.NACE2, "30.92")),
        ((Standards.PKD2007, "30.99"), (Standards.NACE2, "30.99")),
        ((Standards.PKD2007, "30.99.Z"), (Standards.NACE2, "30.99")),
        ((Standards.PKD2007, "31"), (Standards.NACE2, "31")),
        ((Standards.PKD2007, "31.0"), (Standards.NACE2, "31.0")),
        ((Standards.PKD2007, "31.01"), (Standards.NACE2, "31.01")),
        ((Standards.PKD2007, "31.01.Z"), (Standards.NACE2, "31.01")),
        ((Standards.PKD2007, "31.02"), (Standards.NACE2, "31.02")),
        ((Standards.PKD2007, "31.02.Z"), (Standards.NACE2, "31.02")),
        ((Standards.PKD2007, "31.03"), (Standards.NACE2, "31.03")),
        ((Standards.PKD2007, "31.03.Z"), (Standards.NACE2, "31.03")),
        ((Standards.PKD2007, "31.09"), (Standards.NACE2, "31.09")),
        ((Standards.PKD2007, "31.09.Z"), (Standards.NACE2, "31.09")),
        ((Standards.PKD2007, "32"), (Standards.NACE2, "32")),
        ((Standards.PKD2007, "32.1"), (Standards.NACE2, "32.1")),
        ((Standards.PKD2007, "32.11"), (Standards.NACE2, "32.11")),
        ((Standards.PKD2007, "32.11.Z"), (Standards.NACE2, "32.11")),
        ((Standards.PKD2007, "32.12"), (Standards.NACE2, "32.12")),
        ((Standards.PKD2007, "32.12.Z"), (Standards.NACE2, "32.12")),
        ((Standards.PKD2007, "32.13"), (Standards.NACE2, "32.13")),
        ((Standards.PKD2007, "32.13.Z"), (Standards.NACE2, "32.13")),
        ((Standards.PKD2007, "32.2"), (Standards.NACE2, "32.2")),
        ((Standards.PKD2007, "32.20"), (Standards.NACE2, "32.20")),
        ((Standards.PKD2007, "32.20.Z"), (Standards.NACE2, "32.20")),
        ((Standards.PKD2007, "32.3"), (Standards.NACE2, "32.3")),
        ((Standards.PKD2007, "32.30"), (Standards.NACE2, "32.30")),
        ((Standards.PKD2007, "32.30.Z"), (Standards.NACE2, "32.30")),
        ((Standards.PKD2007, "32.4"), (Standards.NACE2, "32.4")),
        ((Standards.PKD2007, "32.40"), (Standards.NACE2, "32.40")),
        ((Standards.PKD2007, "32.40.Z"), (Standards.NACE2, "32.40")),
        ((Standards.PKD2007, "32.5"), (Standards.NACE2, "32.5")),
        ((Standards.PKD2007, "32.50"), (Standards.NACE2, "32.50")),
        ((Standards.PKD2007, "32.50.Z"), (Standards.NACE2, "32.50")),
        ((Standards.PKD2007, "32.9"), (Standards.NACE2, "32.9")),
        ((Standards.PKD2007, "32.91"), (Standards.NACE2, "32.91")),
        ((Standards.PKD2007, "32.91.Z"), (Standards.NACE2, "32.91")),
        ((Standards.PKD2007, "32.99"), (Standards.NACE2, "32.99")),
        ((Standards.PKD2007, "32.99.Z"), (Standards.NACE2, "32.99")),
        ((Standards.PKD2007, "33"), (Standards.NACE2, "33")),
        ((Standards.PKD2007, "33.1"), (Standards.NACE2, "33.1")),
        ((Standards.PKD2007, "33.11"), (Standards.NACE2, "33.11")),
        ((Standards.PKD2007, "33.11.Z"), (Standards.NACE2, "33.11")),
        ((Standards.PKD2007, "33.12"), (Standards.NACE2, "33.12")),
        ((Standards.PKD2007, "33.12.Z"), (Standards.NACE2, "33.12")),
        ((Standards.PKD2007, "33.13"), (Standards.NACE2, "33.13")),
        ((Standards.PKD2007, "33.13.Z"), (Standards.NACE2, "33.13")),
        ((Standards.PKD2007, "33.14"), (Standards.NACE2, "33.14")),
        ((Standards.PKD2007, "33.14.Z"), (Standards.NACE2, "33.14")),
        ((Standards.PKD2007, "33.15"), (Standards.NACE2, "33.15")),
        ((Standards.PKD2007, "33.15.Z"), (Standards.NACE2, "33.15")),
        ((Standards.PKD2007, "33.16"), (Standards.NACE2, "33.16")),
        ((Standards.PKD2007, "33.16.Z"), (Standards.NACE2, "33.16")),
        ((Standards.PKD2007, "33.17"), (Standards.NACE2, "33.17")),
        ((Standards.PKD2007, "33.17.Z"), (Standards.NACE2, "33.17")),
        ((Standards.PKD2007, "33.19"), (Standards.NACE2, "33.19")),
        ((Standards.PKD2007, "33.19.Z"), (Standards.NACE2, "33.19")),
        ((Standards.PKD2007, "33.2"), (Standards.NACE2, "33.2")),
        ((Standards.PKD2007, "33.20"), (Standards.NACE2, "33.20")),
        ((Standards.PKD2007, "33.20.Z"), (Standards.NACE2, "33.20")),
        ((Standards.PKD2007, "D"), (Standards.NACE2, "D")),
        ((Standards.PKD2007, "35"), (Standards.NACE2, "35")),
        ((Standards.PKD2007, "35.1"), (Standards.NACE2, "35.1")),
        ((Standards.PKD2007, "35.11"), (Standards.NACE2, "35.11")),
        ((Standards.PKD2007, "35.11.Z"), (Standards.NACE2, "35.11")),
        ((Standards.PKD2007, "35.12"), (Standards.NACE2, "35.12")),
        ((Standards.PKD2007, "35.12.Z"), (Standards.NACE2, "35.12")),
        ((Standards.PKD2007, "35.13"), (Standards.NACE2, "35.13")),
        ((Standards.PKD2007, "35.13.Z"), (Standards.NACE2, "35.13")),
        ((Standards.PKD2007, "35.14"), (Standards.NACE2, "35.14")),
        ((Standards.PKD2007, "35.14.Z"), (Standards.NACE2, "35.14")),
        ((Standards.PKD2007, "35.2"), (Standards.NACE2, "35.2")),
        ((Standards.PKD2007, "35.21"), (Standards.NACE2, "35.21")),
        ((Standards.PKD2007, "35.21.Z"), (Standards.NACE2, "35.21")),
        ((Standards.PKD2007, "35.22"), (Standards.NACE2, "35.22")),
        ((Standards.PKD2007, "35.22.Z"), (Standards.NACE2, "35.22")),
        ((Standards.PKD2007, "35.23"), (Standards.NACE2, "35.23")),
        ((Standards.PKD2007, "35.23.Z"), (Standards.NACE2, "35.23")),
        ((Standards.PKD2007, "35.3"), (Standards.NACE2, "35.3")),
        ((Standards.PKD2007, "35.30"), (Standards.NACE2, "35.30")),
        ((Standards.PKD2007, "35.30.Z"), (Standards.NACE2, "35.30")),
        ((Standards.PKD2007, "E"), (Standards.NACE2, "E")),
        ((Standards.PKD2007, "36"), (Standards.NACE2, "36")),
        ((Standards.PKD2007, "36.0"), (Standards.NACE2, "36.0")),
        ((Standards.PKD2007, "36.00"), (Standards.NACE2, "36.00")),
        ((Standards.PKD2007, "36.00.Z"), (Standards.NACE2, "36.00")),
        ((Standards.PKD2007, "37"), (Standards.NACE2, "37")),
        ((Standards.PKD2007, "37.0"), (Standards.NACE2, "37.0")),
        ((Standards.PKD2007, "37.00"), (Standards.NACE2, "37.00")),
        ((Standards.PKD2007, "37.00.Z"), (Standards.NACE2, "37.00")),
        ((Standards.PKD2007, "38"), (Standards.NACE2, "38")),
        ((Standards.PKD2007, "38.1"), (Standards.NACE2, "38.1")),
        ((Standards.PKD2007, "38.11"), (Standards.NACE2, "38.11")),
        ((Standards.PKD2007, "38.11.Z"), (Standards.NACE2, "38.11")),
        ((Standards.PKD2007, "38.12"), (Standards.NACE2, "38.12")),
        ((Standards.PKD2007, "38.12.Z"), (Standards.NACE2, "38.12")),
        ((Standards.PKD2007, "38.2"), (Standards.NACE2, "38.2")),
        ((Standards.PKD2007, "38.21"), (Standards.NACE2, "38.21")),
        ((Standards.PKD2007, "38.21.Z"), (Standards.NACE2, "38.21")),
        ((Standards.PKD2007, "38.22"), (Standards.NACE2, "38.22")),
        ((Standards.PKD2007, "38.22.Z"), (Standards.NACE2, "38.22")),
        ((Standards.PKD2007, "38.3"), (Standards.NACE2, "38.3")),
        ((Standards.PKD2007, "38.31"), (Standards.NACE2, "38.31")),
        ((Standards.PKD2007, "38.31.Z"), (Standards.NACE2, "38.31")),
        ((Standards.PKD2007, "38.32"), (Standards.NACE2, "38.32")),
        ((Standards.PKD2007, "38.32.Z"), (Standards.NACE2, "38.32")),
        ((Standards.PKD2007, "39"), (Standards.NACE2, "39")),
        ((Standards.PKD2007, "39.0"), (Standards.NACE2, "39.0")),
        ((Standards.PKD2007, "39.00"), (Standards.NACE2, "39.00")),
        ((Standards.PKD2007, "39.00.Z"), (Standards.NACE2, "39.00")),
        ((Standards.PKD2007, "F"), (Standards.NACE2, "F")),
        ((Standards.PKD2007, "41"), (Standards.NACE2, "41")),
        ((Standards.PKD2007, "41.1"), (Standards.NACE2, "41.1")),
        ((Standards.PKD2007, "41.10"), (Standards.NACE2, "41.10")),
        ((Standards.PKD2007, "41.10.Z"), (Standards.NACE2, "41.10")),
        ((Standards.PKD2007, "41.2"), (Standards.NACE2, "41.2")),
        ((Standards.PKD2007, "41.20"), (Standards.NACE2, "41.20")),
        ((Standards.PKD2007, "41.20.Z"), (Standards.NACE2, "41.20")),
        ((Standards.PKD2007, "42"), (Standards.NACE2, "42")),
        ((Standards.PKD2007, "42.1"), (Standards.NACE2, "42.1")),
        ((Standards.PKD2007, "42.11"), (Standards.NACE2, "42.11")),
        ((Standards.PKD2007, "42.11.Z"), (Standards.NACE2, "42.11")),
        ((Standards.PKD2007, "42.12"), (Standards.NACE2, "42.12")),
        ((Standards.PKD2007, "42.12.Z"), (Standards.NACE2, "42.12")),
        ((Standards.PKD2007, "42.13"), (Standards.NACE2, "42.13")),
        ((Standards.PKD2007, "42.13.Z"), (Standards.NACE2, "42.13")),
        ((Standards.PKD2007, "42.2"), (Standards.NACE2, "42.2")),
        ((Standards.PKD2007, "42.21"), (Standards.NACE2, "42.21")),
        ((Standards.PKD2007, "42.21.Z"), (Standards.NACE2, "42.21")),
        ((Standards.PKD2007, "42.22"), (Standards.NACE2, "42.22")),
        ((Standards.PKD2007, "42.22.Z"), (Standards.NACE2, "42.22")),
        ((Standards.PKD2007, "42.9"), (Standards.NACE2, "42.9")),
        ((Standards.PKD2007, "42.91"), (Standards.NACE2, "42.91")),
        ((Standards.PKD2007, "42.91.Z"), (Standards.NACE2, "42.91")),
        ((Standards.PKD2007, "42.99"), (Standards.NACE2, "42.99")),
        ((Standards.PKD2007, "42.99.Z"), (Standards.NACE2, "42.99")),
        ((Standards.PKD2007, "43"), (Standards.NACE2, "43")),
        ((Standards.PKD2007, "43.1"), (Standards.NACE2, "43.1")),
        ((Standards.PKD2007, "43.11"), (Standards.NACE2, "43.11")),
        ((Standards.PKD2007, "43.11.Z"), (Standards.NACE2, "43.11")),
        ((Standards.PKD2007, "43.12"), (Standards.NACE2, "43.12")),
        ((Standards.PKD2007, "43.12.Z"), (Standards.NACE2, "43.12")),
        ((Standards.PKD2007, "43.13"), (Standards.NACE2, "43.13")),
        ((Standards.PKD2007, "43.13.Z"), (Standards.NACE2, "43.13")),
        ((Standards.PKD2007, "43.2"), (Standards.NACE2, "43.2")),
        ((Standards.PKD2007, "43.21"), (Standards.NACE2, "43.21")),
        ((Standards.PKD2007, "43.21.Z"), (Standards.NACE2, "43.21")),
        ((Standards.PKD2007, "43.22"), (Standards.NACE2, "43.22")),
        ((Standards.PKD2007, "43.22.Z"), (Standards.NACE2, "43.22")),
        ((Standards.PKD2007, "43.29"), (Standards.NACE2, "43.29")),
        ((Standards.PKD2007, "43.29.Z"), (Standards.NACE2, "43.29")),
        ((Standards.PKD2007, "43.3"), (Standards.NACE2, "43.3")),
        ((Standards.PKD2007, "43.31"), (Standards.NACE2, "43.31")),
        ((Standards.PKD2007, "43.31.Z"), (Standards.NACE2, "43.31")),
        ((Standards.PKD2007, "43.32"), (Standards.NACE2, "43.32")),
        ((Standards.PKD2007, "43.32.Z"), (Standards.NACE2, "43.32")),
        ((Standards.PKD2007, "43.33"), (Standards.NACE2, "43.33")),
        ((Standards.PKD2007, "43.33.Z"), (Standards.NACE2, "43.33")),
        ((Standards.PKD2007, "43.34"), (Standards.NACE2, "43.34")),
        ((Standards.PKD2007, "43.34.Z"), (Standards.NACE2, "43.34")),
        ((Standards.PKD2007, "43.39"), (Standards.NACE2, "43.39")),
        ((Standards.PKD2007, "43.39.Z"), (Standards.NACE2, "43.39")),
        ((Standards.PKD2007, "43.9"), (Standards.NACE2, "43.9")),
        ((Standards.PKD2007, "43.91"), (Standards.NACE2, "43.91")),
        ((Standards.PKD2007, "43.91.Z"), (Standards.NACE2, "43.91")),
        ((Standards.PKD2007, "43.99"), (Standards.NACE2, "43.99")),
        ((Standards.PKD2007, "43.99.Z"), (Standards.NACE2, "43.99")),
        ((Standards.PKD2007, "G"), (Standards.NACE2, "G")),
        ((Standards.PKD2007, "45"), (Standards.NACE2, "45")),
        ((Standards.PKD2007, "45.1"), (Standards.NACE2, "45.1")),
        ((Standards.PKD2007, "45.11"), (Standards.NACE2, "45.11")),
        ((Standards.PKD2007, "45.11.Z"), (Standards.NACE2, "45.11")),
        ((Standards.PKD2007, "45.19"), (Standards.NACE2, "45.19")),
        ((Standards.PKD2007, "45.19.Z"), (Standards.NACE2, "45.19")),
        ((Standards.PKD2007, "45.2"), (Standards.NACE2, "45.2")),
        ((Standards.PKD2007, "45.20"), (Standards.NACE2, "45.20")),
        ((Standards.PKD2007, "45.20.Z"), (Standards.NACE2, "45.20")),
        ((Standards.PKD2007, "45.3"), (Standards.NACE2, "45.3")),
        ((Standards.PKD2007, "45.31"), (Standards.NACE2, "45.31")),
        ((Standards.PKD2007, "45.31.Z"), (Standards.NACE2, "45.31")),
        ((Standards.PKD2007, "45.32"), (Standards.NACE2, "45.32")),
        ((Standards.PKD2007, "45.32.Z"), (Standards.NACE2, "45.32")),
        ((Standards.PKD2007, "45.4"), (Standards.NACE2, "45.4")),
        ((Standards.PKD2007, "45.40"), (Standards.NACE2, "45.40")),
        ((Standards.PKD2007, "45.40.Z"), (Standards.NACE2, "45.40")),
        ((Standards.PKD2007, "46"), (Standards.NACE2, "46")),
        ((Standards.PKD2007, "46.1"), (Standards.NACE2, "46.1")),
        ((Standards.PKD2007, "46.11"), (Standards.NACE2, "46.11")),
        ((Standards.PKD2007, "46.11.Z"), (Standards.NACE2, "46.11")),
        ((Standards.PKD2007, "46.12"), (Standards.NACE2, "46.12")),
        ((Standards.PKD2007, "46.12.Z"), (Standards.NACE2, "46.12")),
        ((Standards.PKD2007, "46.13"), (Standards.NACE2, "46.13")),
        ((Standards.PKD2007, "46.13.Z"), (Standards.NACE2, "46.13")),
        ((Standards.PKD2007, "46.14"), (Standards.NACE2, "46.14")),
        ((Standards.PKD2007, "46.14.Z"), (Standards.NACE2, "46.14")),
        ((Standards.PKD2007, "46.15"), (Standards.NACE2, "46.15")),
        ((Standards.PKD2007, "46.15.Z"), (Standards.NACE2, "46.15")),
        ((Standards.PKD2007, "46.16"), (Standards.NACE2, "46.16")),
        ((Standards.PKD2007, "46.16.Z"), (Standards.NACE2, "46.16")),
        ((Standards.PKD2007, "46.17"), (Standards.NACE2, "46.17")),
        ((Standards.PKD2007, "46.17.Z"), (Standards.NACE2, "46.17")),
        ((Standards.PKD2007, "46.18"), (Standards.NACE2, "46.18")),
        ((Standards.PKD2007, "46.18.Z"), (Standards.NACE2, "46.18")),
        ((Standards.PKD2007, "46.19"), (Standards.NACE2, "46.19")),
        ((Standards.PKD2007, "46.19.Z"), (Standards.NACE2, "46.19")),
        ((Standards.PKD2007, "46.2"), (Standards.NACE2, "46.2")),
        ((Standards.PKD2007, "46.21"), (Standards.NACE2, "46.21")),
        ((Standards.PKD2007, "46.21.Z"), (Standards.NACE2, "46.21")),
        ((Standards.PKD2007, "46.22"), (Standards.NACE2, "46.22")),
        ((Standards.PKD2007, "46.22.Z"), (Standards.NACE2, "46.22")),
        ((Standards.PKD2007, "46.23"), (Standards.NACE2, "46.23")),
        ((Standards.PKD2007, "46.23.Z"), (Standards.NACE2, "46.23")),
        ((Standards.PKD2007, "46.24"), (Standards.NACE2, "46.24")),
        ((Standards.PKD2007, "46.24.Z"), (Standards.NACE2, "46.24")),
        ((Standards.PKD2007, "46.3"), (Standards.NACE2, "46.3")),
        ((Standards.PKD2007, "46.31"), (Standards.NACE2, "46.31")),
        ((Standards.PKD2007, "46.31.Z"), (Standards.NACE2, "46.31")),
        ((Standards.PKD2007, "46.32"), (Standards.NACE2, "46.32")),
        ((Standards.PKD2007, "46.32.Z"), (Standards.NACE2, "46.32")),
        ((Standards.PKD2007, "46.33"), (Standards.NACE2, "46.33")),
        ((Standards.PKD2007, "46.33.Z"), (Standards.NACE2, "46.33")),
        ((Standards.PKD2007, "46.34"), (Standards.NACE2, "46.34")),
        ((Standards.PKD2007, "46.34.A"), (Standards.NACE2, "46.34")),
        ((Standards.PKD2007, "46.34.B"), (Standards.NACE2, "46.34")),
        ((Standards.PKD2007, "46.35"), (Standards.NACE2, "46.35")),
        ((Standards.PKD2007, "46.35.Z"), (Standards.NACE2, "46.35")),
        ((Standards.PKD2007, "46.36"), (Standards.NACE2, "46.36")),
        ((Standards.PKD2007, "46.36.Z"), (Standards.NACE2, "46.36")),
        ((Standards.PKD2007, "46.37"), (Standards.NACE2, "46.37")),
        ((Standards.PKD2007, "46.37.Z"), (Standards.NACE2, "46.37")),
        ((Standards.PKD2007, "46.38"), (Standards.NACE2, "46.38")),
        ((Standards.PKD2007, "46.38.Z"), (Standards.NACE2, "46.38")),
        ((Standards.PKD2007, "46.39"), (Standards.NACE2, "46.39")),
        ((Standards.PKD2007, "46.39.Z"), (Standards.NACE2, "46.39")),
        ((Standards.PKD2007, "46.4"), (Standards.NACE2, "46.4")),
        ((Standards.PKD2007, "46.41"), (Standards.NACE2, "46.41")),
        ((Standards.PKD2007, "46.41.Z"), (Standards.NACE2, "46.41")),
        ((Standards.PKD2007, "46.42"), (Standards.NACE2, "46.42")),
        ((Standards.PKD2007, "46.42.Z"), (Standards.NACE2, "46.42")),
        ((Standards.PKD2007, "46.43"), (Standards.NACE2, "46.43")),
        ((Standards.PKD2007, "46.43.Z"), (Standards.NACE2, "46.43")),
        ((Standards.PKD2007, "46.44"), (Standards.NACE2, "46.44")),
        ((Standards.PKD2007, "46.44.Z"), (Standards.NACE2, "46.44")),
        ((Standards.PKD2007, "46.45"), (Standards.NACE2, "46.45")),
        ((Standards.PKD2007, "46.45.Z"), (Standards.NACE2, "46.45")),
        ((Standards.PKD2007, "46.46"), (Standards.NACE2, "46.46")),
        ((Standards.PKD2007, "46.46.Z"), (Standards.NACE2, "46.46")),
        ((Standards.PKD2007, "46.47"), (Standards.NACE2, "46.47")),
        ((Standards.PKD2007, "46.47.Z"), (Standards.NACE2, "46.47")),
        ((Standards.PKD2007, "46.48"), (Standards.NACE2, "46.48")),
        ((Standards.PKD2007, "46.48.Z"), (Standards.NACE2, "46.48")),
        ((Standards.PKD2007, "46.49"), (Standards.NACE2, "46.49")),
        ((Standards.PKD2007, "46.49.Z"), (Standards.NACE2, "46.49")),
        ((Standards.PKD2007, "46.5"), (Standards.NACE2, "46.5")),
        ((Standards.PKD2007, "46.51"), (Standards.NACE2, "46.51")),
        ((Standards.PKD2007, "46.51.Z"), (Standards.NACE2, "46.51")),
        ((Standards.PKD2007, "46.52"), (Standards.NACE2, "46.52")),
        ((Standards.PKD2007, "46.52.Z"), (Standards.NACE2, "46.52")),
        ((Standards.PKD2007, "46.6"), (Standards.NACE2, "46.6")),
        ((Standards.PKD2007, "46.61"), (Standards.NACE2, "46.61")),
        ((Standards.PKD2007, "46.61.Z"), (Standards.NACE2, "46.61")),
        ((Standards.PKD2007, "46.62"), (Standards.NACE2, "46.62")),
        ((Standards.PKD2007, "46.62.Z"), (Standards.NACE2, "46.62")),
        ((Standards.PKD2007, "46.63"), (Standards.NACE2, "46.63")),
        ((Standards.PKD2007, "46.63.Z"), (Standards.NACE2, "46.63")),
        ((Standards.PKD2007, "46.64"), (Standards.NACE2, "46.64")),
        ((Standards.PKD2007, "46.64.Z"), (Standards.NACE2, "46.64")),
        ((Standards.PKD2007, "46.65"), (Standards.NACE2, "46.65")),
        ((Standards.PKD2007, "46.65.Z"), (Standards.NACE2, "46.65")),
        ((Standards.PKD2007, "46.66"), (Standards.NACE2, "46.66")),
        ((Standards.PKD2007, "46.66.Z"), (Standards.NACE2, "46.66")),
        ((Standards.PKD2007, "46.69"), (Standards.NACE2, "46.69")),
        ((Standards.PKD2007, "46.69.Z"), (Standards.NACE2, "46.69")),
        ((Standards.PKD2007, "46.7"), (Standards.NACE2, "46.7")),
        ((Standards.PKD2007, "46.71"), (Standards.NACE2, "46.71")),
        ((Standards.PKD2007, "46.71.Z"), (Standards.NACE2, "46.71")),
        ((Standards.PKD2007, "46.72"), (Standards.NACE2, "46.72")),
        ((Standards.PKD2007, "46.72.Z"), (Standards.NACE2, "46.72")),
        ((Standards.PKD2007, "46.73"), (Standards.NACE2, "46.73")),
        ((Standards.PKD2007, "46.73.Z"), (Standards.NACE2, "46.73")),
        ((Standards.PKD2007, "46.74"), (Standards.NACE2, "46.74")),
        ((Standards.PKD2007, "46.74.Z"), (Standards.NACE2, "46.74")),
        ((Standards.PKD2007, "46.75"), (Standards.NACE2, "46.75")),
        ((Standards.PKD2007, "46.75.Z"), (Standards.NACE2, "46.75")),
        ((Standards.PKD2007, "46.76"), (Standards.NACE2, "46.76")),
        ((Standards.PKD2007, "46.76.Z"), (Standards.NACE2, "46.76")),
        ((Standards.PKD2007, "46.77"), (Standards.NACE2, "46.77")),
        ((Standards.PKD2007, "46.77.Z"), (Standards.NACE2, "46.77")),
        ((Standards.PKD2007, "46.9"), (Standards.NACE2, "46.9")),
        ((Standards.PKD2007, "46.90"), (Standards.NACE2, "46.90")),
        ((Standards.PKD2007, "46.90.Z"), (Standards.NACE2, "46.90")),
        ((Standards.PKD2007, "47"), (Standards.NACE2, "47")),
        ((Standards.PKD2007, "47.1"), (Standards.NACE2, "47.1")),
        ((Standards.PKD2007, "47.11"), (Standards.NACE2, "47.11")),
        ((Standards.PKD2007, "47.11.Z"), (Standards.NACE2, "47.11")),
        ((Standards.PKD2007, "47.19"), (Standards.NACE2, "47.19")),
        ((Standards.PKD2007, "47.19.Z"), (Standards.NACE2, "47.19")),
        ((Standards.PKD2007, "47.2"), (Standards.NACE2, "47.2")),
        ((Standards.PKD2007, "47.21"), (Standards.NACE2, "47.21")),
        ((Standards.PKD2007, "47.21.Z"), (Standards.NACE2, "47.21")),
        ((Standards.PKD2007, "47.22"), (Standards.NACE2, "47.22")),
        ((Standards.PKD2007, "47.22.Z"), (Standards.NACE2, "47.22")),
        ((Standards.PKD2007, "47.23"), (Standards.NACE2, "47.23")),
        ((Standards.PKD2007, "47.23.Z"), (Standards.NACE2, "47.23")),
        ((Standards.PKD2007, "47.24"), (Standards.NACE2, "47.24")),
        ((Standards.PKD2007, "47.24.Z"), (Standards.NACE2, "47.24")),
        ((Standards.PKD2007, "47.25"), (Standards.NACE2, "47.25")),
        ((Standards.PKD2007, "47.25.Z"), (Standards.NACE2, "47.25")),
        ((Standards.PKD2007, "47.26"), (Standards.NACE2, "47.26")),
        ((Standards.PKD2007, "47.26.Z"), (Standards.NACE2, "47.26")),
        ((Standards.PKD2007, "47.29"), (Standards.NACE2, "47.29")),
        ((Standards.PKD2007, "47.29.Z"), (Standards.NACE2, "47.29")),
        ((Standards.PKD2007, "47.3"), (Standards.NACE2, "47.3")),
        ((Standards.PKD2007, "47.30"), (Standards.NACE2, "47.30")),
        ((Standards.PKD2007, "47.30.Z"), (Standards.NACE2, "47.30")),
        ((Standards.PKD2007, "47.4"), (Standards.NACE2, "47.4")),
        ((Standards.PKD2007, "47.41"), (Standards.NACE2, "47.41")),
        ((Standards.PKD2007, "47.41.Z"), (Standards.NACE2, "47.41")),
        ((Standards.PKD2007, "47.42"), (Standards.NACE2, "47.42")),
        ((Standards.PKD2007, "47.42.Z"), (Standards.NACE2, "47.42")),
        ((Standards.PKD2007, "47.43"), (Standards.NACE2, "47.43")),
        ((Standards.PKD2007, "47.43.Z"), (Standards.NACE2, "47.43")),
        ((Standards.PKD2007, "47.5"), (Standards.NACE2, "47.5")),
        ((Standards.PKD2007, "47.51"), (Standards.NACE2, "47.51")),
        ((Standards.PKD2007, "47.51.Z"), (Standards.NACE2, "47.51")),
        ((Standards.PKD2007, "47.52"), (Standards.NACE2, "47.52")),
        ((Standards.PKD2007, "47.52.Z"), (Standards.NACE2, "47.52")),
        ((Standards.PKD2007, "47.53"), (Standards.NACE2, "47.53")),
        ((Standards.PKD2007, "47.53.Z"), (Standards.NACE2, "47.53")),
        ((Standards.PKD2007, "47.54"), (Standards.NACE2, "47.54")),
        ((Standards.PKD2007, "47.54.Z"), (Standards.NACE2, "47.54")),
        ((Standards.PKD2007, "47.59"), (Standards.NACE2, "47.59")),
        ((Standards.PKD2007, "47.59.Z"), (Standards.NACE2, "47.59")),
        ((Standards.PKD2007, "47.6"), (Standards.NACE2, "47.6")),
        ((Standards.PKD2007, "47.61"), (Standards.NACE2, "47.61")),
        ((Standards.PKD2007, "47.61.Z"), (Standards.NACE2, "47.61")),
        ((Standards.PKD2007, "47.62"), (Standards.NACE2, "47.62")),
        ((Standards.PKD2007, "47.62.Z"), (Standards.NACE2, "47.62")),
        ((Standards.PKD2007, "47.63"), (Standards.NACE2, "47.63")),
        ((Standards.PKD2007, "47.63.Z"), (Standards.NACE2, "47.63")),
        ((Standards.PKD2007, "47.64"), (Standards.NACE2, "47.64")),
        ((Standards.PKD2007, "47.64.Z"), (Standards.NACE2, "47.64")),
        ((Standards.PKD2007, "47.65"), (Standards.NACE2, "47.65")),
        ((Standards.PKD2007, "47.65.Z"), (Standards.NACE2, "47.65")),
        ((Standards.PKD2007, "47.7"), (Standards.NACE2, "47.7")),
        ((Standards.PKD2007, "47.71"), (Standards.NACE2, "47.71")),
        ((Standards.PKD2007, "47.71.Z"), (Standards.NACE2, "47.71")),
        ((Standards.PKD2007, "47.72"), (Standards.NACE2, "47.72")),
        ((Standards.PKD2007, "47.72.Z"), (Standards.NACE2, "47.72")),
        ((Standards.PKD2007, "47.73"), (Standards.NACE2, "47.73")),
        ((Standards.PKD2007, "47.73.Z"), (Standards.NACE2, "47.73")),
        ((Standards.PKD2007, "47.74"), (Standards.NACE2, "47.74")),
        ((Standards.PKD2007, "47.74.Z"), (Standards.NACE2, "47.74")),
        ((Standards.PKD2007, "47.75"), (Standards.NACE2, "47.75")),
        ((Standards.PKD2007, "47.75.Z"), (Standards.NACE2, "47.75")),
        ((Standards.PKD2007, "47.76"), (Standards.NACE2, "47.76")),
        ((Standards.PKD2007, "47.76.Z"), (Standards.NACE2, "47.76")),
        ((Standards.PKD2007, "47.77"), (Standards.NACE2, "47.77")),
        ((Standards.PKD2007, "47.77.Z"), (Standards.NACE2, "47.77")),
        ((Standards.PKD2007, "47.78"), (Standards.NACE2, "47.78")),
        ((Standards.PKD2007, "47.78.Z"), (Standards.NACE2, "47.78")),
        ((Standards.PKD2007, "47.79"), (Standards.NACE2, "47.79")),
        ((Standards.PKD2007, "47.79.Z"), (Standards.NACE2, "47.79")),
        ((Standards.PKD2007, "47.8"), (Standards.NACE2, "47.8")),
        ((Standards.PKD2007, "47.81"), (Standards.NACE2, "47.81")),
        ((Standards.PKD2007, "47.81.Z"), (Standards.NACE2, "47.81")),
        ((Standards.PKD2007, "47.82"), (Standards.NACE2, "47.82")),
        ((Standards.PKD2007, "47.82.Z"), (Standards.NACE2, "47.82")),
        ((Standards.PKD2007, "47.89"), (Standards.NACE2, "47.89")),
        ((Standards.PKD2007, "47.89.Z"), (Standards.NACE2, "47.89")),
        ((Standards.PKD2007, "47.9"), (Standards.NACE2, "47.9")),
        ((Standards.PKD2007, "47.91"), (Standards.NACE2, "47.91")),
        ((Standards.PKD2007, "47.91.Z"), (Standards.NACE2, "47.91")),
        ((Standards.PKD2007, "47.99"), (Standards.NACE2, "47.99")),
        ((Standards.PKD2007, "47.99.Z"), (Standards.NACE2, "47.99")),
        ((Standards.PKD2007, "H"), (Standards.NACE2, "H")),
        ((Standards.PKD2007, "49"), (Standards.NACE2, "49")),
        ((Standards.PKD2007, "49.1"), (Standards.NACE2, "49.1")),
        ((Standards.PKD2007, "49.10"), (Standards.NACE2, "49.10")),
        ((Standards.PKD2007, "49.10.Z"), (Standards.NACE2, "49.10")),
        ((Standards.PKD2007, "49.2"), (Standards.NACE2, "49.2")),
        ((Standards.PKD2007, "49.20"), (Standards.NACE2, "49.20")),
        ((Standards.PKD2007, "49.20.Z"), (Standards.NACE2, "49.20")),
        ((Standards.PKD2007, "49.3"), (Standards.NACE2, "49.3")),
        ((Standards.PKD2007, "49.31"), (Standards.NACE2, "49.31")),
        ((Standards.PKD2007, "49.31.Z"), (Standards.NACE2, "49.31")),
        ((Standards.PKD2007, "49.32"), (Standards.NACE2, "49.32")),
        ((Standards.PKD2007, "49.32.Z"), (Standards.NACE2, "49.32")),
        ((Standards.PKD2007, "49.39"), (Standards.NACE2, "49.39")),
        ((Standards.PKD2007, "49.39.Z"), (Standards.NACE2, "49.39")),
        ((Standards.PKD2007, "49.4"), (Standards.NACE2, "49.4")),
        ((Standards.PKD2007, "49.41"), (Standards.NACE2, "49.41")),
        ((Standards.PKD2007, "49.41.Z"), (Standards.NACE2, "49.41")),
        ((Standards.PKD2007, "49.42"), (Standards.NACE2, "49.42")),
        ((Standards.PKD2007, "49.42.Z"), (Standards.NACE2, "49.42")),
        ((Standards.PKD2007, "49.5"), (Standards.NACE2, "49.5")),
        ((Standards.PKD2007, "49.50"), (Standards.NACE2, "49.50")),
        ((Standards.PKD2007, "49.50.A"), (Standards.NACE2, "49.50")),
        ((Standards.PKD2007, "49.50.B"), (Standards.NACE2, "49.50")),
        ((Standards.PKD2007, "50"), (Standards.NACE2, "50")),
        ((Standards.PKD2007, "50.1"), (Standards.NACE2, "50.1")),
        ((Standards.PKD2007, "50.10"), (Standards.NACE2, "50.10")),
        ((Standards.PKD2007, "50.10.Z"), (Standards.NACE2, "50.10")),
        ((Standards.PKD2007, "50.2"), (Standards.NACE2, "50.2")),
        ((Standards.PKD2007, "50.20"), (Standards.NACE2, "50.20")),
        ((Standards.PKD2007, "50.20.Z"), (Standards.NACE2, "50.20")),
        ((Standards.PKD2007, "50.3"), (Standards.NACE2, "50.3")),
        ((Standards.PKD2007, "50.30"), (Standards.NACE2, "50.30")),
        ((Standards.PKD2007, "50.30.Z"), (Standards.NACE2, "50.30")),
        ((Standards.PKD2007, "50.4"), (Standards.NACE2, "50.4")),
        ((Standards.PKD2007, "50.40"), (Standards.NACE2, "50.40")),
        ((Standards.PKD2007, "50.40.Z"), (Standards.NACE2, "50.40")),
        ((Standards.PKD2007, "51"), (Standards.NACE2, "51")),
        ((Standards.PKD2007, "51.1"), (Standards.NACE2, "51.1")),
        ((Standards.PKD2007, "51.10"), (Standards.NACE2, "51.10")),
        ((Standards.PKD2007, "51.10.Z"), (Standards.NACE2, "51.10")),
        ((Standards.PKD2007, "51.2"), (Standards.NACE2, "51.2")),
        ((Standards.PKD2007, "51.21"), (Standards.NACE2, "51.21")),
        ((Standards.PKD2007, "51.21.Z"), (Standards.NACE2, "51.21")),
        ((Standards.PKD2007, "51.22"), (Standards.NACE2, "51.22")),
        ((Standards.PKD2007, "51.22.Z"), (Standards.NACE2, "51.22")),
        ((Standards.PKD2007, "52"), (Standards.NACE2, "52")),
        ((Standards.PKD2007, "52.1"), (Standards.NACE2, "52.1")),
        ((Standards.PKD2007, "52.10"), (Standards.NACE2, "52.10")),
        ((Standards.PKD2007, "52.10.A"), (Standards.NACE2, "52.10")),
        ((Standards.PKD2007, "52.10.B"), (Standards.NACE2, "52.10")),
        ((Standards.PKD2007, "52.2"), (Standards.NACE2, "52.2")),
        ((Standards.PKD2007, "52.21"), (Standards.NACE2, "52.21")),
        ((Standards.PKD2007, "52.21.Z"), (Standards.NACE2, "52.21")),
        ((Standards.PKD2007, "52.22"), (Standards.NACE2, "52.22")),
        ((Standards.PKD2007, "52.22.A"), (Standards.NACE2, "52.22")),
        ((Standards.PKD2007, "52.22.B"), (Standards.NACE2, "52.22")),
        ((Standards.PKD2007, "52.23"), (Standards.NACE2, "52.23")),
        ((Standards.PKD2007, "52.23.Z"), (Standards.NACE2, "52.23")),
        ((Standards.PKD2007, "52.24"), (Standards.NACE2, "52.24")),
        ((Standards.PKD2007, "52.24.A"), (Standards.NACE2, "52.24")),
        ((Standards.PKD2007, "52.24.B"), (Standards.NACE2, "52.24")),
        ((Standards.PKD2007, "52.24.C"), (Standards.NACE2, "52.24")),
        ((Standards.PKD2007, "52.29"), (Standards.NACE2, "52.29")),
        ((Standards.PKD2007, "52.29.A"), (Standards.NACE2, "52.29")),
        ((Standards.PKD2007, "52.29.B"), (Standards.NACE2, "52.29")),
        ((Standards.PKD2007, "52.29.C"), (Standards.NACE2, "52.29")),
        ((Standards.PKD2007, "53"), (Standards.NACE2, "53")),
        ((Standards.PKD2007, "53.1"), (Standards.NACE2, "53.1")),
        ((Standards.PKD2007, "53.10"), (Standards.NACE2, "53.10")),
        ((Standards.PKD2007, "53.10.Z"), (Standards.NACE2, "53.10")),
        ((Standards.PKD2007, "53.2"), (Standards.NACE2, "53.2")),
        ((Standards.PKD2007, "53.20"), (Standards.NACE2, "53.20")),
        ((Standards.PKD2007, "53.20.Z"), (Standards.NACE2, "53.20")),
        ((Standards.PKD2007, "I"), (Standards.NACE2, "I")),
        ((Standards.PKD2007, "55"), (Standards.NACE2, "55")),
        ((Standards.PKD2007, "55.1"), (Standards.NACE2, "55.1")),
        ((Standards.PKD2007, "55.10"), (Standards.NACE2, "55.10")),
        ((Standards.PKD2007, "55.10.Z"), (Standards.NACE2, "55.10")),
        ((Standards.PKD2007, "55.2"), (Standards.NACE2, "55.2")),
        ((Standards.PKD2007, "55.20"), (Standards.NACE2, "55.20")),
        ((Standards.PKD2007, "55.20.Z"), (Standards.NACE2, "55.20")),
        ((Standards.PKD2007, "55.3"), (Standards.NACE2, "55.3")),
        ((Standards.PKD2007, "55.30"), (Standards.NACE2, "55.30")),
        ((Standards.PKD2007, "55.30.Z"), (Standards.NACE2, "55.30")),
        ((Standards.PKD2007, "55.9"), (Standards.NACE2, "55.9")),
        ((Standards.PKD2007, "55.90"), (Standards.NACE2, "55.90")),
        ((Standards.PKD2007, "55.90.Z"), (Standards.NACE2, "55.90")),
        ((Standards.PKD2007, "56"), (Standards.NACE2, "56")),
        ((Standards.PKD2007, "56.1"), (Standards.NACE2, "56.1")),
        ((Standards.PKD2007, "56.10"), (Standards.NACE2, "56.10")),
        ((Standards.PKD2007, "56.10.A"), (Standards.NACE2, "56.10")),
        ((Standards.PKD2007, "56.10.B"), (Standards.NACE2, "56.10")),
        ((Standards.PKD2007, "56.2"), (Standards.NACE2, "56.2")),
        ((Standards.PKD2007, "56.21"), (Standards.NACE2, "56.21")),
        ((Standards.PKD2007, "56.21.Z"), (Standards.NACE2, "56.21")),
        ((Standards.PKD2007, "56.29"), (Standards.NACE2, "56.29")),
        ((Standards.PKD2007, "56.29.Z"), (Standards.NACE2, "56.29")),
        ((Standards.PKD2007, "56.3"), (Standards.NACE2, "56.3")),
        ((Standards.PKD2007, "56.30"), (Standards.NACE2, "56.30")),
        ((Standards.PKD2007, "56.30.Z"), (Standards.NACE2, "56.30")),
        ((Standards.PKD2007, "J"), (Standards.NACE2, "J")),
        ((Standards.PKD2007, "58"), (Standards.NACE2, "58")),
        ((Standards.PKD2007, "58.1"), (Standards.NACE2, "58.1")),
        ((Standards.PKD2007, "58.11"), (Standards.NACE2, "58.11")),
        ((Standards.PKD2007, "58.11.Z"), (Standards.NACE2, "58.11")),
        ((Standards.PKD2007, "58.12"), (Standards.NACE2, "58.12")),
        ((Standards.PKD2007, "58.12.Z"), (Standards.NACE2, "58.12")),
        ((Standards.PKD2007, "58.13"), (Standards.NACE2, "58.13")),
        ((Standards.PKD2007, "58.13.Z"), (Standards.NACE2, "58.13")),
        ((Standards.PKD2007, "58.14"), (Standards.NACE2, "58.14")),
        ((Standards.PKD2007, "58.14.Z"), (Standards.NACE2, "58.14")),
        ((Standards.PKD2007, "58.19"), (Standards.NACE2, "58.19")),
        ((Standards.PKD2007, "58.19.Z"), (Standards.NACE2, "58.19")),
        ((Standards.PKD2007, "58.2"), (Standards.NACE2, "58.2")),
        ((Standards.PKD2007, "58.21"), (Standards.NACE2, "58.21")),
        ((Standards.PKD2007, "58.21.Z"), (Standards.NACE2, "58.21")),
        ((Standards.PKD2007, "58.29"), (Standards.NACE2, "58.29")),
        ((Standards.PKD2007, "58.29.Z"), (Standards.NACE2, "58.29")),
        ((Standards.PKD2007, "59"), (Standards.NACE2, "59")),
        ((Standards.PKD2007, "59.1"), (Standards.NACE2, "59.1")),
        ((Standards.PKD2007, "59.11"), (Standards.NACE2, "59.11")),
        ((Standards.PKD2007, "59.11.Z"), (Standards.NACE2, "59.11")),
        ((Standards.PKD2007, "59.12"), (Standards.NACE2, "59.12")),
        ((Standards.PKD2007, "59.12.Z"), (Standards.NACE2, "59.12")),
        ((Standards.PKD2007, "59.13"), (Standards.NACE2, "59.13")),
        ((Standards.PKD2007, "59.13.Z"), (Standards.NACE2, "59.13")),
        ((Standards.PKD2007, "59.14"), (Standards.NACE2, "59.14")),
        ((Standards.PKD2007, "59.14.Z"), (Standards.NACE2, "59.14")),
        ((Standards.PKD2007, "59.2"), (Standards.NACE2, "59.2")),
        ((Standards.PKD2007, "59.20"), (Standards.NACE2, "59.20")),
        ((Standards.PKD2007, "59.20.Z"), (Standards.NACE2, "59.20")),
        ((Standards.PKD2007, "60"), (Standards.NACE2, "60")),
        ((Standards.PKD2007, "60.1"), (Standards.NACE2, "60.1")),
        ((Standards.PKD2007, "60.10"), (Standards.NACE2, "60.10")),
        ((Standards.PKD2007, "60.10.Z"), (Standards.NACE2, "60.10")),
        ((Standards.PKD2007, "60.2"), (Standards.NACE2, "60.2")),
        ((Standards.PKD2007, "60.20"), (Standards.NACE2, "60.20")),
        ((Standards.PKD2007, "60.20.Z"), (Standards.NACE2, "60.20")),
        ((Standards.PKD2007, "61"), (Standards.NACE2, "61")),
        ((Standards.PKD2007, "61.1"), (Standards.NACE2, "61.1")),
        ((Standards.PKD2007, "61.10"), (Standards.NACE2, "61.10")),
        ((Standards.PKD2007, "61.10.Z"), (Standards.NACE2, "61.10")),
        ((Standards.PKD2007, "61.2"), (Standards.NACE2, "61.2")),
        ((Standards.PKD2007, "61.20"), (Standards.NACE2, "61.20")),
        ((Standards.PKD2007, "61.20.Z"), (Standards.NACE2, "61.20")),
        ((Standards.PKD2007, "61.3"), (Standards.NACE2, "61.3")),
        ((Standards.PKD2007, "61.30"), (Standards.NACE2, "61.30")),
        ((Standards.PKD2007, "61.30.Z"), (Standards.NACE2, "61.30")),
        ((Standards.PKD2007, "61.9"), (Standards.NACE2, "61.9")),
        ((Standards.PKD2007, "61.90"), (Standards.NACE2, "61.90")),
        ((Standards.PKD2007, "61.90.Z"), (Standards.NACE2, "61.90")),
        ((Standards.PKD2007, "62"), (Standards.NACE2, "62")),
        ((Standards.PKD2007, "62.0"), (Standards.NACE2, "62.0")),
        ((Standards.PKD2007, "62.01"), (Standards.NACE2, "62.01")),
        ((Standards.PKD2007, "62.01.Z"), (Standards.NACE2, "62.01")),
        ((Standards.PKD2007, "62.02"), (Standards.NACE2, "62.02")),
        ((Standards.PKD2007, "62.02.Z"), (Standards.NACE2, "62.02")),
        ((Standards.PKD2007, "62.03"), (Standards.NACE2, "62.03")),
        ((Standards.PKD2007, "62.03.Z"), (Standards.NACE2, "62.03")),
        ((Standards.PKD2007, "62.09"), (Standards.NACE2, "62.09")),
        ((Standards.PKD2007, "62.09.Z"), (Standards.NACE2, "62.09")),
        ((Standards.PKD2007, "63"), (Standards.NACE2, "63")),
        ((Standards.PKD2007, "63.1"), (Standards.NACE2, "63.1")),
        ((Standards.PKD2007, "63.11"), (Standards.NACE2, "63.11")),
        ((Standards.PKD2007, "63.11.Z"), (Standards.NACE2, "63.11")),
        ((Standards.PKD2007, "63.12"), (Standards.NACE2, "63.12")),
        ((Standards.PKD2007, "63.12.Z"), (Standards.NACE2, "63.12")),
        ((Standards.PKD2007, "63.9"), (Standards.NACE2, "63.9")),
        ((Standards.PKD2007, "63.91"), (Standards.NACE2, "63.91")),
        ((Standards.PKD2007, "63.91.Z"), (Standards.NACE2, "63.91")),
        ((Standards.PKD2007, "63.99"), (Standards.NACE2, "63.99")),
        ((Standards.PKD2007, "63.99.Z"), (Standards.NACE2, "63.99")),
        ((Standards.PKD2007, "K"), (Standards.NACE2, "K")),
        ((Standards.PKD2007, "64"), (Standards.NACE2, "64")),
        ((Standards.PKD2007, "64.1"), (Standards.NACE2, "64.1")),
        ((Standards.PKD2007, "64.11"), (Standards.NACE2, "64.11")),
        ((Standards.PKD2007, "64.11.Z"), (Standards.NACE2, "64.11")),
        ((Standards.PKD2007, "64.19"), (Standards.NACE2, "64.19")),
        ((Standards.PKD2007, "64.19.Z"), (Standards.NACE2, "64.19")),
        ((Standards.PKD2007, "64.2"), (Standards.NACE2, "64.2")),
        ((Standards.PKD2007, "64.20"), (Standards.NACE2, "64.20")),
        ((Standards.PKD2007, "64.20.Z"), (Standards.NACE2, "64.20")),
        ((Standards.PKD2007, "64.3"), (Standards.NACE2, "64.3")),
        ((Standards.PKD2007, "64.30"), (Standards.NACE2, "64.30")),
        ((Standards.PKD2007, "64.30.Z"), (Standards.NACE2, "64.30")),
        ((Standards.PKD2007, "64.9"), (Standards.NACE2, "64.9")),
        ((Standards.PKD2007, "64.91"), (Standards.NACE2, "64.91")),
        ((Standards.PKD2007, "64.91.Z"), (Standards.NACE2, "64.91")),
        ((Standards.PKD2007, "64.92"), (Standards.NACE2, "64.92")),
        ((Standards.PKD2007, "64.92.Z"), (Standards.NACE2, "64.92")),
        ((Standards.PKD2007, "64.99"), (Standards.NACE2, "64.99")),
        ((Standards.PKD2007, "64.99.Z"), (Standards.NACE2, "64.99")),
        ((Standards.PKD2007, "65"), (Standards.NACE2, "65")),
        ((Standards.PKD2007, "65.1"), (Standards.NACE2, "65.1")),
        ((Standards.PKD2007, "65.11"), (Standards.NACE2, "65.11")),
        ((Standards.PKD2007, "65.11.Z"), (Standards.NACE2, "65.11")),
        ((Standards.PKD2007, "65.12"), (Standards.NACE2, "65.12")),
        ((Standards.PKD2007, "65.12.Z"), (Standards.NACE2, "65.12")),
        ((Standards.PKD2007, "65.2"), (Standards.NACE2, "65.2")),
        ((Standards.PKD2007, "65.20"), (Standards.NACE2, "65.20")),
        ((Standards.PKD2007, "65.20.Z"), (Standards.NACE2, "65.20")),
        ((Standards.PKD2007, "65.3"), (Standards.NACE2, "65.3")),
        ((Standards.PKD2007, "65.30"), (Standards.NACE2, "65.30")),
        ((Standards.PKD2007, "65.30.Z"), (Standards.NACE2, "65.30")),
        ((Standards.PKD2007, "66"), (Standards.NACE2, "66")),
        ((Standards.PKD2007, "66.1"), (Standards.NACE2, "66.1")),
        ((Standards.PKD2007, "66.11"), (Standards.NACE2, "66.11")),
        ((Standards.PKD2007, "66.11.Z"), (Standards.NACE2, "66.11")),
        ((Standards.PKD2007, "66.12"), (Standards.NACE2, "66.12")),
        ((Standards.PKD2007, "66.12.Z"), (Standards.NACE2, "66.12")),
        ((Standards.PKD2007, "66.19"), (Standards.NACE2, "66.19")),
        ((Standards.PKD2007, "66.19.Z"), (Standards.NACE2, "66.19")),
        ((Standards.PKD2007, "66.2"), (Standards.NACE2, "66.2")),
        ((Standards.PKD2007, "66.21"), (Standards.NACE2, "66.21")),
        ((Standards.PKD2007, "66.21.Z"), (Standards.NACE2, "66.21")),
        ((Standards.PKD2007, "66.22"), (Standards.NACE2, "66.22")),
        ((Standards.PKD2007, "66.22.Z"), (Standards.NACE2, "66.22")),
        ((Standards.PKD2007, "66.29"), (Standards.NACE2, "66.29")),
        ((Standards.PKD2007, "66.29.Z"), (Standards.NACE2, "66.29")),
        ((Standards.PKD2007, "66.3"), (Standards.NACE2, "66.3")),
        ((Standards.PKD2007, "66.30"), (Standards.NACE2, "66.30")),
        ((Standards.PKD2007, "66.30.Z"), (Standards.NACE2, "66.30")),
        ((Standards.PKD2007, "L"), (Standards.NACE2, "L")),
        ((Standards.PKD2007, "68"), (Standards.NACE2, "68")),
        ((Standards.PKD2007, "68.1"), (Standards.NACE2, "68.1")),
        ((Standards.PKD2007, "68.10"), (Standards.NACE2, "68.10")),
        ((Standards.PKD2007, "68.10.Z"), (Standards.NACE2, "68.10")),
        ((Standards.PKD2007, "68.2"), (Standards.NACE2, "68.2")),
        ((Standards.PKD2007, "68.20"), (Standards.NACE2, "68.20")),
        ((Standards.PKD2007, "68.20.Z"), (Standards.NACE2, "68.20")),
        ((Standards.PKD2007, "68.3"), (Standards.NACE2, "68.3")),
        ((Standards.PKD2007, "68.31"), (Standards.NACE2, "68.31")),
        ((Standards.PKD2007, "68.31.Z"), (Standards.NACE2, "68.31")),
        ((Standards.PKD2007, "68.32"), (Standards.NACE2, "68.32")),
        ((Standards.PKD2007, "68.32.Z"), (Standards.NACE2, "68.32")),
        ((Standards.PKD2007, "M"), (Standards.NACE2, "M")),
        ((Standards.PKD2007, "69"), (Standards.NACE2, "69")),
        ((Standards.PKD2007, "69.1"), (Standards.NACE2, "69.1")),
        ((Standards.PKD2007, "69.10"), (Standards.NACE2, "69.10")),
        ((Standards.PKD2007, "69.10.Z"), (Standards.NACE2, "69.10")),
        ((Standards.PKD2007, "69.2"), (Standards.NACE2, "69.2")),
        ((Standards.PKD2007, "69.20"), (Standards.NACE2, "69.20")),
        ((Standards.PKD2007, "69.20.Z"), (Standards.NACE2, "69.20")),
        ((Standards.PKD2007, "70"), (Standards.NACE2, "70")),
        ((Standards.PKD2007, "70.1"), (Standards.NACE2, "70.1")),
        ((Standards.PKD2007, "70.10"), (Standards.NACE2, "70.10")),
        ((Standards.PKD2007, "70.10.Z"), (Standards.NACE2, "70.10")),
        ((Standards.PKD2007, "70.2"), (Standards.NACE2, "70.2")),
        ((Standards.PKD2007, "70.21"), (Standards.NACE2, "70.21")),
        ((Standards.PKD2007, "70.21.Z"), (Standards.NACE2, "70.21")),
        ((Standards.PKD2007, "70.22"), (Standards.NACE2, "70.22")),
        ((Standards.PKD2007, "70.22.Z"), (Standards.NACE2, "70.22")),
        ((Standards.PKD2007, "71"), (Standards.NACE2, "71")),
        ((Standards.PKD2007, "71.1"), (Standards.NACE2, "71.1")),
        ((Standards.PKD2007, "71.11"), (Standards.NACE2, "71.11")),
        ((Standards.PKD2007, "71.11.Z"), (Standards.NACE2, "71.11")),
        ((Standards.PKD2007, "71.12"), (Standards.NACE2, "71.12")),
        ((Standards.PKD2007, "71.12.Z"), (Standards.NACE2, "71.12")),
        ((Standards.PKD2007, "71.2"), (Standards.NACE2, "71.2")),
        ((Standards.PKD2007, "71.20"), (Standards.NACE2, "71.20")),
        ((Standards.PKD2007, "71.20.A"), (Standards.NACE2, "71.20")),
        ((Standards.PKD2007, "71.20.B"), (Standards.NACE2, "71.20")),
        ((Standards.PKD2007, "72"), (Standards.NACE2, "72")),
        ((Standards.PKD2007, "72.1"), (Standards.NACE2, "72.1")),
        ((Standards.PKD2007, "72.11"), (Standards.NACE2, "72.11")),
        ((Standards.PKD2007, "72.11.Z"), (Standards.NACE2, "72.11")),
        ((Standards.PKD2007, "72.19"), (Standards.NACE2, "72.19")),
        ((Standards.PKD2007, "72.19.Z"), (Standards.NACE2, "72.19")),
        ((Standards.PKD2007, "72.2"), (Standards.NACE2, "72.2")),
        ((Standards.PKD2007, "72.20"), (Standards.NACE2, "72.20")),
        ((Standards.PKD2007, "72.20.Z"), (Standards.NACE2, "72.20")),
        ((Standards.PKD2007, "73"), (Standards.NACE2, "73")),
        ((Standards.PKD2007, "73.1"), (Standards.NACE2, "73.1")),
        ((Standards.PKD2007, "73.11"), (Standards.NACE2, "73.11")),
        ((Standards.PKD2007, "73.11.Z"), (Standards.NACE2, "73.11")),
        ((Standards.PKD2007, "73.12"), (Standards.NACE2, "73.12")),
        ((Standards.PKD2007, "73.12.A"), (Standards.NACE2, "73.12")),
        ((Standards.PKD2007, "73.12.B"), (Standards.NACE2, "73.12")),
        ((Standards.PKD2007, "73.12.C"), (Standards.NACE2, "73.12")),
        ((Standards.PKD2007, "73.12.D"), (Standards.NACE2, "73.12")),
        ((Standards.PKD2007, "73.2"), (Standards.NACE2, "73.2")),
        ((Standards.PKD2007, "73.20"), (Standards.NACE2, "73.20")),
        ((Standards.PKD2007, "73.20.Z"), (Standards.NACE2, "73.20")),
        ((Standards.PKD2007, "74"), (Standards.NACE2, "74")),
        ((Standards.PKD2007, "74.1"), (Standards.NACE2, "74.1")),
        ((Standards.PKD2007, "74.10"), (Standards.NACE2, "74.10")),
        ((Standards.PKD2007, "74.10.Z"), (Standards.NACE2, "74.10")),
        ((Standards.PKD2007, "74.2"), (Standards.NACE2, "74.2")),
        ((Standards.PKD2007, "74.20"), (Standards.NACE2, "74.20")),
        ((Standards.PKD2007, "74.20.Z"), (Standards.NACE2, "74.20")),
        ((Standards.PKD2007, "74.3"), (Standards.NACE2, "74.3")),
        ((Standards.PKD2007, "74.30"), (Standards.NACE2, "74.30")),
        ((Standards.PKD2007, "74.30.Z"), (Standards.NACE2, "74.30")),
        ((Standards.PKD2007, "74.9"), (Standards.NACE2, "74.9")),
        ((Standards.PKD2007, "74.90"), (Standards.NACE2, "74.90")),
        ((Standards.PKD2007, "74.90.Z"), (Standards.NACE2, "74.90")),
        ((Standards.PKD2007, "75"), (Standards.NACE2, "75")),
        ((Standards.PKD2007, "75.0"), (Standards.NACE2, "75.0")),
        ((Standards.PKD2007, "75.00"), (Standards.NACE2, "75.00")),
        ((Standards.PKD2007, "75.00.Z"), (Standards.NACE2, "75.00")),
        ((Standards.PKD2007, "N"), (Standards.NACE2, "N")),
        ((Standards.PKD2007, "77"), (Standards.NACE2, "77")),
        ((Standards.PKD2007, "77.1"), (Standards.NACE2, "77.1")),
        ((Standards.PKD2007, "77.11"), (Standards.NACE2, "77.11")),
        ((Standards.PKD2007, "77.11.Z"), (Standards.NACE2, "77.11")),
        ((Standards.PKD2007, "77.12"), (Standards.NACE2, "77.12")),
        ((Standards.PKD2007, "77.12.Z"), (Standards.NACE2, "77.12")),
        ((Standards.PKD2007, "77.2"), (Standards.NACE2, "77.2")),
        ((Standards.PKD2007, "77.21"), (Standards.NACE2, "77.21")),
        ((Standards.PKD2007, "77.21.Z"), (Standards.NACE2, "77.21")),
        ((Standards.PKD2007, "77.22"), (Standards.NACE2, "77.22")),
        ((Standards.PKD2007, "77.22.Z"), (Standards.NACE2, "77.22")),
        ((Standards.PKD2007, "77.29"), (Standards.NACE2, "77.29")),
        ((Standards.PKD2007, "77.29.Z"), (Standards.NACE2, "77.29")),
        ((Standards.PKD2007, "77.3"), (Standards.NACE2, "77.3")),
        ((Standards.PKD2007, "77.31"), (Standards.NACE2, "77.31")),
        ((Standards.PKD2007, "77.31.Z"), (Standards.NACE2, "77.31")),
        ((Standards.PKD2007, "77.32"), (Standards.NACE2, "77.32")),
        ((Standards.PKD2007, "77.32.Z"), (Standards.NACE2, "77.32")),
        ((Standards.PKD2007, "77.33"), (Standards.NACE2, "77.33")),
        ((Standards.PKD2007, "77.33.Z"), (Standards.NACE2, "77.33")),
        ((Standards.PKD2007, "77.34"), (Standards.NACE2, "77.34")),
        ((Standards.PKD2007, "77.34.Z"), (Standards.NACE2, "77.34")),
        ((Standards.PKD2007, "77.35"), (Standards.NACE2, "77.35")),
        ((Standards.PKD2007, "77.35.Z"), (Standards.NACE2, "77.35")),
        ((Standards.PKD2007, "77.39"), (Standards.NACE2, "77.39")),
        ((Standards.PKD2007, "77.39.Z"), (Standards.NACE2, "77.39")),
        ((Standards.PKD2007, "77.4"), (Standards.NACE2, "77.4")),
        ((Standards.PKD2007, "77.40"), (Standards.NACE2, "77.40")),
        ((Standards.PKD2007, "77.40.Z"), (Standards.NACE2, "77.40")),
        ((Standards.PKD2007, "78"), (Standards.NACE2, "78")),
        ((Standards.PKD2007, "78.1"), (Standards.NACE2, "78.1")),
        ((Standards.PKD2007, "78.10"), (Standards.NACE2, "78.10")),
        ((Standards.PKD2007, "78.10.Z"), (Standards.NACE2, "78.10")),
        ((Standards.PKD2007, "78.2"), (Standards.NACE2, "78.2")),
        ((Standards.PKD2007, "78.20"), (Standards.NACE2, "78.20")),
        ((Standards.PKD2007, "78.20.Z"), (Standards.NACE2, "78.20")),
        ((Standards.PKD2007, "78.3"), (Standards.NACE2, "78.3")),
        ((Standards.PKD2007, "78.30"), (Standards.NACE2, "78.30")),
        ((Standards.PKD2007, "78.30.Z"), (Standards.NACE2, "78.30")),
        ((Standards.PKD2007, "79"), (Standards.NACE2, "79")),
        ((Standards.PKD2007, "79.1"), (Standards.NACE2, "79.1")),
        ((Standards.PKD2007, "79.11"), (Standards.NACE2, "79.11")),
        ((Standards.PKD2007, "79.11.A"), (Standards.NACE2, "79.11")),
        ((Standards.PKD2007, "79.11.B"), (Standards.NACE2, "79.11")),
        ((Standards.PKD2007, "79.12"), (Standards.NACE2, "79.12")),
        ((Standards.PKD2007, "79.12.Z"), (Standards.NACE2, "79.12")),
        ((Standards.PKD2007, "79.9"), (Standards.NACE2, "79.9")),
        ((Standards.PKD2007, "79.90"), (Standards.NACE2, "79.90")),
        ((Standards.PKD2007, "79.90.A"), (Standards.NACE2, "79.90")),
        ((Standards.PKD2007, "79.90.B"), (Standards.NACE2, "79.90")),
        ((Standards.PKD2007, "79.90.C"), (Standards.NACE2, "79.90")),
        ((Standards.PKD2007, "80"), (Standards.NACE2, "80")),
        ((Standards.PKD2007, "80.1"), (Standards.NACE2, "80.1")),
        ((Standards.PKD2007, "80.10"), (Standards.NACE2, "80.10")),
        ((Standards.PKD2007, "80.10.Z"), (Standards.NACE2, "80.10")),
        ((Standards.PKD2007, "80.2"), (Standards.NACE2, "80.2")),
        ((Standards.PKD2007, "80.20"), (Standards.NACE2, "80.20")),
        ((Standards.PKD2007, "80.20.Z"), (Standards.NACE2, "80.20")),
        ((Standards.PKD2007, "80.3"), (Standards.NACE2, "80.3")),
        ((Standards.PKD2007, "80.30"), (Standards.NACE2, "80.30")),
        ((Standards.PKD2007, "80.30.Z"), (Standards.NACE2, "80.30")),
        ((Standards.PKD2007, "81"), (Standards.NACE2, "81")),
        ((Standards.PKD2007, "81.1"), (Standards.NACE2, "81.1")),
        ((Standards.PKD2007, "81.10"), (Standards.NACE2, "81.10")),
        ((Standards.PKD2007, "81.10.Z"), (Standards.NACE2, "81.10")),
        ((Standards.PKD2007, "81.2"), (Standards.NACE2, "81.2")),
        ((Standards.PKD2007, "81.21"), (Standards.NACE2, "81.21")),
        ((Standards.PKD2007, "81.21.Z"), (Standards.NACE2, "81.21")),
        ((Standards.PKD2007, "81.22"), (Standards.NACE2, "81.22")),
        ((Standards.PKD2007, "81.22.Z"), (Standards.NACE2, "81.22")),
        ((Standards.PKD2007, "81.29"), (Standards.NACE2, "81.29")),
        ((Standards.PKD2007, "81.29.Z"), (Standards.NACE2, "81.29")),
        ((Standards.PKD2007, "81.3"), (Standards.NACE2, "81.3")),
        ((Standards.PKD2007, "81.30"), (Standards.NACE2, "81.30")),
        ((Standards.PKD2007, "81.30.Z"), (Standards.NACE2, "81.30")),
        ((Standards.PKD2007, "82"), (Standards.NACE2, "82")),
        ((Standards.PKD2007, "82.1"), (Standards.NACE2, "82.1")),
        ((Standards.PKD2007, "82.11"), (Standards.NACE2, "82.11")),
        ((Standards.PKD2007, "82.11.Z"), (Standards.NACE2, "82.11")),
        ((Standards.PKD2007, "82.19"), (Standards.NACE2, "82.19")),
        ((Standards.PKD2007, "82.19.Z"), (Standards.NACE2, "82.19")),
        ((Standards.PKD2007, "82.2"), (Standards.NACE2, "82.2")),
        ((Standards.PKD2007, "82.20"), (Standards.NACE2, "82.20")),
        ((Standards.PKD2007, "82.20.Z"), (Standards.NACE2, "82.20")),
        ((Standards.PKD2007, "82.3"), (Standards.NACE2, "82.3")),
        ((Standards.PKD2007, "82.30"), (Standards.NACE2, "82.30")),
        ((Standards.PKD2007, "82.30.Z"), (Standards.NACE2, "82.30")),
        ((Standards.PKD2007, "82.9"), (Standards.NACE2, "82.9")),
        ((Standards.PKD2007, "82.91"), (Standards.NACE2, "82.91")),
        ((Standards.PKD2007, "82.91.Z"), (Standards.NACE2, "82.91")),
        ((Standards.PKD2007, "82.92"), (Standards.NACE2, "82.92")),
        ((Standards.PKD2007, "82.92.Z"), (Standards.NACE2, "82.92")),
        ((Standards.PKD2007, "82.99"), (Standards.NACE2, "82.99")),
        ((Standards.PKD2007, "82.99.Z"), (Standards.NACE2, "82.99")),
        ((Standards.PKD2007, "O"), (Standards.NACE2, "O")),
        ((Standards.PKD2007, "84"), (Standards.NACE2, "84")),
        ((Standards.PKD2007, "84.1"), (Standards.NACE2, "84.1")),
        ((Standards.PKD2007, "84.11"), (Standards.NACE2, "84.11")),
        ((Standards.PKD2007, "84.11.Z"), (Standards.NACE2, "84.11")),
        ((Standards.PKD2007, "84.12"), (Standards.NACE2, "84.12")),
        ((Standards.PKD2007, "84.12.Z"), (Standards.NACE2, "84.12")),
        ((Standards.PKD2007, "84.13"), (Standards.NACE2, "84.13")),
        ((Standards.PKD2007, "84.13.Z"), (Standards.NACE2, "84.13")),
        ((Standards.PKD2007, "84.2"), (Standards.NACE2, "84.2")),
        ((Standards.PKD2007, "84.21"), (Standards.NACE2, "84.21")),
        ((Standards.PKD2007, "84.21.Z"), (Standards.NACE2, "84.21")),
        ((Standards.PKD2007, "84.22"), (Standards.NACE2, "84.22")),
        ((Standards.PKD2007, "84.22.Z"), (Standards.NACE2, "84.22")),
        ((Standards.PKD2007, "84.23"), (Standards.NACE2, "84.23")),
        ((Standards.PKD2007, "84.23.Z"), (Standards.NACE2, "84.23")),
        ((Standards.PKD2007, "84.24"), (Standards.NACE2, "84.24")),
        ((Standards.PKD2007, "84.24.Z"), (Standards.NACE2, "84.24")),
        ((Standards.PKD2007, "84.25"), (Standards.NACE2, "84.25")),
        ((Standards.PKD2007, "84.25.Z"), (Standards.NACE2, "84.25")),
        ((Standards.PKD2007, "84.3"), (Standards.NACE2, "84.3")),
        ((Standards.PKD2007, "84.30"), (Standards.NACE2, "84.30")),
        ((Standards.PKD2007, "84.30.Z"), (Standards.NACE2, "84.30")),
        ((Standards.PKD2007, "P"), (Standards.NACE2, "P")),
        ((Standards.PKD2007, "85"), (Standards.NACE2, "85")),
        ((Standards.PKD2007, "85.1"), (Standards.NACE2, "85.1")),
        ((Standards.PKD2007, "85.10"), (Standards.NACE2, "85.10")),
        ((Standards.PKD2007, "85.10.Z"), (Standards.NACE2, "85.10")),
        ((Standards.PKD2007, "85.2"), (Standards.NACE2, "85.2")),
        ((Standards.PKD2007, "85.20"), (Standards.NACE2, "85.20")),
        ((Standards.PKD2007, "85.20.Z"), (Standards.NACE2, "85.20")),
        ((Standards.PKD2007, "85.3"), (Standards.NACE2, "85.3")),
        ((Standards.PKD2007, "85.31"), (Standards.NACE2, "85.31")),
        ((Standards.PKD2007, "85.31.A"), (Standards.NACE2, "85.31")),
        ((Standards.PKD2007, "85.31.B"), (Standards.NACE2, "85.31")),
        ((Standards.PKD2007, "85.32"), (Standards.NACE2, "85.32")),
        ((Standards.PKD2007, "85.32.A"), (Standards.NACE2, "85.32")),
        ((Standards.PKD2007, "85.32.B"), (Standards.NACE2, "85.32")),
        ((Standards.PKD2007, "85.32.C"), (Standards.NACE2, "85.32")),
        ((Standards.PKD2007, "85.4"), (Standards.NACE2, "85.4")),
        ((Standards.PKD2007, "85.41"), (Standards.NACE2, "85.41")),
        ((Standards.PKD2007, "85.42"), (Standards.NACE2, "85.42")),
        ((Standards.PKD2007, "85.5"), (Standards.NACE2, "85.5")),
        ((Standards.PKD2007, "85.51"), (Standards.NACE2, "85.51")),
        ((Standards.PKD2007, "85.51.Z"), (Standards.NACE2, "85.51")),
        ((Standards.PKD2007, "85.52"), (Standards.NACE2, "85.52")),
        ((Standards.PKD2007, "85.52.Z"), (Standards.NACE2, "85.52")),
        ((Standards.PKD2007, "85.53"), (Standards.NACE2, "85.53")),
        ((Standards.PKD2007, "85.53.Z"), (Standards.NACE2, "85.53")),
        ((Standards.PKD2007, "85.59"), (Standards.NACE2, "85.59")),
        ((Standards.PKD2007, "85.59.A"), (Standards.NACE2, "85.59")),
        ((Standards.PKD2007, "85.59.B"), (Standards.NACE2, "85.59")),
        ((Standards.PKD2007, "85.6"), (Standards.NACE2, "85.6")),
        ((Standards.PKD2007, "85.60"), (Standards.NACE2, "85.60")),
        ((Standards.PKD2007, "85.60.Z"), (Standards.NACE2, "85.60")),
        ((Standards.PKD2007, "Q"), (Standards.NACE2, "Q")),
        ((Standards.PKD2007, "86"), (Standards.NACE2, "86")),
        ((Standards.PKD2007, "86.1"), (Standards.NACE2, "86.1")),
        ((Standards.PKD2007, "86.10"), (Standards.NACE2, "86.10")),
        ((Standards.PKD2007, "86.10.Z"), (Standards.NACE2, "86.10")),
        ((Standards.PKD2007, "86.2"), (Standards.NACE2, "86.2")),
        ((Standards.PKD2007, "86.21"), (Standards.NACE2, "86.21")),
        ((Standards.PKD2007, "86.21.Z"), (Standards.NACE2, "86.21")),
        ((Standards.PKD2007, "86.22"), (Standards.NACE2, "86.22")),
        ((Standards.PKD2007, "86.22.Z"), (Standards.NACE2, "86.22")),
        ((Standards.PKD2007, "86.23"), (Standards.NACE2, "86.23")),
        ((Standards.PKD2007, "86.23.Z"), (Standards.NACE2, "86.23")),
        ((Standards.PKD2007, "86.9"), (Standards.NACE2, "86.9")),
        ((Standards.PKD2007, "86.90"), (Standards.NACE2, "86.90")),
        ((Standards.PKD2007, "86.90.A"), (Standards.NACE2, "86.90")),
        ((Standards.PKD2007, "86.90.B"), (Standards.NACE2, "86.90")),
        ((Standards.PKD2007, "86.90.C"), (Standards.NACE2, "86.90")),
        ((Standards.PKD2007, "86.90.D"), (Standards.NACE2, "86.90")),
        ((Standards.PKD2007, "86.90.E"), (Standards.NACE2, "86.90")),
        ((Standards.PKD2007, "87"), (Standards.NACE2, "87")),
        ((Standards.PKD2007, "87.1"), (Standards.NACE2, "87.1")),
        ((Standards.PKD2007, "87.10"), (Standards.NACE2, "87.10")),
        ((Standards.PKD2007, "87.10.Z"), (Standards.NACE2, "87.10")),
        ((Standards.PKD2007, "87.2"), (Standards.NACE2, "87.2")),
        ((Standards.PKD2007, "87.20"), (Standards.NACE2, "87.20")),
        ((Standards.PKD2007, "87.20.Z"), (Standards.NACE2, "87.20")),
        ((Standards.PKD2007, "87.3"), (Standards.NACE2, "87.3")),
        ((Standards.PKD2007, "87.30"), (Standards.NACE2, "87.30")),
        ((Standards.PKD2007, "87.30.Z"), (Standards.NACE2, "87.30")),
        ((Standards.PKD2007, "87.9"), (Standards.NACE2, "87.9")),
        ((Standards.PKD2007, "87.90"), (Standards.NACE2, "87.90")),
        ((Standards.PKD2007, "87.90.Z"), (Standards.NACE2, "87.90")),
        ((Standards.PKD2007, "88"), (Standards.NACE2, "88")),
        ((Standards.PKD2007, "88.1"), (Standards.NACE2, "88.1")),
        ((Standards.PKD2007, "88.10"), (Standards.NACE2, "88.10")),
        ((Standards.PKD2007, "88.10.Z"), (Standards.NACE2, "88.10")),
        ((Standards.PKD2007, "88.9"), (Standards.NACE2, "88.9")),
        ((Standards.PKD2007, "88.91"), (Standards.NACE2, "88.91")),
        ((Standards.PKD2007, "88.91.Z"), (Standards.NACE2, "88.91")),
        ((Standards.PKD2007, "88.99"), (Standards.NACE2, "88.99")),
        ((Standards.PKD2007, "88.99.Z"), (Standards.NACE2, "88.99")),
        ((Standards.PKD2007, "R"), (Standards.NACE2, "R")),
        ((Standards.PKD2007, "90"), (Standards.NACE2, "90")),
        ((Standards.PKD2007, "90.0"), (Standards.NACE2, "90.0")),
        ((Standards.PKD2007, "90.01"), (Standards.NACE2, "90.01")),
        ((Standards.PKD2007, "90.01.Z"), (Standards.NACE2, "90.01")),
        ((Standards.PKD2007, "90.02"), (Standards.NACE2, "90.02")),
        ((Standards.PKD2007, "90.02.Z"), (Standards.NACE2, "90.02")),
        ((Standards.PKD2007, "90.03"), (Standards.NACE2, "90.03")),
        ((Standards.PKD2007, "90.03.Z"), (Standards.NACE2, "90.03")),
        ((Standards.PKD2007, "90.04"), (Standards.NACE2, "90.04")),
        ((Standards.PKD2007, "90.04.Z"), (Standards.NACE2, "90.04")),
        ((Standards.PKD2007, "91"), (Standards.NACE2, "91")),
        ((Standards.PKD2007, "91.0"), (Standards.NACE2, "91.0")),
        ((Standards.PKD2007, "91.01"), (Standards.NACE2, "91.01")),
        ((Standards.PKD2007, "91.01.A"), (Standards.NACE2, "91.01")),
        ((Standards.PKD2007, "91.01.B"), (Standards.NACE2, "91.01")),
        ((Standards.PKD2007, "91.02"), (Standards.NACE2, "91.02")),
        ((Standards.PKD2007, "91.02.Z"), (Standards.NACE2, "91.02")),
        ((Standards.PKD2007, "91.03"), (Standards.NACE2, "91.03")),
        ((Standards.PKD2007, "91.03.Z"), (Standards.NACE2, "91.03")),
        ((Standards.PKD2007, "91.04"), (Standards.NACE2, "91.04")),
        ((Standards.PKD2007, "91.04.Z"), (Standards.NACE2, "91.04")),
        ((Standards.PKD2007, "92"), (Standards.NACE2, "92")),
        ((Standards.PKD2007, "92.0"), (Standards.NACE2, "92.0")),
        ((Standards.PKD2007, "92.00"), (Standards.NACE2, "92.00")),
        ((Standards.PKD2007, "92.00.Z"), (Standards.NACE2, "92.00")),
        ((Standards.PKD2007, "93"), (Standards.NACE2, "93")),
        ((Standards.PKD2007, "93.1"), (Standards.NACE2, "93.1")),
        ((Standards.PKD2007, "93.11"), (Standards.NACE2, "93.11")),
        ((Standards.PKD2007, "93.11.Z"), (Standards.NACE2, "93.11")),
        ((Standards.PKD2007, "93.12"), (Standards.NACE2, "93.12")),
        ((Standards.PKD2007, "93.12.Z"), (Standards.NACE2, "93.12")),
        ((Standards.PKD2007, "93.13"), (Standards.NACE2, "93.13")),
        ((Standards.PKD2007, "93.13.Z"), (Standards.NACE2, "93.13")),
        ((Standards.PKD2007, "93.19"), (Standards.NACE2, "93.19")),
        ((Standards.PKD2007, "93.19.Z"), (Standards.NACE2, "93.19")),
        ((Standards.PKD2007, "93.2"), (Standards.NACE2, "93.2")),
        ((Standards.PKD2007, "93.21"), (Standards.NACE2, "93.21")),
        ((Standards.PKD2007, "93.21.Z"), (Standards.NACE2, "93.21")),
        ((Standards.PKD2007, "93.29"), (Standards.NACE2, "93.29")),
        ((Standards.PKD2007, "93.29.Z"), (Standards.NACE2, "93.29")),
        ((Standards.PKD2007, "S"), (Standards.NACE2, "S")),
        ((Standards.PKD2007, "94"), (Standards.NACE2, "94")),
        ((Standards.PKD2007, "94.1"), (Standards.NACE2, "94.1")),
        ((Standards.PKD2007, "94.11"), (Standards.NACE2, "94.11")),
        ((Standards.PKD2007, "94.11.Z"), (Standards.NACE2, "94.11")),
        ((Standards.PKD2007, "94.12"), (Standards.NACE2, "94.12")),
        ((Standards.PKD2007, "94.12.Z"), (Standards.NACE2, "94.12")),
        ((Standards.PKD2007, "94.2"), (Standards.NACE2, "94.2")),
        ((Standards.PKD2007, "94.20"), (Standards.NACE2, "94.20")),
        ((Standards.PKD2007, "94.20.Z"), (Standards.NACE2, "94.20")),
        ((Standards.PKD2007, "94.9"), (Standards.NACE2, "94.9")),
        ((Standards.PKD2007, "94.91"), (Standards.NACE2, "94.91")),
        ((Standards.PKD2007, "94.91.Z"), (Standards.NACE2, "94.91")),
        ((Standards.PKD2007, "94.92"), (Standards.NACE2, "94.92")),
        ((Standards.PKD2007, "94.92.Z"), (Standards.NACE2, "94.92")),
        ((Standards.PKD2007, "94.99"), (Standards.NACE2, "94.99")),
        ((Standards.PKD2007, "94.99.Z"), (Standards.NACE2, "94.99")),
        ((Standards.PKD2007, "95"), (Standards.NACE2, "95")),
        ((Standards.PKD2007, "95.1"), (Standards.NACE2, "95.1")),
        ((Standards.PKD2007, "95.11"), (Standards.NACE2, "95.11")),
        ((Standards.PKD2007, "95.11.Z"), (Standards.NACE2, "95.11")),
        ((Standards.PKD2007, "95.12"), (Standards.NACE2, "95.12")),
        ((Standards.PKD2007, "95.12.Z"), (Standards.NACE2, "95.12")),
        ((Standards.PKD2007, "95.2"), (Standards.NACE2, "95.2")),
        ((Standards.PKD2007, "95.21"), (Standards.NACE2, "95.21")),
        ((Standards.PKD2007, "95.21.Z"), (Standards.NACE2, "95.21")),
        ((Standards.PKD2007, "95.22"), (Standards.NACE2, "95.22")),
        ((Standards.PKD2007, "95.22.Z"), (Standards.NACE2, "95.22")),
        ((Standards.PKD2007, "95.23"), (Standards.NACE2, "95.23")),
        ((Standards.PKD2007, "95.23.Z"), (Standards.NACE2, "95.23")),
        ((Standards.PKD2007, "95.24"), (Standards.NACE2, "95.24")),
        ((Standards.PKD2007, "95.24.Z"), (Standards.NACE2, "95.24")),
        ((Standards.PKD2007, "95.25"), (Standards.NACE2, "95.25")),
        ((Standards.PKD2007, "95.25.Z"), (Standards.NACE2, "95.25")),
        ((Standards.PKD2007, "95.29"), (Standards.NACE2, "95.29")),
        ((Standards.PKD2007, "95.29.Z"), (Standards.NACE2, "95.29")),
        ((Standards.PKD2007, "96"), (Standards.NACE2, "96")),
        ((Standards.PKD2007, "96.0"), (Standards.NACE2, "96.0")),
        ((Standards.PKD2007, "96.01"), (Standards.NACE2, "96.01")),
        ((Standards.PKD2007, "96.01.Z"), (Standards.NACE2, "96.01")),
        ((Standards.PKD2007, "96.02"), (Standards.NACE2, "96.02")),
        ((Standards.PKD2007, "96.02.Z"), (Standards.NACE2, "96.02")),
        ((Standards.PKD2007, "96.03"), (Standards.NACE2, "96.03")),
        ((Standards.PKD2007, "96.03.Z"), (Standards.NACE2, "96.03")),
        ((Standards.PKD2007, "96.04"), (Standards.NACE2, "96.04")),
        ((Standards.PKD2007, "96.04.Z"), (Standards.NACE2, "96.04")),
        ((Standards.PKD2007, "96.09"), (Standards.NACE2, "96.09")),
        ((Standards.PKD2007, "96.09.Z"), (Standards.NACE2, "96.09")),
        ((Standards.PKD2007, "T"), (Standards.NACE2, "T")),
        ((Standards.PKD2007, "97"), (Standards.NACE2, "97")),
        ((Standards.PKD2007, "97.0"), (Standards.NACE2, "97.0")),
        ((Standards.PKD2007, "97.00"), (Standards.NACE2, "97.00")),
        ((Standards.PKD2007, "97.00.Z"), (Standards.NACE2, "97.00")),
        ((Standards.PKD2007, "98"), (Standards.NACE2, "98")),
        ((Standards.PKD2007, "98.1"), (Standards.NACE2, "98.1")),
        ((Standards.PKD2007, "98.10"), (Standards.NACE2, "98.10")),
        ((Standards.PKD2007, "98.10.Z"), (Standards.NACE2, "98.10")),
        ((Standards.PKD2007, "98.2"), (Standards.NACE2, "98.2")),
        ((Standards.PKD2007, "98.20"), (Standards.NACE2, "98.20")),
        ((Standards.PKD2007, "98.20.Z"), (Standards.NACE2, "98.20")),
        ((Standards.PKD2007, "U"), (Standards.NACE2, "U")),
        ((Standards.PKD2007, "99"), (Standards.NACE2, "99")),
        ((Standards.PKD2007, "99.0"), (Standards.NACE2, "99.0")),
        ((Standards.PKD2007, "99.00"), (Standards.NACE2, "99.00")),
        ((Standards.PKD2007, "99.00.Z"), (Standards.NACE2, "99.00")),
    ],
)
