# -*- coding: utf-8 -*-
"""`Concordance between TOL2008 and NACE2 <https://www2.stat.fi/en/luokitukset/toimiala/>`_.
"""
from ...types import Concordance, Standards
from ..nace2 import NACE2
from . import TOL2008

TOL2008_to_NACE2 = Concordance(
    src=TOL2008,
    dst=NACE2,
    concordances=[
        ((Standards.TOL2008, "A"), (Standards.NACE2, "A")),
        ((Standards.TOL2008, "01"), (Standards.NACE2, "01")),
        ((Standards.TOL2008, "011"), (Standards.NACE2, "01.1")),
        ((Standards.TOL2008, "0111"), (Standards.NACE2, "01.11")),
        ((Standards.TOL2008, "01110"), (Standards.NACE2, "01.11")),
        ((Standards.TOL2008, "0112"), (Standards.NACE2, "01.12")),
        ((Standards.TOL2008, "01120"), (Standards.NACE2, "01.12")),
        ((Standards.TOL2008, "0113"), (Standards.NACE2, "01.13")),
        ((Standards.TOL2008, "01131"), (Standards.NACE2, "01.13")),
        ((Standards.TOL2008, "01132"), (Standards.NACE2, "01.13")),
        ((Standards.TOL2008, "01133"), (Standards.NACE2, "01.13")),
        ((Standards.TOL2008, "01134"), (Standards.NACE2, "01.13")),
        ((Standards.TOL2008, "0114"), (Standards.NACE2, "01.14")),
        ((Standards.TOL2008, "01140"), (Standards.NACE2, "01.14")),
        ((Standards.TOL2008, "0115"), (Standards.NACE2, "01.15")),
        ((Standards.TOL2008, "01150"), (Standards.NACE2, "01.15")),
        ((Standards.TOL2008, "0116"), (Standards.NACE2, "01.16")),
        ((Standards.TOL2008, "01160"), (Standards.NACE2, "01.16")),
        ((Standards.TOL2008, "0119"), (Standards.NACE2, "01.19")),
        ((Standards.TOL2008, "01191"), (Standards.NACE2, "01.19")),
        ((Standards.TOL2008, "01199"), (Standards.NACE2, "01.19")),
        ((Standards.TOL2008, "012"), (Standards.NACE2, "01.2")),
        ((Standards.TOL2008, "0121"), (Standards.NACE2, "01.21")),
        ((Standards.TOL2008, "01210"), (Standards.NACE2, "01.21")),
        ((Standards.TOL2008, "0122"), (Standards.NACE2, "01.22")),
        ((Standards.TOL2008, "01220"), (Standards.NACE2, "01.22")),
        ((Standards.TOL2008, "0123"), (Standards.NACE2, "01.23")),
        ((Standards.TOL2008, "01230"), (Standards.NACE2, "01.23")),
        ((Standards.TOL2008, "0124"), (Standards.NACE2, "01.24")),
        ((Standards.TOL2008, "01240"), (Standards.NACE2, "01.24")),
        ((Standards.TOL2008, "0125"), (Standards.NACE2, "01.25")),
        ((Standards.TOL2008, "01250"), (Standards.NACE2, "01.25")),
        ((Standards.TOL2008, "0126"), (Standards.NACE2, "01.26")),
        ((Standards.TOL2008, "01260"), (Standards.NACE2, "01.26")),
        ((Standards.TOL2008, "0127"), (Standards.NACE2, "01.27")),
        ((Standards.TOL2008, "01270"), (Standards.NACE2, "01.27")),
        ((Standards.TOL2008, "0128"), (Standards.NACE2, "01.28")),
        ((Standards.TOL2008, "01280"), (Standards.NACE2, "01.28")),
        ((Standards.TOL2008, "0129"), (Standards.NACE2, "01.29")),
        ((Standards.TOL2008, "01290"), (Standards.NACE2, "01.29")),
        ((Standards.TOL2008, "013"), (Standards.NACE2, "01.3")),
        ((Standards.TOL2008, "0130"), (Standards.NACE2, "01.30")),
        ((Standards.TOL2008, "01300"), (Standards.NACE2, "01.30")),
        ((Standards.TOL2008, "014"), (Standards.NACE2, "01.4")),
        ((Standards.TOL2008, "0141"), (Standards.NACE2, "01.41")),
        ((Standards.TOL2008, "01410"), (Standards.NACE2, "01.41")),
        ((Standards.TOL2008, "0142"), (Standards.NACE2, "01.42")),
        ((Standards.TOL2008, "01420"), (Standards.NACE2, "01.42")),
        ((Standards.TOL2008, "0143"), (Standards.NACE2, "01.43")),
        ((Standards.TOL2008, "01430"), (Standards.NACE2, "01.43")),
        ((Standards.TOL2008, "0144"), (Standards.NACE2, "01.44")),
        ((Standards.TOL2008, "01440"), (Standards.NACE2, "01.44")),
        ((Standards.TOL2008, "0145"), (Standards.NACE2, "01.45")),
        ((Standards.TOL2008, "01450"), (Standards.NACE2, "01.45")),
        ((Standards.TOL2008, "0146"), (Standards.NACE2, "01.46")),
        ((Standards.TOL2008, "01461"), (Standards.NACE2, "01.46")),
        ((Standards.TOL2008, "01462"), (Standards.NACE2, "01.46")),
        ((Standards.TOL2008, "0147"), (Standards.NACE2, "01.47")),
        ((Standards.TOL2008, "01471"), (Standards.NACE2, "01.47")),
        ((Standards.TOL2008, "01472"), (Standards.NACE2, "01.47")),
        ((Standards.TOL2008, "01479"), (Standards.NACE2, "01.47")),
        ((Standards.TOL2008, "0149"), (Standards.NACE2, "01.49")),
        ((Standards.TOL2008, "01491"), (Standards.NACE2, "01.49")),
        ((Standards.TOL2008, "01492"), (Standards.NACE2, "01.49")),
        ((Standards.TOL2008, "01499"), (Standards.NACE2, "01.49")),
        ((Standards.TOL2008, "015"), (Standards.NACE2, "01.5")),
        ((Standards.TOL2008, "0150"), (Standards.NACE2, "01.50")),
        ((Standards.TOL2008, "01500"), (Standards.NACE2, "01.50")),
        ((Standards.TOL2008, "016"), (Standards.NACE2, "01.6")),
        ((Standards.TOL2008, "0161"), (Standards.NACE2, "01.61")),
        ((Standards.TOL2008, "01611"), (Standards.NACE2, "01.61")),
        ((Standards.TOL2008, "01612"), (Standards.NACE2, "01.61")),
        ((Standards.TOL2008, "0162"), (Standards.NACE2, "01.62")),
        ((Standards.TOL2008, "01620"), (Standards.NACE2, "01.62")),
        ((Standards.TOL2008, "0163"), (Standards.NACE2, "01.63")),
        ((Standards.TOL2008, "01630"), (Standards.NACE2, "01.63")),
        ((Standards.TOL2008, "0164"), (Standards.NACE2, "01.64")),
        ((Standards.TOL2008, "01640"), (Standards.NACE2, "01.64")),
        ((Standards.TOL2008, "017"), (Standards.NACE2, "01.7")),
        ((Standards.TOL2008, "0170"), (Standards.NACE2, "01.70")),
        ((Standards.TOL2008, "01700"), (Standards.NACE2, "01.70")),
        ((Standards.TOL2008, "02"), (Standards.NACE2, "02")),
        ((Standards.TOL2008, "021"), (Standards.NACE2, "02.1")),
        ((Standards.TOL2008, "0210"), (Standards.NACE2, "02.10")),
        ((Standards.TOL2008, "02100"), (Standards.NACE2, "02.10")),
        ((Standards.TOL2008, "022"), (Standards.NACE2, "02.2")),
        ((Standards.TOL2008, "0220"), (Standards.NACE2, "02.20")),
        ((Standards.TOL2008, "02200"), (Standards.NACE2, "02.20")),
        ((Standards.TOL2008, "023"), (Standards.NACE2, "02.3")),
        ((Standards.TOL2008, "0230"), (Standards.NACE2, "02.30")),
        ((Standards.TOL2008, "02300"), (Standards.NACE2, "02.30")),
        ((Standards.TOL2008, "024"), (Standards.NACE2, "02.4")),
        ((Standards.TOL2008, "0240"), (Standards.NACE2, "02.40")),
        ((Standards.TOL2008, "02400"), (Standards.NACE2, "02.40")),
        ((Standards.TOL2008, "03"), (Standards.NACE2, "03")),
        ((Standards.TOL2008, "031"), (Standards.NACE2, "03.1")),
        ((Standards.TOL2008, "0311"), (Standards.NACE2, "03.11")),
        ((Standards.TOL2008, "03110"), (Standards.NACE2, "03.11")),
        ((Standards.TOL2008, "0312"), (Standards.NACE2, "03.12")),
        ((Standards.TOL2008, "03120"), (Standards.NACE2, "03.12")),
        ((Standards.TOL2008, "032"), (Standards.NACE2, "03.2")),
        ((Standards.TOL2008, "0321"), (Standards.NACE2, "03.21")),
        ((Standards.TOL2008, "03210"), (Standards.NACE2, "03.21")),
        ((Standards.TOL2008, "0322"), (Standards.NACE2, "03.22")),
        ((Standards.TOL2008, "03220"), (Standards.NACE2, "03.22")),
        ((Standards.TOL2008, "B"), (Standards.NACE2, "B")),
        ((Standards.TOL2008, "05"), (Standards.NACE2, "05")),
        ((Standards.TOL2008, "051"), (Standards.NACE2, "05.1")),
        ((Standards.TOL2008, "0510"), (Standards.NACE2, "05.10")),
        ((Standards.TOL2008, "05100"), (Standards.NACE2, "05.10")),
        ((Standards.TOL2008, "052"), (Standards.NACE2, "05.2")),
        ((Standards.TOL2008, "0520"), (Standards.NACE2, "05.20")),
        ((Standards.TOL2008, "05200"), (Standards.NACE2, "05.20")),
        ((Standards.TOL2008, "06"), (Standards.NACE2, "06")),
        ((Standards.TOL2008, "061"), (Standards.NACE2, "06.1")),
        ((Standards.TOL2008, "0610"), (Standards.NACE2, "06.10")),
        ((Standards.TOL2008, "06100"), (Standards.NACE2, "06.10")),
        ((Standards.TOL2008, "062"), (Standards.NACE2, "06.2")),
        ((Standards.TOL2008, "0620"), (Standards.NACE2, "06.20")),
        ((Standards.TOL2008, "06200"), (Standards.NACE2, "06.20")),
        ((Standards.TOL2008, "07"), (Standards.NACE2, "07")),
        ((Standards.TOL2008, "071"), (Standards.NACE2, "07.1")),
        ((Standards.TOL2008, "0710"), (Standards.NACE2, "07.10")),
        ((Standards.TOL2008, "07100"), (Standards.NACE2, "07.10")),
        ((Standards.TOL2008, "072"), (Standards.NACE2, "07.2")),
        ((Standards.TOL2008, "0721"), (Standards.NACE2, "07.21")),
        ((Standards.TOL2008, "07210"), (Standards.NACE2, "07.21")),
        ((Standards.TOL2008, "0729"), (Standards.NACE2, "07.29")),
        ((Standards.TOL2008, "07290"), (Standards.NACE2, "07.29")),
        ((Standards.TOL2008, "08"), (Standards.NACE2, "08")),
        ((Standards.TOL2008, "081"), (Standards.NACE2, "08.1")),
        ((Standards.TOL2008, "0811"), (Standards.NACE2, "08.11")),
        ((Standards.TOL2008, "08111"), (Standards.NACE2, "08.11")),
        ((Standards.TOL2008, "08112"), (Standards.NACE2, "08.11")),
        ((Standards.TOL2008, "08113"), (Standards.NACE2, "08.11")),
        ((Standards.TOL2008, "0812"), (Standards.NACE2, "08.12")),
        ((Standards.TOL2008, "08120"), (Standards.NACE2, "08.12")),
        ((Standards.TOL2008, "089"), (Standards.NACE2, "08.9")),
        ((Standards.TOL2008, "0891"), (Standards.NACE2, "08.91")),
        ((Standards.TOL2008, "08910"), (Standards.NACE2, "08.91")),
        ((Standards.TOL2008, "0892"), (Standards.NACE2, "08.92")),
        ((Standards.TOL2008, "08920"), (Standards.NACE2, "08.92")),
        ((Standards.TOL2008, "0893"), (Standards.NACE2, "08.93")),
        ((Standards.TOL2008, "08930"), (Standards.NACE2, "08.93")),
        ((Standards.TOL2008, "0899"), (Standards.NACE2, "08.99")),
        ((Standards.TOL2008, "08990"), (Standards.NACE2, "08.99")),
        ((Standards.TOL2008, "09"), (Standards.NACE2, "09")),
        ((Standards.TOL2008, "091"), (Standards.NACE2, "09.1")),
        ((Standards.TOL2008, "0910"), (Standards.NACE2, "09.10")),
        ((Standards.TOL2008, "09100"), (Standards.NACE2, "09.10")),
        ((Standards.TOL2008, "099"), (Standards.NACE2, "09.9")),
        ((Standards.TOL2008, "0990"), (Standards.NACE2, "09.90")),
        ((Standards.TOL2008, "09900"), (Standards.NACE2, "09.90")),
        ((Standards.TOL2008, "C"), (Standards.NACE2, "C")),
        ((Standards.TOL2008, "10"), (Standards.NACE2, "10")),
        ((Standards.TOL2008, "101"), (Standards.NACE2, "10.1")),
        ((Standards.TOL2008, "1011"), (Standards.NACE2, "10.11")),
        ((Standards.TOL2008, "10110"), (Standards.NACE2, "10.11")),
        ((Standards.TOL2008, "1012"), (Standards.NACE2, "10.12")),
        ((Standards.TOL2008, "10120"), (Standards.NACE2, "10.12")),
        ((Standards.TOL2008, "1013"), (Standards.NACE2, "10.13")),
        ((Standards.TOL2008, "10130"), (Standards.NACE2, "10.13")),
        ((Standards.TOL2008, "102"), (Standards.NACE2, "10.2")),
        ((Standards.TOL2008, "1020"), (Standards.NACE2, "10.20")),
        ((Standards.TOL2008, "10200"), (Standards.NACE2, "10.20")),
        ((Standards.TOL2008, "103"), (Standards.NACE2, "10.3")),
        ((Standards.TOL2008, "1031"), (Standards.NACE2, "10.31")),
        ((Standards.TOL2008, "10310"), (Standards.NACE2, "10.31")),
        ((Standards.TOL2008, "1032"), (Standards.NACE2, "10.32")),
        ((Standards.TOL2008, "10320"), (Standards.NACE2, "10.32")),
        ((Standards.TOL2008, "1039"), (Standards.NACE2, "10.39")),
        ((Standards.TOL2008, "10390"), (Standards.NACE2, "10.39")),
        ((Standards.TOL2008, "104"), (Standards.NACE2, "10.4")),
        ((Standards.TOL2008, "1041"), (Standards.NACE2, "10.41")),
        ((Standards.TOL2008, "10410"), (Standards.NACE2, "10.41")),
        ((Standards.TOL2008, "1042"), (Standards.NACE2, "10.42")),
        ((Standards.TOL2008, "10420"), (Standards.NACE2, "10.42")),
        ((Standards.TOL2008, "105"), (Standards.NACE2, "10.5")),
        ((Standards.TOL2008, "1051"), (Standards.NACE2, "10.51")),
        ((Standards.TOL2008, "10510"), (Standards.NACE2, "10.51")),
        ((Standards.TOL2008, "1052"), (Standards.NACE2, "10.52")),
        ((Standards.TOL2008, "10520"), (Standards.NACE2, "10.52")),
        ((Standards.TOL2008, "106"), (Standards.NACE2, "10.6")),
        ((Standards.TOL2008, "1061"), (Standards.NACE2, "10.61")),
        ((Standards.TOL2008, "10610"), (Standards.NACE2, "10.61")),
        ((Standards.TOL2008, "1062"), (Standards.NACE2, "10.62")),
        ((Standards.TOL2008, "10620"), (Standards.NACE2, "10.62")),
        ((Standards.TOL2008, "107"), (Standards.NACE2, "10.7")),
        ((Standards.TOL2008, "1071"), (Standards.NACE2, "10.71")),
        ((Standards.TOL2008, "10710"), (Standards.NACE2, "10.71")),
        ((Standards.TOL2008, "1072"), (Standards.NACE2, "10.72")),
        ((Standards.TOL2008, "10720"), (Standards.NACE2, "10.72")),
        ((Standards.TOL2008, "1073"), (Standards.NACE2, "10.73")),
        ((Standards.TOL2008, "10730"), (Standards.NACE2, "10.73")),
        ((Standards.TOL2008, "108"), (Standards.NACE2, "10.8")),
        ((Standards.TOL2008, "1081"), (Standards.NACE2, "10.81")),
        ((Standards.TOL2008, "10810"), (Standards.NACE2, "10.81")),
        ((Standards.TOL2008, "1082"), (Standards.NACE2, "10.82")),
        ((Standards.TOL2008, "10820"), (Standards.NACE2, "10.82")),
        ((Standards.TOL2008, "1083"), (Standards.NACE2, "10.83")),
        ((Standards.TOL2008, "10830"), (Standards.NACE2, "10.83")),
        ((Standards.TOL2008, "1084"), (Standards.NACE2, "10.84")),
        ((Standards.TOL2008, "10840"), (Standards.NACE2, "10.84")),
        ((Standards.TOL2008, "1085"), (Standards.NACE2, "10.85")),
        ((Standards.TOL2008, "10850"), (Standards.NACE2, "10.85")),
        ((Standards.TOL2008, "1086"), (Standards.NACE2, "10.86")),
        ((Standards.TOL2008, "10860"), (Standards.NACE2, "10.86")),
        ((Standards.TOL2008, "1089"), (Standards.NACE2, "10.89")),
        ((Standards.TOL2008, "10890"), (Standards.NACE2, "10.89")),
        ((Standards.TOL2008, "109"), (Standards.NACE2, "10.9")),
        ((Standards.TOL2008, "1091"), (Standards.NACE2, "10.91")),
        ((Standards.TOL2008, "10910"), (Standards.NACE2, "10.91")),
        ((Standards.TOL2008, "1092"), (Standards.NACE2, "10.92")),
        ((Standards.TOL2008, "10920"), (Standards.NACE2, "10.92")),
        ((Standards.TOL2008, "11"), (Standards.NACE2, "11")),
        ((Standards.TOL2008, "110"), (Standards.NACE2, "11.0")),
        ((Standards.TOL2008, "1101"), (Standards.NACE2, "11.01")),
        ((Standards.TOL2008, "11010"), (Standards.NACE2, "11.01")),
        ((Standards.TOL2008, "1102"), (Standards.NACE2, "11.02")),
        ((Standards.TOL2008, "11020"), (Standards.NACE2, "11.02")),
        ((Standards.TOL2008, "1103"), (Standards.NACE2, "11.03")),
        ((Standards.TOL2008, "11030"), (Standards.NACE2, "11.03")),
        ((Standards.TOL2008, "1104"), (Standards.NACE2, "11.04")),
        ((Standards.TOL2008, "11040"), (Standards.NACE2, "11.04")),
        ((Standards.TOL2008, "1105"), (Standards.NACE2, "11.05")),
        ((Standards.TOL2008, "11050"), (Standards.NACE2, "11.05")),
        ((Standards.TOL2008, "1106"), (Standards.NACE2, "11.06")),
        ((Standards.TOL2008, "11060"), (Standards.NACE2, "11.06")),
        ((Standards.TOL2008, "1107"), (Standards.NACE2, "11.07")),
        ((Standards.TOL2008, "11070"), (Standards.NACE2, "11.07")),
        ((Standards.TOL2008, "12"), (Standards.NACE2, "12")),
        ((Standards.TOL2008, "120"), (Standards.NACE2, "12.0")),
        ((Standards.TOL2008, "1200"), (Standards.NACE2, "12.00")),
        ((Standards.TOL2008, "12000"), (Standards.NACE2, "12.00")),
        ((Standards.TOL2008, "13"), (Standards.NACE2, "13")),
        ((Standards.TOL2008, "131"), (Standards.NACE2, "13.1")),
        ((Standards.TOL2008, "1310"), (Standards.NACE2, "13.10")),
        ((Standards.TOL2008, "13100"), (Standards.NACE2, "13.10")),
        ((Standards.TOL2008, "132"), (Standards.NACE2, "13.2")),
        ((Standards.TOL2008, "1320"), (Standards.NACE2, "13.20")),
        ((Standards.TOL2008, "13200"), (Standards.NACE2, "13.20")),
        ((Standards.TOL2008, "133"), (Standards.NACE2, "13.3")),
        ((Standards.TOL2008, "1330"), (Standards.NACE2, "13.30")),
        ((Standards.TOL2008, "13300"), (Standards.NACE2, "13.30")),
        ((Standards.TOL2008, "139"), (Standards.NACE2, "13.9")),
        ((Standards.TOL2008, "1391"), (Standards.NACE2, "13.91")),
        ((Standards.TOL2008, "13910"), (Standards.NACE2, "13.91")),
        ((Standards.TOL2008, "1392"), (Standards.NACE2, "13.92")),
        ((Standards.TOL2008, "13921"), (Standards.NACE2, "13.92")),
        ((Standards.TOL2008, "13922"), (Standards.NACE2, "13.92")),
        ((Standards.TOL2008, "1393"), (Standards.NACE2, "13.93")),
        ((Standards.TOL2008, "13930"), (Standards.NACE2, "13.93")),
        ((Standards.TOL2008, "1394"), (Standards.NACE2, "13.94")),
        ((Standards.TOL2008, "13940"), (Standards.NACE2, "13.94")),
        ((Standards.TOL2008, "1395"), (Standards.NACE2, "13.95")),
        ((Standards.TOL2008, "13950"), (Standards.NACE2, "13.95")),
        ((Standards.TOL2008, "1396"), (Standards.NACE2, "13.96")),
        ((Standards.TOL2008, "13960"), (Standards.NACE2, "13.96")),
        ((Standards.TOL2008, "1399"), (Standards.NACE2, "13.99")),
        ((Standards.TOL2008, "13990"), (Standards.NACE2, "13.99")),
        ((Standards.TOL2008, "14"), (Standards.NACE2, "14")),
        ((Standards.TOL2008, "141"), (Standards.NACE2, "14.1")),
        ((Standards.TOL2008, "1411"), (Standards.NACE2, "14.11")),
        ((Standards.TOL2008, "14110"), (Standards.NACE2, "14.11")),
        ((Standards.TOL2008, "1412"), (Standards.NACE2, "14.12")),
        ((Standards.TOL2008, "14120"), (Standards.NACE2, "14.12")),
        ((Standards.TOL2008, "1413"), (Standards.NACE2, "14.13")),
        ((Standards.TOL2008, "14130"), (Standards.NACE2, "14.13")),
        ((Standards.TOL2008, "1414"), (Standards.NACE2, "14.14")),
        ((Standards.TOL2008, "14140"), (Standards.NACE2, "14.14")),
        ((Standards.TOL2008, "1419"), (Standards.NACE2, "14.19")),
        ((Standards.TOL2008, "14190"), (Standards.NACE2, "14.19")),
        ((Standards.TOL2008, "142"), (Standards.NACE2, "14.2")),
        ((Standards.TOL2008, "1420"), (Standards.NACE2, "14.20")),
        ((Standards.TOL2008, "14200"), (Standards.NACE2, "14.20")),
        ((Standards.TOL2008, "143"), (Standards.NACE2, "14.3")),
        ((Standards.TOL2008, "1431"), (Standards.NACE2, "14.31")),
        ((Standards.TOL2008, "14310"), (Standards.NACE2, "14.31")),
        ((Standards.TOL2008, "1439"), (Standards.NACE2, "14.39")),
        ((Standards.TOL2008, "14390"), (Standards.NACE2, "14.39")),
        ((Standards.TOL2008, "15"), (Standards.NACE2, "15")),
        ((Standards.TOL2008, "151"), (Standards.NACE2, "15.1")),
        ((Standards.TOL2008, "1511"), (Standards.NACE2, "15.11")),
        ((Standards.TOL2008, "15110"), (Standards.NACE2, "15.11")),
        ((Standards.TOL2008, "1512"), (Standards.NACE2, "15.12")),
        ((Standards.TOL2008, "15120"), (Standards.NACE2, "15.12")),
        ((Standards.TOL2008, "152"), (Standards.NACE2, "15.2")),
        ((Standards.TOL2008, "1520"), (Standards.NACE2, "15.20")),
        ((Standards.TOL2008, "15200"), (Standards.NACE2, "15.20")),
        ((Standards.TOL2008, "16"), (Standards.NACE2, "16")),
        ((Standards.TOL2008, "161"), (Standards.NACE2, "16.1")),
        ((Standards.TOL2008, "1610"), (Standards.NACE2, "16.10")),
        ((Standards.TOL2008, "16100"), (Standards.NACE2, "16.10")),
        ((Standards.TOL2008, "162"), (Standards.NACE2, "16.2")),
        ((Standards.TOL2008, "1621"), (Standards.NACE2, "16.21")),
        ((Standards.TOL2008, "16211"), (Standards.NACE2, "16.21")),
        ((Standards.TOL2008, "16212"), (Standards.NACE2, "16.21")),
        ((Standards.TOL2008, "16213"), (Standards.NACE2, "16.21")),
        ((Standards.TOL2008, "1622"), (Standards.NACE2, "16.22")),
        ((Standards.TOL2008, "16220"), (Standards.NACE2, "16.22")),
        ((Standards.TOL2008, "1623"), (Standards.NACE2, "16.23")),
        ((Standards.TOL2008, "16231"), (Standards.NACE2, "16.23")),
        ((Standards.TOL2008, "16239"), (Standards.NACE2, "16.23")),
        ((Standards.TOL2008, "1624"), (Standards.NACE2, "16.24")),
        ((Standards.TOL2008, "16240"), (Standards.NACE2, "16.24")),
        ((Standards.TOL2008, "1629"), (Standards.NACE2, "16.29")),
        ((Standards.TOL2008, "16290"), (Standards.NACE2, "16.29")),
        ((Standards.TOL2008, "17"), (Standards.NACE2, "17")),
        ((Standards.TOL2008, "171"), (Standards.NACE2, "17.1")),
        ((Standards.TOL2008, "1711"), (Standards.NACE2, "17.11")),
        ((Standards.TOL2008, "17110"), (Standards.NACE2, "17.11")),
        ((Standards.TOL2008, "1712"), (Standards.NACE2, "17.12")),
        ((Standards.TOL2008, "17120"), (Standards.NACE2, "17.12")),
        ((Standards.TOL2008, "172"), (Standards.NACE2, "17.2")),
        ((Standards.TOL2008, "1721"), (Standards.NACE2, "17.21")),
        ((Standards.TOL2008, "17211"), (Standards.NACE2, "17.21")),
        ((Standards.TOL2008, "17212"), (Standards.NACE2, "17.21")),
        ((Standards.TOL2008, "1722"), (Standards.NACE2, "17.22")),
        ((Standards.TOL2008, "17220"), (Standards.NACE2, "17.22")),
        ((Standards.TOL2008, "1723"), (Standards.NACE2, "17.23")),
        ((Standards.TOL2008, "17230"), (Standards.NACE2, "17.23")),
        ((Standards.TOL2008, "1724"), (Standards.NACE2, "17.24")),
        ((Standards.TOL2008, "17240"), (Standards.NACE2, "17.24")),
        ((Standards.TOL2008, "1729"), (Standards.NACE2, "17.29")),
        ((Standards.TOL2008, "17290"), (Standards.NACE2, "17.29")),
        ((Standards.TOL2008, "18"), (Standards.NACE2, "18")),
        ((Standards.TOL2008, "181"), (Standards.NACE2, "18.1")),
        ((Standards.TOL2008, "1811"), (Standards.NACE2, "18.11")),
        ((Standards.TOL2008, "18110"), (Standards.NACE2, "18.11")),
        ((Standards.TOL2008, "1812"), (Standards.NACE2, "18.12")),
        ((Standards.TOL2008, "18120"), (Standards.NACE2, "18.12")),
        ((Standards.TOL2008, "1813"), (Standards.NACE2, "18.13")),
        ((Standards.TOL2008, "18130"), (Standards.NACE2, "18.13")),
        ((Standards.TOL2008, "1814"), (Standards.NACE2, "18.14")),
        ((Standards.TOL2008, "18140"), (Standards.NACE2, "18.14")),
        ((Standards.TOL2008, "182"), (Standards.NACE2, "18.2")),
        ((Standards.TOL2008, "1820"), (Standards.NACE2, "18.20")),
        ((Standards.TOL2008, "18200"), (Standards.NACE2, "18.20")),
        ((Standards.TOL2008, "19"), (Standards.NACE2, "19")),
        ((Standards.TOL2008, "191"), (Standards.NACE2, "19.1")),
        ((Standards.TOL2008, "1910"), (Standards.NACE2, "19.10")),
        ((Standards.TOL2008, "19100"), (Standards.NACE2, "19.10")),
        ((Standards.TOL2008, "192"), (Standards.NACE2, "19.2")),
        ((Standards.TOL2008, "1920"), (Standards.NACE2, "19.20")),
        ((Standards.TOL2008, "19200"), (Standards.NACE2, "19.20")),
        ((Standards.TOL2008, "20"), (Standards.NACE2, "20")),
        ((Standards.TOL2008, "201"), (Standards.NACE2, "20.1")),
        ((Standards.TOL2008, "2011"), (Standards.NACE2, "20.11")),
        ((Standards.TOL2008, "20110"), (Standards.NACE2, "20.11")),
        ((Standards.TOL2008, "2012"), (Standards.NACE2, "20.12")),
        ((Standards.TOL2008, "20120"), (Standards.NACE2, "20.12")),
        ((Standards.TOL2008, "2013"), (Standards.NACE2, "20.13")),
        ((Standards.TOL2008, "20130"), (Standards.NACE2, "20.13")),
        ((Standards.TOL2008, "2014"), (Standards.NACE2, "20.14")),
        ((Standards.TOL2008, "20140"), (Standards.NACE2, "20.14")),
        ((Standards.TOL2008, "2015"), (Standards.NACE2, "20.15")),
        ((Standards.TOL2008, "20150"), (Standards.NACE2, "20.15")),
        ((Standards.TOL2008, "2016"), (Standards.NACE2, "20.16")),
        ((Standards.TOL2008, "20160"), (Standards.NACE2, "20.16")),
        ((Standards.TOL2008, "2017"), (Standards.NACE2, "20.17")),
        ((Standards.TOL2008, "20170"), (Standards.NACE2, "20.17")),
        ((Standards.TOL2008, "202"), (Standards.NACE2, "20.2")),
        ((Standards.TOL2008, "2020"), (Standards.NACE2, "20.20")),
        ((Standards.TOL2008, "20200"), (Standards.NACE2, "20.20")),
        ((Standards.TOL2008, "203"), (Standards.NACE2, "20.3")),
        ((Standards.TOL2008, "2030"), (Standards.NACE2, "20.30")),
        ((Standards.TOL2008, "20300"), (Standards.NACE2, "20.30")),
        ((Standards.TOL2008, "204"), (Standards.NACE2, "20.4")),
        ((Standards.TOL2008, "2041"), (Standards.NACE2, "20.41")),
        ((Standards.TOL2008, "20410"), (Standards.NACE2, "20.41")),
        ((Standards.TOL2008, "2042"), (Standards.NACE2, "20.42")),
        ((Standards.TOL2008, "20420"), (Standards.NACE2, "20.42")),
        ((Standards.TOL2008, "205"), (Standards.NACE2, "20.5")),
        ((Standards.TOL2008, "2051"), (Standards.NACE2, "20.51")),
        ((Standards.TOL2008, "20510"), (Standards.NACE2, "20.51")),
        ((Standards.TOL2008, "2052"), (Standards.NACE2, "20.52")),
        ((Standards.TOL2008, "20520"), (Standards.NACE2, "20.52")),
        ((Standards.TOL2008, "2053"), (Standards.NACE2, "20.53")),
        ((Standards.TOL2008, "20530"), (Standards.NACE2, "20.53")),
        ((Standards.TOL2008, "2059"), (Standards.NACE2, "20.59")),
        ((Standards.TOL2008, "20590"), (Standards.NACE2, "20.59")),
        ((Standards.TOL2008, "206"), (Standards.NACE2, "20.6")),
        ((Standards.TOL2008, "2060"), (Standards.NACE2, "20.60")),
        ((Standards.TOL2008, "20600"), (Standards.NACE2, "20.60")),
        ((Standards.TOL2008, "21"), (Standards.NACE2, "21")),
        ((Standards.TOL2008, "211"), (Standards.NACE2, "21.1")),
        ((Standards.TOL2008, "2110"), (Standards.NACE2, "21.10")),
        ((Standards.TOL2008, "21100"), (Standards.NACE2, "21.10")),
        ((Standards.TOL2008, "212"), (Standards.NACE2, "21.2")),
        ((Standards.TOL2008, "2120"), (Standards.NACE2, "21.20")),
        ((Standards.TOL2008, "21200"), (Standards.NACE2, "21.20")),
        ((Standards.TOL2008, "22"), (Standards.NACE2, "22")),
        ((Standards.TOL2008, "221"), (Standards.NACE2, "22.1")),
        ((Standards.TOL2008, "2211"), (Standards.NACE2, "22.11")),
        ((Standards.TOL2008, "22110"), (Standards.NACE2, "22.11")),
        ((Standards.TOL2008, "2219"), (Standards.NACE2, "22.19")),
        ((Standards.TOL2008, "22190"), (Standards.NACE2, "22.19")),
        ((Standards.TOL2008, "222"), (Standards.NACE2, "22.2")),
        ((Standards.TOL2008, "2221"), (Standards.NACE2, "22.21")),
        ((Standards.TOL2008, "22210"), (Standards.NACE2, "22.21")),
        ((Standards.TOL2008, "2222"), (Standards.NACE2, "22.22")),
        ((Standards.TOL2008, "22220"), (Standards.NACE2, "22.22")),
        ((Standards.TOL2008, "2223"), (Standards.NACE2, "22.23")),
        ((Standards.TOL2008, "22230"), (Standards.NACE2, "22.23")),
        ((Standards.TOL2008, "2229"), (Standards.NACE2, "22.29")),
        ((Standards.TOL2008, "22290"), (Standards.NACE2, "22.29")),
        ((Standards.TOL2008, "23"), (Standards.NACE2, "23")),
        ((Standards.TOL2008, "231"), (Standards.NACE2, "23.1")),
        ((Standards.TOL2008, "2311"), (Standards.NACE2, "23.11")),
        ((Standards.TOL2008, "23110"), (Standards.NACE2, "23.11")),
        ((Standards.TOL2008, "2312"), (Standards.NACE2, "23.12")),
        ((Standards.TOL2008, "23120"), (Standards.NACE2, "23.12")),
        ((Standards.TOL2008, "2313"), (Standards.NACE2, "23.13")),
        ((Standards.TOL2008, "23130"), (Standards.NACE2, "23.13")),
        ((Standards.TOL2008, "2314"), (Standards.NACE2, "23.14")),
        ((Standards.TOL2008, "23140"), (Standards.NACE2, "23.14")),
        ((Standards.TOL2008, "2319"), (Standards.NACE2, "23.19")),
        ((Standards.TOL2008, "23190"), (Standards.NACE2, "23.19")),
        ((Standards.TOL2008, "232"), (Standards.NACE2, "23.2")),
        ((Standards.TOL2008, "2320"), (Standards.NACE2, "23.20")),
        ((Standards.TOL2008, "23200"), (Standards.NACE2, "23.20")),
        ((Standards.TOL2008, "233"), (Standards.NACE2, "23.3")),
        ((Standards.TOL2008, "2331"), (Standards.NACE2, "23.31")),
        ((Standards.TOL2008, "23310"), (Standards.NACE2, "23.31")),
        ((Standards.TOL2008, "2332"), (Standards.NACE2, "23.32")),
        ((Standards.TOL2008, "23320"), (Standards.NACE2, "23.32")),
        ((Standards.TOL2008, "234"), (Standards.NACE2, "23.4")),
        ((Standards.TOL2008, "2341"), (Standards.NACE2, "23.41")),
        ((Standards.TOL2008, "23410"), (Standards.NACE2, "23.41")),
        ((Standards.TOL2008, "2342"), (Standards.NACE2, "23.42")),
        ((Standards.TOL2008, "23420"), (Standards.NACE2, "23.42")),
        ((Standards.TOL2008, "2343"), (Standards.NACE2, "23.43")),
        ((Standards.TOL2008, "23430"), (Standards.NACE2, "23.43")),
        ((Standards.TOL2008, "2344"), (Standards.NACE2, "23.44")),
        ((Standards.TOL2008, "23440"), (Standards.NACE2, "23.44")),
        ((Standards.TOL2008, "2349"), (Standards.NACE2, "23.49")),
        ((Standards.TOL2008, "23490"), (Standards.NACE2, "23.49")),
        ((Standards.TOL2008, "235"), (Standards.NACE2, "23.5")),
        ((Standards.TOL2008, "2351"), (Standards.NACE2, "23.51")),
        ((Standards.TOL2008, "23510"), (Standards.NACE2, "23.51")),
        ((Standards.TOL2008, "2352"), (Standards.NACE2, "23.52")),
        ((Standards.TOL2008, "23520"), (Standards.NACE2, "23.52")),
        ((Standards.TOL2008, "236"), (Standards.NACE2, "23.6")),
        ((Standards.TOL2008, "2361"), (Standards.NACE2, "23.61")),
        ((Standards.TOL2008, "23610"), (Standards.NACE2, "23.61")),
        ((Standards.TOL2008, "2362"), (Standards.NACE2, "23.62")),
        ((Standards.TOL2008, "23620"), (Standards.NACE2, "23.62")),
        ((Standards.TOL2008, "2363"), (Standards.NACE2, "23.63")),
        ((Standards.TOL2008, "23630"), (Standards.NACE2, "23.63")),
        ((Standards.TOL2008, "2364"), (Standards.NACE2, "23.64")),
        ((Standards.TOL2008, "23640"), (Standards.NACE2, "23.64")),
        ((Standards.TOL2008, "2365"), (Standards.NACE2, "23.65")),
        ((Standards.TOL2008, "23650"), (Standards.NACE2, "23.65")),
        ((Standards.TOL2008, "2369"), (Standards.NACE2, "23.69")),
        ((Standards.TOL2008, "23690"), (Standards.NACE2, "23.69")),
        ((Standards.TOL2008, "237"), (Standards.NACE2, "23.7")),
        ((Standards.TOL2008, "2370"), (Standards.NACE2, "23.70")),
        ((Standards.TOL2008, "23700"), (Standards.NACE2, "23.70")),
        ((Standards.TOL2008, "239"), (Standards.NACE2, "23.9")),
        ((Standards.TOL2008, "2391"), (Standards.NACE2, "23.91")),
        ((Standards.TOL2008, "23910"), (Standards.NACE2, "23.91")),
        ((Standards.TOL2008, "2399"), (Standards.NACE2, "23.99")),
        ((Standards.TOL2008, "23990"), (Standards.NACE2, "23.99")),
        ((Standards.TOL2008, "24"), (Standards.NACE2, "24")),
        ((Standards.TOL2008, "241"), (Standards.NACE2, "24.1")),
        ((Standards.TOL2008, "2410"), (Standards.NACE2, "24.10")),
        ((Standards.TOL2008, "24100"), (Standards.NACE2, "24.10")),
        ((Standards.TOL2008, "242"), (Standards.NACE2, "24.2")),
        ((Standards.TOL2008, "2420"), (Standards.NACE2, "24.20")),
        ((Standards.TOL2008, "24200"), (Standards.NACE2, "24.20")),
        ((Standards.TOL2008, "243"), (Standards.NACE2, "24.3")),
        ((Standards.TOL2008, "2431"), (Standards.NACE2, "24.31")),
        ((Standards.TOL2008, "24310"), (Standards.NACE2, "24.31")),
        ((Standards.TOL2008, "2432"), (Standards.NACE2, "24.32")),
        ((Standards.TOL2008, "24320"), (Standards.NACE2, "24.32")),
        ((Standards.TOL2008, "2433"), (Standards.NACE2, "24.33")),
        ((Standards.TOL2008, "24330"), (Standards.NACE2, "24.33")),
        ((Standards.TOL2008, "2434"), (Standards.NACE2, "24.34")),
        ((Standards.TOL2008, "24340"), (Standards.NACE2, "24.34")),
        ((Standards.TOL2008, "244"), (Standards.NACE2, "24.4")),
        ((Standards.TOL2008, "2441"), (Standards.NACE2, "24.41")),
        ((Standards.TOL2008, "24410"), (Standards.NACE2, "24.41")),
        ((Standards.TOL2008, "2442"), (Standards.NACE2, "24.42")),
        ((Standards.TOL2008, "24420"), (Standards.NACE2, "24.42")),
        ((Standards.TOL2008, "2443"), (Standards.NACE2, "24.43")),
        ((Standards.TOL2008, "24430"), (Standards.NACE2, "24.43")),
        ((Standards.TOL2008, "2444"), (Standards.NACE2, "24.44")),
        ((Standards.TOL2008, "24440"), (Standards.NACE2, "24.44")),
        ((Standards.TOL2008, "2445"), (Standards.NACE2, "24.45")),
        ((Standards.TOL2008, "24450"), (Standards.NACE2, "24.45")),
        ((Standards.TOL2008, "2446"), (Standards.NACE2, "24.46")),
        ((Standards.TOL2008, "24460"), (Standards.NACE2, "24.46")),
        ((Standards.TOL2008, "245"), (Standards.NACE2, "24.5")),
        ((Standards.TOL2008, "2451"), (Standards.NACE2, "24.51")),
        ((Standards.TOL2008, "24510"), (Standards.NACE2, "24.51")),
        ((Standards.TOL2008, "2452"), (Standards.NACE2, "24.52")),
        ((Standards.TOL2008, "24520"), (Standards.NACE2, "24.52")),
        ((Standards.TOL2008, "2453"), (Standards.NACE2, "24.53")),
        ((Standards.TOL2008, "24530"), (Standards.NACE2, "24.53")),
        ((Standards.TOL2008, "2454"), (Standards.NACE2, "24.54")),
        ((Standards.TOL2008, "24540"), (Standards.NACE2, "24.54")),
        ((Standards.TOL2008, "25"), (Standards.NACE2, "25")),
        ((Standards.TOL2008, "251"), (Standards.NACE2, "25.1")),
        ((Standards.TOL2008, "2511"), (Standards.NACE2, "25.11")),
        ((Standards.TOL2008, "25110"), (Standards.NACE2, "25.11")),
        ((Standards.TOL2008, "2512"), (Standards.NACE2, "25.12")),
        ((Standards.TOL2008, "25120"), (Standards.NACE2, "25.12")),
        ((Standards.TOL2008, "252"), (Standards.NACE2, "25.2")),
        ((Standards.TOL2008, "2521"), (Standards.NACE2, "25.21")),
        ((Standards.TOL2008, "25210"), (Standards.NACE2, "25.21")),
        ((Standards.TOL2008, "2529"), (Standards.NACE2, "25.29")),
        ((Standards.TOL2008, "25290"), (Standards.NACE2, "25.29")),
        ((Standards.TOL2008, "253"), (Standards.NACE2, "25.3")),
        ((Standards.TOL2008, "2530"), (Standards.NACE2, "25.30")),
        ((Standards.TOL2008, "25300"), (Standards.NACE2, "25.30")),
        ((Standards.TOL2008, "254"), (Standards.NACE2, "25.4")),
        ((Standards.TOL2008, "2540"), (Standards.NACE2, "25.40")),
        ((Standards.TOL2008, "25400"), (Standards.NACE2, "25.40")),
        ((Standards.TOL2008, "255"), (Standards.NACE2, "25.5")),
        ((Standards.TOL2008, "2550"), (Standards.NACE2, "25.50")),
        ((Standards.TOL2008, "25500"), (Standards.NACE2, "25.50")),
        ((Standards.TOL2008, "256"), (Standards.NACE2, "25.6")),
        ((Standards.TOL2008, "2561"), (Standards.NACE2, "25.61")),
        ((Standards.TOL2008, "25610"), (Standards.NACE2, "25.61")),
        ((Standards.TOL2008, "2562"), (Standards.NACE2, "25.62")),
        ((Standards.TOL2008, "25620"), (Standards.NACE2, "25.62")),
        ((Standards.TOL2008, "257"), (Standards.NACE2, "25.7")),
        ((Standards.TOL2008, "2571"), (Standards.NACE2, "25.71")),
        ((Standards.TOL2008, "25710"), (Standards.NACE2, "25.71")),
        ((Standards.TOL2008, "2572"), (Standards.NACE2, "25.72")),
        ((Standards.TOL2008, "25720"), (Standards.NACE2, "25.72")),
        ((Standards.TOL2008, "2573"), (Standards.NACE2, "25.73")),
        ((Standards.TOL2008, "25730"), (Standards.NACE2, "25.73")),
        ((Standards.TOL2008, "259"), (Standards.NACE2, "25.9")),
        ((Standards.TOL2008, "2591"), (Standards.NACE2, "25.91")),
        ((Standards.TOL2008, "25910"), (Standards.NACE2, "25.91")),
        ((Standards.TOL2008, "2592"), (Standards.NACE2, "25.92")),
        ((Standards.TOL2008, "25920"), (Standards.NACE2, "25.92")),
        ((Standards.TOL2008, "2593"), (Standards.NACE2, "25.93")),
        ((Standards.TOL2008, "25930"), (Standards.NACE2, "25.93")),
        ((Standards.TOL2008, "2594"), (Standards.NACE2, "25.94")),
        ((Standards.TOL2008, "25940"), (Standards.NACE2, "25.94")),
        ((Standards.TOL2008, "2599"), (Standards.NACE2, "25.99")),
        ((Standards.TOL2008, "25990"), (Standards.NACE2, "25.99")),
        ((Standards.TOL2008, "26"), (Standards.NACE2, "26")),
        ((Standards.TOL2008, "261"), (Standards.NACE2, "26.1")),
        ((Standards.TOL2008, "2611"), (Standards.NACE2, "26.11")),
        ((Standards.TOL2008, "26110"), (Standards.NACE2, "26.11")),
        ((Standards.TOL2008, "2612"), (Standards.NACE2, "26.12")),
        ((Standards.TOL2008, "26120"), (Standards.NACE2, "26.12")),
        ((Standards.TOL2008, "262"), (Standards.NACE2, "26.2")),
        ((Standards.TOL2008, "2620"), (Standards.NACE2, "26.20")),
        ((Standards.TOL2008, "26200"), (Standards.NACE2, "26.20")),
        ((Standards.TOL2008, "263"), (Standards.NACE2, "26.3")),
        ((Standards.TOL2008, "2630"), (Standards.NACE2, "26.30")),
        ((Standards.TOL2008, "26300"), (Standards.NACE2, "26.30")),
        ((Standards.TOL2008, "264"), (Standards.NACE2, "26.4")),
        ((Standards.TOL2008, "2640"), (Standards.NACE2, "26.40")),
        ((Standards.TOL2008, "26400"), (Standards.NACE2, "26.40")),
        ((Standards.TOL2008, "265"), (Standards.NACE2, "26.5")),
        ((Standards.TOL2008, "2651"), (Standards.NACE2, "26.51")),
        ((Standards.TOL2008, "26510"), (Standards.NACE2, "26.51")),
        ((Standards.TOL2008, "2652"), (Standards.NACE2, "26.52")),
        ((Standards.TOL2008, "26520"), (Standards.NACE2, "26.52")),
        ((Standards.TOL2008, "266"), (Standards.NACE2, "26.6")),
        ((Standards.TOL2008, "2660"), (Standards.NACE2, "26.60")),
        ((Standards.TOL2008, "26600"), (Standards.NACE2, "26.60")),
        ((Standards.TOL2008, "267"), (Standards.NACE2, "26.7")),
        ((Standards.TOL2008, "2670"), (Standards.NACE2, "26.70")),
        ((Standards.TOL2008, "26700"), (Standards.NACE2, "26.70")),
        ((Standards.TOL2008, "268"), (Standards.NACE2, "26.8")),
        ((Standards.TOL2008, "2680"), (Standards.NACE2, "26.80")),
        ((Standards.TOL2008, "26800"), (Standards.NACE2, "26.80")),
        ((Standards.TOL2008, "27"), (Standards.NACE2, "27")),
        ((Standards.TOL2008, "271"), (Standards.NACE2, "27.1")),
        ((Standards.TOL2008, "2711"), (Standards.NACE2, "27.11")),
        ((Standards.TOL2008, "27110"), (Standards.NACE2, "27.11")),
        ((Standards.TOL2008, "2712"), (Standards.NACE2, "27.12")),
        ((Standards.TOL2008, "27120"), (Standards.NACE2, "27.12")),
        ((Standards.TOL2008, "272"), (Standards.NACE2, "27.2")),
        ((Standards.TOL2008, "2720"), (Standards.NACE2, "27.20")),
        ((Standards.TOL2008, "27200"), (Standards.NACE2, "27.20")),
        ((Standards.TOL2008, "273"), (Standards.NACE2, "27.3")),
        ((Standards.TOL2008, "2731"), (Standards.NACE2, "27.31")),
        ((Standards.TOL2008, "27310"), (Standards.NACE2, "27.31")),
        ((Standards.TOL2008, "2732"), (Standards.NACE2, "27.32")),
        ((Standards.TOL2008, "27320"), (Standards.NACE2, "27.32")),
        ((Standards.TOL2008, "2733"), (Standards.NACE2, "27.33")),
        ((Standards.TOL2008, "27330"), (Standards.NACE2, "27.33")),
        ((Standards.TOL2008, "274"), (Standards.NACE2, "27.4")),
        ((Standards.TOL2008, "2740"), (Standards.NACE2, "27.40")),
        ((Standards.TOL2008, "27400"), (Standards.NACE2, "27.40")),
        ((Standards.TOL2008, "275"), (Standards.NACE2, "27.5")),
        ((Standards.TOL2008, "2751"), (Standards.NACE2, "27.51")),
        ((Standards.TOL2008, "27510"), (Standards.NACE2, "27.51")),
        ((Standards.TOL2008, "2752"), (Standards.NACE2, "27.52")),
        ((Standards.TOL2008, "27520"), (Standards.NACE2, "27.52")),
        ((Standards.TOL2008, "279"), (Standards.NACE2, "27.9")),
        ((Standards.TOL2008, "2790"), (Standards.NACE2, "27.90")),
        ((Standards.TOL2008, "27900"), (Standards.NACE2, "27.90")),
        ((Standards.TOL2008, "28"), (Standards.NACE2, "28")),
        ((Standards.TOL2008, "281"), (Standards.NACE2, "28.1")),
        ((Standards.TOL2008, "2811"), (Standards.NACE2, "28.11")),
        ((Standards.TOL2008, "28110"), (Standards.NACE2, "28.11")),
        ((Standards.TOL2008, "2812"), (Standards.NACE2, "28.12")),
        ((Standards.TOL2008, "28120"), (Standards.NACE2, "28.12")),
        ((Standards.TOL2008, "2813"), (Standards.NACE2, "28.13")),
        ((Standards.TOL2008, "28130"), (Standards.NACE2, "28.13")),
        ((Standards.TOL2008, "2814"), (Standards.NACE2, "28.14")),
        ((Standards.TOL2008, "28140"), (Standards.NACE2, "28.14")),
        ((Standards.TOL2008, "2815"), (Standards.NACE2, "28.15")),
        ((Standards.TOL2008, "28150"), (Standards.NACE2, "28.15")),
        ((Standards.TOL2008, "282"), (Standards.NACE2, "28.2")),
        ((Standards.TOL2008, "2821"), (Standards.NACE2, "28.21")),
        ((Standards.TOL2008, "28210"), (Standards.NACE2, "28.21")),
        ((Standards.TOL2008, "2822"), (Standards.NACE2, "28.22")),
        ((Standards.TOL2008, "28220"), (Standards.NACE2, "28.22")),
        ((Standards.TOL2008, "2823"), (Standards.NACE2, "28.23")),
        ((Standards.TOL2008, "28230"), (Standards.NACE2, "28.23")),
        ((Standards.TOL2008, "2824"), (Standards.NACE2, "28.24")),
        ((Standards.TOL2008, "28240"), (Standards.NACE2, "28.24")),
        ((Standards.TOL2008, "2825"), (Standards.NACE2, "28.25")),
        ((Standards.TOL2008, "28250"), (Standards.NACE2, "28.25")),
        ((Standards.TOL2008, "2829"), (Standards.NACE2, "28.29")),
        ((Standards.TOL2008, "28290"), (Standards.NACE2, "28.29")),
        ((Standards.TOL2008, "283"), (Standards.NACE2, "28.3")),
        ((Standards.TOL2008, "2830"), (Standards.NACE2, "28.30")),
        ((Standards.TOL2008, "28300"), (Standards.NACE2, "28.30")),
        ((Standards.TOL2008, "284"), (Standards.NACE2, "28.4")),
        ((Standards.TOL2008, "2841"), (Standards.NACE2, "28.41")),
        ((Standards.TOL2008, "28410"), (Standards.NACE2, "28.41")),
        ((Standards.TOL2008, "2849"), (Standards.NACE2, "28.49")),
        ((Standards.TOL2008, "28490"), (Standards.NACE2, "28.49")),
        ((Standards.TOL2008, "289"), (Standards.NACE2, "28.9")),
        ((Standards.TOL2008, "2891"), (Standards.NACE2, "28.91")),
        ((Standards.TOL2008, "28910"), (Standards.NACE2, "28.91")),
        ((Standards.TOL2008, "2892"), (Standards.NACE2, "28.92")),
        ((Standards.TOL2008, "28920"), (Standards.NACE2, "28.92")),
        ((Standards.TOL2008, "2893"), (Standards.NACE2, "28.93")),
        ((Standards.TOL2008, "28930"), (Standards.NACE2, "28.93")),
        ((Standards.TOL2008, "2894"), (Standards.NACE2, "28.94")),
        ((Standards.TOL2008, "28940"), (Standards.NACE2, "28.94")),
        ((Standards.TOL2008, "2895"), (Standards.NACE2, "28.95")),
        ((Standards.TOL2008, "28950"), (Standards.NACE2, "28.95")),
        ((Standards.TOL2008, "2896"), (Standards.NACE2, "28.96")),
        ((Standards.TOL2008, "28960"), (Standards.NACE2, "28.96")),
        ((Standards.TOL2008, "2899"), (Standards.NACE2, "28.99")),
        ((Standards.TOL2008, "28990"), (Standards.NACE2, "28.99")),
        ((Standards.TOL2008, "29"), (Standards.NACE2, "29")),
        ((Standards.TOL2008, "291"), (Standards.NACE2, "29.1")),
        ((Standards.TOL2008, "2910"), (Standards.NACE2, "29.10")),
        ((Standards.TOL2008, "29100"), (Standards.NACE2, "29.10")),
        ((Standards.TOL2008, "292"), (Standards.NACE2, "29.2")),
        ((Standards.TOL2008, "2920"), (Standards.NACE2, "29.20")),
        ((Standards.TOL2008, "29200"), (Standards.NACE2, "29.20")),
        ((Standards.TOL2008, "293"), (Standards.NACE2, "29.3")),
        ((Standards.TOL2008, "2931"), (Standards.NACE2, "29.31")),
        ((Standards.TOL2008, "29310"), (Standards.NACE2, "29.31")),
        ((Standards.TOL2008, "2932"), (Standards.NACE2, "29.32")),
        ((Standards.TOL2008, "29320"), (Standards.NACE2, "29.32")),
        ((Standards.TOL2008, "30"), (Standards.NACE2, "30")),
        ((Standards.TOL2008, "301"), (Standards.NACE2, "30.1")),
        ((Standards.TOL2008, "3011"), (Standards.NACE2, "30.11")),
        ((Standards.TOL2008, "30110"), (Standards.NACE2, "30.11")),
        ((Standards.TOL2008, "3012"), (Standards.NACE2, "30.12")),
        ((Standards.TOL2008, "30120"), (Standards.NACE2, "30.12")),
        ((Standards.TOL2008, "302"), (Standards.NACE2, "30.2")),
        ((Standards.TOL2008, "3020"), (Standards.NACE2, "30.20")),
        ((Standards.TOL2008, "30200"), (Standards.NACE2, "30.20")),
        ((Standards.TOL2008, "303"), (Standards.NACE2, "30.3")),
        ((Standards.TOL2008, "3030"), (Standards.NACE2, "30.30")),
        ((Standards.TOL2008, "30300"), (Standards.NACE2, "30.30")),
        ((Standards.TOL2008, "304"), (Standards.NACE2, "30.4")),
        ((Standards.TOL2008, "3040"), (Standards.NACE2, "30.40")),
        ((Standards.TOL2008, "30400"), (Standards.NACE2, "30.40")),
        ((Standards.TOL2008, "309"), (Standards.NACE2, "30.9")),
        ((Standards.TOL2008, "3091"), (Standards.NACE2, "30.91")),
        ((Standards.TOL2008, "30910"), (Standards.NACE2, "30.91")),
        ((Standards.TOL2008, "3092"), (Standards.NACE2, "30.92")),
        ((Standards.TOL2008, "30920"), (Standards.NACE2, "30.92")),
        ((Standards.TOL2008, "3099"), (Standards.NACE2, "30.99")),
        ((Standards.TOL2008, "30990"), (Standards.NACE2, "30.99")),
        ((Standards.TOL2008, "31"), (Standards.NACE2, "31")),
        ((Standards.TOL2008, "310"), (Standards.NACE2, "31.0")),
        ((Standards.TOL2008, "3101"), (Standards.NACE2, "31.01")),
        ((Standards.TOL2008, "31010"), (Standards.NACE2, "31.01")),
        ((Standards.TOL2008, "3102"), (Standards.NACE2, "31.02")),
        ((Standards.TOL2008, "31020"), (Standards.NACE2, "31.02")),
        ((Standards.TOL2008, "3103"), (Standards.NACE2, "31.03")),
        ((Standards.TOL2008, "31030"), (Standards.NACE2, "31.03")),
        ((Standards.TOL2008, "3109"), (Standards.NACE2, "31.09")),
        ((Standards.TOL2008, "31090"), (Standards.NACE2, "31.09")),
        ((Standards.TOL2008, "32"), (Standards.NACE2, "32")),
        ((Standards.TOL2008, "321"), (Standards.NACE2, "32.1")),
        ((Standards.TOL2008, "3211"), (Standards.NACE2, "32.11")),
        ((Standards.TOL2008, "32110"), (Standards.NACE2, "32.11")),
        ((Standards.TOL2008, "3212"), (Standards.NACE2, "32.12")),
        ((Standards.TOL2008, "32120"), (Standards.NACE2, "32.12")),
        ((Standards.TOL2008, "3213"), (Standards.NACE2, "32.13")),
        ((Standards.TOL2008, "32130"), (Standards.NACE2, "32.13")),
        ((Standards.TOL2008, "322"), (Standards.NACE2, "32.2")),
        ((Standards.TOL2008, "3220"), (Standards.NACE2, "32.20")),
        ((Standards.TOL2008, "32200"), (Standards.NACE2, "32.20")),
        ((Standards.TOL2008, "323"), (Standards.NACE2, "32.3")),
        ((Standards.TOL2008, "3230"), (Standards.NACE2, "32.30")),
        ((Standards.TOL2008, "32300"), (Standards.NACE2, "32.30")),
        ((Standards.TOL2008, "324"), (Standards.NACE2, "32.4")),
        ((Standards.TOL2008, "3240"), (Standards.NACE2, "32.40")),
        ((Standards.TOL2008, "32400"), (Standards.NACE2, "32.40")),
        ((Standards.TOL2008, "325"), (Standards.NACE2, "32.5")),
        ((Standards.TOL2008, "3250"), (Standards.NACE2, "32.50")),
        ((Standards.TOL2008, "32501"), (Standards.NACE2, "32.50")),
        ((Standards.TOL2008, "32502"), (Standards.NACE2, "32.50")),
        ((Standards.TOL2008, "329"), (Standards.NACE2, "32.9")),
        ((Standards.TOL2008, "3291"), (Standards.NACE2, "32.91")),
        ((Standards.TOL2008, "32910"), (Standards.NACE2, "32.91")),
        ((Standards.TOL2008, "3299"), (Standards.NACE2, "32.99")),
        ((Standards.TOL2008, "32991"), (Standards.NACE2, "32.99")),
        ((Standards.TOL2008, "32999"), (Standards.NACE2, "32.99")),
        ((Standards.TOL2008, "33"), (Standards.NACE2, "33")),
        ((Standards.TOL2008, "331"), (Standards.NACE2, "33.1")),
        ((Standards.TOL2008, "3311"), (Standards.NACE2, "33.11")),
        ((Standards.TOL2008, "33110"), (Standards.NACE2, "33.11")),
        ((Standards.TOL2008, "3312"), (Standards.NACE2, "33.12")),
        ((Standards.TOL2008, "33121"), (Standards.NACE2, "33.12")),
        ((Standards.TOL2008, "33122"), (Standards.NACE2, "33.12")),
        ((Standards.TOL2008, "33123"), (Standards.NACE2, "33.12")),
        ((Standards.TOL2008, "33129"), (Standards.NACE2, "33.12")),
        ((Standards.TOL2008, "3313"), (Standards.NACE2, "33.13")),
        ((Standards.TOL2008, "33130"), (Standards.NACE2, "33.13")),
        ((Standards.TOL2008, "3314"), (Standards.NACE2, "33.14")),
        ((Standards.TOL2008, "33140"), (Standards.NACE2, "33.14")),
        ((Standards.TOL2008, "3315"), (Standards.NACE2, "33.15")),
        ((Standards.TOL2008, "33150"), (Standards.NACE2, "33.15")),
        ((Standards.TOL2008, "3316"), (Standards.NACE2, "33.16")),
        ((Standards.TOL2008, "33160"), (Standards.NACE2, "33.16")),
        ((Standards.TOL2008, "3317"), (Standards.NACE2, "33.17")),
        ((Standards.TOL2008, "33170"), (Standards.NACE2, "33.17")),
        ((Standards.TOL2008, "3319"), (Standards.NACE2, "33.19")),
        ((Standards.TOL2008, "33190"), (Standards.NACE2, "33.19")),
        ((Standards.TOL2008, "332"), (Standards.NACE2, "33.2")),
        ((Standards.TOL2008, "3320"), (Standards.NACE2, "33.20")),
        ((Standards.TOL2008, "33200"), (Standards.NACE2, "33.20")),
        ((Standards.TOL2008, "D"), (Standards.NACE2, "D")),
        ((Standards.TOL2008, "35"), (Standards.NACE2, "35")),
        ((Standards.TOL2008, "351"), (Standards.NACE2, "35.1")),
        ((Standards.TOL2008, "3511"), (Standards.NACE2, "35.11")),
        ((Standards.TOL2008, "35111"), (Standards.NACE2, "35.11")),
        ((Standards.TOL2008, "35112"), (Standards.NACE2, "35.11")),
        ((Standards.TOL2008, "35113"), (Standards.NACE2, "35.11")),
        ((Standards.TOL2008, "35114"), (Standards.NACE2, "35.11")),
        ((Standards.TOL2008, "35115"), (Standards.NACE2, "35.11")),
        ((Standards.TOL2008, "3512"), (Standards.NACE2, "35.12")),
        ((Standards.TOL2008, "35120"), (Standards.NACE2, "35.12")),
        ((Standards.TOL2008, "3513"), (Standards.NACE2, "35.13")),
        ((Standards.TOL2008, "35130"), (Standards.NACE2, "35.13")),
        ((Standards.TOL2008, "3514"), (Standards.NACE2, "35.14")),
        ((Standards.TOL2008, "35140"), (Standards.NACE2, "35.14")),
        ((Standards.TOL2008, "352"), (Standards.NACE2, "35.2")),
        ((Standards.TOL2008, "3521"), (Standards.NACE2, "35.21")),
        ((Standards.TOL2008, "35210"), (Standards.NACE2, "35.21")),
        ((Standards.TOL2008, "3522"), (Standards.NACE2, "35.22")),
        ((Standards.TOL2008, "35220"), (Standards.NACE2, "35.22")),
        ((Standards.TOL2008, "3523"), (Standards.NACE2, "35.23")),
        ((Standards.TOL2008, "35230"), (Standards.NACE2, "35.23")),
        ((Standards.TOL2008, "353"), (Standards.NACE2, "35.3")),
        ((Standards.TOL2008, "3530"), (Standards.NACE2, "35.30")),
        ((Standards.TOL2008, "35301"), (Standards.NACE2, "35.30")),
        ((Standards.TOL2008, "35302"), (Standards.NACE2, "35.30")),
        ((Standards.TOL2008, "E"), (Standards.NACE2, "E")),
        ((Standards.TOL2008, "36"), (Standards.NACE2, "36")),
        ((Standards.TOL2008, "360"), (Standards.NACE2, "36.0")),
        ((Standards.TOL2008, "3600"), (Standards.NACE2, "36.00")),
        ((Standards.TOL2008, "36000"), (Standards.NACE2, "36.00")),
        ((Standards.TOL2008, "37"), (Standards.NACE2, "37")),
        ((Standards.TOL2008, "370"), (Standards.NACE2, "37.0")),
        ((Standards.TOL2008, "3700"), (Standards.NACE2, "37.00")),
        ((Standards.TOL2008, "37000"), (Standards.NACE2, "37.00")),
        ((Standards.TOL2008, "38"), (Standards.NACE2, "38")),
        ((Standards.TOL2008, "381"), (Standards.NACE2, "38.1")),
        ((Standards.TOL2008, "3811"), (Standards.NACE2, "38.11")),
        ((Standards.TOL2008, "38110"), (Standards.NACE2, "38.11")),
        ((Standards.TOL2008, "3812"), (Standards.NACE2, "38.12")),
        ((Standards.TOL2008, "38120"), (Standards.NACE2, "38.12")),
        ((Standards.TOL2008, "382"), (Standards.NACE2, "38.2")),
        ((Standards.TOL2008, "3821"), (Standards.NACE2, "38.21")),
        ((Standards.TOL2008, "38210"), (Standards.NACE2, "38.21")),
        ((Standards.TOL2008, "3822"), (Standards.NACE2, "38.22")),
        ((Standards.TOL2008, "38220"), (Standards.NACE2, "38.22")),
        ((Standards.TOL2008, "383"), (Standards.NACE2, "38.3")),
        ((Standards.TOL2008, "3831"), (Standards.NACE2, "38.31")),
        ((Standards.TOL2008, "38310"), (Standards.NACE2, "38.31")),
        ((Standards.TOL2008, "3832"), (Standards.NACE2, "38.32")),
        ((Standards.TOL2008, "38320"), (Standards.NACE2, "38.32")),
        ((Standards.TOL2008, "39"), (Standards.NACE2, "39")),
        ((Standards.TOL2008, "390"), (Standards.NACE2, "39.0")),
        ((Standards.TOL2008, "3900"), (Standards.NACE2, "39.00")),
        ((Standards.TOL2008, "39000"), (Standards.NACE2, "39.00")),
        ((Standards.TOL2008, "F"), (Standards.NACE2, "F")),
        ((Standards.TOL2008, "41"), (Standards.NACE2, "41")),
        ((Standards.TOL2008, "411"), (Standards.NACE2, "41.1")),
        ((Standards.TOL2008, "4110"), (Standards.NACE2, "41.10")),
        ((Standards.TOL2008, "41100"), (Standards.NACE2, "41.10")),
        ((Standards.TOL2008, "412"), (Standards.NACE2, "41.2")),
        ((Standards.TOL2008, "4120"), (Standards.NACE2, "41.20")),
        ((Standards.TOL2008, "41200"), (Standards.NACE2, "41.20")),
        ((Standards.TOL2008, "42"), (Standards.NACE2, "42")),
        ((Standards.TOL2008, "421"), (Standards.NACE2, "42.1")),
        ((Standards.TOL2008, "4211"), (Standards.NACE2, "42.11")),
        ((Standards.TOL2008, "42110"), (Standards.NACE2, "42.11")),
        ((Standards.TOL2008, "4212"), (Standards.NACE2, "42.12")),
        ((Standards.TOL2008, "42120"), (Standards.NACE2, "42.12")),
        ((Standards.TOL2008, "4213"), (Standards.NACE2, "42.13")),
        ((Standards.TOL2008, "42130"), (Standards.NACE2, "42.13")),
        ((Standards.TOL2008, "422"), (Standards.NACE2, "42.2")),
        ((Standards.TOL2008, "4221"), (Standards.NACE2, "42.21")),
        ((Standards.TOL2008, "42210"), (Standards.NACE2, "42.21")),
        ((Standards.TOL2008, "4222"), (Standards.NACE2, "42.22")),
        ((Standards.TOL2008, "42220"), (Standards.NACE2, "42.22")),
        ((Standards.TOL2008, "429"), (Standards.NACE2, "42.9")),
        ((Standards.TOL2008, "4291"), (Standards.NACE2, "42.91")),
        ((Standards.TOL2008, "42910"), (Standards.NACE2, "42.91")),
        ((Standards.TOL2008, "4299"), (Standards.NACE2, "42.99")),
        ((Standards.TOL2008, "42991"), (Standards.NACE2, "42.99")),
        ((Standards.TOL2008, "42999"), (Standards.NACE2, "42.99")),
        ((Standards.TOL2008, "43"), (Standards.NACE2, "43")),
        ((Standards.TOL2008, "431"), (Standards.NACE2, "43.1")),
        ((Standards.TOL2008, "4311"), (Standards.NACE2, "43.11")),
        ((Standards.TOL2008, "43110"), (Standards.NACE2, "43.11")),
        ((Standards.TOL2008, "4312"), (Standards.NACE2, "43.12")),
        ((Standards.TOL2008, "43120"), (Standards.NACE2, "43.12")),
        ((Standards.TOL2008, "4313"), (Standards.NACE2, "43.13")),
        ((Standards.TOL2008, "43130"), (Standards.NACE2, "43.13")),
        ((Standards.TOL2008, "432"), (Standards.NACE2, "43.2")),
        ((Standards.TOL2008, "4321"), (Standards.NACE2, "43.21")),
        ((Standards.TOL2008, "43210"), (Standards.NACE2, "43.21")),
        ((Standards.TOL2008, "4322"), (Standards.NACE2, "43.22")),
        ((Standards.TOL2008, "43220"), (Standards.NACE2, "43.22")),
        ((Standards.TOL2008, "4329"), (Standards.NACE2, "43.29")),
        ((Standards.TOL2008, "43291"), (Standards.NACE2, "43.29")),
        ((Standards.TOL2008, "43292"), (Standards.NACE2, "43.29")),
        ((Standards.TOL2008, "43299"), (Standards.NACE2, "43.29")),
        ((Standards.TOL2008, "433"), (Standards.NACE2, "43.3")),
        ((Standards.TOL2008, "4331"), (Standards.NACE2, "43.31")),
        ((Standards.TOL2008, "43310"), (Standards.NACE2, "43.31")),
        ((Standards.TOL2008, "4332"), (Standards.NACE2, "43.32")),
        ((Standards.TOL2008, "43320"), (Standards.NACE2, "43.32")),
        ((Standards.TOL2008, "4333"), (Standards.NACE2, "43.33")),
        ((Standards.TOL2008, "43330"), (Standards.NACE2, "43.33")),
        ((Standards.TOL2008, "4334"), (Standards.NACE2, "43.34")),
        ((Standards.TOL2008, "43341"), (Standards.NACE2, "43.34")),
        ((Standards.TOL2008, "43342"), (Standards.NACE2, "43.34")),
        ((Standards.TOL2008, "4339"), (Standards.NACE2, "43.39")),
        ((Standards.TOL2008, "43390"), (Standards.NACE2, "43.39")),
        ((Standards.TOL2008, "439"), (Standards.NACE2, "43.9")),
        ((Standards.TOL2008, "4391"), (Standards.NACE2, "43.91")),
        ((Standards.TOL2008, "43910"), (Standards.NACE2, "43.91")),
        ((Standards.TOL2008, "4399"), (Standards.NACE2, "43.99")),
        ((Standards.TOL2008, "43991"), (Standards.NACE2, "43.99")),
        ((Standards.TOL2008, "43999"), (Standards.NACE2, "43.99")),
        ((Standards.TOL2008, "G"), (Standards.NACE2, "G")),
        ((Standards.TOL2008, "45"), (Standards.NACE2, "45")),
        ((Standards.TOL2008, "451"), (Standards.NACE2, "45.1")),
        ((Standards.TOL2008, "4511"), (Standards.NACE2, "45.11")),
        ((Standards.TOL2008, "45111"), (Standards.NACE2, "45.11")),
        ((Standards.TOL2008, "45112"), (Standards.NACE2, "45.11")),
        ((Standards.TOL2008, "4519"), (Standards.NACE2, "45.19")),
        ((Standards.TOL2008, "45191"), (Standards.NACE2, "45.19")),
        ((Standards.TOL2008, "45192"), (Standards.NACE2, "45.19")),
        ((Standards.TOL2008, "452"), (Standards.NACE2, "45.2")),
        ((Standards.TOL2008, "4520"), (Standards.NACE2, "45.20")),
        ((Standards.TOL2008, "45201"), (Standards.NACE2, "45.20")),
        ((Standards.TOL2008, "45202"), (Standards.NACE2, "45.20")),
        ((Standards.TOL2008, "453"), (Standards.NACE2, "45.3")),
        ((Standards.TOL2008, "4531"), (Standards.NACE2, "45.31")),
        ((Standards.TOL2008, "45311"), (Standards.NACE2, "45.31")),
        ((Standards.TOL2008, "45312"), (Standards.NACE2, "45.31")),
        ((Standards.TOL2008, "4532"), (Standards.NACE2, "45.32")),
        ((Standards.TOL2008, "45321"), (Standards.NACE2, "45.32")),
        ((Standards.TOL2008, "45322"), (Standards.NACE2, "45.32")),
        ((Standards.TOL2008, "454"), (Standards.NACE2, "45.4")),
        ((Standards.TOL2008, "4540"), (Standards.NACE2, "45.40")),
        ((Standards.TOL2008, "45401"), (Standards.NACE2, "45.40")),
        ((Standards.TOL2008, "45402"), (Standards.NACE2, "45.40")),
        ((Standards.TOL2008, "45403"), (Standards.NACE2, "45.40")),
        ((Standards.TOL2008, "46"), (Standards.NACE2, "46")),
        ((Standards.TOL2008, "461"), (Standards.NACE2, "46.1")),
        ((Standards.TOL2008, "4611"), (Standards.NACE2, "46.11")),
        ((Standards.TOL2008, "46110"), (Standards.NACE2, "46.11")),
        ((Standards.TOL2008, "4612"), (Standards.NACE2, "46.12")),
        ((Standards.TOL2008, "46120"), (Standards.NACE2, "46.12")),
        ((Standards.TOL2008, "4613"), (Standards.NACE2, "46.13")),
        ((Standards.TOL2008, "46130"), (Standards.NACE2, "46.13")),
        ((Standards.TOL2008, "4614"), (Standards.NACE2, "46.14")),
        ((Standards.TOL2008, "46140"), (Standards.NACE2, "46.14")),
        ((Standards.TOL2008, "4615"), (Standards.NACE2, "46.15")),
        ((Standards.TOL2008, "46150"), (Standards.NACE2, "46.15")),
        ((Standards.TOL2008, "4616"), (Standards.NACE2, "46.16")),
        ((Standards.TOL2008, "46160"), (Standards.NACE2, "46.16")),
        ((Standards.TOL2008, "4617"), (Standards.NACE2, "46.17")),
        ((Standards.TOL2008, "46170"), (Standards.NACE2, "46.17")),
        ((Standards.TOL2008, "4618"), (Standards.NACE2, "46.18")),
        ((Standards.TOL2008, "46181"), (Standards.NACE2, "46.18")),
        ((Standards.TOL2008, "46189"), (Standards.NACE2, "46.18")),
        ((Standards.TOL2008, "4619"), (Standards.NACE2, "46.19")),
        ((Standards.TOL2008, "46190"), (Standards.NACE2, "46.19")),
        ((Standards.TOL2008, "462"), (Standards.NACE2, "46.2")),
        ((Standards.TOL2008, "4621"), (Standards.NACE2, "46.21")),
        ((Standards.TOL2008, "46210"), (Standards.NACE2, "46.21")),
        ((Standards.TOL2008, "4622"), (Standards.NACE2, "46.22")),
        ((Standards.TOL2008, "46220"), (Standards.NACE2, "46.22")),
        ((Standards.TOL2008, "4623"), (Standards.NACE2, "46.23")),
        ((Standards.TOL2008, "46230"), (Standards.NACE2, "46.23")),
        ((Standards.TOL2008, "4624"), (Standards.NACE2, "46.24")),
        ((Standards.TOL2008, "46240"), (Standards.NACE2, "46.24")),
        ((Standards.TOL2008, "463"), (Standards.NACE2, "46.3")),
        ((Standards.TOL2008, "4631"), (Standards.NACE2, "46.31")),
        ((Standards.TOL2008, "46310"), (Standards.NACE2, "46.31")),
        ((Standards.TOL2008, "4632"), (Standards.NACE2, "46.32")),
        ((Standards.TOL2008, "46320"), (Standards.NACE2, "46.32")),
        ((Standards.TOL2008, "4633"), (Standards.NACE2, "46.33")),
        ((Standards.TOL2008, "46331"), (Standards.NACE2, "46.33")),
        ((Standards.TOL2008, "46332"), (Standards.NACE2, "46.33")),
        ((Standards.TOL2008, "4634"), (Standards.NACE2, "46.34")),
        ((Standards.TOL2008, "46340"), (Standards.NACE2, "46.34")),
        ((Standards.TOL2008, "4635"), (Standards.NACE2, "46.35")),
        ((Standards.TOL2008, "46350"), (Standards.NACE2, "46.35")),
        ((Standards.TOL2008, "4636"), (Standards.NACE2, "46.36")),
        ((Standards.TOL2008, "46360"), (Standards.NACE2, "46.36")),
        ((Standards.TOL2008, "4637"), (Standards.NACE2, "46.37")),
        ((Standards.TOL2008, "46370"), (Standards.NACE2, "46.37")),
        ((Standards.TOL2008, "4638"), (Standards.NACE2, "46.38")),
        ((Standards.TOL2008, "46381"), (Standards.NACE2, "46.38")),
        ((Standards.TOL2008, "46382"), (Standards.NACE2, "46.38")),
        ((Standards.TOL2008, "46383"), (Standards.NACE2, "46.38")),
        ((Standards.TOL2008, "46389"), (Standards.NACE2, "46.38")),
        ((Standards.TOL2008, "4639"), (Standards.NACE2, "46.39")),
        ((Standards.TOL2008, "46390"), (Standards.NACE2, "46.39")),
        ((Standards.TOL2008, "464"), (Standards.NACE2, "46.4")),
        ((Standards.TOL2008, "4641"), (Standards.NACE2, "46.41")),
        ((Standards.TOL2008, "46411"), (Standards.NACE2, "46.41")),
        ((Standards.TOL2008, "46412"), (Standards.NACE2, "46.41")),
        ((Standards.TOL2008, "4642"), (Standards.NACE2, "46.42")),
        ((Standards.TOL2008, "46421"), (Standards.NACE2, "46.42")),
        ((Standards.TOL2008, "46422"), (Standards.NACE2, "46.42")),
        ((Standards.TOL2008, "4643"), (Standards.NACE2, "46.43")),
        ((Standards.TOL2008, "46431"), (Standards.NACE2, "46.43")),
        ((Standards.TOL2008, "46432"), (Standards.NACE2, "46.43")),
        ((Standards.TOL2008, "46433"), (Standards.NACE2, "46.43")),
        ((Standards.TOL2008, "46434"), (Standards.NACE2, "46.43")),
        ((Standards.TOL2008, "4644"), (Standards.NACE2, "46.44")),
        ((Standards.TOL2008, "46441"), (Standards.NACE2, "46.44")),
        ((Standards.TOL2008, "46442"), (Standards.NACE2, "46.44")),
        ((Standards.TOL2008, "4645"), (Standards.NACE2, "46.45")),
        ((Standards.TOL2008, "46450"), (Standards.NACE2, "46.45")),
        ((Standards.TOL2008, "4646"), (Standards.NACE2, "46.46")),
        ((Standards.TOL2008, "46461"), (Standards.NACE2, "46.46")),
        ((Standards.TOL2008, "46462"), (Standards.NACE2, "46.46")),
        ((Standards.TOL2008, "4647"), (Standards.NACE2, "46.47")),
        ((Standards.TOL2008, "46470"), (Standards.NACE2, "46.47")),
        ((Standards.TOL2008, "4648"), (Standards.NACE2, "46.48")),
        ((Standards.TOL2008, "46480"), (Standards.NACE2, "46.48")),
        ((Standards.TOL2008, "4649"), (Standards.NACE2, "46.49")),
        ((Standards.TOL2008, "46491"), (Standards.NACE2, "46.49")),
        ((Standards.TOL2008, "46492"), (Standards.NACE2, "46.49")),
        ((Standards.TOL2008, "46493"), (Standards.NACE2, "46.49")),
        ((Standards.TOL2008, "46494"), (Standards.NACE2, "46.49")),
        ((Standards.TOL2008, "46495"), (Standards.NACE2, "46.49")),
        ((Standards.TOL2008, "46496"), (Standards.NACE2, "46.49")),
        ((Standards.TOL2008, "46499"), (Standards.NACE2, "46.49")),
        ((Standards.TOL2008, "465"), (Standards.NACE2, "46.5")),
        ((Standards.TOL2008, "4651"), (Standards.NACE2, "46.51")),
        ((Standards.TOL2008, "46510"), (Standards.NACE2, "46.51")),
        ((Standards.TOL2008, "4652"), (Standards.NACE2, "46.52")),
        ((Standards.TOL2008, "46521"), (Standards.NACE2, "46.52")),
        ((Standards.TOL2008, "46522"), (Standards.NACE2, "46.52")),
        ((Standards.TOL2008, "466"), (Standards.NACE2, "46.6")),
        ((Standards.TOL2008, "4661"), (Standards.NACE2, "46.61")),
        ((Standards.TOL2008, "46610"), (Standards.NACE2, "46.61")),
        ((Standards.TOL2008, "4662"), (Standards.NACE2, "46.62")),
        ((Standards.TOL2008, "46620"), (Standards.NACE2, "46.62")),
        ((Standards.TOL2008, "4663"), (Standards.NACE2, "46.63")),
        ((Standards.TOL2008, "46630"), (Standards.NACE2, "46.63")),
        ((Standards.TOL2008, "4664"), (Standards.NACE2, "46.64")),
        ((Standards.TOL2008, "46640"), (Standards.NACE2, "46.64")),
        ((Standards.TOL2008, "4665"), (Standards.NACE2, "46.65")),
        ((Standards.TOL2008, "46650"), (Standards.NACE2, "46.65")),
        ((Standards.TOL2008, "4666"), (Standards.NACE2, "46.66")),
        ((Standards.TOL2008, "46660"), (Standards.NACE2, "46.66")),
        ((Standards.TOL2008, "4669"), (Standards.NACE2, "46.69")),
        ((Standards.TOL2008, "46691"), (Standards.NACE2, "46.69")),
        ((Standards.TOL2008, "46692"), (Standards.NACE2, "46.69")),
        ((Standards.TOL2008, "46699"), (Standards.NACE2, "46.69")),
        ((Standards.TOL2008, "467"), (Standards.NACE2, "46.7")),
        ((Standards.TOL2008, "4671"), (Standards.NACE2, "46.71")),
        ((Standards.TOL2008, "46711"), (Standards.NACE2, "46.71")),
        ((Standards.TOL2008, "46719"), (Standards.NACE2, "46.71")),
        ((Standards.TOL2008, "4672"), (Standards.NACE2, "46.72")),
        ((Standards.TOL2008, "46720"), (Standards.NACE2, "46.72")),
        ((Standards.TOL2008, "4673"), (Standards.NACE2, "46.73")),
        ((Standards.TOL2008, "46731"), (Standards.NACE2, "46.73")),
        ((Standards.TOL2008, "46732"), (Standards.NACE2, "46.73")),
        ((Standards.TOL2008, "46733"), (Standards.NACE2, "46.73")),
        ((Standards.TOL2008, "46734"), (Standards.NACE2, "46.73")),
        ((Standards.TOL2008, "46735"), (Standards.NACE2, "46.73")),
        ((Standards.TOL2008, "46739"), (Standards.NACE2, "46.73")),
        ((Standards.TOL2008, "4674"), (Standards.NACE2, "46.74")),
        ((Standards.TOL2008, "46741"), (Standards.NACE2, "46.74")),
        ((Standards.TOL2008, "46742"), (Standards.NACE2, "46.74")),
        ((Standards.TOL2008, "4675"), (Standards.NACE2, "46.75")),
        ((Standards.TOL2008, "46750"), (Standards.NACE2, "46.75")),
        ((Standards.TOL2008, "4676"), (Standards.NACE2, "46.76")),
        ((Standards.TOL2008, "46760"), (Standards.NACE2, "46.76")),
        ((Standards.TOL2008, "4677"), (Standards.NACE2, "46.77")),
        ((Standards.TOL2008, "46770"), (Standards.NACE2, "46.77")),
        ((Standards.TOL2008, "469"), (Standards.NACE2, "46.9")),
        ((Standards.TOL2008, "4690"), (Standards.NACE2, "46.90")),
        ((Standards.TOL2008, "46901"), (Standards.NACE2, "46.90")),
        ((Standards.TOL2008, "46909"), (Standards.NACE2, "46.90")),
        ((Standards.TOL2008, "47"), (Standards.NACE2, "47")),
        ((Standards.TOL2008, "471"), (Standards.NACE2, "47.1")),
        ((Standards.TOL2008, "4711"), (Standards.NACE2, "47.11")),
        ((Standards.TOL2008, "47111"), (Standards.NACE2, "47.11")),
        ((Standards.TOL2008, "47112"), (Standards.NACE2, "47.11")),
        ((Standards.TOL2008, "47113"), (Standards.NACE2, "47.11")),
        ((Standards.TOL2008, "47114"), (Standards.NACE2, "47.11")),
        ((Standards.TOL2008, "4719"), (Standards.NACE2, "47.19")),
        ((Standards.TOL2008, "47191"), (Standards.NACE2, "47.19")),
        ((Standards.TOL2008, "47192"), (Standards.NACE2, "47.19")),
        ((Standards.TOL2008, "47199"), (Standards.NACE2, "47.19")),
        ((Standards.TOL2008, "472"), (Standards.NACE2, "47.2")),
        ((Standards.TOL2008, "4721"), (Standards.NACE2, "47.21")),
        ((Standards.TOL2008, "47210"), (Standards.NACE2, "47.21")),
        ((Standards.TOL2008, "4722"), (Standards.NACE2, "47.22")),
        ((Standards.TOL2008, "47220"), (Standards.NACE2, "47.22")),
        ((Standards.TOL2008, "4723"), (Standards.NACE2, "47.23")),
        ((Standards.TOL2008, "47230"), (Standards.NACE2, "47.23")),
        ((Standards.TOL2008, "4724"), (Standards.NACE2, "47.24")),
        ((Standards.TOL2008, "47241"), (Standards.NACE2, "47.24")),
        ((Standards.TOL2008, "47242"), (Standards.NACE2, "47.24")),
        ((Standards.TOL2008, "4725"), (Standards.NACE2, "47.25")),
        ((Standards.TOL2008, "47250"), (Standards.NACE2, "47.25")),
        ((Standards.TOL2008, "4726"), (Standards.NACE2, "47.26")),
        ((Standards.TOL2008, "47260"), (Standards.NACE2, "47.26")),
        ((Standards.TOL2008, "4729"), (Standards.NACE2, "47.29")),
        ((Standards.TOL2008, "47291"), (Standards.NACE2, "47.29")),
        ((Standards.TOL2008, "47292"), (Standards.NACE2, "47.29")),
        ((Standards.TOL2008, "47299"), (Standards.NACE2, "47.29")),
        ((Standards.TOL2008, "473"), (Standards.NACE2, "47.3")),
        ((Standards.TOL2008, "4730"), (Standards.NACE2, "47.30")),
        ((Standards.TOL2008, "47301"), (Standards.NACE2, "47.30")),
        ((Standards.TOL2008, "47302"), (Standards.NACE2, "47.30")),
        ((Standards.TOL2008, "474"), (Standards.NACE2, "47.4")),
        ((Standards.TOL2008, "4741"), (Standards.NACE2, "47.41")),
        ((Standards.TOL2008, "47410"), (Standards.NACE2, "47.41")),
        ((Standards.TOL2008, "4742"), (Standards.NACE2, "47.42")),
        ((Standards.TOL2008, "47420"), (Standards.NACE2, "47.42")),
        ((Standards.TOL2008, "4743"), (Standards.NACE2, "47.43")),
        ((Standards.TOL2008, "47430"), (Standards.NACE2, "47.43")),
        ((Standards.TOL2008, "475"), (Standards.NACE2, "47.5")),
        ((Standards.TOL2008, "4751"), (Standards.NACE2, "47.51")),
        ((Standards.TOL2008, "47511"), (Standards.NACE2, "47.51")),
        ((Standards.TOL2008, "47512"), (Standards.NACE2, "47.51")),
        ((Standards.TOL2008, "4752"), (Standards.NACE2, "47.52")),
        ((Standards.TOL2008, "47521"), (Standards.NACE2, "47.52")),
        ((Standards.TOL2008, "47522"), (Standards.NACE2, "47.52")),
        ((Standards.TOL2008, "47523"), (Standards.NACE2, "47.52")),
        ((Standards.TOL2008, "47529"), (Standards.NACE2, "47.52")),
        ((Standards.TOL2008, "4753"), (Standards.NACE2, "47.53")),
        ((Standards.TOL2008, "47531"), (Standards.NACE2, "47.53")),
        ((Standards.TOL2008, "47532"), (Standards.NACE2, "47.53")),
        ((Standards.TOL2008, "4754"), (Standards.NACE2, "47.54")),
        ((Standards.TOL2008, "47540"), (Standards.NACE2, "47.54")),
        ((Standards.TOL2008, "4759"), (Standards.NACE2, "47.59")),
        ((Standards.TOL2008, "47591"), (Standards.NACE2, "47.59")),
        ((Standards.TOL2008, "47592"), (Standards.NACE2, "47.59")),
        ((Standards.TOL2008, "47593"), (Standards.NACE2, "47.59")),
        ((Standards.TOL2008, "47594"), (Standards.NACE2, "47.59")),
        ((Standards.TOL2008, "47595"), (Standards.NACE2, "47.59")),
        ((Standards.TOL2008, "47596"), (Standards.NACE2, "47.59")),
        ((Standards.TOL2008, "47599"), (Standards.NACE2, "47.59")),
        ((Standards.TOL2008, "476"), (Standards.NACE2, "47.6")),
        ((Standards.TOL2008, "4761"), (Standards.NACE2, "47.61")),
        ((Standards.TOL2008, "47610"), (Standards.NACE2, "47.61")),
        ((Standards.TOL2008, "4762"), (Standards.NACE2, "47.62")),
        ((Standards.TOL2008, "47621"), (Standards.NACE2, "47.62")),
        ((Standards.TOL2008, "47622"), (Standards.NACE2, "47.62")),
        ((Standards.TOL2008, "4763"), (Standards.NACE2, "47.63")),
        ((Standards.TOL2008, "47630"), (Standards.NACE2, "47.63")),
        ((Standards.TOL2008, "4764"), (Standards.NACE2, "47.64")),
        ((Standards.TOL2008, "47641"), (Standards.NACE2, "47.64")),
        ((Standards.TOL2008, "47642"), (Standards.NACE2, "47.64")),
        ((Standards.TOL2008, "4765"), (Standards.NACE2, "47.65")),
        ((Standards.TOL2008, "47650"), (Standards.NACE2, "47.65")),
        ((Standards.TOL2008, "477"), (Standards.NACE2, "47.7")),
        ((Standards.TOL2008, "4771"), (Standards.NACE2, "47.71")),
        ((Standards.TOL2008, "47711"), (Standards.NACE2, "47.71")),
        ((Standards.TOL2008, "47712"), (Standards.NACE2, "47.71")),
        ((Standards.TOL2008, "47713"), (Standards.NACE2, "47.71")),
        ((Standards.TOL2008, "47714"), (Standards.NACE2, "47.71")),
        ((Standards.TOL2008, "47715"), (Standards.NACE2, "47.71")),
        ((Standards.TOL2008, "47719"), (Standards.NACE2, "47.71")),
        ((Standards.TOL2008, "4772"), (Standards.NACE2, "47.72")),
        ((Standards.TOL2008, "47721"), (Standards.NACE2, "47.72")),
        ((Standards.TOL2008, "47722"), (Standards.NACE2, "47.72")),
        ((Standards.TOL2008, "4773"), (Standards.NACE2, "47.73")),
        ((Standards.TOL2008, "47730"), (Standards.NACE2, "47.73")),
        ((Standards.TOL2008, "4774"), (Standards.NACE2, "47.74")),
        ((Standards.TOL2008, "47740"), (Standards.NACE2, "47.74")),
        ((Standards.TOL2008, "4775"), (Standards.NACE2, "47.75")),
        ((Standards.TOL2008, "47750"), (Standards.NACE2, "47.75")),
        ((Standards.TOL2008, "4776"), (Standards.NACE2, "47.76")),
        ((Standards.TOL2008, "47761"), (Standards.NACE2, "47.76")),
        ((Standards.TOL2008, "47762"), (Standards.NACE2, "47.76")),
        ((Standards.TOL2008, "47763"), (Standards.NACE2, "47.76")),
        ((Standards.TOL2008, "47764"), (Standards.NACE2, "47.76")),
        ((Standards.TOL2008, "4777"), (Standards.NACE2, "47.77")),
        ((Standards.TOL2008, "47770"), (Standards.NACE2, "47.77")),
        ((Standards.TOL2008, "4778"), (Standards.NACE2, "47.78")),
        ((Standards.TOL2008, "47781"), (Standards.NACE2, "47.78")),
        ((Standards.TOL2008, "47782"), (Standards.NACE2, "47.78")),
        ((Standards.TOL2008, "47783"), (Standards.NACE2, "47.78")),
        ((Standards.TOL2008, "47784"), (Standards.NACE2, "47.78")),
        ((Standards.TOL2008, "47785"), (Standards.NACE2, "47.78")),
        ((Standards.TOL2008, "47789"), (Standards.NACE2, "47.78")),
        ((Standards.TOL2008, "4779"), (Standards.NACE2, "47.79")),
        ((Standards.TOL2008, "47791"), (Standards.NACE2, "47.79")),
        ((Standards.TOL2008, "47792"), (Standards.NACE2, "47.79")),
        ((Standards.TOL2008, "47793"), (Standards.NACE2, "47.79")),
        ((Standards.TOL2008, "47799"), (Standards.NACE2, "47.79")),
        ((Standards.TOL2008, "478"), (Standards.NACE2, "47.8")),
        ((Standards.TOL2008, "4781"), (Standards.NACE2, "47.81")),
        ((Standards.TOL2008, "47810"), (Standards.NACE2, "47.81")),
        ((Standards.TOL2008, "4782"), (Standards.NACE2, "47.82")),
        ((Standards.TOL2008, "47820"), (Standards.NACE2, "47.82")),
        ((Standards.TOL2008, "4789"), (Standards.NACE2, "47.89")),
        ((Standards.TOL2008, "47890"), (Standards.NACE2, "47.89")),
        ((Standards.TOL2008, "479"), (Standards.NACE2, "47.9")),
        ((Standards.TOL2008, "4791"), (Standards.NACE2, "47.91")),
        ((Standards.TOL2008, "47911"), (Standards.NACE2, "47.91")),
        ((Standards.TOL2008, "47912"), (Standards.NACE2, "47.91")),
        ((Standards.TOL2008, "47913"), (Standards.NACE2, "47.91")),
        ((Standards.TOL2008, "47919"), (Standards.NACE2, "47.91")),
        ((Standards.TOL2008, "4799"), (Standards.NACE2, "47.99")),
        ((Standards.TOL2008, "47990"), (Standards.NACE2, "47.99")),
        ((Standards.TOL2008, "H"), (Standards.NACE2, "H")),
        ((Standards.TOL2008, "49"), (Standards.NACE2, "49")),
        ((Standards.TOL2008, "491"), (Standards.NACE2, "49.1")),
        ((Standards.TOL2008, "4910"), (Standards.NACE2, "49.10")),
        ((Standards.TOL2008, "49100"), (Standards.NACE2, "49.10")),
        ((Standards.TOL2008, "492"), (Standards.NACE2, "49.2")),
        ((Standards.TOL2008, "4920"), (Standards.NACE2, "49.20")),
        ((Standards.TOL2008, "49200"), (Standards.NACE2, "49.20")),
        ((Standards.TOL2008, "493"), (Standards.NACE2, "49.3")),
        ((Standards.TOL2008, "4931"), (Standards.NACE2, "49.31")),
        ((Standards.TOL2008, "49310"), (Standards.NACE2, "49.31")),
        ((Standards.TOL2008, "4932"), (Standards.NACE2, "49.32")),
        ((Standards.TOL2008, "49320"), (Standards.NACE2, "49.32")),
        ((Standards.TOL2008, "4939"), (Standards.NACE2, "49.39")),
        ((Standards.TOL2008, "49391"), (Standards.NACE2, "49.39")),
        ((Standards.TOL2008, "49392"), (Standards.NACE2, "49.39")),
        ((Standards.TOL2008, "49399"), (Standards.NACE2, "49.39")),
        ((Standards.TOL2008, "494"), (Standards.NACE2, "49.4")),
        ((Standards.TOL2008, "4941"), (Standards.NACE2, "49.41")),
        ((Standards.TOL2008, "49410"), (Standards.NACE2, "49.41")),
        ((Standards.TOL2008, "4942"), (Standards.NACE2, "49.42")),
        ((Standards.TOL2008, "49420"), (Standards.NACE2, "49.42")),
        ((Standards.TOL2008, "495"), (Standards.NACE2, "49.5")),
        ((Standards.TOL2008, "4950"), (Standards.NACE2, "49.50")),
        ((Standards.TOL2008, "49500"), (Standards.NACE2, "49.50")),
        ((Standards.TOL2008, "50"), (Standards.NACE2, "50")),
        ((Standards.TOL2008, "501"), (Standards.NACE2, "50.1")),
        ((Standards.TOL2008, "5010"), (Standards.NACE2, "50.10")),
        ((Standards.TOL2008, "50101"), (Standards.NACE2, "50.10")),
        ((Standards.TOL2008, "50102"), (Standards.NACE2, "50.10")),
        ((Standards.TOL2008, "502"), (Standards.NACE2, "50.2")),
        ((Standards.TOL2008, "5020"), (Standards.NACE2, "50.20")),
        ((Standards.TOL2008, "50201"), (Standards.NACE2, "50.20")),
        ((Standards.TOL2008, "50202"), (Standards.NACE2, "50.20")),
        ((Standards.TOL2008, "503"), (Standards.NACE2, "50.3")),
        ((Standards.TOL2008, "5030"), (Standards.NACE2, "50.30")),
        ((Standards.TOL2008, "50300"), (Standards.NACE2, "50.30")),
        ((Standards.TOL2008, "504"), (Standards.NACE2, "50.4")),
        ((Standards.TOL2008, "5040"), (Standards.NACE2, "50.40")),
        ((Standards.TOL2008, "50400"), (Standards.NACE2, "50.40")),
        ((Standards.TOL2008, "51"), (Standards.NACE2, "51")),
        ((Standards.TOL2008, "511"), (Standards.NACE2, "51.1")),
        ((Standards.TOL2008, "5110"), (Standards.NACE2, "51.10")),
        ((Standards.TOL2008, "51101"), (Standards.NACE2, "51.10")),
        ((Standards.TOL2008, "51102"), (Standards.NACE2, "51.10")),
        ((Standards.TOL2008, "512"), (Standards.NACE2, "51.2")),
        ((Standards.TOL2008, "5121"), (Standards.NACE2, "51.21")),
        ((Standards.TOL2008, "51210"), (Standards.NACE2, "51.21")),
        ((Standards.TOL2008, "5122"), (Standards.NACE2, "51.22")),
        ((Standards.TOL2008, "51220"), (Standards.NACE2, "51.22")),
        ((Standards.TOL2008, "52"), (Standards.NACE2, "52")),
        ((Standards.TOL2008, "521"), (Standards.NACE2, "52.1")),
        ((Standards.TOL2008, "5210"), (Standards.NACE2, "52.10")),
        ((Standards.TOL2008, "52100"), (Standards.NACE2, "52.10")),
        ((Standards.TOL2008, "522"), (Standards.NACE2, "52.2")),
        ((Standards.TOL2008, "5221"), (Standards.NACE2, "52.21")),
        ((Standards.TOL2008, "52211"), (Standards.NACE2, "52.21")),
        ((Standards.TOL2008, "52212"), (Standards.NACE2, "52.21")),
        ((Standards.TOL2008, "52213"), (Standards.NACE2, "52.21")),
        ((Standards.TOL2008, "52219"), (Standards.NACE2, "52.21")),
        ((Standards.TOL2008, "5222"), (Standards.NACE2, "52.22")),
        ((Standards.TOL2008, "52221"), (Standards.NACE2, "52.22")),
        ((Standards.TOL2008, "52229"), (Standards.NACE2, "52.22")),
        ((Standards.TOL2008, "5223"), (Standards.NACE2, "52.23")),
        ((Standards.TOL2008, "52230"), (Standards.NACE2, "52.23")),
        ((Standards.TOL2008, "5224"), (Standards.NACE2, "52.24")),
        ((Standards.TOL2008, "52240"), (Standards.NACE2, "52.24")),
        ((Standards.TOL2008, "5229"), (Standards.NACE2, "52.29")),
        ((Standards.TOL2008, "52291"), (Standards.NACE2, "52.29")),
        ((Standards.TOL2008, "52299"), (Standards.NACE2, "52.29")),
        ((Standards.TOL2008, "53"), (Standards.NACE2, "53")),
        ((Standards.TOL2008, "531"), (Standards.NACE2, "53.1")),
        ((Standards.TOL2008, "5310"), (Standards.NACE2, "53.10")),
        ((Standards.TOL2008, "53100"), (Standards.NACE2, "53.10")),
        ((Standards.TOL2008, "532"), (Standards.NACE2, "53.2")),
        ((Standards.TOL2008, "5320"), (Standards.NACE2, "53.20")),
        ((Standards.TOL2008, "53200"), (Standards.NACE2, "53.20")),
        ((Standards.TOL2008, "I"), (Standards.NACE2, "I")),
        ((Standards.TOL2008, "55"), (Standards.NACE2, "55")),
        ((Standards.TOL2008, "551"), (Standards.NACE2, "55.1")),
        ((Standards.TOL2008, "5510"), (Standards.NACE2, "55.10")),
        ((Standards.TOL2008, "55101"), (Standards.NACE2, "55.10")),
        ((Standards.TOL2008, "55109"), (Standards.NACE2, "55.10")),
        ((Standards.TOL2008, "552"), (Standards.NACE2, "55.2")),
        ((Standards.TOL2008, "5520"), (Standards.NACE2, "55.20")),
        ((Standards.TOL2008, "55201"), (Standards.NACE2, "55.20")),
        ((Standards.TOL2008, "55209"), (Standards.NACE2, "55.20")),
        ((Standards.TOL2008, "553"), (Standards.NACE2, "55.3")),
        ((Standards.TOL2008, "5530"), (Standards.NACE2, "55.30")),
        ((Standards.TOL2008, "55300"), (Standards.NACE2, "55.30")),
        ((Standards.TOL2008, "559"), (Standards.NACE2, "55.9")),
        ((Standards.TOL2008, "5590"), (Standards.NACE2, "55.90")),
        ((Standards.TOL2008, "55901"), (Standards.NACE2, "55.90")),
        ((Standards.TOL2008, "55902"), (Standards.NACE2, "55.90")),
        ((Standards.TOL2008, "55903"), (Standards.NACE2, "55.90")),
        ((Standards.TOL2008, "55909"), (Standards.NACE2, "55.90")),
        ((Standards.TOL2008, "56"), (Standards.NACE2, "56")),
        ((Standards.TOL2008, "561"), (Standards.NACE2, "56.1")),
        ((Standards.TOL2008, "5610"), (Standards.NACE2, "56.10")),
        ((Standards.TOL2008, "56101"), (Standards.NACE2, "56.10")),
        ((Standards.TOL2008, "56102"), (Standards.NACE2, "56.10")),
        ((Standards.TOL2008, "56103"), (Standards.NACE2, "56.10")),
        ((Standards.TOL2008, "562"), (Standards.NACE2, "56.2")),
        ((Standards.TOL2008, "5621"), (Standards.NACE2, "56.21")),
        ((Standards.TOL2008, "56210"), (Standards.NACE2, "56.21")),
        ((Standards.TOL2008, "5629"), (Standards.NACE2, "56.29")),
        ((Standards.TOL2008, "56290"), (Standards.NACE2, "56.29")),
        ((Standards.TOL2008, "563"), (Standards.NACE2, "56.3")),
        ((Standards.TOL2008, "5630"), (Standards.NACE2, "56.30")),
        ((Standards.TOL2008, "56301"), (Standards.NACE2, "56.30")),
        ((Standards.TOL2008, "56302"), (Standards.NACE2, "56.30")),
        ((Standards.TOL2008, "J"), (Standards.NACE2, "J")),
        ((Standards.TOL2008, "58"), (Standards.NACE2, "58")),
        ((Standards.TOL2008, "581"), (Standards.NACE2, "58.1")),
        ((Standards.TOL2008, "5811"), (Standards.NACE2, "58.11")),
        ((Standards.TOL2008, "58110"), (Standards.NACE2, "58.11")),
        ((Standards.TOL2008, "5812"), (Standards.NACE2, "58.12")),
        ((Standards.TOL2008, "58120"), (Standards.NACE2, "58.12")),
        ((Standards.TOL2008, "5813"), (Standards.NACE2, "58.13")),
        ((Standards.TOL2008, "58130"), (Standards.NACE2, "58.13")),
        ((Standards.TOL2008, "5814"), (Standards.NACE2, "58.14")),
        ((Standards.TOL2008, "58141"), (Standards.NACE2, "58.14")),
        ((Standards.TOL2008, "58142"), (Standards.NACE2, "58.14")),
        ((Standards.TOL2008, "5819"), (Standards.NACE2, "58.19")),
        ((Standards.TOL2008, "58190"), (Standards.NACE2, "58.19")),
        ((Standards.TOL2008, "582"), (Standards.NACE2, "58.2")),
        ((Standards.TOL2008, "5821"), (Standards.NACE2, "58.21")),
        ((Standards.TOL2008, "58210"), (Standards.NACE2, "58.21")),
        ((Standards.TOL2008, "5829"), (Standards.NACE2, "58.29")),
        ((Standards.TOL2008, "58290"), (Standards.NACE2, "58.29")),
        ((Standards.TOL2008, "59"), (Standards.NACE2, "59")),
        ((Standards.TOL2008, "591"), (Standards.NACE2, "59.1")),
        ((Standards.TOL2008, "5911"), (Standards.NACE2, "59.11")),
        ((Standards.TOL2008, "59110"), (Standards.NACE2, "59.11")),
        ((Standards.TOL2008, "5912"), (Standards.NACE2, "59.12")),
        ((Standards.TOL2008, "59120"), (Standards.NACE2, "59.12")),
        ((Standards.TOL2008, "5913"), (Standards.NACE2, "59.13")),
        ((Standards.TOL2008, "59130"), (Standards.NACE2, "59.13")),
        ((Standards.TOL2008, "5914"), (Standards.NACE2, "59.14")),
        ((Standards.TOL2008, "59140"), (Standards.NACE2, "59.14")),
        ((Standards.TOL2008, "592"), (Standards.NACE2, "59.2")),
        ((Standards.TOL2008, "5920"), (Standards.NACE2, "59.20")),
        ((Standards.TOL2008, "59200"), (Standards.NACE2, "59.20")),
        ((Standards.TOL2008, "60"), (Standards.NACE2, "60")),
        ((Standards.TOL2008, "601"), (Standards.NACE2, "60.1")),
        ((Standards.TOL2008, "6010"), (Standards.NACE2, "60.10")),
        ((Standards.TOL2008, "60100"), (Standards.NACE2, "60.10")),
        ((Standards.TOL2008, "602"), (Standards.NACE2, "60.2")),
        ((Standards.TOL2008, "6020"), (Standards.NACE2, "60.20")),
        ((Standards.TOL2008, "60201"), (Standards.NACE2, "60.20")),
        ((Standards.TOL2008, "60202"), (Standards.NACE2, "60.20")),
        ((Standards.TOL2008, "61"), (Standards.NACE2, "61")),
        ((Standards.TOL2008, "611"), (Standards.NACE2, "61.1")),
        ((Standards.TOL2008, "6110"), (Standards.NACE2, "61.10")),
        ((Standards.TOL2008, "61100"), (Standards.NACE2, "61.10")),
        ((Standards.TOL2008, "612"), (Standards.NACE2, "61.2")),
        ((Standards.TOL2008, "6120"), (Standards.NACE2, "61.20")),
        ((Standards.TOL2008, "61200"), (Standards.NACE2, "61.20")),
        ((Standards.TOL2008, "613"), (Standards.NACE2, "61.3")),
        ((Standards.TOL2008, "6130"), (Standards.NACE2, "61.30")),
        ((Standards.TOL2008, "61300"), (Standards.NACE2, "61.30")),
        ((Standards.TOL2008, "619"), (Standards.NACE2, "61.9")),
        ((Standards.TOL2008, "6190"), (Standards.NACE2, "61.90")),
        ((Standards.TOL2008, "61900"), (Standards.NACE2, "61.90")),
        ((Standards.TOL2008, "62"), (Standards.NACE2, "62")),
        ((Standards.TOL2008, "620"), (Standards.NACE2, "62.0")),
        ((Standards.TOL2008, "6201"), (Standards.NACE2, "62.01")),
        ((Standards.TOL2008, "62010"), (Standards.NACE2, "62.01")),
        ((Standards.TOL2008, "6202"), (Standards.NACE2, "62.02")),
        ((Standards.TOL2008, "62020"), (Standards.NACE2, "62.02")),
        ((Standards.TOL2008, "6203"), (Standards.NACE2, "62.03")),
        ((Standards.TOL2008, "62030"), (Standards.NACE2, "62.03")),
        ((Standards.TOL2008, "6209"), (Standards.NACE2, "62.09")),
        ((Standards.TOL2008, "62090"), (Standards.NACE2, "62.09")),
        ((Standards.TOL2008, "63"), (Standards.NACE2, "63")),
        ((Standards.TOL2008, "631"), (Standards.NACE2, "63.1")),
        ((Standards.TOL2008, "6311"), (Standards.NACE2, "63.11")),
        ((Standards.TOL2008, "63110"), (Standards.NACE2, "63.11")),
        ((Standards.TOL2008, "6312"), (Standards.NACE2, "63.12")),
        ((Standards.TOL2008, "63120"), (Standards.NACE2, "63.12")),
        ((Standards.TOL2008, "639"), (Standards.NACE2, "63.9")),
        ((Standards.TOL2008, "6391"), (Standards.NACE2, "63.91")),
        ((Standards.TOL2008, "63910"), (Standards.NACE2, "63.91")),
        ((Standards.TOL2008, "6399"), (Standards.NACE2, "63.99")),
        ((Standards.TOL2008, "63990"), (Standards.NACE2, "63.99")),
        ((Standards.TOL2008, "K"), (Standards.NACE2, "K")),
        ((Standards.TOL2008, "64"), (Standards.NACE2, "64")),
        ((Standards.TOL2008, "641"), (Standards.NACE2, "64.1")),
        ((Standards.TOL2008, "6411"), (Standards.NACE2, "64.11")),
        ((Standards.TOL2008, "64110"), (Standards.NACE2, "64.11")),
        ((Standards.TOL2008, "6419"), (Standards.NACE2, "64.19")),
        ((Standards.TOL2008, "64190"), (Standards.NACE2, "64.19")),
        ((Standards.TOL2008, "642"), (Standards.NACE2, "64.2")),
        ((Standards.TOL2008, "6420"), (Standards.NACE2, "64.20")),
        ((Standards.TOL2008, "64200"), (Standards.NACE2, "64.20")),
        ((Standards.TOL2008, "643"), (Standards.NACE2, "64.3")),
        ((Standards.TOL2008, "6430"), (Standards.NACE2, "64.30")),
        ((Standards.TOL2008, "64300"), (Standards.NACE2, "64.30")),
        ((Standards.TOL2008, "649"), (Standards.NACE2, "64.9")),
        ((Standards.TOL2008, "6491"), (Standards.NACE2, "64.91")),
        ((Standards.TOL2008, "64910"), (Standards.NACE2, "64.91")),
        ((Standards.TOL2008, "6492"), (Standards.NACE2, "64.92")),
        ((Standards.TOL2008, "64920"), (Standards.NACE2, "64.92")),
        ((Standards.TOL2008, "6499"), (Standards.NACE2, "64.99")),
        ((Standards.TOL2008, "64990"), (Standards.NACE2, "64.99")),
        ((Standards.TOL2008, "65"), (Standards.NACE2, "65")),
        ((Standards.TOL2008, "651"), (Standards.NACE2, "65.1")),
        ((Standards.TOL2008, "6511"), (Standards.NACE2, "65.11")),
        ((Standards.TOL2008, "65110"), (Standards.NACE2, "65.11")),
        ((Standards.TOL2008, "6512"), (Standards.NACE2, "65.12")),
        ((Standards.TOL2008, "65121"), (Standards.NACE2, "65.12")),
        ((Standards.TOL2008, "65122"), (Standards.NACE2, "65.12")),
        ((Standards.TOL2008, "65129"), (Standards.NACE2, "65.12")),
        ((Standards.TOL2008, "652"), (Standards.NACE2, "65.2")),
        ((Standards.TOL2008, "6520"), (Standards.NACE2, "65.20")),
        ((Standards.TOL2008, "65200"), (Standards.NACE2, "65.20")),
        ((Standards.TOL2008, "653"), (Standards.NACE2, "65.3")),
        ((Standards.TOL2008, "6530"), (Standards.NACE2, "65.30")),
        ((Standards.TOL2008, "65300"), (Standards.NACE2, "65.30")),
        ((Standards.TOL2008, "66"), (Standards.NACE2, "66")),
        ((Standards.TOL2008, "661"), (Standards.NACE2, "66.1")),
        ((Standards.TOL2008, "6611"), (Standards.NACE2, "66.11")),
        ((Standards.TOL2008, "66110"), (Standards.NACE2, "66.11")),
        ((Standards.TOL2008, "6612"), (Standards.NACE2, "66.12")),
        ((Standards.TOL2008, "66120"), (Standards.NACE2, "66.12")),
        ((Standards.TOL2008, "6619"), (Standards.NACE2, "66.19")),
        ((Standards.TOL2008, "66190"), (Standards.NACE2, "66.19")),
        ((Standards.TOL2008, "662"), (Standards.NACE2, "66.2")),
        ((Standards.TOL2008, "6621"), (Standards.NACE2, "66.21")),
        ((Standards.TOL2008, "66210"), (Standards.NACE2, "66.21")),
        ((Standards.TOL2008, "6622"), (Standards.NACE2, "66.22")),
        ((Standards.TOL2008, "66220"), (Standards.NACE2, "66.22")),
        ((Standards.TOL2008, "6629"), (Standards.NACE2, "66.29")),
        ((Standards.TOL2008, "66290"), (Standards.NACE2, "66.29")),
        ((Standards.TOL2008, "663"), (Standards.NACE2, "66.3")),
        ((Standards.TOL2008, "6630"), (Standards.NACE2, "66.30")),
        ((Standards.TOL2008, "66300"), (Standards.NACE2, "66.30")),
        ((Standards.TOL2008, "L"), (Standards.NACE2, "L")),
        ((Standards.TOL2008, "68"), (Standards.NACE2, "68")),
        ((Standards.TOL2008, "681"), (Standards.NACE2, "68.1")),
        ((Standards.TOL2008, "6810"), (Standards.NACE2, "68.10")),
        ((Standards.TOL2008, "68100"), (Standards.NACE2, "68.10")),
        ((Standards.TOL2008, "682"), (Standards.NACE2, "68.2")),
        ((Standards.TOL2008, "6820"), (Standards.NACE2, "68.20")),
        ((Standards.TOL2008, "68201"), (Standards.NACE2, "68.20")),
        ((Standards.TOL2008, "68202"), (Standards.NACE2, "68.20")),
        ((Standards.TOL2008, "68209"), (Standards.NACE2, "68.20")),
        ((Standards.TOL2008, "683"), (Standards.NACE2, "68.3")),
        ((Standards.TOL2008, "6831"), (Standards.NACE2, "68.31")),
        ((Standards.TOL2008, "68310"), (Standards.NACE2, "68.31")),
        ((Standards.TOL2008, "6832"), (Standards.NACE2, "68.32")),
        ((Standards.TOL2008, "68320"), (Standards.NACE2, "68.32")),
        ((Standards.TOL2008, "M"), (Standards.NACE2, "M")),
        ((Standards.TOL2008, "69"), (Standards.NACE2, "69")),
        ((Standards.TOL2008, "691"), (Standards.NACE2, "69.1")),
        ((Standards.TOL2008, "6910"), (Standards.NACE2, "69.10")),
        ((Standards.TOL2008, "69101"), (Standards.NACE2, "69.10")),
        ((Standards.TOL2008, "69102"), (Standards.NACE2, "69.10")),
        ((Standards.TOL2008, "69103"), (Standards.NACE2, "69.10")),
        ((Standards.TOL2008, "69109"), (Standards.NACE2, "69.10")),
        ((Standards.TOL2008, "692"), (Standards.NACE2, "69.2")),
        ((Standards.TOL2008, "6920"), (Standards.NACE2, "69.20")),
        ((Standards.TOL2008, "69201"), (Standards.NACE2, "69.20")),
        ((Standards.TOL2008, "69202"), (Standards.NACE2, "69.20")),
        ((Standards.TOL2008, "69209"), (Standards.NACE2, "69.20")),
        ((Standards.TOL2008, "70"), (Standards.NACE2, "70")),
        ((Standards.TOL2008, "701"), (Standards.NACE2, "70.1")),
        ((Standards.TOL2008, "7010"), (Standards.NACE2, "70.10")),
        ((Standards.TOL2008, "70100"), (Standards.NACE2, "70.10")),
        ((Standards.TOL2008, "702"), (Standards.NACE2, "70.2")),
        ((Standards.TOL2008, "7021"), (Standards.NACE2, "70.21")),
        ((Standards.TOL2008, "70210"), (Standards.NACE2, "70.21")),
        ((Standards.TOL2008, "7022"), (Standards.NACE2, "70.22")),
        ((Standards.TOL2008, "70220"), (Standards.NACE2, "70.22")),
        ((Standards.TOL2008, "71"), (Standards.NACE2, "71")),
        ((Standards.TOL2008, "711"), (Standards.NACE2, "71.1")),
        ((Standards.TOL2008, "7111"), (Standards.NACE2, "71.11")),
        ((Standards.TOL2008, "71110"), (Standards.NACE2, "71.11")),
        ((Standards.TOL2008, "7112"), (Standards.NACE2, "71.12")),
        ((Standards.TOL2008, "71121"), (Standards.NACE2, "71.12")),
        ((Standards.TOL2008, "71122"), (Standards.NACE2, "71.12")),
        ((Standards.TOL2008, "71123"), (Standards.NACE2, "71.12")),
        ((Standards.TOL2008, "71124"), (Standards.NACE2, "71.12")),
        ((Standards.TOL2008, "71125"), (Standards.NACE2, "71.12")),
        ((Standards.TOL2008, "71126"), (Standards.NACE2, "71.12")),
        ((Standards.TOL2008, "71127"), (Standards.NACE2, "71.12")),
        ((Standards.TOL2008, "71129"), (Standards.NACE2, "71.12")),
        ((Standards.TOL2008, "712"), (Standards.NACE2, "71.2")),
        ((Standards.TOL2008, "7120"), (Standards.NACE2, "71.20")),
        ((Standards.TOL2008, "71201"), (Standards.NACE2, "71.20")),
        ((Standards.TOL2008, "71202"), (Standards.NACE2, "71.20")),
        ((Standards.TOL2008, "72"), (Standards.NACE2, "72")),
        ((Standards.TOL2008, "721"), (Standards.NACE2, "72.1")),
        ((Standards.TOL2008, "7211"), (Standards.NACE2, "72.11")),
        ((Standards.TOL2008, "72110"), (Standards.NACE2, "72.11")),
        ((Standards.TOL2008, "7219"), (Standards.NACE2, "72.19")),
        ((Standards.TOL2008, "72191"), (Standards.NACE2, "72.19")),
        ((Standards.TOL2008, "72192"), (Standards.NACE2, "72.19")),
        ((Standards.TOL2008, "72193"), (Standards.NACE2, "72.19")),
        ((Standards.TOL2008, "722"), (Standards.NACE2, "72.2")),
        ((Standards.TOL2008, "7220"), (Standards.NACE2, "72.20")),
        ((Standards.TOL2008, "72200"), (Standards.NACE2, "72.20")),
        ((Standards.TOL2008, "73"), (Standards.NACE2, "73")),
        ((Standards.TOL2008, "731"), (Standards.NACE2, "73.1")),
        ((Standards.TOL2008, "7311"), (Standards.NACE2, "73.11")),
        ((Standards.TOL2008, "73111"), (Standards.NACE2, "73.11")),
        ((Standards.TOL2008, "73112"), (Standards.NACE2, "73.11")),
        ((Standards.TOL2008, "73119"), (Standards.NACE2, "73.11")),
        ((Standards.TOL2008, "7312"), (Standards.NACE2, "73.12")),
        ((Standards.TOL2008, "73120"), (Standards.NACE2, "73.12")),
        ((Standards.TOL2008, "732"), (Standards.NACE2, "73.2")),
        ((Standards.TOL2008, "7320"), (Standards.NACE2, "73.20")),
        ((Standards.TOL2008, "73200"), (Standards.NACE2, "73.20")),
        ((Standards.TOL2008, "74"), (Standards.NACE2, "74")),
        ((Standards.TOL2008, "741"), (Standards.NACE2, "74.1")),
        ((Standards.TOL2008, "7410"), (Standards.NACE2, "74.10")),
        ((Standards.TOL2008, "74101"), (Standards.NACE2, "74.10")),
        ((Standards.TOL2008, "74102"), (Standards.NACE2, "74.10")),
        ((Standards.TOL2008, "74109"), (Standards.NACE2, "74.10")),
        ((Standards.TOL2008, "742"), (Standards.NACE2, "74.2")),
        ((Standards.TOL2008, "7420"), (Standards.NACE2, "74.20")),
        ((Standards.TOL2008, "74201"), (Standards.NACE2, "74.20")),
        ((Standards.TOL2008, "74202"), (Standards.NACE2, "74.20")),
        ((Standards.TOL2008, "743"), (Standards.NACE2, "74.3")),
        ((Standards.TOL2008, "7430"), (Standards.NACE2, "74.30")),
        ((Standards.TOL2008, "74300"), (Standards.NACE2, "74.30")),
        ((Standards.TOL2008, "749"), (Standards.NACE2, "74.9")),
        ((Standards.TOL2008, "7490"), (Standards.NACE2, "74.90")),
        ((Standards.TOL2008, "74901"), (Standards.NACE2, "74.90")),
        ((Standards.TOL2008, "74909"), (Standards.NACE2, "74.90")),
        ((Standards.TOL2008, "75"), (Standards.NACE2, "75")),
        ((Standards.TOL2008, "750"), (Standards.NACE2, "75.0")),
        ((Standards.TOL2008, "7500"), (Standards.NACE2, "75.00")),
        ((Standards.TOL2008, "75000"), (Standards.NACE2, "75.00")),
        ((Standards.TOL2008, "N"), (Standards.NACE2, "N")),
        ((Standards.TOL2008, "77"), (Standards.NACE2, "77")),
        ((Standards.TOL2008, "771"), (Standards.NACE2, "77.1")),
        ((Standards.TOL2008, "7711"), (Standards.NACE2, "77.11")),
        ((Standards.TOL2008, "77110"), (Standards.NACE2, "77.11")),
        ((Standards.TOL2008, "7712"), (Standards.NACE2, "77.12")),
        ((Standards.TOL2008, "77120"), (Standards.NACE2, "77.12")),
        ((Standards.TOL2008, "772"), (Standards.NACE2, "77.2")),
        ((Standards.TOL2008, "7721"), (Standards.NACE2, "77.21")),
        ((Standards.TOL2008, "77210"), (Standards.NACE2, "77.21")),
        ((Standards.TOL2008, "7722"), (Standards.NACE2, "77.22")),
        ((Standards.TOL2008, "77220"), (Standards.NACE2, "77.22")),
        ((Standards.TOL2008, "7729"), (Standards.NACE2, "77.29")),
        ((Standards.TOL2008, "77290"), (Standards.NACE2, "77.29")),
        ((Standards.TOL2008, "773"), (Standards.NACE2, "77.3")),
        ((Standards.TOL2008, "7731"), (Standards.NACE2, "77.31")),
        ((Standards.TOL2008, "77310"), (Standards.NACE2, "77.31")),
        ((Standards.TOL2008, "7732"), (Standards.NACE2, "77.32")),
        ((Standards.TOL2008, "77320"), (Standards.NACE2, "77.32")),
        ((Standards.TOL2008, "7733"), (Standards.NACE2, "77.33")),
        ((Standards.TOL2008, "77330"), (Standards.NACE2, "77.33")),
        ((Standards.TOL2008, "7734"), (Standards.NACE2, "77.34")),
        ((Standards.TOL2008, "77340"), (Standards.NACE2, "77.34")),
        ((Standards.TOL2008, "7735"), (Standards.NACE2, "77.35")),
        ((Standards.TOL2008, "77350"), (Standards.NACE2, "77.35")),
        ((Standards.TOL2008, "7739"), (Standards.NACE2, "77.39")),
        ((Standards.TOL2008, "77390"), (Standards.NACE2, "77.39")),
        ((Standards.TOL2008, "774"), (Standards.NACE2, "77.4")),
        ((Standards.TOL2008, "7740"), (Standards.NACE2, "77.40")),
        ((Standards.TOL2008, "77400"), (Standards.NACE2, "77.40")),
        ((Standards.TOL2008, "78"), (Standards.NACE2, "78")),
        ((Standards.TOL2008, "781"), (Standards.NACE2, "78.1")),
        ((Standards.TOL2008, "7810"), (Standards.NACE2, "78.10")),
        ((Standards.TOL2008, "78100"), (Standards.NACE2, "78.10")),
        ((Standards.TOL2008, "782"), (Standards.NACE2, "78.2")),
        ((Standards.TOL2008, "7820"), (Standards.NACE2, "78.20")),
        ((Standards.TOL2008, "78200"), (Standards.NACE2, "78.20")),
        ((Standards.TOL2008, "783"), (Standards.NACE2, "78.3")),
        ((Standards.TOL2008, "7830"), (Standards.NACE2, "78.30")),
        ((Standards.TOL2008, "78300"), (Standards.NACE2, "78.30")),
        ((Standards.TOL2008, "79"), (Standards.NACE2, "79")),
        ((Standards.TOL2008, "791"), (Standards.NACE2, "79.1")),
        ((Standards.TOL2008, "7911"), (Standards.NACE2, "79.11")),
        ((Standards.TOL2008, "79110"), (Standards.NACE2, "79.11")),
        ((Standards.TOL2008, "7912"), (Standards.NACE2, "79.12")),
        ((Standards.TOL2008, "79120"), (Standards.NACE2, "79.12")),
        ((Standards.TOL2008, "799"), (Standards.NACE2, "79.9")),
        ((Standards.TOL2008, "7990"), (Standards.NACE2, "79.90")),
        ((Standards.TOL2008, "79900"), (Standards.NACE2, "79.90")),
        ((Standards.TOL2008, "80"), (Standards.NACE2, "80")),
        ((Standards.TOL2008, "801"), (Standards.NACE2, "80.1")),
        ((Standards.TOL2008, "8010"), (Standards.NACE2, "80.10")),
        ((Standards.TOL2008, "80100"), (Standards.NACE2, "80.10")),
        ((Standards.TOL2008, "802"), (Standards.NACE2, "80.2")),
        ((Standards.TOL2008, "8020"), (Standards.NACE2, "80.20")),
        ((Standards.TOL2008, "80200"), (Standards.NACE2, "80.20")),
        ((Standards.TOL2008, "803"), (Standards.NACE2, "80.3")),
        ((Standards.TOL2008, "8030"), (Standards.NACE2, "80.30")),
        ((Standards.TOL2008, "80300"), (Standards.NACE2, "80.30")),
        ((Standards.TOL2008, "81"), (Standards.NACE2, "81")),
        ((Standards.TOL2008, "811"), (Standards.NACE2, "81.1")),
        ((Standards.TOL2008, "8110"), (Standards.NACE2, "81.10")),
        ((Standards.TOL2008, "81100"), (Standards.NACE2, "81.10")),
        ((Standards.TOL2008, "812"), (Standards.NACE2, "81.2")),
        ((Standards.TOL2008, "8121"), (Standards.NACE2, "81.21")),
        ((Standards.TOL2008, "81210"), (Standards.NACE2, "81.21")),
        ((Standards.TOL2008, "8122"), (Standards.NACE2, "81.22")),
        ((Standards.TOL2008, "81220"), (Standards.NACE2, "81.22")),
        ((Standards.TOL2008, "8129"), (Standards.NACE2, "81.29")),
        ((Standards.TOL2008, "81291"), (Standards.NACE2, "81.29")),
        ((Standards.TOL2008, "81299"), (Standards.NACE2, "81.29")),
        ((Standards.TOL2008, "813"), (Standards.NACE2, "81.3")),
        ((Standards.TOL2008, "8130"), (Standards.NACE2, "81.30")),
        ((Standards.TOL2008, "81300"), (Standards.NACE2, "81.30")),
        ((Standards.TOL2008, "82"), (Standards.NACE2, "82")),
        ((Standards.TOL2008, "821"), (Standards.NACE2, "82.1")),
        ((Standards.TOL2008, "8211"), (Standards.NACE2, "82.11")),
        ((Standards.TOL2008, "82110"), (Standards.NACE2, "82.11")),
        ((Standards.TOL2008, "8219"), (Standards.NACE2, "82.19")),
        ((Standards.TOL2008, "82191"), (Standards.NACE2, "82.19")),
        ((Standards.TOL2008, "82192"), (Standards.NACE2, "82.19")),
        ((Standards.TOL2008, "822"), (Standards.NACE2, "82.2")),
        ((Standards.TOL2008, "8220"), (Standards.NACE2, "82.20")),
        ((Standards.TOL2008, "82200"), (Standards.NACE2, "82.20")),
        ((Standards.TOL2008, "823"), (Standards.NACE2, "82.3")),
        ((Standards.TOL2008, "8230"), (Standards.NACE2, "82.30")),
        ((Standards.TOL2008, "82300"), (Standards.NACE2, "82.30")),
        ((Standards.TOL2008, "829"), (Standards.NACE2, "82.9")),
        ((Standards.TOL2008, "8291"), (Standards.NACE2, "82.91")),
        ((Standards.TOL2008, "82910"), (Standards.NACE2, "82.91")),
        ((Standards.TOL2008, "8292"), (Standards.NACE2, "82.92")),
        ((Standards.TOL2008, "82920"), (Standards.NACE2, "82.92")),
        ((Standards.TOL2008, "8299"), (Standards.NACE2, "82.99")),
        ((Standards.TOL2008, "82990"), (Standards.NACE2, "82.99")),
        ((Standards.TOL2008, "O"), (Standards.NACE2, "O")),
        ((Standards.TOL2008, "84"), (Standards.NACE2, "84")),
        ((Standards.TOL2008, "841"), (Standards.NACE2, "84.1")),
        ((Standards.TOL2008, "8411"), (Standards.NACE2, "84.11")),
        ((Standards.TOL2008, "84110"), (Standards.NACE2, "84.11")),
        ((Standards.TOL2008, "8412"), (Standards.NACE2, "84.12")),
        ((Standards.TOL2008, "84121"), (Standards.NACE2, "84.12")),
        ((Standards.TOL2008, "84122"), (Standards.NACE2, "84.12")),
        ((Standards.TOL2008, "8413"), (Standards.NACE2, "84.13")),
        ((Standards.TOL2008, "84130"), (Standards.NACE2, "84.13")),
        ((Standards.TOL2008, "842"), (Standards.NACE2, "84.2")),
        ((Standards.TOL2008, "8421"), (Standards.NACE2, "84.21")),
        ((Standards.TOL2008, "84210"), (Standards.NACE2, "84.21")),
        ((Standards.TOL2008, "8422"), (Standards.NACE2, "84.22")),
        ((Standards.TOL2008, "84220"), (Standards.NACE2, "84.22")),
        ((Standards.TOL2008, "8423"), (Standards.NACE2, "84.23")),
        ((Standards.TOL2008, "84231"), (Standards.NACE2, "84.23")),
        ((Standards.TOL2008, "84232"), (Standards.NACE2, "84.23")),
        ((Standards.TOL2008, "8424"), (Standards.NACE2, "84.24")),
        ((Standards.TOL2008, "84241"), (Standards.NACE2, "84.24")),
        ((Standards.TOL2008, "84242"), (Standards.NACE2, "84.24")),
        ((Standards.TOL2008, "8425"), (Standards.NACE2, "84.25")),
        ((Standards.TOL2008, "84250"), (Standards.NACE2, "84.25")),
        ((Standards.TOL2008, "843"), (Standards.NACE2, "84.3")),
        ((Standards.TOL2008, "8430"), (Standards.NACE2, "84.30")),
        ((Standards.TOL2008, "84301"), (Standards.NACE2, "84.30")),
        ((Standards.TOL2008, "84302"), (Standards.NACE2, "84.30")),
        ((Standards.TOL2008, "84309"), (Standards.NACE2, "84.30")),
        ((Standards.TOL2008, "P"), (Standards.NACE2, "P")),
        ((Standards.TOL2008, "85"), (Standards.NACE2, "85")),
        ((Standards.TOL2008, "851"), (Standards.NACE2, "85.1")),
        ((Standards.TOL2008, "8510"), (Standards.NACE2, "85.10")),
        ((Standards.TOL2008, "85100"), (Standards.NACE2, "85.10")),
        ((Standards.TOL2008, "852"), (Standards.NACE2, "85.2")),
        ((Standards.TOL2008, "8520"), (Standards.NACE2, "85.20")),
        ((Standards.TOL2008, "85200"), (Standards.NACE2, "85.20")),
        ((Standards.TOL2008, "853"), (Standards.NACE2, "85.3")),
        ((Standards.TOL2008, "8531"), (Standards.NACE2, "85.31")),
        ((Standards.TOL2008, "85311"), (Standards.NACE2, "85.31")),
        ((Standards.TOL2008, "85312"), (Standards.NACE2, "85.31")),
        ((Standards.TOL2008, "8532"), (Standards.NACE2, "85.32")),
        ((Standards.TOL2008, "85320"), (Standards.NACE2, "85.32")),
        ((Standards.TOL2008, "854"), (Standards.NACE2, "85.4")),
        ((Standards.TOL2008, "8541"), (Standards.NACE2, "85.41")),
        ((Standards.TOL2008, "85410"), (Standards.NACE2, "85.41")),
        ((Standards.TOL2008, "8542"), (Standards.NACE2, "85.42")),
        ((Standards.TOL2008, "85420"), (Standards.NACE2, "85.42")),
        ((Standards.TOL2008, "855"), (Standards.NACE2, "85.5")),
        ((Standards.TOL2008, "8551"), (Standards.NACE2, "85.51")),
        ((Standards.TOL2008, "85510"), (Standards.NACE2, "85.51")),
        ((Standards.TOL2008, "8552"), (Standards.NACE2, "85.52")),
        ((Standards.TOL2008, "85520"), (Standards.NACE2, "85.52")),
        ((Standards.TOL2008, "8553"), (Standards.NACE2, "85.53")),
        ((Standards.TOL2008, "85530"), (Standards.NACE2, "85.53")),
        ((Standards.TOL2008, "8559"), (Standards.NACE2, "85.59")),
        ((Standards.TOL2008, "85591"), (Standards.NACE2, "85.59")),
        ((Standards.TOL2008, "85592"), (Standards.NACE2, "85.59")),
        ((Standards.TOL2008, "85593"), (Standards.NACE2, "85.59")),
        ((Standards.TOL2008, "85599"), (Standards.NACE2, "85.59")),
        ((Standards.TOL2008, "856"), (Standards.NACE2, "85.6")),
        ((Standards.TOL2008, "8560"), (Standards.NACE2, "85.60")),
        ((Standards.TOL2008, "85600"), (Standards.NACE2, "85.60")),
        ((Standards.TOL2008, "Q"), (Standards.NACE2, "Q")),
        ((Standards.TOL2008, "86"), (Standards.NACE2, "86")),
        ((Standards.TOL2008, "861"), (Standards.NACE2, "86.1")),
        ((Standards.TOL2008, "8610"), (Standards.NACE2, "86.10")),
        ((Standards.TOL2008, "86101"), (Standards.NACE2, "86.10")),
        ((Standards.TOL2008, "86102"), (Standards.NACE2, "86.10")),
        ((Standards.TOL2008, "862"), (Standards.NACE2, "86.2")),
        ((Standards.TOL2008, "8621"), (Standards.NACE2, "86.21")),
        ((Standards.TOL2008, "86210"), (Standards.NACE2, "86.21")),
        ((Standards.TOL2008, "8622"), (Standards.NACE2, "86.22")),
        ((Standards.TOL2008, "86220"), (Standards.NACE2, "86.22")),
        ((Standards.TOL2008, "8623"), (Standards.NACE2, "86.23")),
        ((Standards.TOL2008, "86230"), (Standards.NACE2, "86.23")),
        ((Standards.TOL2008, "869"), (Standards.NACE2, "86.9")),
        ((Standards.TOL2008, "8690"), (Standards.NACE2, "86.90")),
        ((Standards.TOL2008, "86901"), (Standards.NACE2, "86.90")),
        ((Standards.TOL2008, "86902"), (Standards.NACE2, "86.90")),
        ((Standards.TOL2008, "86903"), (Standards.NACE2, "86.90")),
        ((Standards.TOL2008, "86904"), (Standards.NACE2, "86.90")),
        ((Standards.TOL2008, "86909"), (Standards.NACE2, "86.90")),
        ((Standards.TOL2008, "87"), (Standards.NACE2, "87")),
        ((Standards.TOL2008, "871"), (Standards.NACE2, "87.1")),
        ((Standards.TOL2008, "8710"), (Standards.NACE2, "87.10")),
        ((Standards.TOL2008, "87101"), (Standards.NACE2, "87.10")),
        ((Standards.TOL2008, "87102"), (Standards.NACE2, "87.10")),
        ((Standards.TOL2008, "872"), (Standards.NACE2, "87.2")),
        ((Standards.TOL2008, "8720"), (Standards.NACE2, "87.20")),
        ((Standards.TOL2008, "87201"), (Standards.NACE2, "87.20")),
        ((Standards.TOL2008, "87202"), (Standards.NACE2, "87.20")),
        ((Standards.TOL2008, "87203"), (Standards.NACE2, "87.20")),
        ((Standards.TOL2008, "87204"), (Standards.NACE2, "87.20")),
        ((Standards.TOL2008, "873"), (Standards.NACE2, "87.3")),
        ((Standards.TOL2008, "8730"), (Standards.NACE2, "87.30")),
        ((Standards.TOL2008, "87301"), (Standards.NACE2, "87.30")),
        ((Standards.TOL2008, "87302"), (Standards.NACE2, "87.30")),
        ((Standards.TOL2008, "879"), (Standards.NACE2, "87.9")),
        ((Standards.TOL2008, "8790"), (Standards.NACE2, "87.90")),
        ((Standards.TOL2008, "87901"), (Standards.NACE2, "87.90")),
        ((Standards.TOL2008, "87902"), (Standards.NACE2, "87.90")),
        ((Standards.TOL2008, "87909"), (Standards.NACE2, "87.90")),
        ((Standards.TOL2008, "88"), (Standards.NACE2, "88")),
        ((Standards.TOL2008, "881"), (Standards.NACE2, "88.1")),
        ((Standards.TOL2008, "8810"), (Standards.NACE2, "88.10")),
        ((Standards.TOL2008, "88101"), (Standards.NACE2, "88.10")),
        ((Standards.TOL2008, "88102"), (Standards.NACE2, "88.10")),
        ((Standards.TOL2008, "88103"), (Standards.NACE2, "88.10")),
        ((Standards.TOL2008, "88109"), (Standards.NACE2, "88.10")),
        ((Standards.TOL2008, "889"), (Standards.NACE2, "88.9")),
        ((Standards.TOL2008, "8891"), (Standards.NACE2, "88.91")),
        ((Standards.TOL2008, "88911"), (Standards.NACE2, "88.91")),
        ((Standards.TOL2008, "88919"), (Standards.NACE2, "88.91")),
        ((Standards.TOL2008, "8899"), (Standards.NACE2, "88.99")),
        ((Standards.TOL2008, "88991"), (Standards.NACE2, "88.99")),
        ((Standards.TOL2008, "88992"), (Standards.NACE2, "88.99")),
        ((Standards.TOL2008, "88993"), (Standards.NACE2, "88.99")),
        ((Standards.TOL2008, "88999"), (Standards.NACE2, "88.99")),
        ((Standards.TOL2008, "R"), (Standards.NACE2, "R")),
        ((Standards.TOL2008, "90"), (Standards.NACE2, "90")),
        ((Standards.TOL2008, "900"), (Standards.NACE2, "90.0")),
        ((Standards.TOL2008, "9001"), (Standards.NACE2, "90.01")),
        ((Standards.TOL2008, "90010"), (Standards.NACE2, "90.01")),
        ((Standards.TOL2008, "9002"), (Standards.NACE2, "90.02")),
        ((Standards.TOL2008, "90020"), (Standards.NACE2, "90.02")),
        ((Standards.TOL2008, "9003"), (Standards.NACE2, "90.03")),
        ((Standards.TOL2008, "90030"), (Standards.NACE2, "90.03")),
        ((Standards.TOL2008, "9004"), (Standards.NACE2, "90.04")),
        ((Standards.TOL2008, "90040"), (Standards.NACE2, "90.04")),
        ((Standards.TOL2008, "91"), (Standards.NACE2, "91")),
        ((Standards.TOL2008, "910"), (Standards.NACE2, "91.0")),
        ((Standards.TOL2008, "9101"), (Standards.NACE2, "91.01")),
        ((Standards.TOL2008, "91010"), (Standards.NACE2, "91.01")),
        ((Standards.TOL2008, "9102"), (Standards.NACE2, "91.02")),
        ((Standards.TOL2008, "91020"), (Standards.NACE2, "91.02")),
        ((Standards.TOL2008, "9103"), (Standards.NACE2, "91.03")),
        ((Standards.TOL2008, "91030"), (Standards.NACE2, "91.03")),
        ((Standards.TOL2008, "9104"), (Standards.NACE2, "91.04")),
        ((Standards.TOL2008, "91040"), (Standards.NACE2, "91.04")),
        ((Standards.TOL2008, "92"), (Standards.NACE2, "92")),
        ((Standards.TOL2008, "920"), (Standards.NACE2, "92.0")),
        ((Standards.TOL2008, "9200"), (Standards.NACE2, "92.00")),
        ((Standards.TOL2008, "92000"), (Standards.NACE2, "92.00")),
        ((Standards.TOL2008, "93"), (Standards.NACE2, "93")),
        ((Standards.TOL2008, "931"), (Standards.NACE2, "93.1")),
        ((Standards.TOL2008, "9311"), (Standards.NACE2, "93.11")),
        ((Standards.TOL2008, "93110"), (Standards.NACE2, "93.11")),
        ((Standards.TOL2008, "9312"), (Standards.NACE2, "93.12")),
        ((Standards.TOL2008, "93120"), (Standards.NACE2, "93.12")),
        ((Standards.TOL2008, "9313"), (Standards.NACE2, "93.13")),
        ((Standards.TOL2008, "93130"), (Standards.NACE2, "93.13")),
        ((Standards.TOL2008, "9319"), (Standards.NACE2, "93.19")),
        ((Standards.TOL2008, "93190"), (Standards.NACE2, "93.19")),
        ((Standards.TOL2008, "932"), (Standards.NACE2, "93.2")),
        ((Standards.TOL2008, "9321"), (Standards.NACE2, "93.21")),
        ((Standards.TOL2008, "93210"), (Standards.NACE2, "93.21")),
        ((Standards.TOL2008, "9329"), (Standards.NACE2, "93.29")),
        ((Standards.TOL2008, "93291"), (Standards.NACE2, "93.29")),
        ((Standards.TOL2008, "93299"), (Standards.NACE2, "93.29")),
        ((Standards.TOL2008, "S"), (Standards.NACE2, "S")),
        ((Standards.TOL2008, "94"), (Standards.NACE2, "94")),
        ((Standards.TOL2008, "941"), (Standards.NACE2, "94.1")),
        ((Standards.TOL2008, "9411"), (Standards.NACE2, "94.11")),
        ((Standards.TOL2008, "94110"), (Standards.NACE2, "94.11")),
        ((Standards.TOL2008, "9412"), (Standards.NACE2, "94.12")),
        ((Standards.TOL2008, "94120"), (Standards.NACE2, "94.12")),
        ((Standards.TOL2008, "942"), (Standards.NACE2, "94.2")),
        ((Standards.TOL2008, "9420"), (Standards.NACE2, "94.20")),
        ((Standards.TOL2008, "94200"), (Standards.NACE2, "94.20")),
        ((Standards.TOL2008, "949"), (Standards.NACE2, "94.9")),
        ((Standards.TOL2008, "9491"), (Standards.NACE2, "94.91")),
        ((Standards.TOL2008, "94910"), (Standards.NACE2, "94.91")),
        ((Standards.TOL2008, "9492"), (Standards.NACE2, "94.92")),
        ((Standards.TOL2008, "94920"), (Standards.NACE2, "94.92")),
        ((Standards.TOL2008, "9499"), (Standards.NACE2, "94.99")),
        ((Standards.TOL2008, "94991"), (Standards.NACE2, "94.99")),
        ((Standards.TOL2008, "94999"), (Standards.NACE2, "94.99")),
        ((Standards.TOL2008, "95"), (Standards.NACE2, "95")),
        ((Standards.TOL2008, "951"), (Standards.NACE2, "95.1")),
        ((Standards.TOL2008, "9511"), (Standards.NACE2, "95.11")),
        ((Standards.TOL2008, "95110"), (Standards.NACE2, "95.11")),
        ((Standards.TOL2008, "9512"), (Standards.NACE2, "95.12")),
        ((Standards.TOL2008, "95120"), (Standards.NACE2, "95.12")),
        ((Standards.TOL2008, "952"), (Standards.NACE2, "95.2")),
        ((Standards.TOL2008, "9521"), (Standards.NACE2, "95.21")),
        ((Standards.TOL2008, "95210"), (Standards.NACE2, "95.21")),
        ((Standards.TOL2008, "9522"), (Standards.NACE2, "95.22")),
        ((Standards.TOL2008, "95220"), (Standards.NACE2, "95.22")),
        ((Standards.TOL2008, "9523"), (Standards.NACE2, "95.23")),
        ((Standards.TOL2008, "95230"), (Standards.NACE2, "95.23")),
        ((Standards.TOL2008, "9524"), (Standards.NACE2, "95.24")),
        ((Standards.TOL2008, "95240"), (Standards.NACE2, "95.24")),
        ((Standards.TOL2008, "9525"), (Standards.NACE2, "95.25")),
        ((Standards.TOL2008, "95250"), (Standards.NACE2, "95.25")),
        ((Standards.TOL2008, "9529"), (Standards.NACE2, "95.29")),
        ((Standards.TOL2008, "95290"), (Standards.NACE2, "95.29")),
        ((Standards.TOL2008, "96"), (Standards.NACE2, "96")),
        ((Standards.TOL2008, "960"), (Standards.NACE2, "96.0")),
        ((Standards.TOL2008, "9601"), (Standards.NACE2, "96.01")),
        ((Standards.TOL2008, "96011"), (Standards.NACE2, "96.01")),
        ((Standards.TOL2008, "96012"), (Standards.NACE2, "96.01")),
        ((Standards.TOL2008, "9602"), (Standards.NACE2, "96.02")),
        ((Standards.TOL2008, "96021"), (Standards.NACE2, "96.02")),
        ((Standards.TOL2008, "96022"), (Standards.NACE2, "96.02")),
        ((Standards.TOL2008, "9603"), (Standards.NACE2, "96.03")),
        ((Standards.TOL2008, "96030"), (Standards.NACE2, "96.03")),
        ((Standards.TOL2008, "9604"), (Standards.NACE2, "96.04")),
        ((Standards.TOL2008, "96040"), (Standards.NACE2, "96.04")),
        ((Standards.TOL2008, "9609"), (Standards.NACE2, "96.09")),
        ((Standards.TOL2008, "96090"), (Standards.NACE2, "96.09")),
        ((Standards.TOL2008, "T"), (Standards.NACE2, "T")),
        ((Standards.TOL2008, "97"), (Standards.NACE2, "97")),
        ((Standards.TOL2008, "970"), (Standards.NACE2, "97.0")),
        ((Standards.TOL2008, "9700"), (Standards.NACE2, "97.00")),
        ((Standards.TOL2008, "97000"), (Standards.NACE2, "97.00")),
        ((Standards.TOL2008, "98"), (Standards.NACE2, "98")),
        ((Standards.TOL2008, "981"), (Standards.NACE2, "98.1")),
        ((Standards.TOL2008, "9810"), (Standards.NACE2, "98.10")),
        ((Standards.TOL2008, "98100"), (Standards.NACE2, "98.10")),
        ((Standards.TOL2008, "982"), (Standards.NACE2, "98.2")),
        ((Standards.TOL2008, "9820"), (Standards.NACE2, "98.20")),
        ((Standards.TOL2008, "98200"), (Standards.NACE2, "98.20")),
        ((Standards.TOL2008, "U"), (Standards.NACE2, "U")),
        ((Standards.TOL2008, "99"), (Standards.NACE2, "99")),
        ((Standards.TOL2008, "990"), (Standards.NACE2, "99.0")),
        ((Standards.TOL2008, "9900"), (Standards.NACE2, "99.00")),
        ((Standards.TOL2008, "99000"), (Standards.NACE2, "99.00")),
    ],
)
